/* Automatically @generated by tree-sitter v0.25.6 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 1413
#define LARGE_STATE_COUNT 158
#define SYMBOL_COUNT 202
#define ALIAS_COUNT 2
#define TOKEN_COUNT 94
#define EXTERNAL_TOKEN_COUNT 15
#define FIELD_COUNT 10
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 27
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_SEMI = 1,
  anon_sym_COMMA = 2,
  anon_sym_get = 3,
  anon_sym_set = 4,
  anon_sym_properties = 5,
  anon_sym_LPAREN = 6,
  anon_sym_RPAREN = 7,
  anon_sym_PLUS = 8,
  anon_sym_DOT_PLUS = 9,
  anon_sym_DASH = 10,
  anon_sym_DOT_DASH = 11,
  anon_sym_STAR = 12,
  anon_sym_DOT_STAR = 13,
  anon_sym_SLASH = 14,
  anon_sym_DOT_SLASH = 15,
  anon_sym_BSLASH = 16,
  anon_sym_DOT_BSLASH = 17,
  anon_sym_CARET = 18,
  anon_sym_DOT_CARET = 19,
  anon_sym_PIPE = 20,
  anon_sym_AMP = 21,
  anon_sym_end = 22,
  anon_sym_DOT = 23,
  anon_sym_TILDE = 24,
  anon_sym_QMARK = 25,
  anon_sym_AT = 26,
  anon_sym_LT = 27,
  anon_sym_LT_EQ = 28,
  anon_sym_EQ_EQ = 29,
  anon_sym_TILDE_EQ = 30,
  anon_sym_GT_EQ = 31,
  anon_sym_GT = 32,
  anon_sym_AMP_AMP = 33,
  anon_sym_PIPE_PIPE = 34,
  anon_sym_DOT_SQUOTE = 35,
  anon_sym_SQUOTE = 36,
  anon_sym_LBRACK = 37,
  anon_sym_LF = 38,
  aux_sym_matrix_token1 = 39,
  anon_sym_RBRACK = 40,
  anon_sym_LBRACE = 41,
  anon_sym_RBRACE = 42,
  anon_sym_EQ = 43,
  anon_sym_COLON = 44,
  sym_return_statement = 45,
  sym_continue_statement = 46,
  sym_break_statement = 47,
  anon_sym_elseif = 48,
  anon_sym_else = 49,
  anon_sym_if = 50,
  anon_sym_for = 51,
  anon_sym_parfor = 52,
  anon_sym_while = 53,
  anon_sym_case = 54,
  anon_sym_otherwise = 55,
  anon_sym_switch = 56,
  anon_sym_global = 57,
  anon_sym_persistent = 58,
  anon_sym_DOT_QMARK = 59,
  anon_sym_arguments = 60,
  anon_sym_function = 61,
  anon_sym_get_DOT = 62,
  anon_sym_set_DOT = 63,
  anon_sym_endfunction = 64,
  anon_sym_vector = 65,
  anon_sym_matrix = 66,
  anon_sym_scalar = 67,
  anon_sym_methods = 68,
  anon_sym_events = 69,
  anon_sym_enumeration = 70,
  anon_sym_classdef = 71,
  anon_sym_catch = 72,
  anon_sym_try = 73,
  anon_sym_spmd = 74,
  sym_number = 75,
  anon_sym_true = 76,
  anon_sym_false = 77,
  anon_sym_CR = 78,
  sym_comment = 79,
  sym_line_continuation = 80,
  sym_command_name = 81,
  sym_command_argument = 82,
  sym__single_quote_string_start = 83,
  sym__single_quote_string_end = 84,
  sym__double_quote_string_start = 85,
  sym__double_quote_string_end = 86,
  sym_formatting_sequence = 87,
  sym_escape_sequence = 88,
  sym_string_content = 89,
  sym__entry_delimiter = 90,
  sym__multioutput_variable_start = 91,
  sym__external_identifier = 92,
  sym_error_sentinel = 93,
  sym_source_file = 94,
  aux_sym__block = 95,
  sym_block = 96,
  sym_identifier = 97,
  sym__statement = 98,
  sym__expression = 99,
  sym__expression_with_end = 100,
  sym_parenthesis = 101,
  sym__binary_expression = 102,
  sym_binary_operator = 103,
  sym__binary_expression_with_end = 104,
  sym__binary_operator_with_end = 105,
  sym_unary_operator = 106,
  sym_indirect_access = 107,
  sym_field_expression = 108,
  sym_not_operator = 109,
  sym_metaclass_operator = 110,
  sym_handle_operator = 111,
  sym_comparison_operator = 112,
  sym_boolean_operator = 113,
  sym_postfix_operator = 114,
  sym_string = 115,
  sym_row = 116,
  sym_matrix = 117,
  sym_cell = 118,
  sym_ignored_argument = 119,
  sym_assignment = 120,
  sym_multioutput_variable = 121,
  sym_spread_operator = 122,
  sym_arguments = 123,
  sym__args = 124,
  sym_function_call = 125,
  sym_command = 126,
  sym__range_element = 127,
  sym_range = 128,
  sym__range_element_with_end = 129,
  sym__range_with_end = 130,
  sym_elseif_clause = 131,
  sym_else_clause = 132,
  sym_if_statement = 133,
  sym_iterator = 134,
  sym_parfor_options = 135,
  sym_for_statement = 136,
  sym_while_statement = 137,
  sym_case_clause = 138,
  sym_otherwise_clause = 139,
  sym_switch_statement = 140,
  sym__lambda_arguments = 141,
  sym_lambda = 142,
  sym_global_operator = 143,
  sym_persistent_operator = 144,
  sym__argument_attributes = 145,
  sym_class_property = 146,
  sym_arguments_statement = 147,
  sym_function_output = 148,
  sym_function_arguments = 149,
  sym_function_definition = 150,
  sym__function_definition_with_end = 151,
  sym_attribute = 152,
  sym_attributes = 153,
  sym_superclasses = 154,
  sym_dimensions = 155,
  sym_validation_functions = 156,
  sym_default_value = 157,
  sym_property_name = 158,
  sym_property = 159,
  sym_properties = 160,
  sym_function_signature = 161,
  sym_methods = 162,
  sym_events = 163,
  sym_enum = 164,
  sym_enumeration = 165,
  sym_class_definition = 166,
  sym_catch_clause = 167,
  sym_try_statement = 168,
  sym_spmd_statement = 169,
  sym_boolean = 170,
  sym__end_of_line = 171,
  aux_sym_source_file_repeat1 = 172,
  aux_sym__block_repeat1 = 173,
  aux_sym_field_expression_repeat1 = 174,
  aux_sym_metaclass_operator_repeat1 = 175,
  aux_sym_string_repeat1 = 176,
  aux_sym_row_repeat1 = 177,
  aux_sym_matrix_repeat1 = 178,
  aux_sym_matrix_repeat2 = 179,
  aux_sym_multioutput_variable_repeat1 = 180,
  aux_sym_arguments_repeat1 = 181,
  aux_sym_arguments_repeat2 = 182,
  aux_sym_command_repeat1 = 183,
  aux_sym_elseif_clause_repeat1 = 184,
  aux_sym_if_statement_repeat1 = 185,
  aux_sym_switch_statement_repeat1 = 186,
  aux_sym__lambda_arguments_repeat1 = 187,
  aux_sym_global_operator_repeat1 = 188,
  aux_sym__argument_attributes_repeat1 = 189,
  aux_sym_arguments_statement_repeat1 = 190,
  aux_sym_function_definition_repeat1 = 191,
  aux_sym_attributes_repeat1 = 192,
  aux_sym_superclasses_repeat1 = 193,
  aux_sym_dimensions_repeat1 = 194,
  aux_sym_validation_functions_repeat1 = 195,
  aux_sym_properties_repeat1 = 196,
  aux_sym_methods_repeat1 = 197,
  aux_sym_events_repeat1 = 198,
  aux_sym_enum_repeat1 = 199,
  aux_sym_enumeration_repeat1 = 200,
  aux_sym_class_definition_repeat1 = 201,
  alias_sym_end_keyword = 202,
  alias_sym_superclass = 203,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_SEMI] = ";",
  [anon_sym_COMMA] = ",",
  [anon_sym_get] = "get",
  [anon_sym_set] = "set",
  [anon_sym_properties] = "properties",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_PLUS] = "+",
  [anon_sym_DOT_PLUS] = ".+",
  [anon_sym_DASH] = "-",
  [anon_sym_DOT_DASH] = ".-",
  [anon_sym_STAR] = "*",
  [anon_sym_DOT_STAR] = ".*",
  [anon_sym_SLASH] = "/",
  [anon_sym_DOT_SLASH] = "./",
  [anon_sym_BSLASH] = "\\",
  [anon_sym_DOT_BSLASH] = ".\\",
  [anon_sym_CARET] = "^",
  [anon_sym_DOT_CARET] = ".^",
  [anon_sym_PIPE] = "|",
  [anon_sym_AMP] = "&",
  [anon_sym_end] = "end",
  [anon_sym_DOT] = ".",
  [anon_sym_TILDE] = "~",
  [anon_sym_QMARK] = "\?",
  [anon_sym_AT] = "@",
  [anon_sym_LT] = "<",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_TILDE_EQ] = "~=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_GT] = ">",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_DOT_SQUOTE] = ".'",
  [anon_sym_SQUOTE] = "'",
  [anon_sym_LBRACK] = "[",
  [anon_sym_LF] = "\n",
  [aux_sym_matrix_token1] = "matrix_token1",
  [anon_sym_RBRACK] = "]",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_EQ] = "=",
  [anon_sym_COLON] = ":",
  [sym_return_statement] = "return_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_break_statement] = "break_statement",
  [anon_sym_elseif] = "elseif",
  [anon_sym_else] = "else",
  [anon_sym_if] = "if",
  [anon_sym_for] = "for",
  [anon_sym_parfor] = "parfor",
  [anon_sym_while] = "while",
  [anon_sym_case] = "case",
  [anon_sym_otherwise] = "otherwise",
  [anon_sym_switch] = "switch",
  [anon_sym_global] = "global",
  [anon_sym_persistent] = "persistent",
  [anon_sym_DOT_QMARK] = ".\?",
  [anon_sym_arguments] = "arguments",
  [anon_sym_function] = "function",
  [anon_sym_get_DOT] = "get.",
  [anon_sym_set_DOT] = "set.",
  [anon_sym_endfunction] = "endfunction",
  [anon_sym_vector] = "identifier",
  [anon_sym_matrix] = "identifier",
  [anon_sym_scalar] = "identifier",
  [anon_sym_methods] = "methods",
  [anon_sym_events] = "events",
  [anon_sym_enumeration] = "enumeration",
  [anon_sym_classdef] = "classdef",
  [anon_sym_catch] = "catch",
  [anon_sym_try] = "try",
  [anon_sym_spmd] = "spmd",
  [sym_number] = "number",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [anon_sym_CR] = "\r",
  [sym_comment] = "comment",
  [sym_line_continuation] = "line_continuation",
  [sym_command_name] = "command_name",
  [sym_command_argument] = "command_argument",
  [sym__single_quote_string_start] = "'",
  [sym__single_quote_string_end] = "'",
  [sym__double_quote_string_start] = "\"",
  [sym__double_quote_string_end] = "\"",
  [sym_formatting_sequence] = "formatting_sequence",
  [sym_escape_sequence] = "escape_sequence",
  [sym_string_content] = "string_content",
  [sym__entry_delimiter] = ",",
  [sym__multioutput_variable_start] = "[",
  [sym__external_identifier] = "_external_identifier",
  [sym_error_sentinel] = "error_sentinel",
  [sym_source_file] = "source_file",
  [aux_sym__block] = "_block",
  [sym_block] = "block",
  [sym_identifier] = "identifier",
  [sym__statement] = "_statement",
  [sym__expression] = "_expression",
  [sym__expression_with_end] = "_expression_with_end",
  [sym_parenthesis] = "parenthesis",
  [sym__binary_expression] = "_binary_expression",
  [sym_binary_operator] = "binary_operator",
  [sym__binary_expression_with_end] = "_binary_expression_with_end",
  [sym__binary_operator_with_end] = "binary_operator",
  [sym_unary_operator] = "unary_operator",
  [sym_indirect_access] = "indirect_access",
  [sym_field_expression] = "field_expression",
  [sym_not_operator] = "not_operator",
  [sym_metaclass_operator] = "metaclass_operator",
  [sym_handle_operator] = "handle_operator",
  [sym_comparison_operator] = "comparison_operator",
  [sym_boolean_operator] = "boolean_operator",
  [sym_postfix_operator] = "postfix_operator",
  [sym_string] = "string",
  [sym_row] = "row",
  [sym_matrix] = "matrix",
  [sym_cell] = "cell",
  [sym_ignored_argument] = "ignored_argument",
  [sym_assignment] = "assignment",
  [sym_multioutput_variable] = "multioutput_variable",
  [sym_spread_operator] = "spread_operator",
  [sym_arguments] = "arguments",
  [sym__args] = "_args",
  [sym_function_call] = "function_call",
  [sym_command] = "command",
  [sym__range_element] = "_range_element",
  [sym_range] = "range",
  [sym__range_element_with_end] = "_range_element_with_end",
  [sym__range_with_end] = "range",
  [sym_elseif_clause] = "elseif_clause",
  [sym_else_clause] = "else_clause",
  [sym_if_statement] = "if_statement",
  [sym_iterator] = "iterator",
  [sym_parfor_options] = "parfor_options",
  [sym_for_statement] = "for_statement",
  [sym_while_statement] = "while_statement",
  [sym_case_clause] = "case_clause",
  [sym_otherwise_clause] = "otherwise_clause",
  [sym_switch_statement] = "switch_statement",
  [sym__lambda_arguments] = "_lambda_arguments",
  [sym_lambda] = "lambda",
  [sym_global_operator] = "global_operator",
  [sym_persistent_operator] = "persistent_operator",
  [sym__argument_attributes] = "attributes",
  [sym_class_property] = "class_property",
  [sym_arguments_statement] = "arguments_statement",
  [sym_function_output] = "function_output",
  [sym_function_arguments] = "function_arguments",
  [sym_function_definition] = "function_definition",
  [sym__function_definition_with_end] = "function_definition",
  [sym_attribute] = "attribute",
  [sym_attributes] = "attributes",
  [sym_superclasses] = "superclasses",
  [sym_dimensions] = "dimensions",
  [sym_validation_functions] = "validation_functions",
  [sym_default_value] = "default_value",
  [sym_property_name] = "property_name",
  [sym_property] = "property",
  [sym_properties] = "properties",
  [sym_function_signature] = "function_signature",
  [sym_methods] = "methods",
  [sym_events] = "events",
  [sym_enum] = "enum",
  [sym_enumeration] = "enumeration",
  [sym_class_definition] = "class_definition",
  [sym_catch_clause] = "catch_clause",
  [sym_try_statement] = "try_statement",
  [sym_spmd_statement] = "spmd_statement",
  [sym_boolean] = "boolean",
  [sym__end_of_line] = "_end_of_line",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym__block_repeat1] = "_block_repeat1",
  [aux_sym_field_expression_repeat1] = "field_expression_repeat1",
  [aux_sym_metaclass_operator_repeat1] = "metaclass_operator_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_row_repeat1] = "row_repeat1",
  [aux_sym_matrix_repeat1] = "matrix_repeat1",
  [aux_sym_matrix_repeat2] = "matrix_repeat2",
  [aux_sym_multioutput_variable_repeat1] = "multioutput_variable_repeat1",
  [aux_sym_arguments_repeat1] = "arguments_repeat1",
  [aux_sym_arguments_repeat2] = "arguments_repeat2",
  [aux_sym_command_repeat1] = "command_repeat1",
  [aux_sym_elseif_clause_repeat1] = "elseif_clause_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym_switch_statement_repeat1] = "switch_statement_repeat1",
  [aux_sym__lambda_arguments_repeat1] = "_lambda_arguments_repeat1",
  [aux_sym_global_operator_repeat1] = "global_operator_repeat1",
  [aux_sym__argument_attributes_repeat1] = "_argument_attributes_repeat1",
  [aux_sym_arguments_statement_repeat1] = "arguments_statement_repeat1",
  [aux_sym_function_definition_repeat1] = "function_definition_repeat1",
  [aux_sym_attributes_repeat1] = "attributes_repeat1",
  [aux_sym_superclasses_repeat1] = "superclasses_repeat1",
  [aux_sym_dimensions_repeat1] = "dimensions_repeat1",
  [aux_sym_validation_functions_repeat1] = "validation_functions_repeat1",
  [aux_sym_properties_repeat1] = "properties_repeat1",
  [aux_sym_methods_repeat1] = "methods_repeat1",
  [aux_sym_events_repeat1] = "events_repeat1",
  [aux_sym_enum_repeat1] = "enum_repeat1",
  [aux_sym_enumeration_repeat1] = "enumeration_repeat1",
  [aux_sym_class_definition_repeat1] = "class_definition_repeat1",
  [alias_sym_end_keyword] = "end_keyword",
  [alias_sym_superclass] = "superclass",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_get] = anon_sym_get,
  [anon_sym_set] = anon_sym_set,
  [anon_sym_properties] = anon_sym_properties,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DOT_PLUS] = anon_sym_DOT_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_DOT_DASH] = anon_sym_DOT_DASH,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_DOT_STAR] = anon_sym_DOT_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_DOT_SLASH] = anon_sym_DOT_SLASH,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [anon_sym_DOT_BSLASH] = anon_sym_DOT_BSLASH,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_DOT_CARET] = anon_sym_DOT_CARET,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_TILDE_EQ] = anon_sym_TILDE_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_DOT_SQUOTE] = anon_sym_DOT_SQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_LF] = anon_sym_LF,
  [aux_sym_matrix_token1] = aux_sym_matrix_token1,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_COLON] = anon_sym_COLON,
  [sym_return_statement] = sym_return_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_break_statement] = sym_break_statement,
  [anon_sym_elseif] = anon_sym_elseif,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_parfor] = anon_sym_parfor,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_otherwise] = anon_sym_otherwise,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_persistent] = anon_sym_persistent,
  [anon_sym_DOT_QMARK] = anon_sym_DOT_QMARK,
  [anon_sym_arguments] = anon_sym_arguments,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_get_DOT] = anon_sym_get_DOT,
  [anon_sym_set_DOT] = anon_sym_set_DOT,
  [anon_sym_endfunction] = anon_sym_endfunction,
  [anon_sym_vector] = sym_identifier,
  [anon_sym_matrix] = sym_identifier,
  [anon_sym_scalar] = sym_identifier,
  [anon_sym_methods] = anon_sym_methods,
  [anon_sym_events] = anon_sym_events,
  [anon_sym_enumeration] = anon_sym_enumeration,
  [anon_sym_classdef] = anon_sym_classdef,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_spmd] = anon_sym_spmd,
  [sym_number] = sym_number,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_CR] = anon_sym_CR,
  [sym_comment] = sym_comment,
  [sym_line_continuation] = sym_line_continuation,
  [sym_command_name] = sym_command_name,
  [sym_command_argument] = sym_command_argument,
  [sym__single_quote_string_start] = anon_sym_SQUOTE,
  [sym__single_quote_string_end] = anon_sym_SQUOTE,
  [sym__double_quote_string_start] = sym__double_quote_string_start,
  [sym__double_quote_string_end] = sym__double_quote_string_start,
  [sym_formatting_sequence] = sym_formatting_sequence,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_string_content] = sym_string_content,
  [sym__entry_delimiter] = anon_sym_COMMA,
  [sym__multioutput_variable_start] = anon_sym_LBRACK,
  [sym__external_identifier] = sym__external_identifier,
  [sym_error_sentinel] = sym_error_sentinel,
  [sym_source_file] = sym_source_file,
  [aux_sym__block] = aux_sym__block,
  [sym_block] = sym_block,
  [sym_identifier] = sym_identifier,
  [sym__statement] = sym__statement,
  [sym__expression] = sym__expression,
  [sym__expression_with_end] = sym__expression_with_end,
  [sym_parenthesis] = sym_parenthesis,
  [sym__binary_expression] = sym__binary_expression,
  [sym_binary_operator] = sym_binary_operator,
  [sym__binary_expression_with_end] = sym__binary_expression_with_end,
  [sym__binary_operator_with_end] = sym_binary_operator,
  [sym_unary_operator] = sym_unary_operator,
  [sym_indirect_access] = sym_indirect_access,
  [sym_field_expression] = sym_field_expression,
  [sym_not_operator] = sym_not_operator,
  [sym_metaclass_operator] = sym_metaclass_operator,
  [sym_handle_operator] = sym_handle_operator,
  [sym_comparison_operator] = sym_comparison_operator,
  [sym_boolean_operator] = sym_boolean_operator,
  [sym_postfix_operator] = sym_postfix_operator,
  [sym_string] = sym_string,
  [sym_row] = sym_row,
  [sym_matrix] = sym_matrix,
  [sym_cell] = sym_cell,
  [sym_ignored_argument] = sym_ignored_argument,
  [sym_assignment] = sym_assignment,
  [sym_multioutput_variable] = sym_multioutput_variable,
  [sym_spread_operator] = sym_spread_operator,
  [sym_arguments] = sym_arguments,
  [sym__args] = sym__args,
  [sym_function_call] = sym_function_call,
  [sym_command] = sym_command,
  [sym__range_element] = sym__range_element,
  [sym_range] = sym_range,
  [sym__range_element_with_end] = sym__range_element_with_end,
  [sym__range_with_end] = sym_range,
  [sym_elseif_clause] = sym_elseif_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_if_statement] = sym_if_statement,
  [sym_iterator] = sym_iterator,
  [sym_parfor_options] = sym_parfor_options,
  [sym_for_statement] = sym_for_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_case_clause] = sym_case_clause,
  [sym_otherwise_clause] = sym_otherwise_clause,
  [sym_switch_statement] = sym_switch_statement,
  [sym__lambda_arguments] = sym__lambda_arguments,
  [sym_lambda] = sym_lambda,
  [sym_global_operator] = sym_global_operator,
  [sym_persistent_operator] = sym_persistent_operator,
  [sym__argument_attributes] = sym_attributes,
  [sym_class_property] = sym_class_property,
  [sym_arguments_statement] = sym_arguments_statement,
  [sym_function_output] = sym_function_output,
  [sym_function_arguments] = sym_function_arguments,
  [sym_function_definition] = sym_function_definition,
  [sym__function_definition_with_end] = sym_function_definition,
  [sym_attribute] = sym_attribute,
  [sym_attributes] = sym_attributes,
  [sym_superclasses] = sym_superclasses,
  [sym_dimensions] = sym_dimensions,
  [sym_validation_functions] = sym_validation_functions,
  [sym_default_value] = sym_default_value,
  [sym_property_name] = sym_property_name,
  [sym_property] = sym_property,
  [sym_properties] = sym_properties,
  [sym_function_signature] = sym_function_signature,
  [sym_methods] = sym_methods,
  [sym_events] = sym_events,
  [sym_enum] = sym_enum,
  [sym_enumeration] = sym_enumeration,
  [sym_class_definition] = sym_class_definition,
  [sym_catch_clause] = sym_catch_clause,
  [sym_try_statement] = sym_try_statement,
  [sym_spmd_statement] = sym_spmd_statement,
  [sym_boolean] = sym_boolean,
  [sym__end_of_line] = sym__end_of_line,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym__block_repeat1] = aux_sym__block_repeat1,
  [aux_sym_field_expression_repeat1] = aux_sym_field_expression_repeat1,
  [aux_sym_metaclass_operator_repeat1] = aux_sym_metaclass_operator_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_row_repeat1] = aux_sym_row_repeat1,
  [aux_sym_matrix_repeat1] = aux_sym_matrix_repeat1,
  [aux_sym_matrix_repeat2] = aux_sym_matrix_repeat2,
  [aux_sym_multioutput_variable_repeat1] = aux_sym_multioutput_variable_repeat1,
  [aux_sym_arguments_repeat1] = aux_sym_arguments_repeat1,
  [aux_sym_arguments_repeat2] = aux_sym_arguments_repeat2,
  [aux_sym_command_repeat1] = aux_sym_command_repeat1,
  [aux_sym_elseif_clause_repeat1] = aux_sym_elseif_clause_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym_switch_statement_repeat1] = aux_sym_switch_statement_repeat1,
  [aux_sym__lambda_arguments_repeat1] = aux_sym__lambda_arguments_repeat1,
  [aux_sym_global_operator_repeat1] = aux_sym_global_operator_repeat1,
  [aux_sym__argument_attributes_repeat1] = aux_sym__argument_attributes_repeat1,
  [aux_sym_arguments_statement_repeat1] = aux_sym_arguments_statement_repeat1,
  [aux_sym_function_definition_repeat1] = aux_sym_function_definition_repeat1,
  [aux_sym_attributes_repeat1] = aux_sym_attributes_repeat1,
  [aux_sym_superclasses_repeat1] = aux_sym_superclasses_repeat1,
  [aux_sym_dimensions_repeat1] = aux_sym_dimensions_repeat1,
  [aux_sym_validation_functions_repeat1] = aux_sym_validation_functions_repeat1,
  [aux_sym_properties_repeat1] = aux_sym_properties_repeat1,
  [aux_sym_methods_repeat1] = aux_sym_methods_repeat1,
  [aux_sym_events_repeat1] = aux_sym_events_repeat1,
  [aux_sym_enum_repeat1] = aux_sym_enum_repeat1,
  [aux_sym_enumeration_repeat1] = aux_sym_enumeration_repeat1,
  [aux_sym_class_definition_repeat1] = aux_sym_class_definition_repeat1,
  [alias_sym_end_keyword] = alias_sym_end_keyword,
  [alias_sym_superclass] = alias_sym_superclass,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_get] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_properties] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_matrix_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_elseif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_parfor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_otherwise] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_persistent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_arguments] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_get_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endfunction] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_vector] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_matrix] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_scalar] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_methods] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_events] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enumeration] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_classdef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_spmd] = {
    .visible = true,
    .named = false,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CR] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_line_continuation] = {
    .visible = true,
    .named = true,
  },
  [sym_command_name] = {
    .visible = true,
    .named = true,
  },
  [sym_command_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__single_quote_string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__single_quote_string_end] = {
    .visible = true,
    .named = false,
  },
  [sym__double_quote_string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__double_quote_string_end] = {
    .visible = true,
    .named = false,
  },
  [sym_formatting_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym__entry_delimiter] = {
    .visible = true,
    .named = false,
  },
  [sym__multioutput_variable_start] = {
    .visible = true,
    .named = false,
  },
  [sym__external_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_error_sentinel] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__block] = {
    .visible = false,
    .named = false,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
  },
  [sym__expression_with_end] = {
    .visible = false,
    .named = true,
  },
  [sym_parenthesis] = {
    .visible = true,
    .named = true,
  },
  [sym__binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_binary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__binary_expression_with_end] = {
    .visible = false,
    .named = true,
  },
  [sym__binary_operator_with_end] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_indirect_access] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_not_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_metaclass_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_handle_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_postfix_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_row] = {
    .visible = true,
    .named = true,
  },
  [sym_matrix] = {
    .visible = true,
    .named = true,
  },
  [sym_cell] = {
    .visible = true,
    .named = true,
  },
  [sym_ignored_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_multioutput_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_spread_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym__args] = {
    .visible = false,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_command] = {
    .visible = true,
    .named = true,
  },
  [sym__range_element] = {
    .visible = false,
    .named = true,
  },
  [sym_range] = {
    .visible = true,
    .named = true,
  },
  [sym__range_element_with_end] = {
    .visible = false,
    .named = true,
  },
  [sym__range_with_end] = {
    .visible = true,
    .named = true,
  },
  [sym_elseif_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_iterator] = {
    .visible = true,
    .named = true,
  },
  [sym_parfor_options] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_case_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_otherwise_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__lambda_arguments] = {
    .visible = false,
    .named = true,
  },
  [sym_lambda] = {
    .visible = true,
    .named = true,
  },
  [sym_global_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_persistent_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__argument_attributes] = {
    .visible = true,
    .named = true,
  },
  [sym_class_property] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_function_output] = {
    .visible = true,
    .named = true,
  },
  [sym_function_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__function_definition_with_end] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attributes] = {
    .visible = true,
    .named = true,
  },
  [sym_superclasses] = {
    .visible = true,
    .named = true,
  },
  [sym_dimensions] = {
    .visible = true,
    .named = true,
  },
  [sym_validation_functions] = {
    .visible = true,
    .named = true,
  },
  [sym_default_value] = {
    .visible = true,
    .named = true,
  },
  [sym_property_name] = {
    .visible = true,
    .named = true,
  },
  [sym_property] = {
    .visible = true,
    .named = true,
  },
  [sym_properties] = {
    .visible = true,
    .named = true,
  },
  [sym_function_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_methods] = {
    .visible = true,
    .named = true,
  },
  [sym_events] = {
    .visible = true,
    .named = true,
  },
  [sym_enum] = {
    .visible = true,
    .named = true,
  },
  [sym_enumeration] = {
    .visible = true,
    .named = true,
  },
  [sym_class_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_spmd_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym__end_of_line] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metaclass_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_row_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_matrix_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_matrix_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_multioutput_variable_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_command_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_elseif_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__lambda_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_global_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__argument_attributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_superclasses_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dimensions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_validation_functions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_properties_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_methods_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_events_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enumeration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_end_keyword] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_superclass] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_argument = 1,
  field_arguments = 2,
  field_condition = 3,
  field_expression = 4,
  field_field = 5,
  field_left = 6,
  field_name = 7,
  field_object = 8,
  field_operand = 9,
  field_right = 10,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_condition] = "condition",
  [field_expression] = "expression",
  [field_field] = "field",
  [field_left] = "left",
  [field_name] = "name",
  [field_object] = "object",
  [field_operand] = "operand",
  [field_right] = "right",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 2},
  [5] = {.index = 5, .length = 1},
  [6] = {.index = 2, .length = 1},
  [7] = {.index = 6, .length = 1},
  [8] = {.index = 7, .length = 1},
  [10] = {.index = 8, .length = 1},
  [11] = {.index = 9, .length = 2},
  [12] = {.index = 11, .length = 1},
  [13] = {.index = 12, .length = 2},
  [14] = {.index = 14, .length = 2},
  [15] = {.index = 16, .length = 1},
  [16] = {.index = 17, .length = 1},
  [17] = {.index = 18, .length = 2},
  [18] = {.index = 2, .length = 1},
  [19] = {.index = 2, .length = 1},
  [20] = {.index = 20, .length = 1},
  [21] = {.index = 21, .length = 1},
  [22] = {.index = 22, .length = 1},
  [23] = {.index = 23, .length = 1},
  [24] = {.index = 24, .length = 2},
  [25] = {.index = 26, .length = 1},
  [26] = {.index = 27, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_operand, 1},
  [1] =
    {field_operand, 0},
  [2] =
    {field_name, 0},
  [3] =
    {field_field, 1, .inherited = true},
    {field_object, 0},
  [5] =
    {field_name, 0, .inherited = true},
  [6] =
    {field_condition, 1},
  [7] =
    {field_name, 1},
  [8] =
    {field_argument, 0},
  [9] =
    {field_left, 0, .inherited = true},
    {field_right, 0, .inherited = true},
  [11] =
    {field_field, 1},
  [12] =
    {field_left, 0},
    {field_right, 2},
  [14] =
    {field_field, 0, .inherited = true},
    {field_field, 1, .inherited = true},
  [16] =
    {field_expression, 3},
  [17] =
    {field_name, 2},
  [18] =
    {field_argument, 0},
    {field_argument, 1, .inherited = true},
  [20] =
    {field_expression, 4},
  [21] =
    {field_arguments, 1},
  [22] =
    {field_name, 3},
  [23] =
    {field_argument, 1},
  [24] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [26] =
    {field_argument, 1, .inherited = true},
  [27] =
    {field_argument, 1},
    {field_argument, 2, .inherited = true},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [6] = {
    [0] = sym_identifier,
  },
  [9] = {
    [0] = alias_sym_end_keyword,
  },
  [18] = {
    [2] = alias_sym_superclass,
  },
  [19] = {
    [0] = sym_identifier,
    [2] = alias_sym_superclass,
  },
  [20] = {
    [2] = sym_arguments,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__lambda_arguments, 2,
    sym__lambda_arguments,
    sym_arguments,
  sym_property_name, 2,
    sym_property_name,
    alias_sym_superclass,
  sym_boolean, 2,
    sym_boolean,
    sym_identifier,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 53,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 56,
  [68] = 58,
  [69] = 59,
  [70] = 70,
  [71] = 65,
  [72] = 54,
  [73] = 55,
  [74] = 61,
  [75] = 62,
  [76] = 63,
  [77] = 64,
  [78] = 70,
  [79] = 66,
  [80] = 60,
  [81] = 81,
  [82] = 60,
  [83] = 66,
  [84] = 84,
  [85] = 84,
  [86] = 84,
  [87] = 84,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 99,
  [108] = 108,
  [109] = 99,
  [110] = 99,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 120,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 127,
  [135] = 135,
  [136] = 121,
  [137] = 120,
  [138] = 121,
  [139] = 139,
  [140] = 121,
  [141] = 120,
  [142] = 122,
  [143] = 143,
  [144] = 143,
  [145] = 143,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 143,
  [158] = 122,
  [159] = 129,
  [160] = 111,
  [161] = 132,
  [162] = 128,
  [163] = 92,
  [164] = 89,
  [165] = 91,
  [166] = 90,
  [167] = 96,
  [168] = 108,
  [169] = 169,
  [170] = 170,
  [171] = 169,
  [172] = 170,
  [173] = 106,
  [174] = 169,
  [175] = 170,
  [176] = 176,
  [177] = 170,
  [178] = 169,
  [179] = 170,
  [180] = 169,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 186,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 186,
  [194] = 190,
  [195] = 191,
  [196] = 196,
  [197] = 197,
  [198] = 186,
  [199] = 189,
  [200] = 190,
  [201] = 191,
  [202] = 202,
  [203] = 189,
  [204] = 190,
  [205] = 191,
  [206] = 189,
  [207] = 207,
  [208] = 208,
  [209] = 209,
  [210] = 210,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 216,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 221,
  [223] = 218,
  [224] = 219,
  [225] = 225,
  [226] = 225,
  [227] = 220,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 210,
  [232] = 106,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 238,
  [239] = 233,
  [240] = 240,
  [241] = 241,
  [242] = 242,
  [243] = 243,
  [244] = 244,
  [245] = 245,
  [246] = 246,
  [247] = 247,
  [248] = 248,
  [249] = 249,
  [250] = 250,
  [251] = 235,
  [252] = 235,
  [253] = 236,
  [254] = 237,
  [255] = 238,
  [256] = 234,
  [257] = 240,
  [258] = 241,
  [259] = 242,
  [260] = 243,
  [261] = 236,
  [262] = 237,
  [263] = 244,
  [264] = 238,
  [265] = 233,
  [266] = 246,
  [267] = 240,
  [268] = 241,
  [269] = 242,
  [270] = 245,
  [271] = 246,
  [272] = 243,
  [273] = 273,
  [274] = 274,
  [275] = 275,
  [276] = 244,
  [277] = 235,
  [278] = 236,
  [279] = 237,
  [280] = 244,
  [281] = 281,
  [282] = 282,
  [283] = 245,
  [284] = 284,
  [285] = 236,
  [286] = 237,
  [287] = 244,
  [288] = 245,
  [289] = 235,
  [290] = 236,
  [291] = 237,
  [292] = 244,
  [293] = 245,
  [294] = 294,
  [295] = 235,
  [296] = 236,
  [297] = 237,
  [298] = 244,
  [299] = 299,
  [300] = 300,
  [301] = 245,
  [302] = 244,
  [303] = 245,
  [304] = 304,
  [305] = 245,
  [306] = 306,
  [307] = 307,
  [308] = 306,
  [309] = 273,
  [310] = 274,
  [311] = 274,
  [312] = 282,
  [313] = 234,
  [314] = 213,
  [315] = 235,
  [316] = 236,
  [317] = 237,
  [318] = 238,
  [319] = 233,
  [320] = 240,
  [321] = 241,
  [322] = 242,
  [323] = 243,
  [324] = 214,
  [325] = 306,
  [326] = 244,
  [327] = 211,
  [328] = 273,
  [329] = 274,
  [330] = 216,
  [331] = 245,
  [332] = 215,
  [333] = 246,
  [334] = 306,
  [335] = 273,
  [336] = 273,
  [337] = 234,
  [338] = 244,
  [339] = 245,
  [340] = 244,
  [341] = 245,
  [342] = 244,
  [343] = 245,
  [344] = 235,
  [345] = 88,
  [346] = 84,
  [347] = 84,
  [348] = 95,
  [349] = 84,
  [350] = 84,
  [351] = 351,
  [352] = 103,
  [353] = 100,
  [354] = 102,
  [355] = 355,
  [356] = 356,
  [357] = 104,
  [358] = 101,
  [359] = 359,
  [360] = 97,
  [361] = 105,
  [362] = 98,
  [363] = 99,
  [364] = 84,
  [365] = 99,
  [366] = 99,
  [367] = 84,
  [368] = 368,
  [369] = 84,
  [370] = 84,
  [371] = 99,
  [372] = 88,
  [373] = 93,
  [374] = 374,
  [375] = 94,
  [376] = 376,
  [377] = 95,
  [378] = 124,
  [379] = 379,
  [380] = 84,
  [381] = 99,
  [382] = 382,
  [383] = 99,
  [384] = 384,
  [385] = 91,
  [386] = 101,
  [387] = 100,
  [388] = 89,
  [389] = 96,
  [390] = 99,
  [391] = 88,
  [392] = 90,
  [393] = 103,
  [394] = 104,
  [395] = 105,
  [396] = 99,
  [397] = 92,
  [398] = 106,
  [399] = 102,
  [400] = 84,
  [401] = 401,
  [402] = 402,
  [403] = 97,
  [404] = 84,
  [405] = 84,
  [406] = 401,
  [407] = 98,
  [408] = 402,
  [409] = 124,
  [410] = 95,
  [411] = 411,
  [412] = 108,
  [413] = 413,
  [414] = 106,
  [415] = 113,
  [416] = 99,
  [417] = 120,
  [418] = 143,
  [419] = 150,
  [420] = 156,
  [421] = 112,
  [422] = 146,
  [423] = 97,
  [424] = 411,
  [425] = 114,
  [426] = 115,
  [427] = 116,
  [428] = 151,
  [429] = 147,
  [430] = 93,
  [431] = 148,
  [432] = 131,
  [433] = 94,
  [434] = 130,
  [435] = 132,
  [436] = 117,
  [437] = 105,
  [438] = 438,
  [439] = 120,
  [440] = 99,
  [441] = 111,
  [442] = 411,
  [443] = 149,
  [444] = 96,
  [445] = 98,
  [446] = 89,
  [447] = 118,
  [448] = 121,
  [449] = 143,
  [450] = 119,
  [451] = 123,
  [452] = 99,
  [453] = 103,
  [454] = 454,
  [455] = 102,
  [456] = 121,
  [457] = 100,
  [458] = 120,
  [459] = 133,
  [460] = 91,
  [461] = 153,
  [462] = 411,
  [463] = 152,
  [464] = 127,
  [465] = 101,
  [466] = 411,
  [467] = 411,
  [468] = 154,
  [469] = 126,
  [470] = 90,
  [471] = 104,
  [472] = 472,
  [473] = 139,
  [474] = 454,
  [475] = 121,
  [476] = 121,
  [477] = 127,
  [478] = 122,
  [479] = 143,
  [480] = 92,
  [481] = 122,
  [482] = 128,
  [483] = 135,
  [484] = 155,
  [485] = 99,
  [486] = 129,
  [487] = 472,
  [488] = 143,
  [489] = 120,
  [490] = 108,
  [491] = 124,
  [492] = 121,
  [493] = 139,
  [494] = 146,
  [495] = 147,
  [496] = 148,
  [497] = 149,
  [498] = 150,
  [499] = 151,
  [500] = 152,
  [501] = 93,
  [502] = 153,
  [503] = 154,
  [504] = 155,
  [505] = 156,
  [506] = 94,
  [507] = 133,
  [508] = 135,
  [509] = 112,
  [510] = 113,
  [511] = 114,
  [512] = 115,
  [513] = 116,
  [514] = 117,
  [515] = 118,
  [516] = 119,
  [517] = 123,
  [518] = 130,
  [519] = 143,
  [520] = 520,
  [521] = 120,
  [522] = 96,
  [523] = 89,
  [524] = 91,
  [525] = 90,
  [526] = 92,
  [527] = 121,
  [528] = 122,
  [529] = 122,
  [530] = 530,
  [531] = 128,
  [532] = 129,
  [533] = 132,
  [534] = 111,
  [535] = 127,
  [536] = 143,
  [537] = 121,
  [538] = 120,
  [539] = 120,
  [540] = 122,
  [541] = 143,
  [542] = 131,
  [543] = 143,
  [544] = 120,
  [545] = 126,
  [546] = 127,
  [547] = 121,
  [548] = 108,
  [549] = 128,
  [550] = 129,
  [551] = 111,
  [552] = 132,
  [553] = 116,
  [554] = 120,
  [555] = 121,
  [556] = 143,
  [557] = 557,
  [558] = 122,
  [559] = 559,
  [560] = 121,
  [561] = 561,
  [562] = 128,
  [563] = 129,
  [564] = 132,
  [565] = 111,
  [566] = 566,
  [567] = 143,
  [568] = 127,
  [569] = 126,
  [570] = 127,
  [571] = 131,
  [572] = 139,
  [573] = 146,
  [574] = 147,
  [575] = 148,
  [576] = 149,
  [577] = 150,
  [578] = 151,
  [579] = 579,
  [580] = 152,
  [581] = 130,
  [582] = 153,
  [583] = 120,
  [584] = 154,
  [585] = 121,
  [586] = 120,
  [587] = 121,
  [588] = 155,
  [589] = 120,
  [590] = 122,
  [591] = 156,
  [592] = 592,
  [593] = 143,
  [594] = 133,
  [595] = 143,
  [596] = 135,
  [597] = 112,
  [598] = 113,
  [599] = 114,
  [600] = 115,
  [601] = 122,
  [602] = 117,
  [603] = 118,
  [604] = 119,
  [605] = 123,
  [606] = 559,
  [607] = 561,
  [608] = 592,
  [609] = 557,
  [610] = 610,
  [611] = 611,
  [612] = 612,
  [613] = 613,
  [614] = 128,
  [615] = 129,
  [616] = 132,
  [617] = 617,
  [618] = 618,
  [619] = 619,
  [620] = 111,
  [621] = 611,
  [622] = 612,
  [623] = 611,
  [624] = 624,
  [625] = 617,
  [626] = 122,
  [627] = 611,
  [628] = 617,
  [629] = 612,
  [630] = 612,
  [631] = 617,
  [632] = 612,
  [633] = 633,
  [634] = 611,
  [635] = 611,
  [636] = 636,
  [637] = 637,
  [638] = 617,
  [639] = 624,
  [640] = 612,
  [641] = 637,
  [642] = 617,
  [643] = 643,
  [644] = 143,
  [645] = 132,
  [646] = 128,
  [647] = 111,
  [648] = 129,
  [649] = 143,
  [650] = 143,
  [651] = 127,
  [652] = 127,
  [653] = 127,
  [654] = 654,
  [655] = 655,
  [656] = 656,
  [657] = 657,
  [658] = 658,
  [659] = 92,
  [660] = 660,
  [661] = 106,
  [662] = 662,
  [663] = 108,
  [664] = 664,
  [665] = 665,
  [666] = 666,
  [667] = 667,
  [668] = 668,
  [669] = 669,
  [670] = 670,
  [671] = 671,
  [672] = 672,
  [673] = 673,
  [674] = 674,
  [675] = 675,
  [676] = 676,
  [677] = 677,
  [678] = 678,
  [679] = 679,
  [680] = 680,
  [681] = 681,
  [682] = 91,
  [683] = 90,
  [684] = 684,
  [685] = 96,
  [686] = 89,
  [687] = 687,
  [688] = 688,
  [689] = 689,
  [690] = 674,
  [691] = 666,
  [692] = 669,
  [693] = 675,
  [694] = 668,
  [695] = 695,
  [696] = 696,
  [697] = 90,
  [698] = 698,
  [699] = 92,
  [700] = 106,
  [701] = 701,
  [702] = 702,
  [703] = 96,
  [704] = 89,
  [705] = 705,
  [706] = 92,
  [707] = 91,
  [708] = 708,
  [709] = 709,
  [710] = 710,
  [711] = 711,
  [712] = 712,
  [713] = 713,
  [714] = 92,
  [715] = 715,
  [716] = 108,
  [717] = 717,
  [718] = 97,
  [719] = 719,
  [720] = 102,
  [721] = 95,
  [722] = 106,
  [723] = 723,
  [724] = 106,
  [725] = 108,
  [726] = 717,
  [727] = 103,
  [728] = 104,
  [729] = 105,
  [730] = 100,
  [731] = 731,
  [732] = 732,
  [733] = 106,
  [734] = 734,
  [735] = 735,
  [736] = 717,
  [737] = 717,
  [738] = 731,
  [739] = 739,
  [740] = 740,
  [741] = 89,
  [742] = 101,
  [743] = 743,
  [744] = 744,
  [745] = 90,
  [746] = 746,
  [747] = 747,
  [748] = 96,
  [749] = 749,
  [750] = 740,
  [751] = 740,
  [752] = 108,
  [753] = 753,
  [754] = 91,
  [755] = 755,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 761,
  [762] = 94,
  [763] = 196,
  [764] = 764,
  [765] = 765,
  [766] = 766,
  [767] = 767,
  [768] = 768,
  [769] = 769,
  [770] = 770,
  [771] = 771,
  [772] = 772,
  [773] = 773,
  [774] = 774,
  [775] = 93,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 781,
  [782] = 782,
  [783] = 783,
  [784] = 784,
  [785] = 785,
  [786] = 785,
  [787] = 787,
  [788] = 788,
  [789] = 789,
  [790] = 785,
  [791] = 785,
  [792] = 792,
  [793] = 793,
  [794] = 655,
  [795] = 795,
  [796] = 796,
  [797] = 797,
  [798] = 798,
  [799] = 799,
  [800] = 785,
  [801] = 801,
  [802] = 802,
  [803] = 803,
  [804] = 804,
  [805] = 805,
  [806] = 806,
  [807] = 807,
  [808] = 808,
  [809] = 809,
  [810] = 810,
  [811] = 811,
  [812] = 771,
  [813] = 813,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 820,
  [821] = 821,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 824,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 837,
  [838] = 723,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 842,
  [843] = 843,
  [844] = 844,
  [845] = 845,
  [846] = 846,
  [847] = 847,
  [848] = 848,
  [849] = 849,
  [850] = 850,
  [851] = 851,
  [852] = 848,
  [853] = 853,
  [854] = 854,
  [855] = 855,
  [856] = 847,
  [857] = 848,
  [858] = 858,
  [859] = 859,
  [860] = 860,
  [861] = 848,
  [862] = 862,
  [863] = 848,
  [864] = 848,
  [865] = 848,
  [866] = 848,
  [867] = 867,
  [868] = 185,
  [869] = 847,
  [870] = 847,
  [871] = 196,
  [872] = 848,
  [873] = 848,
  [874] = 848,
  [875] = 848,
  [876] = 876,
  [877] = 877,
  [878] = 878,
  [879] = 879,
  [880] = 880,
  [881] = 881,
  [882] = 882,
  [883] = 883,
  [884] = 879,
  [885] = 879,
  [886] = 886,
  [887] = 887,
  [888] = 879,
  [889] = 889,
  [890] = 92,
  [891] = 879,
  [892] = 892,
  [893] = 880,
  [894] = 894,
  [895] = 895,
  [896] = 896,
  [897] = 897,
  [898] = 898,
  [899] = 899,
  [900] = 900,
  [901] = 901,
  [902] = 902,
  [903] = 896,
  [904] = 904,
  [905] = 905,
  [906] = 906,
  [907] = 907,
  [908] = 908,
  [909] = 909,
  [910] = 108,
  [911] = 911,
  [912] = 895,
  [913] = 913,
  [914] = 914,
  [915] = 915,
  [916] = 916,
  [917] = 760,
  [918] = 918,
  [919] = 764,
  [920] = 905,
  [921] = 921,
  [922] = 922,
  [923] = 923,
  [924] = 924,
  [925] = 925,
  [926] = 926,
  [927] = 927,
  [928] = 928,
  [929] = 929,
  [930] = 930,
  [931] = 931,
  [932] = 932,
  [933] = 933,
  [934] = 934,
  [935] = 935,
  [936] = 936,
  [937] = 937,
  [938] = 938,
  [939] = 939,
  [940] = 940,
  [941] = 941,
  [942] = 942,
  [943] = 943,
  [944] = 944,
  [945] = 922,
  [946] = 946,
  [947] = 947,
  [948] = 948,
  [949] = 949,
  [950] = 950,
  [951] = 951,
  [952] = 952,
  [953] = 953,
  [954] = 954,
  [955] = 955,
  [956] = 956,
  [957] = 957,
  [958] = 958,
  [959] = 959,
  [960] = 960,
  [961] = 961,
  [962] = 962,
  [963] = 963,
  [964] = 964,
  [965] = 949,
  [966] = 966,
  [967] = 967,
  [968] = 968,
  [969] = 969,
  [970] = 970,
  [971] = 938,
  [972] = 972,
  [973] = 973,
  [974] = 949,
  [975] = 975,
  [976] = 976,
  [977] = 977,
  [978] = 978,
  [979] = 979,
  [980] = 949,
  [981] = 981,
  [982] = 982,
  [983] = 983,
  [984] = 984,
  [985] = 985,
  [986] = 938,
  [987] = 973,
  [988] = 988,
  [989] = 949,
  [990] = 990,
  [991] = 991,
  [992] = 949,
  [993] = 993,
  [994] = 994,
  [995] = 995,
  [996] = 949,
  [997] = 949,
  [998] = 949,
  [999] = 999,
  [1000] = 949,
  [1001] = 949,
  [1002] = 953,
  [1003] = 975,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 949,
  [1008] = 1008,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 975,
  [1013] = 922,
  [1014] = 975,
  [1015] = 922,
  [1016] = 975,
  [1017] = 922,
  [1018] = 973,
  [1019] = 1019,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 1022,
  [1023] = 1023,
  [1024] = 1024,
  [1025] = 1025,
  [1026] = 1026,
  [1027] = 1027,
  [1028] = 1028,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 1031,
  [1032] = 1032,
  [1033] = 1033,
  [1034] = 1034,
  [1035] = 1035,
  [1036] = 1036,
  [1037] = 1037,
  [1038] = 1038,
  [1039] = 1039,
  [1040] = 1040,
  [1041] = 1041,
  [1042] = 1042,
  [1043] = 1043,
  [1044] = 1044,
  [1045] = 1045,
  [1046] = 1046,
  [1047] = 1037,
  [1048] = 1019,
  [1049] = 1049,
  [1050] = 1050,
  [1051] = 1049,
  [1052] = 1052,
  [1053] = 1053,
  [1054] = 1025,
  [1055] = 1035,
  [1056] = 1033,
  [1057] = 1020,
  [1058] = 1042,
  [1059] = 1044,
  [1060] = 1060,
  [1061] = 1061,
  [1062] = 1062,
  [1063] = 1063,
  [1064] = 1049,
  [1065] = 1065,
  [1066] = 1035,
  [1067] = 1067,
  [1068] = 1068,
  [1069] = 1069,
  [1070] = 1019,
  [1071] = 1025,
  [1072] = 1035,
  [1073] = 1033,
  [1074] = 1074,
  [1075] = 1020,
  [1076] = 1042,
  [1077] = 1044,
  [1078] = 1049,
  [1079] = 1019,
  [1080] = 1025,
  [1081] = 1035,
  [1082] = 1082,
  [1083] = 1042,
  [1084] = 1044,
  [1085] = 1085,
  [1086] = 1086,
  [1087] = 1049,
  [1088] = 1035,
  [1089] = 1049,
  [1090] = 1035,
  [1091] = 1049,
  [1092] = 1035,
  [1093] = 1049,
  [1094] = 1049,
  [1095] = 1095,
  [1096] = 1049,
  [1097] = 1097,
  [1098] = 1065,
  [1099] = 1050,
  [1100] = 1021,
  [1101] = 1101,
  [1102] = 1102,
  [1103] = 1103,
  [1104] = 1104,
  [1105] = 1105,
  [1106] = 1067,
  [1107] = 1069,
  [1108] = 1108,
  [1109] = 1109,
  [1110] = 1110,
  [1111] = 828,
  [1112] = 1112,
  [1113] = 1113,
  [1114] = 1114,
  [1115] = 1115,
  [1116] = 1116,
  [1117] = 813,
  [1118] = 849,
  [1119] = 820,
  [1120] = 1120,
  [1121] = 1121,
  [1122] = 1122,
  [1123] = 855,
  [1124] = 805,
  [1125] = 858,
  [1126] = 1126,
  [1127] = 1127,
  [1128] = 1128,
  [1129] = 1129,
  [1130] = 859,
  [1131] = 1131,
  [1132] = 825,
  [1133] = 1133,
  [1134] = 1134,
  [1135] = 1135,
  [1136] = 1136,
  [1137] = 1137,
  [1138] = 1138,
  [1139] = 1139,
  [1140] = 1140,
  [1141] = 1141,
  [1142] = 1142,
  [1143] = 1143,
  [1144] = 1127,
  [1145] = 1137,
  [1146] = 1138,
  [1147] = 1147,
  [1148] = 1139,
  [1149] = 851,
  [1150] = 1140,
  [1151] = 1151,
  [1152] = 1122,
  [1153] = 821,
  [1154] = 1154,
  [1155] = 1155,
  [1156] = 822,
  [1157] = 817,
  [1158] = 1158,
  [1159] = 860,
  [1160] = 1160,
  [1161] = 842,
  [1162] = 845,
  [1163] = 818,
  [1164] = 862,
  [1165] = 826,
  [1166] = 1166,
  [1167] = 867,
  [1168] = 1168,
  [1169] = 1169,
  [1170] = 1122,
  [1171] = 1143,
  [1172] = 854,
  [1173] = 1173,
  [1174] = 1127,
  [1175] = 1131,
  [1176] = 1176,
  [1177] = 819,
  [1178] = 1131,
  [1179] = 1179,
  [1180] = 1133,
  [1181] = 1181,
  [1182] = 1182,
  [1183] = 1137,
  [1184] = 1138,
  [1185] = 1139,
  [1186] = 1140,
  [1187] = 1141,
  [1188] = 1188,
  [1189] = 1189,
  [1190] = 1190,
  [1191] = 1191,
  [1192] = 1192,
  [1193] = 1193,
  [1194] = 1194,
  [1195] = 1195,
  [1196] = 1196,
  [1197] = 1122,
  [1198] = 1198,
  [1199] = 1199,
  [1200] = 1200,
  [1201] = 1127,
  [1202] = 1202,
  [1203] = 1203,
  [1204] = 1131,
  [1205] = 1133,
  [1206] = 1206,
  [1207] = 1141,
  [1208] = 1208,
  [1209] = 1209,
  [1210] = 1137,
  [1211] = 1138,
  [1212] = 1139,
  [1213] = 1140,
  [1214] = 1141,
  [1215] = 1142,
  [1216] = 1216,
  [1217] = 1122,
  [1218] = 1127,
  [1219] = 1219,
  [1220] = 1220,
  [1221] = 1221,
  [1222] = 1142,
  [1223] = 1223,
  [1224] = 1224,
  [1225] = 1225,
  [1226] = 1226,
  [1227] = 1227,
  [1228] = 1228,
  [1229] = 1154,
  [1230] = 814,
  [1231] = 1231,
  [1232] = 1232,
  [1233] = 1233,
  [1234] = 1234,
  [1235] = 1235,
  [1236] = 1236,
  [1237] = 723,
  [1238] = 1238,
  [1239] = 1239,
  [1240] = 1133,
  [1241] = 1241,
  [1242] = 1242,
  [1243] = 1243,
  [1244] = 913,
  [1245] = 1245,
  [1246] = 840,
  [1247] = 1247,
  [1248] = 1248,
  [1249] = 1249,
  [1250] = 1250,
  [1251] = 1251,
  [1252] = 1252,
  [1253] = 1253,
  [1254] = 1142,
  [1255] = 1255,
  [1256] = 1256,
  [1257] = 1257,
  [1258] = 1258,
  [1259] = 1259,
  [1260] = 1260,
  [1261] = 1261,
  [1262] = 1262,
  [1263] = 1263,
  [1264] = 1264,
  [1265] = 1265,
  [1266] = 1266,
  [1267] = 1267,
  [1268] = 1259,
  [1269] = 1269,
  [1270] = 1270,
  [1271] = 1271,
  [1272] = 1272,
  [1273] = 1273,
  [1274] = 1274,
  [1275] = 1275,
  [1276] = 1276,
  [1277] = 1277,
  [1278] = 1278,
  [1279] = 1279,
  [1280] = 1259,
  [1281] = 1269,
  [1282] = 1282,
  [1283] = 1283,
  [1284] = 1284,
  [1285] = 1285,
  [1286] = 1286,
  [1287] = 1259,
  [1288] = 1259,
  [1289] = 1269,
  [1290] = 1269,
  [1291] = 1291,
  [1292] = 1272,
  [1293] = 1293,
  [1294] = 1294,
  [1295] = 1295,
  [1296] = 1296,
  [1297] = 1297,
  [1298] = 1298,
  [1299] = 1299,
  [1300] = 1300,
  [1301] = 1286,
  [1302] = 1302,
  [1303] = 1303,
  [1304] = 1269,
  [1305] = 1305,
  [1306] = 1306,
  [1307] = 1307,
  [1308] = 1308,
  [1309] = 1309,
  [1310] = 1309,
  [1311] = 1306,
  [1312] = 771,
  [1313] = 1313,
  [1314] = 1314,
  [1315] = 1315,
  [1316] = 1316,
  [1317] = 1317,
  [1318] = 1318,
  [1319] = 1319,
  [1320] = 1320,
  [1321] = 1321,
  [1322] = 1322,
  [1323] = 1323,
  [1324] = 1324,
  [1325] = 764,
  [1326] = 1326,
  [1327] = 1327,
  [1328] = 1328,
  [1329] = 1317,
  [1330] = 1330,
  [1331] = 1331,
  [1332] = 1313,
  [1333] = 760,
  [1334] = 1318,
  [1335] = 1335,
  [1336] = 1336,
  [1337] = 1305,
  [1338] = 1338,
  [1339] = 1338,
  [1340] = 1327,
  [1341] = 1320,
  [1342] = 1342,
  [1343] = 1343,
  [1344] = 1344,
  [1345] = 1345,
  [1346] = 1346,
  [1347] = 1347,
  [1348] = 1348,
  [1349] = 1349,
  [1350] = 1350,
  [1351] = 1351,
  [1352] = 1348,
  [1353] = 1353,
  [1354] = 1350,
  [1355] = 1355,
  [1356] = 1356,
  [1357] = 1357,
  [1358] = 1358,
  [1359] = 1351,
  [1360] = 1351,
  [1361] = 1361,
  [1362] = 1362,
  [1363] = 1363,
  [1364] = 1364,
  [1365] = 1351,
  [1366] = 1366,
  [1367] = 1367,
  [1368] = 1368,
  [1369] = 1351,
  [1370] = 1370,
  [1371] = 1371,
  [1372] = 1372,
  [1373] = 1351,
  [1374] = 1374,
  [1375] = 1375,
  [1376] = 1367,
  [1377] = 1377,
  [1378] = 1378,
  [1379] = 1379,
  [1380] = 1380,
  [1381] = 1348,
  [1382] = 1362,
  [1383] = 1383,
  [1384] = 1351,
  [1385] = 1385,
  [1386] = 1386,
  [1387] = 1350,
  [1388] = 1362,
  [1389] = 1389,
  [1390] = 1390,
  [1391] = 1391,
  [1392] = 1392,
  [1393] = 1393,
  [1394] = 1394,
  [1395] = 1351,
  [1396] = 1396,
  [1397] = 1351,
  [1398] = 1398,
  [1399] = 1351,
  [1400] = 1348,
  [1401] = 1362,
  [1402] = 1402,
  [1403] = 1350,
  [1404] = 1404,
  [1405] = 1405,
  [1406] = 1406,
  [1407] = 1351,
  [1408] = 1408,
  [1409] = 1350,
  [1410] = 1351,
  [1411] = 1411,
  [1412] = 1348,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(183);
      ADVANCE_MAP(
        '&', 207,
        '\'', 229,
        '(', 191,
        ')', 192,
        '*', 197,
        '+', 193,
        ',', 185,
        '-', 195,
        '.', 211,
        '/', 199,
        ':', 239,
        ';', 184,
        '<', 220,
        '=', 238,
        '>', 225,
        '?', 218,
        '@', 219,
        '[', 230,
        '\\', 201,
        ']', 234,
        '^', 203,
        'a', 119,
        'b', 128,
        'c', 11,
        'e', 87,
        'f', 13,
        'g', 48,
        'i', 65,
        'm', 18,
        'o', 153,
        'p', 20,
        'r', 51,
        's', 25,
        't', 120,
        'v', 39,
        'w', 72,
        '{', 235,
        '|', 205,
        '}', 236,
        '~', 217,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '\n', 231,
        '\r', 276,
        '&', 207,
        '(', 191,
        '+', 193,
        ',', 185,
        '-', 195,
        '.', 215,
        ';', 184,
        '<', 220,
        '=', 238,
        '>', 225,
        '?', 218,
        '@', 219,
        '[', 230,
        'b', 128,
        'c', 23,
        'e', 89,
        'f', 13,
        'g', 58,
        'i', 65,
        'o', 153,
        'p', 20,
        'r', 51,
        's', 60,
        't', 120,
        'w', 72,
        '{', 235,
        '|', 176,
        '~', 217,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '\n', 231,
        '\r', 276,
        '&', 206,
        '(', 191,
        '+', 193,
        ',', 185,
        '-', 195,
        '.', 214,
        ';', 184,
        '=', 237,
        '?', 218,
        '@', 219,
        '[', 230,
        'b', 128,
        'c', 11,
        'e', 89,
        'f', 13,
        'g', 58,
        'i', 65,
        'o', 153,
        'p', 20,
        'r', 51,
        's', 60,
        't', 120,
        'w', 72,
        '{', 235,
        '~', 216,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(2);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '\n', 232,
        '(', 191,
        '+', 193,
        ',', 185,
        '-', 195,
        '.', 178,
        '?', 218,
        '@', 219,
        '[', 230,
        ']', 234,
        'f', 12,
        'g', 57,
        'p', 127,
        's', 59,
        't', 134,
        '{', 235,
        '}', 236,
        '~', 216,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '&', 207,
        '\'', 229,
        '(', 191,
        '*', 197,
        '+', 193,
        '-', 195,
        '.', 212,
        '/', 199,
        ':', 239,
        ';', 184,
        '<', 220,
        '=', 9,
        '>', 225,
        '@', 219,
        '\\', 201,
        ']', 234,
        '^', 203,
        '{', 235,
        '|', 205,
        '}', 236,
        '~', 10,
        '\n', 233,
        '\r', 233,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(4);
      END_STATE();
    case 5:
      if (lookahead == '&') ADVANCE(226);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '&', 5,
        '(', 191,
        ')', 192,
        ',', 185,
        '.', 210,
        ';', 184,
        '<', 220,
        '=', 9,
        '>', 225,
        'e', 103,
        'f', 167,
        'g', 47,
        'p', 127,
        's', 52,
        '{', 235,
        '|', 176,
        '}', 236,
        '~', 10,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(6);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '&', 5,
        '.', 210,
        ';', 184,
        '<', 220,
        '=', 9,
        '>', 225,
        ']', 234,
        '|', 176,
        '}', 236,
        '~', 10,
        '\n', 233,
        '\r', 233,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(7);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '(', 191,
        '+', 193,
        ',', 185,
        '-', 195,
        '.', 178,
        ';', 184,
        '?', 218,
        '@', 219,
        '[', 230,
        ']', 234,
        'f', 12,
        'g', 57,
        'p', 127,
        's', 59,
        't', 134,
        '{', 235,
        '}', 236,
        '~', 216,
        '\n', 233,
        '\r', 233,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(8);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 9:
      if (lookahead == '=') ADVANCE(222);
      END_STATE();
    case 10:
      if (lookahead == '=') ADVANCE(223);
      END_STATE();
    case 11:
      if (lookahead == 'a') ADVANCE(142);
      if (lookahead == 'l') ADVANCE(15);
      if (lookahead == 'o') ADVANCE(104);
      END_STATE();
    case 12:
      if (lookahead == 'a') ADVANCE(93);
      END_STATE();
    case 13:
      if (lookahead == 'a') ADVANCE(93);
      if (lookahead == 'o') ADVANCE(121);
      if (lookahead == 'u') ADVANCE(108);
      END_STATE();
    case 14:
      if (lookahead == 'a') ADVANCE(85);
      END_STATE();
    case 15:
      if (lookahead == 'a') ADVANCE(140);
      END_STATE();
    case 16:
      if (lookahead == 'a') ADVANCE(91);
      END_STATE();
    case 17:
      if (lookahead == 'a') ADVANCE(159);
      END_STATE();
    case 18:
      if (lookahead == 'a') ADVANCE(159);
      if (lookahead == 'e') ADVANCE(155);
      END_STATE();
    case 19:
      if (lookahead == 'a') ADVANCE(90);
      END_STATE();
    case 20:
      if (lookahead == 'a') ADVANCE(126);
      if (lookahead == 'e') ADVANCE(129);
      if (lookahead == 'r') ADVANCE(111);
      END_STATE();
    case 21:
      if (lookahead == 'a') ADVANCE(124);
      END_STATE();
    case 22:
      if (lookahead == 'a') ADVANCE(163);
      END_STATE();
    case 23:
      if (lookahead == 'a') ADVANCE(141);
      if (lookahead == 'l') ADVANCE(15);
      if (lookahead == 'o') ADVANCE(104);
      END_STATE();
    case 24:
      if (lookahead == 'b') ADVANCE(19);
      END_STATE();
    case 25:
      if (lookahead == 'c') ADVANCE(16);
      if (lookahead == 'e') ADVANCE(149);
      if (lookahead == 'p') ADVANCE(94);
      if (lookahead == 'w') ADVANCE(81);
      END_STATE();
    case 26:
      if (lookahead == 'c') ADVANCE(16);
      if (lookahead == 'e') ADVANCE(152);
      if (lookahead == 'p') ADVANCE(94);
      if (lookahead == 'w') ADVANCE(81);
      END_STATE();
    case 27:
      if (lookahead == 'c') ADVANCE(70);
      END_STATE();
    case 28:
      if (lookahead == 'c') ADVANCE(71);
      END_STATE();
    case 29:
      if (lookahead == 'c') ADVANCE(165);
      END_STATE();
    case 30:
      if (lookahead == 'c') ADVANCE(158);
      END_STATE();
    case 31:
      if (lookahead == 'c') ADVANCE(162);
      END_STATE();
    case 32:
      if (lookahead == 'd') ADVANCE(209);
      END_STATE();
    case 33:
      if (lookahead == 'd') ADVANCE(209);
      if (lookahead == 'u') ADVANCE(95);
      END_STATE();
    case 34:
      if (lookahead == 'd') ADVANCE(269);
      END_STATE();
    case 35:
      if (lookahead == 'd') ADVANCE(208);
      END_STATE();
    case 36:
      if (lookahead == 'd') ADVANCE(208);
      if (lookahead == 'u') ADVANCE(95);
      END_STATE();
    case 37:
      if (lookahead == 'd') ADVANCE(136);
      END_STATE();
    case 38:
      if (lookahead == 'd') ADVANCE(50);
      END_STATE();
    case 39:
      if (lookahead == 'e') ADVANCE(29);
      END_STATE();
    case 40:
      if (lookahead == 'e') ADVANCE(249);
      END_STATE();
    case 41:
      if (lookahead == 'e') ADVANCE(244);
      END_STATE();
    case 42:
      if (lookahead == 'e') ADVANCE(274);
      END_STATE();
    case 43:
      if (lookahead == 'e') ADVANCE(275);
      END_STATE();
    case 44:
      if (lookahead == 'e') ADVANCE(248);
      END_STATE();
    case 45:
      if (lookahead == 'e') ADVANCE(241);
      END_STATE();
    case 46:
      if (lookahead == 'e') ADVANCE(250);
      END_STATE();
    case 47:
      if (lookahead == 'e') ADVANCE(148);
      END_STATE();
    case 48:
      if (lookahead == 'e') ADVANCE(148);
      if (lookahead == 'l') ADVANCE(110);
      END_STATE();
    case 49:
      if (lookahead == 'e') ADVANCE(14);
      END_STATE();
    case 50:
      if (lookahead == 'e') ADVANCE(67);
      END_STATE();
    case 51:
      if (lookahead == 'e') ADVANCE(154);
      END_STATE();
    case 52:
      if (lookahead == 'e') ADVANCE(149);
      END_STATE();
    case 53:
      if (lookahead == 'e') ADVANCE(122);
      END_STATE();
    case 54:
      if (lookahead == 'e') ADVANCE(138);
      END_STATE();
    case 55:
      if (lookahead == 'e') ADVANCE(132);
      END_STATE();
    case 56:
      if (lookahead == 'e') ADVANCE(133);
      END_STATE();
    case 57:
      if (lookahead == 'e') ADVANCE(151);
      END_STATE();
    case 58:
      if (lookahead == 'e') ADVANCE(151);
      if (lookahead == 'l') ADVANCE(110);
      END_STATE();
    case 59:
      if (lookahead == 'e') ADVANCE(152);
      END_STATE();
    case 60:
      if (lookahead == 'e') ADVANCE(152);
      if (lookahead == 'p') ADVANCE(94);
      if (lookahead == 'w') ADVANCE(81);
      END_STATE();
    case 61:
      if (lookahead == 'e') ADVANCE(155);
      END_STATE();
    case 62:
      if (lookahead == 'e') ADVANCE(105);
      END_STATE();
    case 63:
      if (lookahead == 'e') ADVANCE(106);
      END_STATE();
    case 64:
      if (lookahead == 'e') ADVANCE(107);
      END_STATE();
    case 65:
      if (lookahead == 'f') ADVANCE(245);
      END_STATE();
    case 66:
      if (lookahead == 'f') ADVANCE(243);
      END_STATE();
    case 67:
      if (lookahead == 'f') ADVANCE(266);
      END_STATE();
    case 68:
      if (lookahead == 'f') ADVANCE(116);
      END_STATE();
    case 69:
      if (lookahead == 'g') ADVANCE(172);
      END_STATE();
    case 70:
      if (lookahead == 'h') ADVANCE(267);
      END_STATE();
    case 71:
      if (lookahead == 'h') ADVANCE(251);
      END_STATE();
    case 72:
      if (lookahead == 'h') ADVANCE(77);
      END_STATE();
    case 73:
      if (lookahead == 'h') ADVANCE(112);
      END_STATE();
    case 74:
      if (lookahead == 'h') ADVANCE(53);
      END_STATE();
    case 75:
      if (lookahead == 'i') ADVANCE(175);
      END_STATE();
    case 76:
      if (lookahead == 'i') ADVANCE(101);
      END_STATE();
    case 77:
      if (lookahead == 'i') ADVANCE(92);
      END_STATE();
    case 78:
      if (lookahead == 'i') ADVANCE(113);
      END_STATE();
    case 79:
      if (lookahead == 'i') ADVANCE(146);
      END_STATE();
    case 80:
      if (lookahead == 'i') ADVANCE(114);
      END_STATE();
    case 81:
      if (lookahead == 'i') ADVANCE(164);
      END_STATE();
    case 82:
      if (lookahead == 'i') ADVANCE(115);
      END_STATE();
    case 83:
      if (lookahead == 'i') ADVANCE(54);
      END_STATE();
    case 84:
      if (lookahead == 'i') ADVANCE(147);
      END_STATE();
    case 85:
      if (lookahead == 'k') ADVANCE(242);
      END_STATE();
    case 86:
      if (lookahead == 'l') ADVANCE(15);
      if (lookahead == 'o') ADVANCE(104);
      END_STATE();
    case 87:
      if (lookahead == 'l') ADVANCE(144);
      if (lookahead == 'n') ADVANCE(33);
      if (lookahead == 'v') ADVANCE(62);
      END_STATE();
    case 88:
      if (lookahead == 'l') ADVANCE(144);
      if (lookahead == 'n') ADVANCE(36);
      if (lookahead == 'v') ADVANCE(62);
      END_STATE();
    case 89:
      if (lookahead == 'l') ADVANCE(144);
      if (lookahead == 'n') ADVANCE(35);
      END_STATE();
    case 90:
      if (lookahead == 'l') ADVANCE(252);
      END_STATE();
    case 91:
      if (lookahead == 'l') ADVANCE(21);
      END_STATE();
    case 92:
      if (lookahead == 'l') ADVANCE(44);
      END_STATE();
    case 93:
      if (lookahead == 'l') ADVANCE(145);
      END_STATE();
    case 94:
      if (lookahead == 'm') ADVANCE(34);
      END_STATE();
    case 95:
      if (lookahead == 'm') ADVANCE(55);
      END_STATE();
    case 96:
      if (lookahead == 'm') ADVANCE(63);
      END_STATE();
    case 97:
      if (lookahead == 'n') ADVANCE(240);
      END_STATE();
    case 98:
      if (lookahead == 'n') ADVANCE(256);
      END_STATE();
    case 99:
      if (lookahead == 'n') ADVANCE(259);
      END_STATE();
    case 100:
      if (lookahead == 'n') ADVANCE(265);
      END_STATE();
    case 101:
      if (lookahead == 'n') ADVANCE(171);
      END_STATE();
    case 102:
      if (lookahead == 'n') ADVANCE(32);
      END_STATE();
    case 103:
      if (lookahead == 'n') ADVANCE(35);
      END_STATE();
    case 104:
      if (lookahead == 'n') ADVANCE(156);
      END_STATE();
    case 105:
      if (lookahead == 'n') ADVANCE(157);
      END_STATE();
    case 106:
      if (lookahead == 'n') ADVANCE(160);
      END_STATE();
    case 107:
      if (lookahead == 'n') ADVANCE(150);
      END_STATE();
    case 108:
      if (lookahead == 'n') ADVANCE(30);
      END_STATE();
    case 109:
      if (lookahead == 'n') ADVANCE(31);
      END_STATE();
    case 110:
      if (lookahead == 'o') ADVANCE(24);
      END_STATE();
    case 111:
      if (lookahead == 'o') ADVANCE(118);
      END_STATE();
    case 112:
      if (lookahead == 'o') ADVANCE(37);
      END_STATE();
    case 113:
      if (lookahead == 'o') ADVANCE(98);
      END_STATE();
    case 114:
      if (lookahead == 'o') ADVANCE(99);
      END_STATE();
    case 115:
      if (lookahead == 'o') ADVANCE(100);
      END_STATE();
    case 116:
      if (lookahead == 'o') ADVANCE(123);
      END_STATE();
    case 117:
      if (lookahead == 'o') ADVANCE(125);
      END_STATE();
    case 118:
      if (lookahead == 'p') ADVANCE(56);
      END_STATE();
    case 119:
      if (lookahead == 'r') ADVANCE(69);
      END_STATE();
    case 120:
      if (lookahead == 'r') ADVANCE(169);
      END_STATE();
    case 121:
      if (lookahead == 'r') ADVANCE(246);
      END_STATE();
    case 122:
      if (lookahead == 'r') ADVANCE(174);
      END_STATE();
    case 123:
      if (lookahead == 'r') ADVANCE(247);
      END_STATE();
    case 124:
      if (lookahead == 'r') ADVANCE(262);
      END_STATE();
    case 125:
      if (lookahead == 'r') ADVANCE(260);
      END_STATE();
    case 126:
      if (lookahead == 'r') ADVANCE(68);
      END_STATE();
    case 127:
      if (lookahead == 'r') ADVANCE(111);
      END_STATE();
    case 128:
      if (lookahead == 'r') ADVANCE(49);
      END_STATE();
    case 129:
      if (lookahead == 'r') ADVANCE(143);
      END_STATE();
    case 130:
      if (lookahead == 'r') ADVANCE(97);
      END_STATE();
    case 131:
      if (lookahead == 'r') ADVANCE(75);
      END_STATE();
    case 132:
      if (lookahead == 'r') ADVANCE(22);
      END_STATE();
    case 133:
      if (lookahead == 'r') ADVANCE(161);
      END_STATE();
    case 134:
      if (lookahead == 'r') ADVANCE(168);
      END_STATE();
    case 135:
      if (lookahead == 's') ADVANCE(264);
      END_STATE();
    case 136:
      if (lookahead == 's') ADVANCE(263);
      END_STATE();
    case 137:
      if (lookahead == 's') ADVANCE(255);
      END_STATE();
    case 138:
      if (lookahead == 's') ADVANCE(190);
      END_STATE();
    case 139:
      if (lookahead == 's') ADVANCE(38);
      END_STATE();
    case 140:
      if (lookahead == 's') ADVANCE(139);
      END_STATE();
    case 141:
      if (lookahead == 's') ADVANCE(40);
      END_STATE();
    case 142:
      if (lookahead == 's') ADVANCE(40);
      if (lookahead == 't') ADVANCE(27);
      END_STATE();
    case 143:
      if (lookahead == 's') ADVANCE(79);
      END_STATE();
    case 144:
      if (lookahead == 's') ADVANCE(41);
      END_STATE();
    case 145:
      if (lookahead == 's') ADVANCE(43);
      END_STATE();
    case 146:
      if (lookahead == 's') ADVANCE(166);
      END_STATE();
    case 147:
      if (lookahead == 's') ADVANCE(46);
      END_STATE();
    case 148:
      if (lookahead == 't') ADVANCE(187);
      END_STATE();
    case 149:
      if (lookahead == 't') ADVANCE(189);
      END_STATE();
    case 150:
      if (lookahead == 't') ADVANCE(253);
      END_STATE();
    case 151:
      if (lookahead == 't') ADVANCE(186);
      END_STATE();
    case 152:
      if (lookahead == 't') ADVANCE(188);
      END_STATE();
    case 153:
      if (lookahead == 't') ADVANCE(74);
      END_STATE();
    case 154:
      if (lookahead == 't') ADVANCE(170);
      END_STATE();
    case 155:
      if (lookahead == 't') ADVANCE(73);
      END_STATE();
    case 156:
      if (lookahead == 't') ADVANCE(76);
      END_STATE();
    case 157:
      if (lookahead == 't') ADVANCE(135);
      END_STATE();
    case 158:
      if (lookahead == 't') ADVANCE(78);
      END_STATE();
    case 159:
      if (lookahead == 't') ADVANCE(131);
      END_STATE();
    case 160:
      if (lookahead == 't') ADVANCE(137);
      END_STATE();
    case 161:
      if (lookahead == 't') ADVANCE(83);
      END_STATE();
    case 162:
      if (lookahead == 't') ADVANCE(80);
      END_STATE();
    case 163:
      if (lookahead == 't') ADVANCE(82);
      END_STATE();
    case 164:
      if (lookahead == 't') ADVANCE(28);
      END_STATE();
    case 165:
      if (lookahead == 't') ADVANCE(117);
      END_STATE();
    case 166:
      if (lookahead == 't') ADVANCE(64);
      END_STATE();
    case 167:
      if (lookahead == 'u') ADVANCE(108);
      END_STATE();
    case 168:
      if (lookahead == 'u') ADVANCE(42);
      END_STATE();
    case 169:
      if (lookahead == 'u') ADVANCE(42);
      if (lookahead == 'y') ADVANCE(268);
      END_STATE();
    case 170:
      if (lookahead == 'u') ADVANCE(130);
      END_STATE();
    case 171:
      if (lookahead == 'u') ADVANCE(45);
      END_STATE();
    case 172:
      if (lookahead == 'u') ADVANCE(96);
      END_STATE();
    case 173:
      if (lookahead == 'u') ADVANCE(109);
      END_STATE();
    case 174:
      if (lookahead == 'w') ADVANCE(84);
      END_STATE();
    case 175:
      if (lookahead == 'x') ADVANCE(261);
      END_STATE();
    case 176:
      if (lookahead == '|') ADVANCE(227);
      END_STATE();
    case 177:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(179);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 178:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(272);
      END_STATE();
    case 179:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 180:
      if (eof) ADVANCE(183);
      ADVANCE_MAP(
        '\n', 231,
        '\r', 276,
        '&', 207,
        '\'', 229,
        '(', 191,
        '*', 197,
        '+', 193,
        ',', 185,
        '-', 195,
        '.', 213,
        '/', 199,
        ':', 239,
        ';', 184,
        '<', 220,
        '=', 238,
        '>', 225,
        '?', 218,
        '@', 219,
        '[', 230,
        '\\', 201,
        '^', 203,
        'b', 128,
        'c', 23,
        'e', 89,
        'f', 13,
        'g', 58,
        'i', 65,
        'm', 17,
        'o', 153,
        'p', 20,
        'r', 51,
        's', 26,
        't', 120,
        'v', 39,
        'w', 72,
        '{', 235,
        '|', 205,
        '~', 217,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(180);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 181:
      if (eof) ADVANCE(183);
      ADVANCE_MAP(
        '(', 191,
        ')', 192,
        '*', 197,
        '+', 193,
        ',', 185,
        '-', 195,
        '.', 215,
        ';', 184,
        '=', 237,
        '?', 218,
        '@', 219,
        '[', 230,
        ']', 234,
        'a', 119,
        'b', 128,
        'c', 86,
        'e', 102,
        'f', 13,
        'g', 58,
        'i', 65,
        'p', 20,
        'r', 51,
        's', 60,
        't', 120,
        'w', 72,
        '{', 235,
        '}', 236,
        '~', 216,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(181);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 182:
      if (eof) ADVANCE(183);
      ADVANCE_MAP(
        '(', 191,
        ')', 192,
        '+', 193,
        ',', 185,
        '-', 195,
        '.', 215,
        ':', 239,
        ';', 184,
        '?', 218,
        '@', 219,
        '[', 230,
        ']', 234,
        'b', 128,
        'c', 11,
        'e', 88,
        'f', 13,
        'g', 58,
        'i', 65,
        'm', 61,
        'o', 153,
        'p', 20,
        'r', 51,
        's', 60,
        't', 120,
        'w', 72,
        '{', 235,
        '}', 236,
        '~', 216,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(182);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(anon_sym_get);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_get);
      if (lookahead == '.') ADVANCE(257);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(anon_sym_set);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_set);
      if (lookahead == '.') ADVANCE(258);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_properties);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(anon_sym_DOT_PLUS);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_DOT_DASH);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(anon_sym_DOT_STAR);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(anon_sym_DOT_SLASH);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(anon_sym_DOT_BSLASH);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(anon_sym_DOT_CARET);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(227);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(226);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(anon_sym_end);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(anon_sym_end);
      if (lookahead == 'f') ADVANCE(173);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(anon_sym_DOT);
      ADVANCE_MAP(
        '\'', 228,
        '*', 198,
        '+', 194,
        '-', 196,
        '/', 200,
        '?', 254,
        '\\', 202,
        '^', 204,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(272);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '\'') ADVANCE(228);
      if (lookahead == '*') ADVANCE(198);
      if (lookahead == '+') ADVANCE(194);
      if (lookahead == '-') ADVANCE(196);
      if (lookahead == '/') ADVANCE(200);
      if (lookahead == '\\') ADVANCE(202);
      if (lookahead == '^') ADVANCE(204);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '\'') ADVANCE(228);
      if (lookahead == '*') ADVANCE(198);
      if (lookahead == '+') ADVANCE(194);
      if (lookahead == '-') ADVANCE(196);
      if (lookahead == '/') ADVANCE(200);
      if (lookahead == '\\') ADVANCE(202);
      if (lookahead == '^') ADVANCE(204);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(272);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '?') ADVANCE(254);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(272);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(272);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '=') ADVANCE(223);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(221);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(anon_sym_TILDE_EQ);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(224);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(anon_sym_DOT_SQUOTE);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(231);
      if (lookahead == '\r') ADVANCE(276);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(232);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(aux_sym_matrix_token1);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(233);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 236:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 237:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(222);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(sym_return_statement);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(sym_continue_statement);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(sym_break_statement);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(anon_sym_elseif);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(anon_sym_else);
      if (lookahead == 'i') ADVANCE(66);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(anon_sym_parfor);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(anon_sym_otherwise);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(anon_sym_persistent);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(anon_sym_DOT_QMARK);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(anon_sym_arguments);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(anon_sym_get_DOT);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(anon_sym_set_DOT);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(anon_sym_endfunction);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(anon_sym_vector);
      END_STATE();
    case 261:
      ACCEPT_TOKEN(anon_sym_matrix);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(anon_sym_scalar);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(anon_sym_methods);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(anon_sym_events);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(anon_sym_enumeration);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(anon_sym_classdef);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(anon_sym_spmd);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(sym_number);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '.') ADVANCE(272);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(177);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(270);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(177);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(270);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(272);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(270);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 276:
      ACCEPT_TOKEN(anon_sym_CR);
      if (lookahead == '\n') ADVANCE(231);
      if (lookahead == '\r') ADVANCE(276);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 181, .external_lex_state = 2},
  [2] = {.lex_state = 180, .external_lex_state = 2},
  [3] = {.lex_state = 180, .external_lex_state = 2},
  [4] = {.lex_state = 180, .external_lex_state = 2},
  [5] = {.lex_state = 180, .external_lex_state = 2},
  [6] = {.lex_state = 2, .external_lex_state = 2},
  [7] = {.lex_state = 2, .external_lex_state = 2},
  [8] = {.lex_state = 2, .external_lex_state = 2},
  [9] = {.lex_state = 2, .external_lex_state = 2},
  [10] = {.lex_state = 2, .external_lex_state = 2},
  [11] = {.lex_state = 2, .external_lex_state = 2},
  [12] = {.lex_state = 2, .external_lex_state = 2},
  [13] = {.lex_state = 2, .external_lex_state = 2},
  [14] = {.lex_state = 2, .external_lex_state = 2},
  [15] = {.lex_state = 2, .external_lex_state = 2},
  [16] = {.lex_state = 2, .external_lex_state = 2},
  [17] = {.lex_state = 2, .external_lex_state = 2},
  [18] = {.lex_state = 2, .external_lex_state = 2},
  [19] = {.lex_state = 2, .external_lex_state = 2},
  [20] = {.lex_state = 2, .external_lex_state = 2},
  [21] = {.lex_state = 2, .external_lex_state = 2},
  [22] = {.lex_state = 2, .external_lex_state = 2},
  [23] = {.lex_state = 2, .external_lex_state = 2},
  [24] = {.lex_state = 2, .external_lex_state = 2},
  [25] = {.lex_state = 2, .external_lex_state = 2},
  [26] = {.lex_state = 2, .external_lex_state = 2},
  [27] = {.lex_state = 2, .external_lex_state = 2},
  [28] = {.lex_state = 2, .external_lex_state = 2},
  [29] = {.lex_state = 181, .external_lex_state = 2},
  [30] = {.lex_state = 181, .external_lex_state = 2},
  [31] = {.lex_state = 181, .external_lex_state = 2},
  [32] = {.lex_state = 181, .external_lex_state = 2},
  [33] = {.lex_state = 181, .external_lex_state = 2},
  [34] = {.lex_state = 181, .external_lex_state = 2},
  [35] = {.lex_state = 181, .external_lex_state = 2},
  [36] = {.lex_state = 181, .external_lex_state = 2},
  [37] = {.lex_state = 181, .external_lex_state = 2},
  [38] = {.lex_state = 181, .external_lex_state = 2},
  [39] = {.lex_state = 181, .external_lex_state = 2},
  [40] = {.lex_state = 181, .external_lex_state = 2},
  [41] = {.lex_state = 181, .external_lex_state = 2},
  [42] = {.lex_state = 181, .external_lex_state = 2},
  [43] = {.lex_state = 181, .external_lex_state = 2},
  [44] = {.lex_state = 181, .external_lex_state = 2},
  [45] = {.lex_state = 181, .external_lex_state = 2},
  [46] = {.lex_state = 181, .external_lex_state = 2},
  [47] = {.lex_state = 181, .external_lex_state = 2},
  [48] = {.lex_state = 181, .external_lex_state = 2},
  [49] = {.lex_state = 181, .external_lex_state = 2},
  [50] = {.lex_state = 181, .external_lex_state = 2},
  [51] = {.lex_state = 181, .external_lex_state = 2},
  [52] = {.lex_state = 181, .external_lex_state = 2},
  [53] = {.lex_state = 181, .external_lex_state = 2},
  [54] = {.lex_state = 181, .external_lex_state = 2},
  [55] = {.lex_state = 181, .external_lex_state = 2},
  [56] = {.lex_state = 181, .external_lex_state = 2},
  [57] = {.lex_state = 181, .external_lex_state = 2},
  [58] = {.lex_state = 181, .external_lex_state = 2},
  [59] = {.lex_state = 181, .external_lex_state = 2},
  [60] = {.lex_state = 182, .external_lex_state = 2},
  [61] = {.lex_state = 181, .external_lex_state = 2},
  [62] = {.lex_state = 181, .external_lex_state = 2},
  [63] = {.lex_state = 181, .external_lex_state = 2},
  [64] = {.lex_state = 181, .external_lex_state = 2},
  [65] = {.lex_state = 181, .external_lex_state = 2},
  [66] = {.lex_state = 182, .external_lex_state = 2},
  [67] = {.lex_state = 181, .external_lex_state = 2},
  [68] = {.lex_state = 181, .external_lex_state = 2},
  [69] = {.lex_state = 181, .external_lex_state = 2},
  [70] = {.lex_state = 181, .external_lex_state = 2},
  [71] = {.lex_state = 181, .external_lex_state = 2},
  [72] = {.lex_state = 181, .external_lex_state = 2},
  [73] = {.lex_state = 181, .external_lex_state = 2},
  [74] = {.lex_state = 181, .external_lex_state = 2},
  [75] = {.lex_state = 181, .external_lex_state = 2},
  [76] = {.lex_state = 181, .external_lex_state = 2},
  [77] = {.lex_state = 181, .external_lex_state = 2},
  [78] = {.lex_state = 181, .external_lex_state = 2},
  [79] = {.lex_state = 181, .external_lex_state = 2},
  [80] = {.lex_state = 181, .external_lex_state = 2},
  [81] = {.lex_state = 181, .external_lex_state = 2},
  [82] = {.lex_state = 181, .external_lex_state = 2},
  [83] = {.lex_state = 181, .external_lex_state = 2},
  [84] = {.lex_state = 180, .external_lex_state = 2},
  [85] = {.lex_state = 180, .external_lex_state = 2},
  [86] = {.lex_state = 180, .external_lex_state = 2},
  [87] = {.lex_state = 180, .external_lex_state = 2},
  [88] = {.lex_state = 180, .external_lex_state = 2},
  [89] = {.lex_state = 180, .external_lex_state = 2},
  [90] = {.lex_state = 180, .external_lex_state = 2},
  [91] = {.lex_state = 180, .external_lex_state = 2},
  [92] = {.lex_state = 180, .external_lex_state = 2},
  [93] = {.lex_state = 180, .external_lex_state = 2},
  [94] = {.lex_state = 180, .external_lex_state = 2},
  [95] = {.lex_state = 180, .external_lex_state = 2},
  [96] = {.lex_state = 180, .external_lex_state = 2},
  [97] = {.lex_state = 180, .external_lex_state = 2},
  [98] = {.lex_state = 180, .external_lex_state = 2},
  [99] = {.lex_state = 180, .external_lex_state = 2},
  [100] = {.lex_state = 180, .external_lex_state = 2},
  [101] = {.lex_state = 180, .external_lex_state = 2},
  [102] = {.lex_state = 180, .external_lex_state = 2},
  [103] = {.lex_state = 180, .external_lex_state = 2},
  [104] = {.lex_state = 180, .external_lex_state = 2},
  [105] = {.lex_state = 180, .external_lex_state = 2},
  [106] = {.lex_state = 180, .external_lex_state = 2},
  [107] = {.lex_state = 180, .external_lex_state = 2},
  [108] = {.lex_state = 180, .external_lex_state = 2},
  [109] = {.lex_state = 180, .external_lex_state = 2},
  [110] = {.lex_state = 180, .external_lex_state = 2},
  [111] = {.lex_state = 180, .external_lex_state = 2},
  [112] = {.lex_state = 180, .external_lex_state = 2},
  [113] = {.lex_state = 180, .external_lex_state = 2},
  [114] = {.lex_state = 180, .external_lex_state = 2},
  [115] = {.lex_state = 180, .external_lex_state = 2},
  [116] = {.lex_state = 180, .external_lex_state = 2},
  [117] = {.lex_state = 180, .external_lex_state = 2},
  [118] = {.lex_state = 180, .external_lex_state = 2},
  [119] = {.lex_state = 180, .external_lex_state = 2},
  [120] = {.lex_state = 180, .external_lex_state = 2},
  [121] = {.lex_state = 180, .external_lex_state = 2},
  [122] = {.lex_state = 180, .external_lex_state = 2},
  [123] = {.lex_state = 180, .external_lex_state = 2},
  [124] = {.lex_state = 180, .external_lex_state = 2},
  [125] = {.lex_state = 180, .external_lex_state = 2},
  [126] = {.lex_state = 180, .external_lex_state = 2},
  [127] = {.lex_state = 180, .external_lex_state = 2},
  [128] = {.lex_state = 180, .external_lex_state = 2},
  [129] = {.lex_state = 180, .external_lex_state = 2},
  [130] = {.lex_state = 180, .external_lex_state = 2},
  [131] = {.lex_state = 180, .external_lex_state = 2},
  [132] = {.lex_state = 180, .external_lex_state = 2},
  [133] = {.lex_state = 180, .external_lex_state = 2},
  [134] = {.lex_state = 180, .external_lex_state = 2},
  [135] = {.lex_state = 180, .external_lex_state = 2},
  [136] = {.lex_state = 180, .external_lex_state = 2},
  [137] = {.lex_state = 180, .external_lex_state = 2},
  [138] = {.lex_state = 180, .external_lex_state = 2},
  [139] = {.lex_state = 180, .external_lex_state = 2},
  [140] = {.lex_state = 180, .external_lex_state = 2},
  [141] = {.lex_state = 180, .external_lex_state = 2},
  [142] = {.lex_state = 180, .external_lex_state = 2},
  [143] = {.lex_state = 180, .external_lex_state = 2},
  [144] = {.lex_state = 180, .external_lex_state = 2},
  [145] = {.lex_state = 180, .external_lex_state = 2},
  [146] = {.lex_state = 180, .external_lex_state = 2},
  [147] = {.lex_state = 180, .external_lex_state = 2},
  [148] = {.lex_state = 180, .external_lex_state = 2},
  [149] = {.lex_state = 180, .external_lex_state = 2},
  [150] = {.lex_state = 180, .external_lex_state = 2},
  [151] = {.lex_state = 180, .external_lex_state = 2},
  [152] = {.lex_state = 180, .external_lex_state = 2},
  [153] = {.lex_state = 180, .external_lex_state = 2},
  [154] = {.lex_state = 180, .external_lex_state = 2},
  [155] = {.lex_state = 180, .external_lex_state = 2},
  [156] = {.lex_state = 180, .external_lex_state = 2},
  [157] = {.lex_state = 180, .external_lex_state = 2},
  [158] = {.lex_state = 180, .external_lex_state = 2},
  [159] = {.lex_state = 180, .external_lex_state = 2},
  [160] = {.lex_state = 180, .external_lex_state = 2},
  [161] = {.lex_state = 180, .external_lex_state = 2},
  [162] = {.lex_state = 180, .external_lex_state = 2},
  [163] = {.lex_state = 1, .external_lex_state = 2},
  [164] = {.lex_state = 1, .external_lex_state = 2},
  [165] = {.lex_state = 1, .external_lex_state = 2},
  [166] = {.lex_state = 1, .external_lex_state = 2},
  [167] = {.lex_state = 1, .external_lex_state = 2},
  [168] = {.lex_state = 1, .external_lex_state = 2},
  [169] = {.lex_state = 182, .external_lex_state = 3},
  [170] = {.lex_state = 182, .external_lex_state = 3},
  [171] = {.lex_state = 182, .external_lex_state = 3},
  [172] = {.lex_state = 182, .external_lex_state = 3},
  [173] = {.lex_state = 1, .external_lex_state = 2},
  [174] = {.lex_state = 182, .external_lex_state = 3},
  [175] = {.lex_state = 182, .external_lex_state = 3},
  [176] = {.lex_state = 182, .external_lex_state = 3},
  [177] = {.lex_state = 182, .external_lex_state = 3},
  [178] = {.lex_state = 182, .external_lex_state = 3},
  [179] = {.lex_state = 182, .external_lex_state = 3},
  [180] = {.lex_state = 182, .external_lex_state = 3},
  [181] = {.lex_state = 182, .external_lex_state = 3},
  [182] = {.lex_state = 182, .external_lex_state = 3},
  [183] = {.lex_state = 182, .external_lex_state = 3},
  [184] = {.lex_state = 8, .external_lex_state = 3},
  [185] = {.lex_state = 180, .external_lex_state = 2},
  [186] = {.lex_state = 3, .external_lex_state = 3},
  [187] = {.lex_state = 182, .external_lex_state = 3},
  [188] = {.lex_state = 3, .external_lex_state = 3},
  [189] = {.lex_state = 3, .external_lex_state = 3},
  [190] = {.lex_state = 3, .external_lex_state = 3},
  [191] = {.lex_state = 3, .external_lex_state = 3},
  [192] = {.lex_state = 182, .external_lex_state = 3},
  [193] = {.lex_state = 3, .external_lex_state = 3},
  [194] = {.lex_state = 3, .external_lex_state = 3},
  [195] = {.lex_state = 3, .external_lex_state = 3},
  [196] = {.lex_state = 2, .external_lex_state = 2},
  [197] = {.lex_state = 182, .external_lex_state = 3},
  [198] = {.lex_state = 3, .external_lex_state = 3},
  [199] = {.lex_state = 3, .external_lex_state = 3},
  [200] = {.lex_state = 3, .external_lex_state = 3},
  [201] = {.lex_state = 3, .external_lex_state = 3},
  [202] = {.lex_state = 182, .external_lex_state = 3},
  [203] = {.lex_state = 3, .external_lex_state = 3},
  [204] = {.lex_state = 3, .external_lex_state = 3},
  [205] = {.lex_state = 3, .external_lex_state = 3},
  [206] = {.lex_state = 3, .external_lex_state = 3},
  [207] = {.lex_state = 8, .external_lex_state = 3},
  [208] = {.lex_state = 8, .external_lex_state = 3},
  [209] = {.lex_state = 8, .external_lex_state = 3},
  [210] = {.lex_state = 8, .external_lex_state = 4},
  [211] = {.lex_state = 182, .external_lex_state = 2},
  [212] = {.lex_state = 182, .external_lex_state = 3},
  [213] = {.lex_state = 182, .external_lex_state = 2},
  [214] = {.lex_state = 182, .external_lex_state = 2},
  [215] = {.lex_state = 182, .external_lex_state = 2},
  [216] = {.lex_state = 182, .external_lex_state = 2},
  [217] = {.lex_state = 182, .external_lex_state = 3},
  [218] = {.lex_state = 182, .external_lex_state = 3},
  [219] = {.lex_state = 182, .external_lex_state = 3},
  [220] = {.lex_state = 182, .external_lex_state = 3},
  [221] = {.lex_state = 182, .external_lex_state = 3},
  [222] = {.lex_state = 182, .external_lex_state = 3},
  [223] = {.lex_state = 182, .external_lex_state = 3},
  [224] = {.lex_state = 182, .external_lex_state = 3},
  [225] = {.lex_state = 182, .external_lex_state = 3},
  [226] = {.lex_state = 182, .external_lex_state = 3},
  [227] = {.lex_state = 182, .external_lex_state = 3},
  [228] = {.lex_state = 181, .external_lex_state = 3},
  [229] = {.lex_state = 181, .external_lex_state = 3},
  [230] = {.lex_state = 181, .external_lex_state = 3},
  [231] = {.lex_state = 181, .external_lex_state = 3},
  [232] = {.lex_state = 180, .external_lex_state = 5},
  [233] = {.lex_state = 181, .external_lex_state = 3},
  [234] = {.lex_state = 181, .external_lex_state = 3},
  [235] = {.lex_state = 181, .external_lex_state = 3},
  [236] = {.lex_state = 181, .external_lex_state = 3},
  [237] = {.lex_state = 181, .external_lex_state = 3},
  [238] = {.lex_state = 181, .external_lex_state = 3},
  [239] = {.lex_state = 181, .external_lex_state = 3},
  [240] = {.lex_state = 181, .external_lex_state = 3},
  [241] = {.lex_state = 181, .external_lex_state = 3},
  [242] = {.lex_state = 181, .external_lex_state = 3},
  [243] = {.lex_state = 181, .external_lex_state = 3},
  [244] = {.lex_state = 181, .external_lex_state = 3},
  [245] = {.lex_state = 181, .external_lex_state = 3},
  [246] = {.lex_state = 181, .external_lex_state = 3},
  [247] = {.lex_state = 181, .external_lex_state = 3},
  [248] = {.lex_state = 181, .external_lex_state = 3},
  [249] = {.lex_state = 181, .external_lex_state = 3},
  [250] = {.lex_state = 181, .external_lex_state = 3},
  [251] = {.lex_state = 181, .external_lex_state = 3},
  [252] = {.lex_state = 181, .external_lex_state = 3},
  [253] = {.lex_state = 181, .external_lex_state = 3},
  [254] = {.lex_state = 181, .external_lex_state = 3},
  [255] = {.lex_state = 181, .external_lex_state = 3},
  [256] = {.lex_state = 181, .external_lex_state = 3},
  [257] = {.lex_state = 181, .external_lex_state = 3},
  [258] = {.lex_state = 181, .external_lex_state = 3},
  [259] = {.lex_state = 181, .external_lex_state = 3},
  [260] = {.lex_state = 181, .external_lex_state = 3},
  [261] = {.lex_state = 181, .external_lex_state = 3},
  [262] = {.lex_state = 181, .external_lex_state = 3},
  [263] = {.lex_state = 181, .external_lex_state = 3},
  [264] = {.lex_state = 181, .external_lex_state = 3},
  [265] = {.lex_state = 181, .external_lex_state = 3},
  [266] = {.lex_state = 181, .external_lex_state = 3},
  [267] = {.lex_state = 181, .external_lex_state = 3},
  [268] = {.lex_state = 181, .external_lex_state = 3},
  [269] = {.lex_state = 181, .external_lex_state = 3},
  [270] = {.lex_state = 181, .external_lex_state = 3},
  [271] = {.lex_state = 181, .external_lex_state = 3},
  [272] = {.lex_state = 181, .external_lex_state = 3},
  [273] = {.lex_state = 181, .external_lex_state = 3},
  [274] = {.lex_state = 181, .external_lex_state = 3},
  [275] = {.lex_state = 181, .external_lex_state = 2},
  [276] = {.lex_state = 181, .external_lex_state = 3},
  [277] = {.lex_state = 181, .external_lex_state = 3},
  [278] = {.lex_state = 181, .external_lex_state = 3},
  [279] = {.lex_state = 181, .external_lex_state = 3},
  [280] = {.lex_state = 181, .external_lex_state = 3},
  [281] = {.lex_state = 181, .external_lex_state = 3},
  [282] = {.lex_state = 181, .external_lex_state = 3},
  [283] = {.lex_state = 181, .external_lex_state = 3},
  [284] = {.lex_state = 181, .external_lex_state = 3},
  [285] = {.lex_state = 181, .external_lex_state = 3},
  [286] = {.lex_state = 181, .external_lex_state = 3},
  [287] = {.lex_state = 181, .external_lex_state = 3},
  [288] = {.lex_state = 181, .external_lex_state = 3},
  [289] = {.lex_state = 181, .external_lex_state = 3},
  [290] = {.lex_state = 181, .external_lex_state = 3},
  [291] = {.lex_state = 181, .external_lex_state = 3},
  [292] = {.lex_state = 181, .external_lex_state = 3},
  [293] = {.lex_state = 181, .external_lex_state = 3},
  [294] = {.lex_state = 181, .external_lex_state = 3},
  [295] = {.lex_state = 181, .external_lex_state = 3},
  [296] = {.lex_state = 181, .external_lex_state = 3},
  [297] = {.lex_state = 181, .external_lex_state = 3},
  [298] = {.lex_state = 181, .external_lex_state = 3},
  [299] = {.lex_state = 181, .external_lex_state = 3},
  [300] = {.lex_state = 181, .external_lex_state = 3},
  [301] = {.lex_state = 181, .external_lex_state = 3},
  [302] = {.lex_state = 181, .external_lex_state = 3},
  [303] = {.lex_state = 181, .external_lex_state = 3},
  [304] = {.lex_state = 181, .external_lex_state = 3},
  [305] = {.lex_state = 181, .external_lex_state = 3},
  [306] = {.lex_state = 181, .external_lex_state = 3},
  [307] = {.lex_state = 181, .external_lex_state = 3},
  [308] = {.lex_state = 181, .external_lex_state = 3},
  [309] = {.lex_state = 181, .external_lex_state = 3},
  [310] = {.lex_state = 181, .external_lex_state = 3},
  [311] = {.lex_state = 181, .external_lex_state = 3},
  [312] = {.lex_state = 181, .external_lex_state = 3},
  [313] = {.lex_state = 181, .external_lex_state = 3},
  [314] = {.lex_state = 181, .external_lex_state = 2},
  [315] = {.lex_state = 181, .external_lex_state = 3},
  [316] = {.lex_state = 181, .external_lex_state = 3},
  [317] = {.lex_state = 181, .external_lex_state = 3},
  [318] = {.lex_state = 181, .external_lex_state = 3},
  [319] = {.lex_state = 181, .external_lex_state = 3},
  [320] = {.lex_state = 181, .external_lex_state = 3},
  [321] = {.lex_state = 181, .external_lex_state = 3},
  [322] = {.lex_state = 181, .external_lex_state = 3},
  [323] = {.lex_state = 181, .external_lex_state = 3},
  [324] = {.lex_state = 181, .external_lex_state = 2},
  [325] = {.lex_state = 181, .external_lex_state = 3},
  [326] = {.lex_state = 181, .external_lex_state = 3},
  [327] = {.lex_state = 181, .external_lex_state = 2},
  [328] = {.lex_state = 181, .external_lex_state = 3},
  [329] = {.lex_state = 181, .external_lex_state = 3},
  [330] = {.lex_state = 181, .external_lex_state = 2},
  [331] = {.lex_state = 181, .external_lex_state = 3},
  [332] = {.lex_state = 181, .external_lex_state = 2},
  [333] = {.lex_state = 181, .external_lex_state = 3},
  [334] = {.lex_state = 181, .external_lex_state = 3},
  [335] = {.lex_state = 181, .external_lex_state = 3},
  [336] = {.lex_state = 181, .external_lex_state = 3},
  [337] = {.lex_state = 181, .external_lex_state = 3},
  [338] = {.lex_state = 181, .external_lex_state = 3},
  [339] = {.lex_state = 181, .external_lex_state = 3},
  [340] = {.lex_state = 181, .external_lex_state = 3},
  [341] = {.lex_state = 181, .external_lex_state = 3},
  [342] = {.lex_state = 181, .external_lex_state = 3},
  [343] = {.lex_state = 181, .external_lex_state = 3},
  [344] = {.lex_state = 181, .external_lex_state = 3},
  [345] = {.lex_state = 180, .external_lex_state = 5},
  [346] = {.lex_state = 180, .external_lex_state = 5},
  [347] = {.lex_state = 180, .external_lex_state = 5},
  [348] = {.lex_state = 180, .external_lex_state = 5},
  [349] = {.lex_state = 180, .external_lex_state = 5},
  [350] = {.lex_state = 180, .external_lex_state = 5},
  [351] = {.lex_state = 181, .external_lex_state = 2},
  [352] = {.lex_state = 180, .external_lex_state = 5},
  [353] = {.lex_state = 180, .external_lex_state = 5},
  [354] = {.lex_state = 180, .external_lex_state = 5},
  [355] = {.lex_state = 181, .external_lex_state = 2},
  [356] = {.lex_state = 181, .external_lex_state = 2},
  [357] = {.lex_state = 180, .external_lex_state = 5},
  [358] = {.lex_state = 180, .external_lex_state = 5},
  [359] = {.lex_state = 181, .external_lex_state = 2},
  [360] = {.lex_state = 180, .external_lex_state = 5},
  [361] = {.lex_state = 180, .external_lex_state = 5},
  [362] = {.lex_state = 180, .external_lex_state = 5},
  [363] = {.lex_state = 180, .external_lex_state = 5},
  [364] = {.lex_state = 4, .external_lex_state = 6},
  [365] = {.lex_state = 180, .external_lex_state = 5},
  [366] = {.lex_state = 180, .external_lex_state = 5},
  [367] = {.lex_state = 4, .external_lex_state = 6},
  [368] = {.lex_state = 180, .external_lex_state = 5},
  [369] = {.lex_state = 4, .external_lex_state = 6},
  [370] = {.lex_state = 4, .external_lex_state = 6},
  [371] = {.lex_state = 180, .external_lex_state = 5},
  [372] = {.lex_state = 4, .external_lex_state = 6},
  [373] = {.lex_state = 180, .external_lex_state = 5},
  [374] = {.lex_state = 0, .external_lex_state = 5},
  [375] = {.lex_state = 180, .external_lex_state = 5},
  [376] = {.lex_state = 0, .external_lex_state = 5},
  [377] = {.lex_state = 4, .external_lex_state = 6},
  [378] = {.lex_state = 180, .external_lex_state = 5},
  [379] = {.lex_state = 0, .external_lex_state = 5},
  [380] = {.lex_state = 0, .external_lex_state = 5},
  [381] = {.lex_state = 4, .external_lex_state = 6},
  [382] = {.lex_state = 0, .external_lex_state = 5},
  [383] = {.lex_state = 4, .external_lex_state = 6},
  [384] = {.lex_state = 0, .external_lex_state = 5},
  [385] = {.lex_state = 180, .external_lex_state = 5},
  [386] = {.lex_state = 4, .external_lex_state = 6},
  [387] = {.lex_state = 4, .external_lex_state = 6},
  [388] = {.lex_state = 180, .external_lex_state = 5},
  [389] = {.lex_state = 180, .external_lex_state = 5},
  [390] = {.lex_state = 4, .external_lex_state = 6},
  [391] = {.lex_state = 0, .external_lex_state = 5},
  [392] = {.lex_state = 180, .external_lex_state = 5},
  [393] = {.lex_state = 4, .external_lex_state = 6},
  [394] = {.lex_state = 4, .external_lex_state = 6},
  [395] = {.lex_state = 4, .external_lex_state = 6},
  [396] = {.lex_state = 4, .external_lex_state = 6},
  [397] = {.lex_state = 180, .external_lex_state = 5},
  [398] = {.lex_state = 4, .external_lex_state = 6},
  [399] = {.lex_state = 4, .external_lex_state = 6},
  [400] = {.lex_state = 0, .external_lex_state = 5},
  [401] = {.lex_state = 0, .external_lex_state = 5},
  [402] = {.lex_state = 0, .external_lex_state = 5},
  [403] = {.lex_state = 4, .external_lex_state = 6},
  [404] = {.lex_state = 0, .external_lex_state = 5},
  [405] = {.lex_state = 0, .external_lex_state = 5},
  [406] = {.lex_state = 0, .external_lex_state = 5},
  [407] = {.lex_state = 4, .external_lex_state = 6},
  [408] = {.lex_state = 0, .external_lex_state = 5},
  [409] = {.lex_state = 4, .external_lex_state = 6},
  [410] = {.lex_state = 0, .external_lex_state = 5},
  [411] = {.lex_state = 0, .external_lex_state = 5},
  [412] = {.lex_state = 180, .external_lex_state = 5},
  [413] = {.lex_state = 0, .external_lex_state = 5},
  [414] = {.lex_state = 0, .external_lex_state = 5},
  [415] = {.lex_state = 180, .external_lex_state = 5},
  [416] = {.lex_state = 0, .external_lex_state = 5},
  [417] = {.lex_state = 180, .external_lex_state = 5},
  [418] = {.lex_state = 180, .external_lex_state = 5},
  [419] = {.lex_state = 180, .external_lex_state = 5},
  [420] = {.lex_state = 180, .external_lex_state = 5},
  [421] = {.lex_state = 180, .external_lex_state = 5},
  [422] = {.lex_state = 180, .external_lex_state = 5},
  [423] = {.lex_state = 0, .external_lex_state = 5},
  [424] = {.lex_state = 0, .external_lex_state = 5},
  [425] = {.lex_state = 180, .external_lex_state = 5},
  [426] = {.lex_state = 180, .external_lex_state = 5},
  [427] = {.lex_state = 180, .external_lex_state = 5},
  [428] = {.lex_state = 180, .external_lex_state = 5},
  [429] = {.lex_state = 180, .external_lex_state = 5},
  [430] = {.lex_state = 4, .external_lex_state = 6},
  [431] = {.lex_state = 180, .external_lex_state = 5},
  [432] = {.lex_state = 180, .external_lex_state = 5},
  [433] = {.lex_state = 4, .external_lex_state = 6},
  [434] = {.lex_state = 180, .external_lex_state = 5},
  [435] = {.lex_state = 180, .external_lex_state = 5},
  [436] = {.lex_state = 180, .external_lex_state = 5},
  [437] = {.lex_state = 0, .external_lex_state = 5},
  [438] = {.lex_state = 0, .external_lex_state = 5},
  [439] = {.lex_state = 180, .external_lex_state = 5},
  [440] = {.lex_state = 0, .external_lex_state = 5},
  [441] = {.lex_state = 180, .external_lex_state = 5},
  [442] = {.lex_state = 0, .external_lex_state = 5},
  [443] = {.lex_state = 180, .external_lex_state = 5},
  [444] = {.lex_state = 4, .external_lex_state = 6},
  [445] = {.lex_state = 0, .external_lex_state = 5},
  [446] = {.lex_state = 4, .external_lex_state = 6},
  [447] = {.lex_state = 180, .external_lex_state = 5},
  [448] = {.lex_state = 180, .external_lex_state = 5},
  [449] = {.lex_state = 180, .external_lex_state = 5},
  [450] = {.lex_state = 180, .external_lex_state = 5},
  [451] = {.lex_state = 180, .external_lex_state = 5},
  [452] = {.lex_state = 0, .external_lex_state = 5},
  [453] = {.lex_state = 0, .external_lex_state = 5},
  [454] = {.lex_state = 0, .external_lex_state = 5},
  [455] = {.lex_state = 0, .external_lex_state = 5},
  [456] = {.lex_state = 180, .external_lex_state = 5},
  [457] = {.lex_state = 0, .external_lex_state = 5},
  [458] = {.lex_state = 180, .external_lex_state = 5},
  [459] = {.lex_state = 180, .external_lex_state = 5},
  [460] = {.lex_state = 4, .external_lex_state = 6},
  [461] = {.lex_state = 180, .external_lex_state = 5},
  [462] = {.lex_state = 0, .external_lex_state = 5},
  [463] = {.lex_state = 180, .external_lex_state = 5},
  [464] = {.lex_state = 180, .external_lex_state = 5},
  [465] = {.lex_state = 0, .external_lex_state = 5},
  [466] = {.lex_state = 0, .external_lex_state = 5},
  [467] = {.lex_state = 0, .external_lex_state = 5},
  [468] = {.lex_state = 180, .external_lex_state = 5},
  [469] = {.lex_state = 180, .external_lex_state = 5},
  [470] = {.lex_state = 4, .external_lex_state = 6},
  [471] = {.lex_state = 0, .external_lex_state = 5},
  [472] = {.lex_state = 0, .external_lex_state = 5},
  [473] = {.lex_state = 180, .external_lex_state = 5},
  [474] = {.lex_state = 0, .external_lex_state = 5},
  [475] = {.lex_state = 180, .external_lex_state = 5},
  [476] = {.lex_state = 180, .external_lex_state = 5},
  [477] = {.lex_state = 180, .external_lex_state = 5},
  [478] = {.lex_state = 180, .external_lex_state = 5},
  [479] = {.lex_state = 180, .external_lex_state = 5},
  [480] = {.lex_state = 4, .external_lex_state = 6},
  [481] = {.lex_state = 180, .external_lex_state = 5},
  [482] = {.lex_state = 180, .external_lex_state = 5},
  [483] = {.lex_state = 180, .external_lex_state = 5},
  [484] = {.lex_state = 180, .external_lex_state = 5},
  [485] = {.lex_state = 0, .external_lex_state = 5},
  [486] = {.lex_state = 180, .external_lex_state = 5},
  [487] = {.lex_state = 0, .external_lex_state = 5},
  [488] = {.lex_state = 180, .external_lex_state = 5},
  [489] = {.lex_state = 180, .external_lex_state = 5},
  [490] = {.lex_state = 4, .external_lex_state = 6},
  [491] = {.lex_state = 0, .external_lex_state = 5},
  [492] = {.lex_state = 4, .external_lex_state = 6},
  [493] = {.lex_state = 4, .external_lex_state = 6},
  [494] = {.lex_state = 4, .external_lex_state = 6},
  [495] = {.lex_state = 4, .external_lex_state = 6},
  [496] = {.lex_state = 4, .external_lex_state = 6},
  [497] = {.lex_state = 4, .external_lex_state = 6},
  [498] = {.lex_state = 4, .external_lex_state = 6},
  [499] = {.lex_state = 4, .external_lex_state = 6},
  [500] = {.lex_state = 4, .external_lex_state = 6},
  [501] = {.lex_state = 0, .external_lex_state = 5},
  [502] = {.lex_state = 4, .external_lex_state = 6},
  [503] = {.lex_state = 4, .external_lex_state = 6},
  [504] = {.lex_state = 4, .external_lex_state = 6},
  [505] = {.lex_state = 4, .external_lex_state = 6},
  [506] = {.lex_state = 0, .external_lex_state = 5},
  [507] = {.lex_state = 4, .external_lex_state = 6},
  [508] = {.lex_state = 4, .external_lex_state = 6},
  [509] = {.lex_state = 4, .external_lex_state = 6},
  [510] = {.lex_state = 4, .external_lex_state = 6},
  [511] = {.lex_state = 4, .external_lex_state = 6},
  [512] = {.lex_state = 4, .external_lex_state = 6},
  [513] = {.lex_state = 4, .external_lex_state = 6},
  [514] = {.lex_state = 4, .external_lex_state = 6},
  [515] = {.lex_state = 4, .external_lex_state = 6},
  [516] = {.lex_state = 4, .external_lex_state = 6},
  [517] = {.lex_state = 4, .external_lex_state = 6},
  [518] = {.lex_state = 4, .external_lex_state = 6},
  [519] = {.lex_state = 4, .external_lex_state = 6},
  [520] = {.lex_state = 180, .external_lex_state = 5},
  [521] = {.lex_state = 4, .external_lex_state = 6},
  [522] = {.lex_state = 0, .external_lex_state = 5},
  [523] = {.lex_state = 0, .external_lex_state = 5},
  [524] = {.lex_state = 0, .external_lex_state = 5},
  [525] = {.lex_state = 0, .external_lex_state = 5},
  [526] = {.lex_state = 0, .external_lex_state = 5},
  [527] = {.lex_state = 4, .external_lex_state = 6},
  [528] = {.lex_state = 4, .external_lex_state = 6},
  [529] = {.lex_state = 180, .external_lex_state = 5},
  [530] = {.lex_state = 0, .external_lex_state = 5},
  [531] = {.lex_state = 4, .external_lex_state = 6},
  [532] = {.lex_state = 4, .external_lex_state = 6},
  [533] = {.lex_state = 4, .external_lex_state = 6},
  [534] = {.lex_state = 4, .external_lex_state = 6},
  [535] = {.lex_state = 4, .external_lex_state = 6},
  [536] = {.lex_state = 4, .external_lex_state = 6},
  [537] = {.lex_state = 4, .external_lex_state = 6},
  [538] = {.lex_state = 4, .external_lex_state = 6},
  [539] = {.lex_state = 4, .external_lex_state = 6},
  [540] = {.lex_state = 4, .external_lex_state = 6},
  [541] = {.lex_state = 4, .external_lex_state = 6},
  [542] = {.lex_state = 4, .external_lex_state = 6},
  [543] = {.lex_state = 4, .external_lex_state = 6},
  [544] = {.lex_state = 4, .external_lex_state = 6},
  [545] = {.lex_state = 4, .external_lex_state = 6},
  [546] = {.lex_state = 4, .external_lex_state = 6},
  [547] = {.lex_state = 4, .external_lex_state = 6},
  [548] = {.lex_state = 0, .external_lex_state = 5},
  [549] = {.lex_state = 180, .external_lex_state = 5},
  [550] = {.lex_state = 180, .external_lex_state = 5},
  [551] = {.lex_state = 180, .external_lex_state = 5},
  [552] = {.lex_state = 180, .external_lex_state = 5},
  [553] = {.lex_state = 0, .external_lex_state = 5},
  [554] = {.lex_state = 0, .external_lex_state = 5},
  [555] = {.lex_state = 0, .external_lex_state = 5},
  [556] = {.lex_state = 0, .external_lex_state = 5},
  [557] = {.lex_state = 0, .external_lex_state = 5},
  [558] = {.lex_state = 0, .external_lex_state = 5},
  [559] = {.lex_state = 0, .external_lex_state = 5},
  [560] = {.lex_state = 0, .external_lex_state = 5},
  [561] = {.lex_state = 0, .external_lex_state = 5},
  [562] = {.lex_state = 0, .external_lex_state = 5},
  [563] = {.lex_state = 0, .external_lex_state = 5},
  [564] = {.lex_state = 0, .external_lex_state = 5},
  [565] = {.lex_state = 0, .external_lex_state = 5},
  [566] = {.lex_state = 0, .external_lex_state = 5},
  [567] = {.lex_state = 0, .external_lex_state = 5},
  [568] = {.lex_state = 0, .external_lex_state = 5},
  [569] = {.lex_state = 0, .external_lex_state = 5},
  [570] = {.lex_state = 0, .external_lex_state = 5},
  [571] = {.lex_state = 0, .external_lex_state = 5},
  [572] = {.lex_state = 0, .external_lex_state = 5},
  [573] = {.lex_state = 0, .external_lex_state = 5},
  [574] = {.lex_state = 0, .external_lex_state = 5},
  [575] = {.lex_state = 0, .external_lex_state = 5},
  [576] = {.lex_state = 0, .external_lex_state = 5},
  [577] = {.lex_state = 0, .external_lex_state = 5},
  [578] = {.lex_state = 0, .external_lex_state = 5},
  [579] = {.lex_state = 0, .external_lex_state = 5},
  [580] = {.lex_state = 0, .external_lex_state = 5},
  [581] = {.lex_state = 0, .external_lex_state = 5},
  [582] = {.lex_state = 0, .external_lex_state = 5},
  [583] = {.lex_state = 0, .external_lex_state = 5},
  [584] = {.lex_state = 0, .external_lex_state = 5},
  [585] = {.lex_state = 0, .external_lex_state = 5},
  [586] = {.lex_state = 0, .external_lex_state = 5},
  [587] = {.lex_state = 0, .external_lex_state = 5},
  [588] = {.lex_state = 0, .external_lex_state = 5},
  [589] = {.lex_state = 0, .external_lex_state = 5},
  [590] = {.lex_state = 0, .external_lex_state = 5},
  [591] = {.lex_state = 0, .external_lex_state = 5},
  [592] = {.lex_state = 0, .external_lex_state = 5},
  [593] = {.lex_state = 0, .external_lex_state = 5},
  [594] = {.lex_state = 0, .external_lex_state = 5},
  [595] = {.lex_state = 0, .external_lex_state = 5},
  [596] = {.lex_state = 0, .external_lex_state = 5},
  [597] = {.lex_state = 0, .external_lex_state = 5},
  [598] = {.lex_state = 0, .external_lex_state = 5},
  [599] = {.lex_state = 0, .external_lex_state = 5},
  [600] = {.lex_state = 0, .external_lex_state = 5},
  [601] = {.lex_state = 4, .external_lex_state = 6},
  [602] = {.lex_state = 0, .external_lex_state = 5},
  [603] = {.lex_state = 0, .external_lex_state = 5},
  [604] = {.lex_state = 0, .external_lex_state = 5},
  [605] = {.lex_state = 0, .external_lex_state = 5},
  [606] = {.lex_state = 0, .external_lex_state = 5},
  [607] = {.lex_state = 0, .external_lex_state = 5},
  [608] = {.lex_state = 0, .external_lex_state = 5},
  [609] = {.lex_state = 0, .external_lex_state = 5},
  [610] = {.lex_state = 0, .external_lex_state = 5},
  [611] = {.lex_state = 0, .external_lex_state = 5},
  [612] = {.lex_state = 0, .external_lex_state = 5},
  [613] = {.lex_state = 0, .external_lex_state = 5},
  [614] = {.lex_state = 4, .external_lex_state = 6},
  [615] = {.lex_state = 4, .external_lex_state = 6},
  [616] = {.lex_state = 4, .external_lex_state = 6},
  [617] = {.lex_state = 0, .external_lex_state = 5},
  [618] = {.lex_state = 0, .external_lex_state = 5},
  [619] = {.lex_state = 0, .external_lex_state = 5},
  [620] = {.lex_state = 4, .external_lex_state = 6},
  [621] = {.lex_state = 0, .external_lex_state = 5},
  [622] = {.lex_state = 0, .external_lex_state = 5},
  [623] = {.lex_state = 0, .external_lex_state = 5},
  [624] = {.lex_state = 0, .external_lex_state = 5},
  [625] = {.lex_state = 0, .external_lex_state = 5},
  [626] = {.lex_state = 0, .external_lex_state = 5},
  [627] = {.lex_state = 0, .external_lex_state = 5},
  [628] = {.lex_state = 0, .external_lex_state = 5},
  [629] = {.lex_state = 0, .external_lex_state = 5},
  [630] = {.lex_state = 0, .external_lex_state = 5},
  [631] = {.lex_state = 0, .external_lex_state = 5},
  [632] = {.lex_state = 0, .external_lex_state = 5},
  [633] = {.lex_state = 0, .external_lex_state = 5},
  [634] = {.lex_state = 0, .external_lex_state = 5},
  [635] = {.lex_state = 0, .external_lex_state = 5},
  [636] = {.lex_state = 0, .external_lex_state = 5},
  [637] = {.lex_state = 0, .external_lex_state = 5},
  [638] = {.lex_state = 0, .external_lex_state = 5},
  [639] = {.lex_state = 0, .external_lex_state = 5},
  [640] = {.lex_state = 0, .external_lex_state = 5},
  [641] = {.lex_state = 0, .external_lex_state = 5},
  [642] = {.lex_state = 0, .external_lex_state = 5},
  [643] = {.lex_state = 0, .external_lex_state = 5},
  [644] = {.lex_state = 0, .external_lex_state = 5},
  [645] = {.lex_state = 0, .external_lex_state = 5},
  [646] = {.lex_state = 0, .external_lex_state = 5},
  [647] = {.lex_state = 0, .external_lex_state = 5},
  [648] = {.lex_state = 0, .external_lex_state = 5},
  [649] = {.lex_state = 0, .external_lex_state = 5},
  [650] = {.lex_state = 0, .external_lex_state = 5},
  [651] = {.lex_state = 0, .external_lex_state = 5},
  [652] = {.lex_state = 0, .external_lex_state = 5},
  [653] = {.lex_state = 0, .external_lex_state = 5},
  [654] = {.lex_state = 181, .external_lex_state = 7},
  [655] = {.lex_state = 3, .external_lex_state = 3},
  [656] = {.lex_state = 2, .external_lex_state = 7},
  [657] = {.lex_state = 181, .external_lex_state = 7},
  [658] = {.lex_state = 2, .external_lex_state = 7},
  [659] = {.lex_state = 1, .external_lex_state = 5},
  [660] = {.lex_state = 180, .external_lex_state = 5},
  [661] = {.lex_state = 1, .external_lex_state = 5},
  [662] = {.lex_state = 180, .external_lex_state = 7},
  [663] = {.lex_state = 1, .external_lex_state = 5},
  [664] = {.lex_state = 2, .external_lex_state = 7},
  [665] = {.lex_state = 0, .external_lex_state = 5},
  [666] = {.lex_state = 0, .external_lex_state = 5},
  [667] = {.lex_state = 0, .external_lex_state = 5},
  [668] = {.lex_state = 0, .external_lex_state = 5},
  [669] = {.lex_state = 0, .external_lex_state = 5},
  [670] = {.lex_state = 0, .external_lex_state = 5},
  [671] = {.lex_state = 0, .external_lex_state = 5},
  [672] = {.lex_state = 0, .external_lex_state = 5},
  [673] = {.lex_state = 2, .external_lex_state = 7},
  [674] = {.lex_state = 0, .external_lex_state = 5},
  [675] = {.lex_state = 0, .external_lex_state = 5},
  [676] = {.lex_state = 3, .external_lex_state = 7},
  [677] = {.lex_state = 2, .external_lex_state = 7},
  [678] = {.lex_state = 181, .external_lex_state = 7},
  [679] = {.lex_state = 181, .external_lex_state = 7},
  [680] = {.lex_state = 181, .external_lex_state = 7},
  [681] = {.lex_state = 181, .external_lex_state = 7},
  [682] = {.lex_state = 1, .external_lex_state = 5},
  [683] = {.lex_state = 1, .external_lex_state = 5},
  [684] = {.lex_state = 181, .external_lex_state = 7},
  [685] = {.lex_state = 1, .external_lex_state = 5},
  [686] = {.lex_state = 1, .external_lex_state = 5},
  [687] = {.lex_state = 3, .external_lex_state = 7},
  [688] = {.lex_state = 181, .external_lex_state = 7},
  [689] = {.lex_state = 2, .external_lex_state = 7},
  [690] = {.lex_state = 0, .external_lex_state = 5},
  [691] = {.lex_state = 0, .external_lex_state = 5},
  [692] = {.lex_state = 0, .external_lex_state = 5},
  [693] = {.lex_state = 0, .external_lex_state = 5},
  [694] = {.lex_state = 0, .external_lex_state = 5},
  [695] = {.lex_state = 181, .external_lex_state = 3},
  [696] = {.lex_state = 180, .external_lex_state = 7},
  [697] = {.lex_state = 7, .external_lex_state = 6},
  [698] = {.lex_state = 6, .external_lex_state = 8},
  [699] = {.lex_state = 7, .external_lex_state = 6},
  [700] = {.lex_state = 182, .external_lex_state = 7},
  [701] = {.lex_state = 6, .external_lex_state = 8},
  [702] = {.lex_state = 6, .external_lex_state = 8},
  [703] = {.lex_state = 7, .external_lex_state = 6},
  [704] = {.lex_state = 7, .external_lex_state = 6},
  [705] = {.lex_state = 181, .external_lex_state = 7},
  [706] = {.lex_state = 6, .external_lex_state = 5},
  [707] = {.lex_state = 7, .external_lex_state = 6},
  [708] = {.lex_state = 6, .external_lex_state = 8},
  [709] = {.lex_state = 181, .external_lex_state = 7},
  [710] = {.lex_state = 181, .external_lex_state = 7},
  [711] = {.lex_state = 181, .external_lex_state = 7},
  [712] = {.lex_state = 181, .external_lex_state = 7},
  [713] = {.lex_state = 6, .external_lex_state = 8},
  [714] = {.lex_state = 2, .external_lex_state = 7},
  [715] = {.lex_state = 4, .external_lex_state = 6},
  [716] = {.lex_state = 7, .external_lex_state = 6},
  [717] = {.lex_state = 0, .external_lex_state = 5},
  [718] = {.lex_state = 181, .external_lex_state = 7},
  [719] = {.lex_state = 180, .external_lex_state = 5},
  [720] = {.lex_state = 181, .external_lex_state = 7},
  [721] = {.lex_state = 181, .external_lex_state = 7},
  [722] = {.lex_state = 6, .external_lex_state = 5},
  [723] = {.lex_state = 2, .external_lex_state = 7},
  [724] = {.lex_state = 2, .external_lex_state = 7},
  [725] = {.lex_state = 6, .external_lex_state = 5},
  [726] = {.lex_state = 0, .external_lex_state = 5},
  [727] = {.lex_state = 181, .external_lex_state = 7},
  [728] = {.lex_state = 181, .external_lex_state = 7},
  [729] = {.lex_state = 181, .external_lex_state = 7},
  [730] = {.lex_state = 181, .external_lex_state = 7},
  [731] = {.lex_state = 0, .external_lex_state = 5},
  [732] = {.lex_state = 181, .external_lex_state = 7},
  [733] = {.lex_state = 7, .external_lex_state = 6},
  [734] = {.lex_state = 181, .external_lex_state = 7},
  [735] = {.lex_state = 4, .external_lex_state = 6},
  [736] = {.lex_state = 0, .external_lex_state = 5},
  [737] = {.lex_state = 0, .external_lex_state = 5},
  [738] = {.lex_state = 0, .external_lex_state = 5},
  [739] = {.lex_state = 181, .external_lex_state = 7},
  [740] = {.lex_state = 180, .external_lex_state = 5},
  [741] = {.lex_state = 6, .external_lex_state = 5},
  [742] = {.lex_state = 181, .external_lex_state = 7},
  [743] = {.lex_state = 180, .external_lex_state = 7},
  [744] = {.lex_state = 180, .external_lex_state = 7},
  [745] = {.lex_state = 6, .external_lex_state = 5},
  [746] = {.lex_state = 4, .external_lex_state = 6},
  [747] = {.lex_state = 180, .external_lex_state = 7},
  [748] = {.lex_state = 6, .external_lex_state = 5},
  [749] = {.lex_state = 180, .external_lex_state = 7},
  [750] = {.lex_state = 180, .external_lex_state = 5},
  [751] = {.lex_state = 180, .external_lex_state = 5},
  [752] = {.lex_state = 2, .external_lex_state = 7},
  [753] = {.lex_state = 180, .external_lex_state = 7},
  [754] = {.lex_state = 6, .external_lex_state = 5},
  [755] = {.lex_state = 2, .external_lex_state = 5},
  [756] = {.lex_state = 181, .external_lex_state = 7},
  [757] = {.lex_state = 180, .external_lex_state = 7},
  [758] = {.lex_state = 180, .external_lex_state = 7},
  [759] = {.lex_state = 182, .external_lex_state = 7},
  [760] = {.lex_state = 180, .external_lex_state = 7},
  [761] = {.lex_state = 2, .external_lex_state = 5},
  [762] = {.lex_state = 181, .external_lex_state = 7},
  [763] = {.lex_state = 2, .external_lex_state = 7},
  [764] = {.lex_state = 180, .external_lex_state = 7},
  [765] = {.lex_state = 180, .external_lex_state = 5},
  [766] = {.lex_state = 2, .external_lex_state = 7},
  [767] = {.lex_state = 2, .external_lex_state = 7},
  [768] = {.lex_state = 180, .external_lex_state = 5},
  [769] = {.lex_state = 182, .external_lex_state = 7},
  [770] = {.lex_state = 182, .external_lex_state = 7},
  [771] = {.lex_state = 180, .external_lex_state = 7},
  [772] = {.lex_state = 2, .external_lex_state = 7},
  [773] = {.lex_state = 180, .external_lex_state = 5},
  [774] = {.lex_state = 2, .external_lex_state = 7},
  [775] = {.lex_state = 181, .external_lex_state = 7},
  [776] = {.lex_state = 180, .external_lex_state = 7},
  [777] = {.lex_state = 181, .external_lex_state = 7},
  [778] = {.lex_state = 180, .external_lex_state = 7},
  [779] = {.lex_state = 180, .external_lex_state = 7},
  [780] = {.lex_state = 2, .external_lex_state = 7},
  [781] = {.lex_state = 181, .external_lex_state = 7},
  [782] = {.lex_state = 182, .external_lex_state = 5},
  [783] = {.lex_state = 180, .external_lex_state = 5},
  [784] = {.lex_state = 180, .external_lex_state = 7},
  [785] = {.lex_state = 181, .external_lex_state = 7},
  [786] = {.lex_state = 181, .external_lex_state = 7},
  [787] = {.lex_state = 0, .external_lex_state = 5},
  [788] = {.lex_state = 182, .external_lex_state = 7},
  [789] = {.lex_state = 182, .external_lex_state = 5},
  [790] = {.lex_state = 181, .external_lex_state = 7},
  [791] = {.lex_state = 181, .external_lex_state = 7},
  [792] = {.lex_state = 182, .external_lex_state = 5},
  [793] = {.lex_state = 181, .external_lex_state = 7},
  [794] = {.lex_state = 3, .external_lex_state = 7},
  [795] = {.lex_state = 182, .external_lex_state = 5},
  [796] = {.lex_state = 182, .external_lex_state = 7},
  [797] = {.lex_state = 182, .external_lex_state = 5},
  [798] = {.lex_state = 182, .external_lex_state = 5},
  [799] = {.lex_state = 182, .external_lex_state = 7},
  [800] = {.lex_state = 181, .external_lex_state = 7},
  [801] = {.lex_state = 0, .external_lex_state = 5},
  [802] = {.lex_state = 182, .external_lex_state = 5},
  [803] = {.lex_state = 182, .external_lex_state = 5},
  [804] = {.lex_state = 182, .external_lex_state = 5},
  [805] = {.lex_state = 6, .external_lex_state = 8},
  [806] = {.lex_state = 0, .external_lex_state = 8},
  [807] = {.lex_state = 180, .external_lex_state = 7},
  [808] = {.lex_state = 0, .external_lex_state = 5},
  [809] = {.lex_state = 0, .external_lex_state = 5},
  [810] = {.lex_state = 180, .external_lex_state = 5},
  [811] = {.lex_state = 180, .external_lex_state = 7},
  [812] = {.lex_state = 181, .external_lex_state = 7},
  [813] = {.lex_state = 6, .external_lex_state = 8},
  [814] = {.lex_state = 6, .external_lex_state = 8},
  [815] = {.lex_state = 180, .external_lex_state = 7},
  [816] = {.lex_state = 180, .external_lex_state = 7},
  [817] = {.lex_state = 6, .external_lex_state = 8},
  [818] = {.lex_state = 6, .external_lex_state = 8},
  [819] = {.lex_state = 6, .external_lex_state = 8},
  [820] = {.lex_state = 6, .external_lex_state = 8},
  [821] = {.lex_state = 6, .external_lex_state = 8},
  [822] = {.lex_state = 6, .external_lex_state = 8},
  [823] = {.lex_state = 0, .external_lex_state = 5},
  [824] = {.lex_state = 0, .external_lex_state = 8},
  [825] = {.lex_state = 6, .external_lex_state = 8},
  [826] = {.lex_state = 6, .external_lex_state = 8},
  [827] = {.lex_state = 180, .external_lex_state = 7},
  [828] = {.lex_state = 6, .external_lex_state = 8},
  [829] = {.lex_state = 180, .external_lex_state = 5},
  [830] = {.lex_state = 0, .external_lex_state = 8},
  [831] = {.lex_state = 0, .external_lex_state = 8},
  [832] = {.lex_state = 180, .external_lex_state = 7},
  [833] = {.lex_state = 180, .external_lex_state = 7},
  [834] = {.lex_state = 181, .external_lex_state = 7},
  [835] = {.lex_state = 6, .external_lex_state = 8},
  [836] = {.lex_state = 180, .external_lex_state = 7},
  [837] = {.lex_state = 6, .external_lex_state = 8},
  [838] = {.lex_state = 2, .external_lex_state = 5},
  [839] = {.lex_state = 0, .external_lex_state = 5},
  [840] = {.lex_state = 6, .external_lex_state = 8},
  [841] = {.lex_state = 6, .external_lex_state = 8},
  [842] = {.lex_state = 6, .external_lex_state = 8},
  [843] = {.lex_state = 6, .external_lex_state = 8},
  [844] = {.lex_state = 6, .external_lex_state = 8},
  [845] = {.lex_state = 6, .external_lex_state = 8},
  [846] = {.lex_state = 6, .external_lex_state = 8},
  [847] = {.lex_state = 0, .external_lex_state = 5},
  [848] = {.lex_state = 181, .external_lex_state = 7},
  [849] = {.lex_state = 6, .external_lex_state = 8},
  [850] = {.lex_state = 6, .external_lex_state = 8},
  [851] = {.lex_state = 6, .external_lex_state = 8},
  [852] = {.lex_state = 181, .external_lex_state = 7},
  [853] = {.lex_state = 181, .external_lex_state = 7},
  [854] = {.lex_state = 6, .external_lex_state = 8},
  [855] = {.lex_state = 6, .external_lex_state = 8},
  [856] = {.lex_state = 0, .external_lex_state = 5},
  [857] = {.lex_state = 181, .external_lex_state = 7},
  [858] = {.lex_state = 6, .external_lex_state = 8},
  [859] = {.lex_state = 6, .external_lex_state = 8},
  [860] = {.lex_state = 6, .external_lex_state = 8},
  [861] = {.lex_state = 181, .external_lex_state = 7},
  [862] = {.lex_state = 6, .external_lex_state = 8},
  [863] = {.lex_state = 181, .external_lex_state = 7},
  [864] = {.lex_state = 181, .external_lex_state = 7},
  [865] = {.lex_state = 181, .external_lex_state = 7},
  [866] = {.lex_state = 181, .external_lex_state = 7},
  [867] = {.lex_state = 6, .external_lex_state = 8},
  [868] = {.lex_state = 0, .external_lex_state = 5},
  [869] = {.lex_state = 0, .external_lex_state = 5},
  [870] = {.lex_state = 0, .external_lex_state = 5},
  [871] = {.lex_state = 180, .external_lex_state = 5},
  [872] = {.lex_state = 181, .external_lex_state = 7},
  [873] = {.lex_state = 181, .external_lex_state = 7},
  [874] = {.lex_state = 181, .external_lex_state = 7},
  [875] = {.lex_state = 181, .external_lex_state = 7},
  [876] = {.lex_state = 180, .external_lex_state = 7},
  [877] = {.lex_state = 182, .external_lex_state = 7},
  [878] = {.lex_state = 180, .external_lex_state = 5},
  [879] = {.lex_state = 0, .external_lex_state = 5},
  [880] = {.lex_state = 180, .external_lex_state = 5},
  [881] = {.lex_state = 180, .external_lex_state = 5},
  [882] = {.lex_state = 180, .external_lex_state = 5},
  [883] = {.lex_state = 180, .external_lex_state = 5},
  [884] = {.lex_state = 0, .external_lex_state = 5},
  [885] = {.lex_state = 0, .external_lex_state = 5},
  [886] = {.lex_state = 180, .external_lex_state = 5},
  [887] = {.lex_state = 180, .external_lex_state = 5},
  [888] = {.lex_state = 0, .external_lex_state = 5},
  [889] = {.lex_state = 180, .external_lex_state = 5},
  [890] = {.lex_state = 182, .external_lex_state = 7},
  [891] = {.lex_state = 0, .external_lex_state = 5},
  [892] = {.lex_state = 180, .external_lex_state = 5},
  [893] = {.lex_state = 180, .external_lex_state = 5},
  [894] = {.lex_state = 182, .external_lex_state = 7},
  [895] = {.lex_state = 180, .external_lex_state = 5},
  [896] = {.lex_state = 180, .external_lex_state = 5},
  [897] = {.lex_state = 180, .external_lex_state = 5},
  [898] = {.lex_state = 180, .external_lex_state = 5},
  [899] = {.lex_state = 180, .external_lex_state = 5},
  [900] = {.lex_state = 180, .external_lex_state = 5},
  [901] = {.lex_state = 180, .external_lex_state = 5},
  [902] = {.lex_state = 180, .external_lex_state = 5},
  [903] = {.lex_state = 180, .external_lex_state = 5},
  [904] = {.lex_state = 180, .external_lex_state = 5},
  [905] = {.lex_state = 0, .external_lex_state = 7},
  [906] = {.lex_state = 180, .external_lex_state = 5},
  [907] = {.lex_state = 180, .external_lex_state = 5},
  [908] = {.lex_state = 0, .external_lex_state = 7},
  [909] = {.lex_state = 180, .external_lex_state = 5},
  [910] = {.lex_state = 182, .external_lex_state = 7},
  [911] = {.lex_state = 181, .external_lex_state = 7},
  [912] = {.lex_state = 180, .external_lex_state = 5},
  [913] = {.lex_state = 2, .external_lex_state = 5},
  [914] = {.lex_state = 181, .external_lex_state = 7},
  [915] = {.lex_state = 0, .external_lex_state = 7},
  [916] = {.lex_state = 181, .external_lex_state = 7},
  [917] = {.lex_state = 180, .external_lex_state = 5},
  [918] = {.lex_state = 180, .external_lex_state = 5},
  [919] = {.lex_state = 180, .external_lex_state = 5},
  [920] = {.lex_state = 0, .external_lex_state = 7},
  [921] = {.lex_state = 0, .external_lex_state = 7},
  [922] = {.lex_state = 181, .external_lex_state = 7},
  [923] = {.lex_state = 180, .external_lex_state = 5},
  [924] = {.lex_state = 181, .external_lex_state = 7},
  [925] = {.lex_state = 181, .external_lex_state = 7},
  [926] = {.lex_state = 182, .external_lex_state = 5},
  [927] = {.lex_state = 180, .external_lex_state = 5},
  [928] = {.lex_state = 180, .external_lex_state = 5},
  [929] = {.lex_state = 180, .external_lex_state = 5},
  [930] = {.lex_state = 180, .external_lex_state = 5},
  [931] = {.lex_state = 182, .external_lex_state = 5},
  [932] = {.lex_state = 182, .external_lex_state = 5},
  [933] = {.lex_state = 180, .external_lex_state = 5},
  [934] = {.lex_state = 180, .external_lex_state = 9},
  [935] = {.lex_state = 181, .external_lex_state = 7},
  [936] = {.lex_state = 182, .external_lex_state = 5},
  [937] = {.lex_state = 182, .external_lex_state = 5},
  [938] = {.lex_state = 181, .external_lex_state = 7},
  [939] = {.lex_state = 180, .external_lex_state = 5},
  [940] = {.lex_state = 180, .external_lex_state = 5},
  [941] = {.lex_state = 180, .external_lex_state = 9},
  [942] = {.lex_state = 180, .external_lex_state = 5},
  [943] = {.lex_state = 180, .external_lex_state = 5},
  [944] = {.lex_state = 180, .external_lex_state = 5},
  [945] = {.lex_state = 181, .external_lex_state = 7},
  [946] = {.lex_state = 180, .external_lex_state = 5},
  [947] = {.lex_state = 180, .external_lex_state = 5},
  [948] = {.lex_state = 180, .external_lex_state = 9},
  [949] = {.lex_state = 181, .external_lex_state = 7},
  [950] = {.lex_state = 182, .external_lex_state = 5},
  [951] = {.lex_state = 180, .external_lex_state = 5},
  [952] = {.lex_state = 180, .external_lex_state = 5},
  [953] = {.lex_state = 181, .external_lex_state = 7},
  [954] = {.lex_state = 180, .external_lex_state = 5},
  [955] = {.lex_state = 180, .external_lex_state = 5},
  [956] = {.lex_state = 180, .external_lex_state = 5},
  [957] = {.lex_state = 180, .external_lex_state = 5},
  [958] = {.lex_state = 182, .external_lex_state = 5},
  [959] = {.lex_state = 181, .external_lex_state = 7},
  [960] = {.lex_state = 180, .external_lex_state = 5},
  [961] = {.lex_state = 180, .external_lex_state = 5},
  [962] = {.lex_state = 180, .external_lex_state = 5},
  [963] = {.lex_state = 182, .external_lex_state = 5},
  [964] = {.lex_state = 180, .external_lex_state = 5},
  [965] = {.lex_state = 181, .external_lex_state = 7},
  [966] = {.lex_state = 8, .external_lex_state = 6},
  [967] = {.lex_state = 181, .external_lex_state = 7},
  [968] = {.lex_state = 8, .external_lex_state = 6},
  [969] = {.lex_state = 180, .external_lex_state = 5},
  [970] = {.lex_state = 180, .external_lex_state = 5},
  [971] = {.lex_state = 181, .external_lex_state = 7},
  [972] = {.lex_state = 182, .external_lex_state = 5},
  [973] = {.lex_state = 181, .external_lex_state = 7},
  [974] = {.lex_state = 181, .external_lex_state = 7},
  [975] = {.lex_state = 181, .external_lex_state = 7},
  [976] = {.lex_state = 182, .external_lex_state = 5},
  [977] = {.lex_state = 180, .external_lex_state = 5},
  [978] = {.lex_state = 182, .external_lex_state = 5},
  [979] = {.lex_state = 0, .external_lex_state = 7},
  [980] = {.lex_state = 181, .external_lex_state = 7},
  [981] = {.lex_state = 182, .external_lex_state = 5},
  [982] = {.lex_state = 180, .external_lex_state = 5},
  [983] = {.lex_state = 8, .external_lex_state = 6},
  [984] = {.lex_state = 180, .external_lex_state = 5},
  [985] = {.lex_state = 180, .external_lex_state = 5},
  [986] = {.lex_state = 181, .external_lex_state = 7},
  [987] = {.lex_state = 181, .external_lex_state = 7},
  [988] = {.lex_state = 180, .external_lex_state = 5},
  [989] = {.lex_state = 181, .external_lex_state = 7},
  [990] = {.lex_state = 8, .external_lex_state = 6},
  [991] = {.lex_state = 180, .external_lex_state = 5},
  [992] = {.lex_state = 181, .external_lex_state = 7},
  [993] = {.lex_state = 180, .external_lex_state = 5},
  [994] = {.lex_state = 8, .external_lex_state = 6},
  [995] = {.lex_state = 182, .external_lex_state = 5},
  [996] = {.lex_state = 181, .external_lex_state = 7},
  [997] = {.lex_state = 181, .external_lex_state = 7},
  [998] = {.lex_state = 181, .external_lex_state = 7},
  [999] = {.lex_state = 182, .external_lex_state = 5},
  [1000] = {.lex_state = 181, .external_lex_state = 7},
  [1001] = {.lex_state = 181, .external_lex_state = 7},
  [1002] = {.lex_state = 181, .external_lex_state = 7},
  [1003] = {.lex_state = 181, .external_lex_state = 7},
  [1004] = {.lex_state = 182, .external_lex_state = 5},
  [1005] = {.lex_state = 180, .external_lex_state = 5},
  [1006] = {.lex_state = 180, .external_lex_state = 5},
  [1007] = {.lex_state = 181, .external_lex_state = 7},
  [1008] = {.lex_state = 182, .external_lex_state = 5},
  [1009] = {.lex_state = 182, .external_lex_state = 5},
  [1010] = {.lex_state = 182, .external_lex_state = 5},
  [1011] = {.lex_state = 182, .external_lex_state = 5},
  [1012] = {.lex_state = 181, .external_lex_state = 7},
  [1013] = {.lex_state = 181, .external_lex_state = 7},
  [1014] = {.lex_state = 181, .external_lex_state = 7},
  [1015] = {.lex_state = 181, .external_lex_state = 7},
  [1016] = {.lex_state = 181, .external_lex_state = 7},
  [1017] = {.lex_state = 181, .external_lex_state = 7},
  [1018] = {.lex_state = 181, .external_lex_state = 7},
  [1019] = {.lex_state = 0, .external_lex_state = 10},
  [1020] = {.lex_state = 180, .external_lex_state = 5},
  [1021] = {.lex_state = 180, .external_lex_state = 5},
  [1022] = {.lex_state = 181, .external_lex_state = 7},
  [1023] = {.lex_state = 180, .external_lex_state = 5},
  [1024] = {.lex_state = 181, .external_lex_state = 7},
  [1025] = {.lex_state = 0, .external_lex_state = 11},
  [1026] = {.lex_state = 181, .external_lex_state = 7},
  [1027] = {.lex_state = 181, .external_lex_state = 7},
  [1028] = {.lex_state = 180, .external_lex_state = 5},
  [1029] = {.lex_state = 180, .external_lex_state = 5},
  [1030] = {.lex_state = 181, .external_lex_state = 7},
  [1031] = {.lex_state = 180, .external_lex_state = 5},
  [1032] = {.lex_state = 180, .external_lex_state = 5},
  [1033] = {.lex_state = 180, .external_lex_state = 5},
  [1034] = {.lex_state = 181, .external_lex_state = 7},
  [1035] = {.lex_state = 181, .external_lex_state = 7},
  [1036] = {.lex_state = 0, .external_lex_state = 5},
  [1037] = {.lex_state = 0, .external_lex_state = 10},
  [1038] = {.lex_state = 181, .external_lex_state = 7},
  [1039] = {.lex_state = 181, .external_lex_state = 7},
  [1040] = {.lex_state = 180, .external_lex_state = 5},
  [1041] = {.lex_state = 180, .external_lex_state = 5},
  [1042] = {.lex_state = 0, .external_lex_state = 10},
  [1043] = {.lex_state = 180, .external_lex_state = 5},
  [1044] = {.lex_state = 0, .external_lex_state = 11},
  [1045] = {.lex_state = 180, .external_lex_state = 5},
  [1046] = {.lex_state = 180, .external_lex_state = 5},
  [1047] = {.lex_state = 0, .external_lex_state = 11},
  [1048] = {.lex_state = 0, .external_lex_state = 10},
  [1049] = {.lex_state = 181, .external_lex_state = 7},
  [1050] = {.lex_state = 180, .external_lex_state = 5},
  [1051] = {.lex_state = 181, .external_lex_state = 7},
  [1052] = {.lex_state = 181, .external_lex_state = 7},
  [1053] = {.lex_state = 182, .external_lex_state = 5},
  [1054] = {.lex_state = 0, .external_lex_state = 11},
  [1055] = {.lex_state = 181, .external_lex_state = 7},
  [1056] = {.lex_state = 180, .external_lex_state = 5},
  [1057] = {.lex_state = 180, .external_lex_state = 5},
  [1058] = {.lex_state = 0, .external_lex_state = 10},
  [1059] = {.lex_state = 0, .external_lex_state = 11},
  [1060] = {.lex_state = 180, .external_lex_state = 5},
  [1061] = {.lex_state = 180, .external_lex_state = 5},
  [1062] = {.lex_state = 181, .external_lex_state = 7},
  [1063] = {.lex_state = 180, .external_lex_state = 5},
  [1064] = {.lex_state = 181, .external_lex_state = 7},
  [1065] = {.lex_state = 180, .external_lex_state = 5},
  [1066] = {.lex_state = 181, .external_lex_state = 7},
  [1067] = {.lex_state = 181, .external_lex_state = 7},
  [1068] = {.lex_state = 180, .external_lex_state = 5},
  [1069] = {.lex_state = 181, .external_lex_state = 7},
  [1070] = {.lex_state = 0, .external_lex_state = 10},
  [1071] = {.lex_state = 0, .external_lex_state = 11},
  [1072] = {.lex_state = 181, .external_lex_state = 7},
  [1073] = {.lex_state = 180, .external_lex_state = 5},
  [1074] = {.lex_state = 181, .external_lex_state = 7},
  [1075] = {.lex_state = 180, .external_lex_state = 5},
  [1076] = {.lex_state = 0, .external_lex_state = 10},
  [1077] = {.lex_state = 0, .external_lex_state = 11},
  [1078] = {.lex_state = 181, .external_lex_state = 7},
  [1079] = {.lex_state = 0, .external_lex_state = 10},
  [1080] = {.lex_state = 0, .external_lex_state = 11},
  [1081] = {.lex_state = 181, .external_lex_state = 7},
  [1082] = {.lex_state = 8, .external_lex_state = 6},
  [1083] = {.lex_state = 0, .external_lex_state = 10},
  [1084] = {.lex_state = 0, .external_lex_state = 11},
  [1085] = {.lex_state = 8, .external_lex_state = 5},
  [1086] = {.lex_state = 180, .external_lex_state = 5},
  [1087] = {.lex_state = 181, .external_lex_state = 7},
  [1088] = {.lex_state = 181, .external_lex_state = 7},
  [1089] = {.lex_state = 181, .external_lex_state = 7},
  [1090] = {.lex_state = 181, .external_lex_state = 7},
  [1091] = {.lex_state = 181, .external_lex_state = 7},
  [1092] = {.lex_state = 181, .external_lex_state = 7},
  [1093] = {.lex_state = 181, .external_lex_state = 7},
  [1094] = {.lex_state = 181, .external_lex_state = 7},
  [1095] = {.lex_state = 181, .external_lex_state = 7},
  [1096] = {.lex_state = 181, .external_lex_state = 7},
  [1097] = {.lex_state = 180, .external_lex_state = 5},
  [1098] = {.lex_state = 180, .external_lex_state = 5},
  [1099] = {.lex_state = 180, .external_lex_state = 5},
  [1100] = {.lex_state = 180, .external_lex_state = 5},
  [1101] = {.lex_state = 180, .external_lex_state = 5},
  [1102] = {.lex_state = 182, .external_lex_state = 5},
  [1103] = {.lex_state = 180, .external_lex_state = 5},
  [1104] = {.lex_state = 180, .external_lex_state = 5},
  [1105] = {.lex_state = 180, .external_lex_state = 5},
  [1106] = {.lex_state = 181, .external_lex_state = 7},
  [1107] = {.lex_state = 181, .external_lex_state = 7},
  [1108] = {.lex_state = 180, .external_lex_state = 5},
  [1109] = {.lex_state = 180, .external_lex_state = 5},
  [1110] = {.lex_state = 180, .external_lex_state = 5},
  [1111] = {.lex_state = 180, .external_lex_state = 5},
  [1112] = {.lex_state = 180, .external_lex_state = 5},
  [1113] = {.lex_state = 0, .external_lex_state = 5},
  [1114] = {.lex_state = 180, .external_lex_state = 5},
  [1115] = {.lex_state = 180, .external_lex_state = 5},
  [1116] = {.lex_state = 180, .external_lex_state = 5},
  [1117] = {.lex_state = 180, .external_lex_state = 5},
  [1118] = {.lex_state = 180, .external_lex_state = 5},
  [1119] = {.lex_state = 180, .external_lex_state = 5},
  [1120] = {.lex_state = 0, .external_lex_state = 5},
  [1121] = {.lex_state = 180, .external_lex_state = 5},
  [1122] = {.lex_state = 0, .external_lex_state = 5},
  [1123] = {.lex_state = 180, .external_lex_state = 5},
  [1124] = {.lex_state = 180, .external_lex_state = 5},
  [1125] = {.lex_state = 180, .external_lex_state = 5},
  [1126] = {.lex_state = 180, .external_lex_state = 5},
  [1127] = {.lex_state = 0, .external_lex_state = 5},
  [1128] = {.lex_state = 0, .external_lex_state = 5},
  [1129] = {.lex_state = 0, .external_lex_state = 5},
  [1130] = {.lex_state = 180, .external_lex_state = 5},
  [1131] = {.lex_state = 8, .external_lex_state = 5},
  [1132] = {.lex_state = 180, .external_lex_state = 5},
  [1133] = {.lex_state = 8, .external_lex_state = 5},
  [1134] = {.lex_state = 180, .external_lex_state = 5},
  [1135] = {.lex_state = 0, .external_lex_state = 5},
  [1136] = {.lex_state = 0, .external_lex_state = 5},
  [1137] = {.lex_state = 8, .external_lex_state = 5},
  [1138] = {.lex_state = 8, .external_lex_state = 5},
  [1139] = {.lex_state = 8, .external_lex_state = 5},
  [1140] = {.lex_state = 8, .external_lex_state = 5},
  [1141] = {.lex_state = 8, .external_lex_state = 5},
  [1142] = {.lex_state = 8, .external_lex_state = 5},
  [1143] = {.lex_state = 180, .external_lex_state = 5},
  [1144] = {.lex_state = 0, .external_lex_state = 5},
  [1145] = {.lex_state = 8, .external_lex_state = 5},
  [1146] = {.lex_state = 8, .external_lex_state = 5},
  [1147] = {.lex_state = 0, .external_lex_state = 5},
  [1148] = {.lex_state = 8, .external_lex_state = 5},
  [1149] = {.lex_state = 180, .external_lex_state = 5},
  [1150] = {.lex_state = 8, .external_lex_state = 5},
  [1151] = {.lex_state = 180, .external_lex_state = 5},
  [1152] = {.lex_state = 0, .external_lex_state = 5},
  [1153] = {.lex_state = 180, .external_lex_state = 5},
  [1154] = {.lex_state = 180, .external_lex_state = 5},
  [1155] = {.lex_state = 0, .external_lex_state = 5},
  [1156] = {.lex_state = 180, .external_lex_state = 5},
  [1157] = {.lex_state = 180, .external_lex_state = 5},
  [1158] = {.lex_state = 180, .external_lex_state = 5},
  [1159] = {.lex_state = 180, .external_lex_state = 5},
  [1160] = {.lex_state = 0, .external_lex_state = 5},
  [1161] = {.lex_state = 180, .external_lex_state = 5},
  [1162] = {.lex_state = 180, .external_lex_state = 5},
  [1163] = {.lex_state = 180, .external_lex_state = 5},
  [1164] = {.lex_state = 180, .external_lex_state = 5},
  [1165] = {.lex_state = 180, .external_lex_state = 5},
  [1166] = {.lex_state = 0, .external_lex_state = 5},
  [1167] = {.lex_state = 180, .external_lex_state = 5},
  [1168] = {.lex_state = 0, .external_lex_state = 5},
  [1169] = {.lex_state = 180, .external_lex_state = 5},
  [1170] = {.lex_state = 0, .external_lex_state = 5},
  [1171] = {.lex_state = 181, .external_lex_state = 7},
  [1172] = {.lex_state = 180, .external_lex_state = 5},
  [1173] = {.lex_state = 180, .external_lex_state = 5},
  [1174] = {.lex_state = 0, .external_lex_state = 5},
  [1175] = {.lex_state = 8, .external_lex_state = 5},
  [1176] = {.lex_state = 180, .external_lex_state = 5},
  [1177] = {.lex_state = 180, .external_lex_state = 5},
  [1178] = {.lex_state = 8, .external_lex_state = 5},
  [1179] = {.lex_state = 0, .external_lex_state = 5},
  [1180] = {.lex_state = 8, .external_lex_state = 5},
  [1181] = {.lex_state = 180, .external_lex_state = 5},
  [1182] = {.lex_state = 0, .external_lex_state = 5},
  [1183] = {.lex_state = 8, .external_lex_state = 5},
  [1184] = {.lex_state = 8, .external_lex_state = 5},
  [1185] = {.lex_state = 8, .external_lex_state = 5},
  [1186] = {.lex_state = 8, .external_lex_state = 5},
  [1187] = {.lex_state = 8, .external_lex_state = 5},
  [1188] = {.lex_state = 0, .external_lex_state = 5},
  [1189] = {.lex_state = 180, .external_lex_state = 5},
  [1190] = {.lex_state = 0, .external_lex_state = 5},
  [1191] = {.lex_state = 180, .external_lex_state = 5},
  [1192] = {.lex_state = 180, .external_lex_state = 5},
  [1193] = {.lex_state = 180, .external_lex_state = 5},
  [1194] = {.lex_state = 0, .external_lex_state = 5},
  [1195] = {.lex_state = 180, .external_lex_state = 5},
  [1196] = {.lex_state = 0, .external_lex_state = 5},
  [1197] = {.lex_state = 0, .external_lex_state = 5},
  [1198] = {.lex_state = 180, .external_lex_state = 5},
  [1199] = {.lex_state = 0, .external_lex_state = 5},
  [1200] = {.lex_state = 0, .external_lex_state = 5},
  [1201] = {.lex_state = 0, .external_lex_state = 5},
  [1202] = {.lex_state = 8, .external_lex_state = 5},
  [1203] = {.lex_state = 0, .external_lex_state = 5},
  [1204] = {.lex_state = 8, .external_lex_state = 5},
  [1205] = {.lex_state = 8, .external_lex_state = 5},
  [1206] = {.lex_state = 0, .external_lex_state = 5},
  [1207] = {.lex_state = 8, .external_lex_state = 5},
  [1208] = {.lex_state = 180, .external_lex_state = 5},
  [1209] = {.lex_state = 180, .external_lex_state = 5},
  [1210] = {.lex_state = 8, .external_lex_state = 5},
  [1211] = {.lex_state = 8, .external_lex_state = 5},
  [1212] = {.lex_state = 8, .external_lex_state = 5},
  [1213] = {.lex_state = 8, .external_lex_state = 5},
  [1214] = {.lex_state = 8, .external_lex_state = 5},
  [1215] = {.lex_state = 8, .external_lex_state = 5},
  [1216] = {.lex_state = 0, .external_lex_state = 5},
  [1217] = {.lex_state = 0, .external_lex_state = 5},
  [1218] = {.lex_state = 0, .external_lex_state = 5},
  [1219] = {.lex_state = 180, .external_lex_state = 5},
  [1220] = {.lex_state = 0, .external_lex_state = 5},
  [1221] = {.lex_state = 180, .external_lex_state = 5},
  [1222] = {.lex_state = 8, .external_lex_state = 5},
  [1223] = {.lex_state = 0, .external_lex_state = 5},
  [1224] = {.lex_state = 0, .external_lex_state = 5},
  [1225] = {.lex_state = 180, .external_lex_state = 5},
  [1226] = {.lex_state = 0, .external_lex_state = 5},
  [1227] = {.lex_state = 180, .external_lex_state = 5},
  [1228] = {.lex_state = 0, .external_lex_state = 5},
  [1229] = {.lex_state = 181, .external_lex_state = 7},
  [1230] = {.lex_state = 180, .external_lex_state = 5},
  [1231] = {.lex_state = 0, .external_lex_state = 5},
  [1232] = {.lex_state = 180, .external_lex_state = 5},
  [1233] = {.lex_state = 0, .external_lex_state = 5},
  [1234] = {.lex_state = 180, .external_lex_state = 5},
  [1235] = {.lex_state = 180, .external_lex_state = 5},
  [1236] = {.lex_state = 180, .external_lex_state = 5},
  [1237] = {.lex_state = 181, .external_lex_state = 5},
  [1238] = {.lex_state = 180, .external_lex_state = 5},
  [1239] = {.lex_state = 0, .external_lex_state = 5},
  [1240] = {.lex_state = 8, .external_lex_state = 5},
  [1241] = {.lex_state = 180, .external_lex_state = 5},
  [1242] = {.lex_state = 180, .external_lex_state = 5},
  [1243] = {.lex_state = 180, .external_lex_state = 5},
  [1244] = {.lex_state = 181, .external_lex_state = 5},
  [1245] = {.lex_state = 0, .external_lex_state = 5},
  [1246] = {.lex_state = 180, .external_lex_state = 5},
  [1247] = {.lex_state = 180, .external_lex_state = 5},
  [1248] = {.lex_state = 180, .external_lex_state = 5},
  [1249] = {.lex_state = 180, .external_lex_state = 5},
  [1250] = {.lex_state = 180, .external_lex_state = 5},
  [1251] = {.lex_state = 0, .external_lex_state = 5},
  [1252] = {.lex_state = 180, .external_lex_state = 5},
  [1253] = {.lex_state = 180, .external_lex_state = 5},
  [1254] = {.lex_state = 8, .external_lex_state = 5},
  [1255] = {.lex_state = 0, .external_lex_state = 5},
  [1256] = {.lex_state = 0, .external_lex_state = 5},
  [1257] = {.lex_state = 0, .external_lex_state = 5},
  [1258] = {.lex_state = 0, .external_lex_state = 5},
  [1259] = {.lex_state = 0, .external_lex_state = 5},
  [1260] = {.lex_state = 182, .external_lex_state = 5},
  [1261] = {.lex_state = 0, .external_lex_state = 5},
  [1262] = {.lex_state = 182, .external_lex_state = 5},
  [1263] = {.lex_state = 0, .external_lex_state = 5},
  [1264] = {.lex_state = 0, .external_lex_state = 5},
  [1265] = {.lex_state = 182, .external_lex_state = 5},
  [1266] = {.lex_state = 0, .external_lex_state = 5},
  [1267] = {.lex_state = 182, .external_lex_state = 5},
  [1268] = {.lex_state = 0, .external_lex_state = 5},
  [1269] = {.lex_state = 0, .external_lex_state = 5},
  [1270] = {.lex_state = 0, .external_lex_state = 5},
  [1271] = {.lex_state = 0, .external_lex_state = 5},
  [1272] = {.lex_state = 0, .external_lex_state = 5},
  [1273] = {.lex_state = 0, .external_lex_state = 5},
  [1274] = {.lex_state = 0, .external_lex_state = 5},
  [1275] = {.lex_state = 0, .external_lex_state = 5},
  [1276] = {.lex_state = 0, .external_lex_state = 5},
  [1277] = {.lex_state = 182, .external_lex_state = 5},
  [1278] = {.lex_state = 0, .external_lex_state = 5},
  [1279] = {.lex_state = 0, .external_lex_state = 5},
  [1280] = {.lex_state = 0, .external_lex_state = 5},
  [1281] = {.lex_state = 0, .external_lex_state = 5},
  [1282] = {.lex_state = 0, .external_lex_state = 5},
  [1283] = {.lex_state = 0, .external_lex_state = 5},
  [1284] = {.lex_state = 0, .external_lex_state = 5},
  [1285] = {.lex_state = 0, .external_lex_state = 5},
  [1286] = {.lex_state = 0, .external_lex_state = 5},
  [1287] = {.lex_state = 0, .external_lex_state = 5},
  [1288] = {.lex_state = 0, .external_lex_state = 5},
  [1289] = {.lex_state = 0, .external_lex_state = 5},
  [1290] = {.lex_state = 0, .external_lex_state = 5},
  [1291] = {.lex_state = 0, .external_lex_state = 5},
  [1292] = {.lex_state = 0, .external_lex_state = 5},
  [1293] = {.lex_state = 0, .external_lex_state = 5},
  [1294] = {.lex_state = 0, .external_lex_state = 5},
  [1295] = {.lex_state = 0, .external_lex_state = 5},
  [1296] = {.lex_state = 0, .external_lex_state = 5},
  [1297] = {.lex_state = 0, .external_lex_state = 5},
  [1298] = {.lex_state = 0, .external_lex_state = 5},
  [1299] = {.lex_state = 0, .external_lex_state = 5},
  [1300] = {.lex_state = 0, .external_lex_state = 5},
  [1301] = {.lex_state = 0, .external_lex_state = 5},
  [1302] = {.lex_state = 0, .external_lex_state = 5},
  [1303] = {.lex_state = 0, .external_lex_state = 5},
  [1304] = {.lex_state = 0, .external_lex_state = 5},
  [1305] = {.lex_state = 0, .external_lex_state = 5},
  [1306] = {.lex_state = 0, .external_lex_state = 5},
  [1307] = {.lex_state = 0, .external_lex_state = 5},
  [1308] = {.lex_state = 0, .external_lex_state = 5},
  [1309] = {.lex_state = 0, .external_lex_state = 5},
  [1310] = {.lex_state = 0, .external_lex_state = 5},
  [1311] = {.lex_state = 0, .external_lex_state = 5},
  [1312] = {.lex_state = 0, .external_lex_state = 5},
  [1313] = {.lex_state = 0, .external_lex_state = 5},
  [1314] = {.lex_state = 0, .external_lex_state = 5},
  [1315] = {.lex_state = 0, .external_lex_state = 5},
  [1316] = {.lex_state = 0, .external_lex_state = 5},
  [1317] = {.lex_state = 0, .external_lex_state = 5},
  [1318] = {.lex_state = 0, .external_lex_state = 5},
  [1319] = {.lex_state = 0, .external_lex_state = 5},
  [1320] = {.lex_state = 0, .external_lex_state = 5},
  [1321] = {.lex_state = 0, .external_lex_state = 5},
  [1322] = {.lex_state = 0, .external_lex_state = 5},
  [1323] = {.lex_state = 0, .external_lex_state = 5},
  [1324] = {.lex_state = 0, .external_lex_state = 5},
  [1325] = {.lex_state = 0, .external_lex_state = 5},
  [1326] = {.lex_state = 0, .external_lex_state = 5},
  [1327] = {.lex_state = 0, .external_lex_state = 5},
  [1328] = {.lex_state = 0, .external_lex_state = 5},
  [1329] = {.lex_state = 0, .external_lex_state = 5},
  [1330] = {.lex_state = 0, .external_lex_state = 5},
  [1331] = {.lex_state = 0, .external_lex_state = 5},
  [1332] = {.lex_state = 0, .external_lex_state = 5},
  [1333] = {.lex_state = 0, .external_lex_state = 5},
  [1334] = {.lex_state = 0, .external_lex_state = 5},
  [1335] = {.lex_state = 0, .external_lex_state = 5},
  [1336] = {.lex_state = 0, .external_lex_state = 5},
  [1337] = {.lex_state = 0, .external_lex_state = 5},
  [1338] = {.lex_state = 0, .external_lex_state = 5},
  [1339] = {.lex_state = 0, .external_lex_state = 5},
  [1340] = {.lex_state = 0, .external_lex_state = 5},
  [1341] = {.lex_state = 0, .external_lex_state = 5},
  [1342] = {.lex_state = 182, .external_lex_state = 5},
  [1343] = {.lex_state = 0, .external_lex_state = 5},
  [1344] = {.lex_state = 182, .external_lex_state = 5},
  [1345] = {.lex_state = 0, .external_lex_state = 5},
  [1346] = {.lex_state = 0, .external_lex_state = 5},
  [1347] = {.lex_state = 182, .external_lex_state = 5},
  [1348] = {.lex_state = 0, .external_lex_state = 5},
  [1349] = {.lex_state = 0, .external_lex_state = 5},
  [1350] = {.lex_state = 0, .external_lex_state = 5},
  [1351] = {.lex_state = 0, .external_lex_state = 5},
  [1352] = {.lex_state = 0, .external_lex_state = 5},
  [1353] = {.lex_state = 182, .external_lex_state = 5},
  [1354] = {.lex_state = 0, .external_lex_state = 5},
  [1355] = {.lex_state = 182, .external_lex_state = 5},
  [1356] = {.lex_state = 182, .external_lex_state = 5},
  [1357] = {.lex_state = 182, .external_lex_state = 5},
  [1358] = {.lex_state = 0, .external_lex_state = 5},
  [1359] = {.lex_state = 0, .external_lex_state = 5},
  [1360] = {.lex_state = 0, .external_lex_state = 5},
  [1361] = {.lex_state = 182, .external_lex_state = 5},
  [1362] = {.lex_state = 0, .external_lex_state = 5},
  [1363] = {.lex_state = 182, .external_lex_state = 5},
  [1364] = {.lex_state = 0, .external_lex_state = 5},
  [1365] = {.lex_state = 0, .external_lex_state = 5},
  [1366] = {.lex_state = 182, .external_lex_state = 5},
  [1367] = {.lex_state = 0, .external_lex_state = 5},
  [1368] = {.lex_state = 182, .external_lex_state = 5},
  [1369] = {.lex_state = 0, .external_lex_state = 5},
  [1370] = {.lex_state = 182, .external_lex_state = 5},
  [1371] = {.lex_state = 182, .external_lex_state = 5},
  [1372] = {.lex_state = 0, .external_lex_state = 5},
  [1373] = {.lex_state = 0, .external_lex_state = 5},
  [1374] = {.lex_state = 0, .external_lex_state = 5},
  [1375] = {.lex_state = 182, .external_lex_state = 5},
  [1376] = {.lex_state = 0, .external_lex_state = 5},
  [1377] = {.lex_state = 0, .external_lex_state = 5},
  [1378] = {.lex_state = 182, .external_lex_state = 5},
  [1379] = {.lex_state = 0, .external_lex_state = 5},
  [1380] = {.lex_state = 182, .external_lex_state = 5},
  [1381] = {.lex_state = 0, .external_lex_state = 5},
  [1382] = {.lex_state = 0, .external_lex_state = 5},
  [1383] = {.lex_state = 182, .external_lex_state = 5},
  [1384] = {.lex_state = 0, .external_lex_state = 5},
  [1385] = {.lex_state = 182, .external_lex_state = 5},
  [1386] = {.lex_state = 182, .external_lex_state = 5},
  [1387] = {.lex_state = 0, .external_lex_state = 5},
  [1388] = {.lex_state = 0, .external_lex_state = 5},
  [1389] = {.lex_state = 182, .external_lex_state = 5},
  [1390] = {.lex_state = 182, .external_lex_state = 5},
  [1391] = {.lex_state = 182, .external_lex_state = 5},
  [1392] = {.lex_state = 0, .external_lex_state = 5},
  [1393] = {.lex_state = 182, .external_lex_state = 5},
  [1394] = {.lex_state = 182, .external_lex_state = 5},
  [1395] = {.lex_state = 0, .external_lex_state = 5},
  [1396] = {.lex_state = 182, .external_lex_state = 5},
  [1397] = {.lex_state = 0, .external_lex_state = 5},
  [1398] = {.lex_state = 182, .external_lex_state = 5},
  [1399] = {.lex_state = 0, .external_lex_state = 5},
  [1400] = {.lex_state = 0, .external_lex_state = 5},
  [1401] = {.lex_state = 0, .external_lex_state = 5},
  [1402] = {.lex_state = 182, .external_lex_state = 5},
  [1403] = {.lex_state = 0, .external_lex_state = 5},
  [1404] = {.lex_state = 0, .external_lex_state = 5},
  [1405] = {.lex_state = 0, .external_lex_state = 5},
  [1406] = {.lex_state = 182, .external_lex_state = 5},
  [1407] = {.lex_state = 0, .external_lex_state = 5},
  [1408] = {.lex_state = 182, .external_lex_state = 5},
  [1409] = {.lex_state = 0, .external_lex_state = 5},
  [1410] = {.lex_state = 0, .external_lex_state = 5},
  [1411] = {.lex_state = 0, .external_lex_state = 5},
  [1412] = {.lex_state = 0, .external_lex_state = 5},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_get] = ACTIONS(1),
    [anon_sym_set] = ACTIONS(1),
    [anon_sym_properties] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DOT_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_DOT_DASH] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_DOT_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_DOT_SLASH] = ACTIONS(1),
    [anon_sym_BSLASH] = ACTIONS(1),
    [anon_sym_DOT_BSLASH] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_DOT_CARET] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_TILDE_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_DOT_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [sym_return_statement] = ACTIONS(1),
    [sym_continue_statement] = ACTIONS(1),
    [sym_break_statement] = ACTIONS(1),
    [anon_sym_elseif] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_parfor] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_otherwise] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_persistent] = ACTIONS(1),
    [anon_sym_DOT_QMARK] = ACTIONS(1),
    [anon_sym_arguments] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_get_DOT] = ACTIONS(1),
    [anon_sym_set_DOT] = ACTIONS(1),
    [anon_sym_endfunction] = ACTIONS(1),
    [anon_sym_vector] = ACTIONS(1),
    [anon_sym_matrix] = ACTIONS(1),
    [anon_sym_scalar] = ACTIONS(1),
    [anon_sym_methods] = ACTIONS(1),
    [anon_sym_events] = ACTIONS(1),
    [anon_sym_enumeration] = ACTIONS(1),
    [anon_sym_classdef] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_spmd] = ACTIONS(1),
    [sym_number] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(1),
    [sym_command_argument] = ACTIONS(1),
    [sym__single_quote_string_start] = ACTIONS(1),
    [sym__single_quote_string_end] = ACTIONS(1),
    [sym__double_quote_string_start] = ACTIONS(1),
    [sym__double_quote_string_end] = ACTIONS(1),
    [sym_formatting_sequence] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [sym_string_content] = ACTIONS(1),
    [sym__entry_delimiter] = ACTIONS(1),
    [sym__multioutput_variable_start] = ACTIONS(1),
    [sym__external_identifier] = ACTIONS(1),
    [sym_error_sentinel] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(1377),
    [aux_sym__block] = STATE(81),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1033),
    [sym__expression] = STATE(751),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(751),
    [sym_handle_operator] = STATE(751),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1033),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1033),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(751),
    [sym_if_statement] = STATE(1033),
    [sym_for_statement] = STATE(1033),
    [sym_while_statement] = STATE(1033),
    [sym_switch_statement] = STATE(1033),
    [sym_lambda] = STATE(751),
    [sym_global_operator] = STATE(1033),
    [sym_persistent_operator] = STATE(1033),
    [sym_function_definition] = STATE(1239),
    [sym__function_definition_with_end] = STATE(1020),
    [sym_class_definition] = STATE(1033),
    [sym_try_statement] = STATE(1033),
    [sym_spmd_statement] = STATE(1033),
    [sym_boolean] = STATE(371),
    [aux_sym_source_file_repeat1] = STATE(1239),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(23),
    [sym_continue_statement] = ACTIONS(23),
    [sym_break_statement] = ACTIONS(23),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(39),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(2)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1366),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(23),
    [aux_sym_elseif_clause_repeat1] = STATE(23),
    [anon_sym_SEMI] = ACTIONS(59),
    [anon_sym_COMMA] = ACTIONS(59),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DOT_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_DOT_DASH] = ACTIONS(67),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_DOT_STAR] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(67),
    [anon_sym_DOT_SLASH] = ACTIONS(67),
    [anon_sym_BSLASH] = ACTIONS(67),
    [anon_sym_DOT_BSLASH] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_DOT_CARET] = ACTIONS(67),
    [anon_sym_PIPE] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [anon_sym_end] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LT] = ACTIONS(67),
    [anon_sym_LT_EQ] = ACTIONS(67),
    [anon_sym_EQ_EQ] = ACTIONS(67),
    [anon_sym_TILDE_EQ] = ACTIONS(67),
    [anon_sym_GT_EQ] = ACTIONS(67),
    [anon_sym_GT] = ACTIONS(67),
    [anon_sym_AMP_AMP] = ACTIONS(67),
    [anon_sym_PIPE_PIPE] = ACTIONS(67),
    [anon_sym_DOT_SQUOTE] = ACTIONS(67),
    [anon_sym_SQUOTE] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(59),
    [anon_sym_LBRACE] = ACTIONS(79),
    [anon_sym_COLON] = ACTIONS(67),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(59),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(3)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(972),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_elseif_clause] = STATE(978),
    [sym_else_clause] = STATE(1391),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(6),
    [aux_sym_elseif_clause_repeat1] = STATE(6),
    [aux_sym_if_statement_repeat1] = STATE(978),
    [anon_sym_SEMI] = ACTIONS(109),
    [anon_sym_COMMA] = ACTIONS(109),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(111),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LT] = ACTIONS(113),
    [anon_sym_LT_EQ] = ACTIONS(113),
    [anon_sym_EQ_EQ] = ACTIONS(113),
    [anon_sym_TILDE_EQ] = ACTIONS(113),
    [anon_sym_GT_EQ] = ACTIONS(113),
    [anon_sym_GT] = ACTIONS(113),
    [anon_sym_AMP_AMP] = ACTIONS(115),
    [anon_sym_PIPE_PIPE] = ACTIONS(117),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(109),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_elseif] = ACTIONS(119),
    [anon_sym_else] = ACTIONS(121),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(109),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(4)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1267),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(9),
    [aux_sym_elseif_clause_repeat1] = STATE(9),
    [anon_sym_SEMI] = ACTIONS(123),
    [anon_sym_COMMA] = ACTIONS(123),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(125),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LT] = ACTIONS(113),
    [anon_sym_LT_EQ] = ACTIONS(113),
    [anon_sym_EQ_EQ] = ACTIONS(113),
    [anon_sym_TILDE_EQ] = ACTIONS(113),
    [anon_sym_GT_EQ] = ACTIONS(113),
    [anon_sym_GT] = ACTIONS(113),
    [anon_sym_AMP_AMP] = ACTIONS(115),
    [anon_sym_PIPE_PIPE] = ACTIONS(117),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(123),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_elseif] = ACTIONS(125),
    [anon_sym_else] = ACTIONS(125),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(123),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(5)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1398),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(16),
    [aux_sym_elseif_clause_repeat1] = STATE(16),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(129),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LT] = ACTIONS(113),
    [anon_sym_LT_EQ] = ACTIONS(113),
    [anon_sym_EQ_EQ] = ACTIONS(113),
    [anon_sym_TILDE_EQ] = ACTIONS(113),
    [anon_sym_GT_EQ] = ACTIONS(113),
    [anon_sym_GT] = ACTIONS(113),
    [anon_sym_AMP_AMP] = ACTIONS(115),
    [anon_sym_PIPE_PIPE] = ACTIONS(117),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(127),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(127),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(6)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1010),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_elseif_clause] = STATE(1008),
    [sym_else_clause] = STATE(1385),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [aux_sym_if_statement_repeat1] = STATE(1008),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(133),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_elseif] = ACTIONS(119),
    [anon_sym_else] = ACTIONS(121),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(7)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1277),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_catch_clause] = STATE(1344),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(135),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_catch] = ACTIONS(137),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(8)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1262),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_catch_clause] = STATE(1383),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(7),
    [aux_sym_elseif_clause_repeat1] = STATE(7),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(141),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_catch] = ACTIONS(137),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(9)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1260),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_elseif] = ACTIONS(143),
    [anon_sym_else] = ACTIONS(143),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(10)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1265),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(145),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_case] = ACTIONS(145),
    [anon_sym_otherwise] = ACTIONS(145),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(11)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1356),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(15),
    [aux_sym_elseif_clause_repeat1] = STATE(15),
    [anon_sym_SEMI] = ACTIONS(147),
    [anon_sym_COMMA] = ACTIONS(147),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(149),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(147),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(147),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(12)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1393),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(13)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1363),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(20),
    [aux_sym_elseif_clause_repeat1] = STATE(20),
    [anon_sym_SEMI] = ACTIONS(153),
    [anon_sym_COMMA] = ACTIONS(153),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(153),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(153),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(14)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1357),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(12),
    [aux_sym_elseif_clause_repeat1] = STATE(12),
    [anon_sym_SEMI] = ACTIONS(157),
    [anon_sym_COMMA] = ACTIONS(157),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(159),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(161),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(157),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(157),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(15)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1408),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(163),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(16)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1378),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(165),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(17)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1396),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(26),
    [aux_sym_elseif_clause_repeat1] = STATE(26),
    [anon_sym_SEMI] = ACTIONS(167),
    [anon_sym_COMMA] = ACTIONS(167),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(169),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(167),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(167),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(18)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1353),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(171),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(19)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1370),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(22),
    [aux_sym_elseif_clause_repeat1] = STATE(22),
    [anon_sym_SEMI] = ACTIONS(173),
    [anon_sym_COMMA] = ACTIONS(173),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(175),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(173),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(173),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(20)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1371),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(177),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(21)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1347),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(22)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1366),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(69),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(23)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1386),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(181),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(24)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1406),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(27),
    [aux_sym_elseif_clause_repeat1] = STATE(27),
    [anon_sym_SEMI] = ACTIONS(183),
    [anon_sym_COMMA] = ACTIONS(183),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(183),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(183),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(25)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1402),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(28),
    [aux_sym_elseif_clause_repeat1] = STATE(28),
    [anon_sym_SEMI] = ACTIONS(187),
    [anon_sym_COMMA] = ACTIONS(187),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(189),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(187),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(187),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(26)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1342),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(191),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(27)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1380),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(193),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(28)] = {
    [aux_sym__block] = STATE(60),
    [sym_block] = STATE(1390),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [sym__end_of_line] = STATE(196),
    [aux_sym_elseif_clause_repeat1] = STATE(196),
    [anon_sym_SEMI] = ACTIONS(131),
    [anon_sym_COMMA] = ACTIONS(131),
    [anon_sym_get] = ACTIONS(61),
    [anon_sym_set] = ACTIONS(61),
    [anon_sym_properties] = ACTIONS(61),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_PLUS] = ACTIONS(65),
    [anon_sym_DASH] = ACTIONS(65),
    [anon_sym_end] = ACTIONS(195),
    [anon_sym_TILDE] = ACTIONS(71),
    [anon_sym_QMARK] = ACTIONS(73),
    [anon_sym_AT] = ACTIONS(75),
    [anon_sym_LBRACK] = ACTIONS(77),
    [anon_sym_LF] = ACTIONS(131),
    [anon_sym_LBRACE] = ACTIONS(79),
    [sym_return_statement] = ACTIONS(81),
    [sym_continue_statement] = ACTIONS(81),
    [sym_break_statement] = ACTIONS(81),
    [anon_sym_if] = ACTIONS(83),
    [anon_sym_for] = ACTIONS(85),
    [anon_sym_parfor] = ACTIONS(87),
    [anon_sym_while] = ACTIONS(89),
    [anon_sym_switch] = ACTIONS(91),
    [anon_sym_global] = ACTIONS(93),
    [anon_sym_persistent] = ACTIONS(95),
    [anon_sym_function] = ACTIONS(97),
    [anon_sym_classdef] = ACTIONS(99),
    [anon_sym_try] = ACTIONS(101),
    [anon_sym_spmd] = ACTIONS(103),
    [sym_number] = ACTIONS(105),
    [anon_sym_true] = ACTIONS(107),
    [anon_sym_false] = ACTIONS(107),
    [anon_sym_CR] = ACTIONS(131),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(29)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1228),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [ts_builtin_sym_end] = ACTIONS(197),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(199),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(207),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(30)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1206),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(38),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(38),
    [ts_builtin_sym_end] = ACTIONS(209),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(211),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(213),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(31)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1203),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(51),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(51),
    [ts_builtin_sym_end] = ACTIONS(215),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(217),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(219),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(32)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1113),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(41),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(41),
    [ts_builtin_sym_end] = ACTIONS(215),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(221),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(223),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(33)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1129),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(29),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(29),
    [ts_builtin_sym_end] = ACTIONS(225),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(227),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(229),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(34)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1129),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [ts_builtin_sym_end] = ACTIONS(225),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(227),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(229),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(35)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1216),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(52),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(52),
    [ts_builtin_sym_end] = ACTIONS(225),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(231),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(233),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(36)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1245),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [ts_builtin_sym_end] = ACTIONS(235),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(237),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(239),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(37)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1196),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(45),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(45),
    [ts_builtin_sym_end] = ACTIONS(241),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(243),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(245),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(38)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1196),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [ts_builtin_sym_end] = ACTIONS(241),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(243),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(245),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(39)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1160),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(34),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(247),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(249),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(251),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(40)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1220),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(47),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(47),
    [ts_builtin_sym_end] = ACTIONS(253),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(255),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(257),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(41)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1220),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [ts_builtin_sym_end] = ACTIONS(253),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(255),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(257),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(42)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1216),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [ts_builtin_sym_end] = ACTIONS(225),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(231),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(233),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(43)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1233),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(49),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(49),
    [ts_builtin_sym_end] = ACTIONS(209),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(259),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(261),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(44)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1188),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(42),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(42),
    [ts_builtin_sym_end] = ACTIONS(247),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(263),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(265),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(45)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1199),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [ts_builtin_sym_end] = ACTIONS(267),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(269),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(271),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(46)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1179),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(36),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(36),
    [ts_builtin_sym_end] = ACTIONS(253),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(273),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(275),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(47)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1226),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [ts_builtin_sym_end] = ACTIONS(235),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(277),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(279),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(48)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1231),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(50),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(50),
    [ts_builtin_sym_end] = ACTIONS(241),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(281),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(283),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(49)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1231),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [ts_builtin_sym_end] = ACTIONS(241),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(281),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(283),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(50)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1136),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [ts_builtin_sym_end] = ACTIONS(267),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(285),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(287),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(51)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1179),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [ts_builtin_sym_end] = ACTIONS(253),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(273),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(275),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(52)] = {
    [aux_sym__block] = STATE(80),
    [sym_block] = STATE(1190),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [ts_builtin_sym_end] = ACTIONS(197),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(289),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(291),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(53)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1334),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(71),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(71),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(293),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(295),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(54)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1327),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(297),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(299),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(55)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1320),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(63),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(63),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(301),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(303),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(56)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1317),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(59),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(59),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(305),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(307),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(57)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1318),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(65),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(65),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(309),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(311),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(58)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1305),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(54),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(54),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(313),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(315),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(59)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1305),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(313),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(315),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(60)] = {
    [aux_sym__block] = STATE(66),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(317),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(319),
    [sym_continue_statement] = ACTIONS(319),
    [sym_break_statement] = ACTIONS(319),
    [anon_sym_elseif] = ACTIONS(317),
    [anon_sym_else] = ACTIONS(321),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_case] = ACTIONS(317),
    [anon_sym_otherwise] = ACTIONS(317),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_catch] = ACTIONS(317),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(61)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1309),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(323),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(325),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(62)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1306),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(64),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(64),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(329),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(63)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1306),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(327),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(329),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(64)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1313),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(331),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(333),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(65)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1338),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(335),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(337),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(66)] = {
    [aux_sym__block] = STATE(66),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1056),
    [sym__expression] = STATE(750),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(750),
    [sym_handle_operator] = STATE(750),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1056),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1056),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(750),
    [sym_if_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_lambda] = STATE(750),
    [sym_global_operator] = STATE(1056),
    [sym_persistent_operator] = STATE(1056),
    [sym__function_definition_with_end] = STATE(1057),
    [sym_class_definition] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_spmd_statement] = STATE(1056),
    [sym_boolean] = STATE(371),
    [anon_sym_get] = ACTIONS(339),
    [anon_sym_set] = ACTIONS(339),
    [anon_sym_properties] = ACTIONS(339),
    [anon_sym_LPAREN] = ACTIONS(342),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_end] = ACTIONS(348),
    [anon_sym_TILDE] = ACTIONS(350),
    [anon_sym_QMARK] = ACTIONS(353),
    [anon_sym_AT] = ACTIONS(356),
    [anon_sym_LBRACK] = ACTIONS(359),
    [anon_sym_LBRACE] = ACTIONS(362),
    [sym_return_statement] = ACTIONS(365),
    [sym_continue_statement] = ACTIONS(365),
    [sym_break_statement] = ACTIONS(365),
    [anon_sym_elseif] = ACTIONS(348),
    [anon_sym_else] = ACTIONS(368),
    [anon_sym_if] = ACTIONS(370),
    [anon_sym_for] = ACTIONS(373),
    [anon_sym_parfor] = ACTIONS(376),
    [anon_sym_while] = ACTIONS(379),
    [anon_sym_case] = ACTIONS(348),
    [anon_sym_otherwise] = ACTIONS(348),
    [anon_sym_switch] = ACTIONS(382),
    [anon_sym_global] = ACTIONS(385),
    [anon_sym_persistent] = ACTIONS(388),
    [anon_sym_function] = ACTIONS(391),
    [anon_sym_classdef] = ACTIONS(394),
    [anon_sym_catch] = ACTIONS(348),
    [anon_sym_try] = ACTIONS(397),
    [anon_sym_spmd] = ACTIONS(400),
    [sym_number] = ACTIONS(403),
    [anon_sym_true] = ACTIONS(406),
    [anon_sym_false] = ACTIONS(406),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(409),
    [sym__single_quote_string_start] = ACTIONS(412),
    [sym__double_quote_string_start] = ACTIONS(415),
    [sym__multioutput_variable_start] = ACTIONS(418),
    [sym__external_identifier] = ACTIONS(339),
  },
  [STATE(67)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1329),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(69),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(69),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(421),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(423),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(68)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1337),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(72),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(72),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(425),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(427),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(69)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1337),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(425),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(427),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(70)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1339),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(74),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(74),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(431),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(71)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1339),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(429),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(431),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(72)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1340),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(433),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(435),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(73)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1341),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(76),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(76),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(437),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(439),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(74)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1310),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(441),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(443),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(75)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1311),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(77),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(77),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(445),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(447),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(76)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1311),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(445),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(447),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(77)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1332),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(275),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(275),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(449),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(451),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(78)] = {
    [aux_sym__block] = STATE(82),
    [sym_block] = STATE(1338),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym_arguments_statement] = STATE(61),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [aux_sym_function_definition_repeat1] = STATE(61),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(335),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(203),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(337),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(79)] = {
    [aux_sym__block] = STATE(79),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [ts_builtin_sym_end] = ACTIONS(348),
    [anon_sym_get] = ACTIONS(339),
    [anon_sym_set] = ACTIONS(339),
    [anon_sym_properties] = ACTIONS(339),
    [anon_sym_LPAREN] = ACTIONS(342),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_end] = ACTIONS(368),
    [anon_sym_TILDE] = ACTIONS(350),
    [anon_sym_QMARK] = ACTIONS(353),
    [anon_sym_AT] = ACTIONS(356),
    [anon_sym_LBRACK] = ACTIONS(359),
    [anon_sym_LBRACE] = ACTIONS(362),
    [sym_return_statement] = ACTIONS(453),
    [sym_continue_statement] = ACTIONS(453),
    [sym_break_statement] = ACTIONS(453),
    [anon_sym_if] = ACTIONS(370),
    [anon_sym_for] = ACTIONS(373),
    [anon_sym_parfor] = ACTIONS(376),
    [anon_sym_while] = ACTIONS(379),
    [anon_sym_switch] = ACTIONS(382),
    [anon_sym_global] = ACTIONS(385),
    [anon_sym_persistent] = ACTIONS(388),
    [anon_sym_function] = ACTIONS(391),
    [anon_sym_endfunction] = ACTIONS(348),
    [anon_sym_classdef] = ACTIONS(394),
    [anon_sym_try] = ACTIONS(397),
    [anon_sym_spmd] = ACTIONS(400),
    [sym_number] = ACTIONS(403),
    [anon_sym_true] = ACTIONS(406),
    [anon_sym_false] = ACTIONS(406),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(409),
    [sym__single_quote_string_start] = ACTIONS(412),
    [sym__double_quote_string_start] = ACTIONS(415),
    [sym__multioutput_variable_start] = ACTIONS(418),
    [sym__external_identifier] = ACTIONS(339),
  },
  [STATE(80)] = {
    [aux_sym__block] = STATE(79),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [ts_builtin_sym_end] = ACTIONS(317),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(321),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(456),
    [anon_sym_endfunction] = ACTIONS(317),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(81)] = {
    [aux_sym__block] = STATE(83),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1033),
    [sym__expression] = STATE(751),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(751),
    [sym_handle_operator] = STATE(751),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1033),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1033),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(751),
    [sym_if_statement] = STATE(1033),
    [sym_for_statement] = STATE(1033),
    [sym_while_statement] = STATE(1033),
    [sym_switch_statement] = STATE(1033),
    [sym_lambda] = STATE(751),
    [sym_global_operator] = STATE(1033),
    [sym_persistent_operator] = STATE(1033),
    [sym_function_definition] = STATE(1147),
    [sym__function_definition_with_end] = STATE(1020),
    [sym_class_definition] = STATE(1033),
    [sym_try_statement] = STATE(1033),
    [sym_spmd_statement] = STATE(1033),
    [sym_boolean] = STATE(371),
    [aux_sym_source_file_repeat1] = STATE(1147),
    [ts_builtin_sym_end] = ACTIONS(459),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(23),
    [sym_continue_statement] = ACTIONS(23),
    [sym_break_statement] = ACTIONS(23),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(39),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(82)] = {
    [aux_sym__block] = STATE(79),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1073),
    [sym__expression] = STATE(740),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(740),
    [sym_handle_operator] = STATE(740),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1073),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1073),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(740),
    [sym_if_statement] = STATE(1073),
    [sym_for_statement] = STATE(1073),
    [sym_while_statement] = STATE(1073),
    [sym_switch_statement] = STATE(1073),
    [sym_lambda] = STATE(740),
    [sym_global_operator] = STATE(1073),
    [sym_persistent_operator] = STATE(1073),
    [sym__function_definition_with_end] = STATE(1075),
    [sym_class_definition] = STATE(1073),
    [sym_try_statement] = STATE(1073),
    [sym_spmd_statement] = STATE(1073),
    [sym_boolean] = STATE(371),
    [anon_sym_get] = ACTIONS(7),
    [anon_sym_set] = ACTIONS(7),
    [anon_sym_properties] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_end] = ACTIONS(321),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(201),
    [sym_continue_statement] = ACTIONS(201),
    [sym_break_statement] = ACTIONS(201),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(205),
    [anon_sym_endfunction] = ACTIONS(317),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [anon_sym_spmd] = ACTIONS(45),
    [sym_number] = ACTIONS(47),
    [anon_sym_true] = ACTIONS(49),
    [anon_sym_false] = ACTIONS(49),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(51),
    [sym__single_quote_string_start] = ACTIONS(53),
    [sym__double_quote_string_start] = ACTIONS(55),
    [sym__multioutput_variable_start] = ACTIONS(57),
    [sym__external_identifier] = ACTIONS(7),
  },
  [STATE(83)] = {
    [aux_sym__block] = STATE(83),
    [sym_identifier] = STATE(368),
    [sym__statement] = STATE(1033),
    [sym__expression] = STATE(751),
    [sym_parenthesis] = STATE(448),
    [sym__binary_expression] = STATE(717),
    [sym_binary_operator] = STATE(449),
    [sym_unary_operator] = STATE(489),
    [sym_indirect_access] = STATE(1152),
    [sym_field_expression] = STATE(520),
    [sym_not_operator] = STATE(529),
    [sym_metaclass_operator] = STATE(751),
    [sym_handle_operator] = STATE(751),
    [sym_comparison_operator] = STATE(469),
    [sym_boolean_operator] = STATE(469),
    [sym_postfix_operator] = STATE(448),
    [sym_string] = STATE(448),
    [sym_matrix] = STATE(448),
    [sym_cell] = STATE(477),
    [sym_ignored_argument] = STATE(1392),
    [sym_assignment] = STATE(1033),
    [sym_multioutput_variable] = STATE(1392),
    [sym_function_call] = STATE(368),
    [sym_command] = STATE(1033),
    [sym__range_element] = STATE(1388),
    [sym_range] = STATE(751),
    [sym_if_statement] = STATE(1033),
    [sym_for_statement] = STATE(1033),
    [sym_while_statement] = STATE(1033),
    [sym_switch_statement] = STATE(1033),
    [sym_lambda] = STATE(751),
    [sym_global_operator] = STATE(1033),
    [sym_persistent_operator] = STATE(1033),
    [sym__function_definition_with_end] = STATE(1020),
    [sym_class_definition] = STATE(1033),
    [sym_try_statement] = STATE(1033),
    [sym_spmd_statement] = STATE(1033),
    [sym_boolean] = STATE(371),
    [ts_builtin_sym_end] = ACTIONS(348),
    [anon_sym_get] = ACTIONS(339),
    [anon_sym_set] = ACTIONS(339),
    [anon_sym_properties] = ACTIONS(339),
    [anon_sym_LPAREN] = ACTIONS(342),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_TILDE] = ACTIONS(350),
    [anon_sym_QMARK] = ACTIONS(353),
    [anon_sym_AT] = ACTIONS(356),
    [anon_sym_LBRACK] = ACTIONS(359),
    [anon_sym_LBRACE] = ACTIONS(362),
    [sym_return_statement] = ACTIONS(461),
    [sym_continue_statement] = ACTIONS(461),
    [sym_break_statement] = ACTIONS(461),
    [anon_sym_if] = ACTIONS(370),
    [anon_sym_for] = ACTIONS(373),
    [anon_sym_parfor] = ACTIONS(376),
    [anon_sym_while] = ACTIONS(379),
    [anon_sym_switch] = ACTIONS(382),
    [anon_sym_global] = ACTIONS(385),
    [anon_sym_persistent] = ACTIONS(388),
    [anon_sym_function] = ACTIONS(391),
    [anon_sym_classdef] = ACTIONS(394),
    [anon_sym_try] = ACTIONS(397),
    [anon_sym_spmd] = ACTIONS(400),
    [sym_number] = ACTIONS(403),
    [anon_sym_true] = ACTIONS(406),
    [anon_sym_false] = ACTIONS(406),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(409),
    [sym__single_quote_string_start] = ACTIONS(412),
    [sym__double_quote_string_start] = ACTIONS(415),
    [sym__multioutput_variable_start] = ACTIONS(418),
    [sym__external_identifier] = ACTIONS(339),
  },
  [STATE(84)] = {
    [sym__args] = STATE(100),
    [aux_sym_field_expression_repeat1] = STATE(93),
    [anon_sym_SEMI] = ACTIONS(464),
    [anon_sym_COMMA] = ACTIONS(464),
    [anon_sym_get] = ACTIONS(464),
    [anon_sym_set] = ACTIONS(464),
    [anon_sym_properties] = ACTIONS(464),
    [anon_sym_LPAREN] = ACTIONS(466),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(464),
    [anon_sym_DOT] = ACTIONS(468),
    [anon_sym_TILDE] = ACTIONS(464),
    [anon_sym_QMARK] = ACTIONS(464),
    [anon_sym_AT] = ACTIONS(470),
    [anon_sym_LT] = ACTIONS(464),
    [anon_sym_LT_EQ] = ACTIONS(464),
    [anon_sym_EQ_EQ] = ACTIONS(464),
    [anon_sym_TILDE_EQ] = ACTIONS(464),
    [anon_sym_GT_EQ] = ACTIONS(464),
    [anon_sym_GT] = ACTIONS(464),
    [anon_sym_AMP_AMP] = ACTIONS(464),
    [anon_sym_PIPE_PIPE] = ACTIONS(464),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(464),
    [anon_sym_LF] = ACTIONS(464),
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_COLON] = ACTIONS(464),
    [sym_return_statement] = ACTIONS(464),
    [sym_continue_statement] = ACTIONS(464),
    [sym_break_statement] = ACTIONS(464),
    [anon_sym_elseif] = ACTIONS(464),
    [anon_sym_else] = ACTIONS(464),
    [anon_sym_if] = ACTIONS(464),
    [anon_sym_for] = ACTIONS(464),
    [anon_sym_parfor] = ACTIONS(464),
    [anon_sym_while] = ACTIONS(464),
    [anon_sym_switch] = ACTIONS(464),
    [anon_sym_global] = ACTIONS(464),
    [anon_sym_persistent] = ACTIONS(464),
    [anon_sym_function] = ACTIONS(464),
    [anon_sym_classdef] = ACTIONS(464),
    [anon_sym_try] = ACTIONS(464),
    [anon_sym_spmd] = ACTIONS(464),
    [sym_number] = ACTIONS(464),
    [anon_sym_true] = ACTIONS(464),
    [anon_sym_false] = ACTIONS(464),
    [anon_sym_CR] = ACTIONS(464),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(476),
    [sym__single_quote_string_start] = ACTIONS(476),
    [sym__double_quote_string_start] = ACTIONS(476),
    [sym__multioutput_variable_start] = ACTIONS(476),
    [sym__external_identifier] = ACTIONS(476),
  },
  [STATE(85)] = {
    [sym__args] = STATE(100),
    [aux_sym_field_expression_repeat1] = STATE(93),
    [anon_sym_SEMI] = ACTIONS(478),
    [anon_sym_COMMA] = ACTIONS(478),
    [anon_sym_get] = ACTIONS(478),
    [anon_sym_set] = ACTIONS(478),
    [anon_sym_properties] = ACTIONS(478),
    [anon_sym_LPAREN] = ACTIONS(466),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(478),
    [anon_sym_DOT] = ACTIONS(468),
    [anon_sym_TILDE] = ACTIONS(478),
    [anon_sym_QMARK] = ACTIONS(478),
    [anon_sym_AT] = ACTIONS(470),
    [anon_sym_LT] = ACTIONS(480),
    [anon_sym_LT_EQ] = ACTIONS(480),
    [anon_sym_EQ_EQ] = ACTIONS(480),
    [anon_sym_TILDE_EQ] = ACTIONS(480),
    [anon_sym_GT_EQ] = ACTIONS(480),
    [anon_sym_GT] = ACTIONS(480),
    [anon_sym_AMP_AMP] = ACTIONS(480),
    [anon_sym_PIPE_PIPE] = ACTIONS(480),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(478),
    [anon_sym_LF] = ACTIONS(478),
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_COLON] = ACTIONS(478),
    [sym_return_statement] = ACTIONS(478),
    [sym_continue_statement] = ACTIONS(478),
    [sym_break_statement] = ACTIONS(478),
    [anon_sym_elseif] = ACTIONS(478),
    [anon_sym_else] = ACTIONS(478),
    [anon_sym_if] = ACTIONS(478),
    [anon_sym_for] = ACTIONS(478),
    [anon_sym_parfor] = ACTIONS(478),
    [anon_sym_while] = ACTIONS(478),
    [anon_sym_switch] = ACTIONS(478),
    [anon_sym_global] = ACTIONS(478),
    [anon_sym_persistent] = ACTIONS(478),
    [anon_sym_function] = ACTIONS(478),
    [anon_sym_classdef] = ACTIONS(478),
    [anon_sym_try] = ACTIONS(478),
    [anon_sym_spmd] = ACTIONS(478),
    [sym_number] = ACTIONS(478),
    [anon_sym_true] = ACTIONS(478),
    [anon_sym_false] = ACTIONS(478),
    [anon_sym_CR] = ACTIONS(478),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(483),
    [sym__single_quote_string_start] = ACTIONS(483),
    [sym__double_quote_string_start] = ACTIONS(483),
    [sym__multioutput_variable_start] = ACTIONS(483),
    [sym__external_identifier] = ACTIONS(483),
  },
  [STATE(86)] = {
    [sym__args] = STATE(100),
    [aux_sym_field_expression_repeat1] = STATE(93),
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(466),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_DOT] = ACTIONS(468),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(470),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_COLON] = ACTIONS(478),
    [sym_return_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
  [STATE(87)] = {
    [sym__args] = STATE(100),
    [aux_sym_field_expression_repeat1] = STATE(93),
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(466),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_DOT] = ACTIONS(468),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(470),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_COLON] = ACTIONS(480),
    [sym_return_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
  [STATE(88)] = {
    [sym__args] = STATE(100),
    [aux_sym_field_expression_repeat1] = STATE(93),
    [anon_sym_SEMI] = ACTIONS(489),
    [anon_sym_COMMA] = ACTIONS(489),
    [anon_sym_get] = ACTIONS(489),
    [anon_sym_set] = ACTIONS(489),
    [anon_sym_properties] = ACTIONS(489),
    [anon_sym_LPAREN] = ACTIONS(466),
    [anon_sym_PLUS] = ACTIONS(489),
    [anon_sym_DOT_PLUS] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(489),
    [anon_sym_DOT_DASH] = ACTIONS(489),
    [anon_sym_STAR] = ACTIONS(489),
    [anon_sym_DOT_STAR] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(489),
    [anon_sym_DOT_SLASH] = ACTIONS(489),
    [anon_sym_BSLASH] = ACTIONS(489),
    [anon_sym_DOT_BSLASH] = ACTIONS(489),
    [anon_sym_CARET] = ACTIONS(489),
    [anon_sym_DOT_CARET] = ACTIONS(489),
    [anon_sym_PIPE] = ACTIONS(489),
    [anon_sym_AMP] = ACTIONS(489),
    [anon_sym_end] = ACTIONS(489),
    [anon_sym_DOT] = ACTIONS(468),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_QMARK] = ACTIONS(489),
    [anon_sym_AT] = ACTIONS(470),
    [anon_sym_LT] = ACTIONS(489),
    [anon_sym_LT_EQ] = ACTIONS(489),
    [anon_sym_EQ_EQ] = ACTIONS(489),
    [anon_sym_TILDE_EQ] = ACTIONS(489),
    [anon_sym_GT_EQ] = ACTIONS(489),
    [anon_sym_GT] = ACTIONS(489),
    [anon_sym_AMP_AMP] = ACTIONS(489),
    [anon_sym_PIPE_PIPE] = ACTIONS(489),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_LF] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_COLON] = ACTIONS(489),
    [sym_return_statement] = ACTIONS(489),
    [sym_continue_statement] = ACTIONS(489),
    [sym_break_statement] = ACTIONS(489),
    [anon_sym_elseif] = ACTIONS(489),
    [anon_sym_else] = ACTIONS(489),
    [anon_sym_if] = ACTIONS(489),
    [anon_sym_for] = ACTIONS(489),
    [anon_sym_parfor] = ACTIONS(489),
    [anon_sym_while] = ACTIONS(489),
    [anon_sym_switch] = ACTIONS(489),
    [anon_sym_global] = ACTIONS(489),
    [anon_sym_persistent] = ACTIONS(489),
    [anon_sym_function] = ACTIONS(489),
    [anon_sym_classdef] = ACTIONS(489),
    [anon_sym_try] = ACTIONS(489),
    [anon_sym_spmd] = ACTIONS(489),
    [sym_number] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(489),
    [anon_sym_false] = ACTIONS(489),
    [anon_sym_CR] = ACTIONS(489),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(491),
    [sym__single_quote_string_start] = ACTIONS(491),
    [sym__double_quote_string_start] = ACTIONS(491),
    [sym__multioutput_variable_start] = ACTIONS(491),
    [sym__external_identifier] = ACTIONS(491),
  },
  [STATE(89)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(90),
    [anon_sym_SEMI] = ACTIONS(493),
    [anon_sym_COMMA] = ACTIONS(493),
    [anon_sym_get] = ACTIONS(493),
    [anon_sym_set] = ACTIONS(493),
    [anon_sym_properties] = ACTIONS(493),
    [anon_sym_LPAREN] = ACTIONS(493),
    [anon_sym_PLUS] = ACTIONS(493),
    [anon_sym_DOT_PLUS] = ACTIONS(493),
    [anon_sym_DASH] = ACTIONS(493),
    [anon_sym_DOT_DASH] = ACTIONS(493),
    [anon_sym_STAR] = ACTIONS(493),
    [anon_sym_DOT_STAR] = ACTIONS(493),
    [anon_sym_SLASH] = ACTIONS(493),
    [anon_sym_DOT_SLASH] = ACTIONS(493),
    [anon_sym_BSLASH] = ACTIONS(493),
    [anon_sym_DOT_BSLASH] = ACTIONS(493),
    [anon_sym_CARET] = ACTIONS(493),
    [anon_sym_DOT_CARET] = ACTIONS(493),
    [anon_sym_PIPE] = ACTIONS(493),
    [anon_sym_AMP] = ACTIONS(493),
    [anon_sym_end] = ACTIONS(493),
    [anon_sym_DOT] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(493),
    [anon_sym_QMARK] = ACTIONS(493),
    [anon_sym_AT] = ACTIONS(493),
    [anon_sym_LT] = ACTIONS(493),
    [anon_sym_LT_EQ] = ACTIONS(493),
    [anon_sym_EQ_EQ] = ACTIONS(493),
    [anon_sym_TILDE_EQ] = ACTIONS(493),
    [anon_sym_GT_EQ] = ACTIONS(493),
    [anon_sym_GT] = ACTIONS(493),
    [anon_sym_AMP_AMP] = ACTIONS(493),
    [anon_sym_PIPE_PIPE] = ACTIONS(493),
    [anon_sym_DOT_SQUOTE] = ACTIONS(493),
    [anon_sym_SQUOTE] = ACTIONS(493),
    [anon_sym_LBRACK] = ACTIONS(493),
    [anon_sym_LF] = ACTIONS(493),
    [anon_sym_LBRACE] = ACTIONS(493),
    [anon_sym_COLON] = ACTIONS(493),
    [sym_return_statement] = ACTIONS(493),
    [sym_continue_statement] = ACTIONS(493),
    [sym_break_statement] = ACTIONS(493),
    [anon_sym_elseif] = ACTIONS(493),
    [anon_sym_else] = ACTIONS(493),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_for] = ACTIONS(493),
    [anon_sym_parfor] = ACTIONS(493),
    [anon_sym_while] = ACTIONS(493),
    [anon_sym_switch] = ACTIONS(493),
    [anon_sym_global] = ACTIONS(493),
    [anon_sym_persistent] = ACTIONS(493),
    [anon_sym_function] = ACTIONS(493),
    [anon_sym_classdef] = ACTIONS(493),
    [anon_sym_try] = ACTIONS(493),
    [anon_sym_spmd] = ACTIONS(493),
    [sym_number] = ACTIONS(493),
    [anon_sym_true] = ACTIONS(493),
    [anon_sym_false] = ACTIONS(493),
    [anon_sym_CR] = ACTIONS(493),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(497),
    [sym__single_quote_string_start] = ACTIONS(497),
    [sym__double_quote_string_start] = ACTIONS(497),
    [sym__multioutput_variable_start] = ACTIONS(497),
    [sym__external_identifier] = ACTIONS(497),
  },
  [STATE(90)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(92),
    [anon_sym_SEMI] = ACTIONS(499),
    [anon_sym_COMMA] = ACTIONS(499),
    [anon_sym_get] = ACTIONS(499),
    [anon_sym_set] = ACTIONS(499),
    [anon_sym_properties] = ACTIONS(499),
    [anon_sym_LPAREN] = ACTIONS(499),
    [anon_sym_PLUS] = ACTIONS(499),
    [anon_sym_DOT_PLUS] = ACTIONS(499),
    [anon_sym_DASH] = ACTIONS(499),
    [anon_sym_DOT_DASH] = ACTIONS(499),
    [anon_sym_STAR] = ACTIONS(499),
    [anon_sym_DOT_STAR] = ACTIONS(499),
    [anon_sym_SLASH] = ACTIONS(499),
    [anon_sym_DOT_SLASH] = ACTIONS(499),
    [anon_sym_BSLASH] = ACTIONS(499),
    [anon_sym_DOT_BSLASH] = ACTIONS(499),
    [anon_sym_CARET] = ACTIONS(499),
    [anon_sym_DOT_CARET] = ACTIONS(499),
    [anon_sym_PIPE] = ACTIONS(499),
    [anon_sym_AMP] = ACTIONS(499),
    [anon_sym_end] = ACTIONS(499),
    [anon_sym_DOT] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(499),
    [anon_sym_QMARK] = ACTIONS(499),
    [anon_sym_AT] = ACTIONS(499),
    [anon_sym_LT] = ACTIONS(499),
    [anon_sym_LT_EQ] = ACTIONS(499),
    [anon_sym_EQ_EQ] = ACTIONS(499),
    [anon_sym_TILDE_EQ] = ACTIONS(499),
    [anon_sym_GT_EQ] = ACTIONS(499),
    [anon_sym_GT] = ACTIONS(499),
    [anon_sym_AMP_AMP] = ACTIONS(499),
    [anon_sym_PIPE_PIPE] = ACTIONS(499),
    [anon_sym_DOT_SQUOTE] = ACTIONS(499),
    [anon_sym_SQUOTE] = ACTIONS(499),
    [anon_sym_LBRACK] = ACTIONS(499),
    [anon_sym_LF] = ACTIONS(499),
    [anon_sym_LBRACE] = ACTIONS(499),
    [anon_sym_COLON] = ACTIONS(499),
    [sym_return_statement] = ACTIONS(499),
    [sym_continue_statement] = ACTIONS(499),
    [sym_break_statement] = ACTIONS(499),
    [anon_sym_elseif] = ACTIONS(499),
    [anon_sym_else] = ACTIONS(499),
    [anon_sym_if] = ACTIONS(499),
    [anon_sym_for] = ACTIONS(499),
    [anon_sym_parfor] = ACTIONS(499),
    [anon_sym_while] = ACTIONS(499),
    [anon_sym_switch] = ACTIONS(499),
    [anon_sym_global] = ACTIONS(499),
    [anon_sym_persistent] = ACTIONS(499),
    [anon_sym_function] = ACTIONS(499),
    [anon_sym_classdef] = ACTIONS(499),
    [anon_sym_try] = ACTIONS(499),
    [anon_sym_spmd] = ACTIONS(499),
    [sym_number] = ACTIONS(499),
    [anon_sym_true] = ACTIONS(499),
    [anon_sym_false] = ACTIONS(499),
    [anon_sym_CR] = ACTIONS(499),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(501),
    [sym__single_quote_string_start] = ACTIONS(501),
    [sym__double_quote_string_start] = ACTIONS(501),
    [sym__multioutput_variable_start] = ACTIONS(501),
    [sym__external_identifier] = ACTIONS(501),
  },
  [STATE(91)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(92),
    [anon_sym_SEMI] = ACTIONS(503),
    [anon_sym_COMMA] = ACTIONS(503),
    [anon_sym_get] = ACTIONS(503),
    [anon_sym_set] = ACTIONS(503),
    [anon_sym_properties] = ACTIONS(503),
    [anon_sym_LPAREN] = ACTIONS(503),
    [anon_sym_PLUS] = ACTIONS(503),
    [anon_sym_DOT_PLUS] = ACTIONS(503),
    [anon_sym_DASH] = ACTIONS(503),
    [anon_sym_DOT_DASH] = ACTIONS(503),
    [anon_sym_STAR] = ACTIONS(503),
    [anon_sym_DOT_STAR] = ACTIONS(503),
    [anon_sym_SLASH] = ACTIONS(503),
    [anon_sym_DOT_SLASH] = ACTIONS(503),
    [anon_sym_BSLASH] = ACTIONS(503),
    [anon_sym_DOT_BSLASH] = ACTIONS(503),
    [anon_sym_CARET] = ACTIONS(503),
    [anon_sym_DOT_CARET] = ACTIONS(503),
    [anon_sym_PIPE] = ACTIONS(503),
    [anon_sym_AMP] = ACTIONS(503),
    [anon_sym_end] = ACTIONS(503),
    [anon_sym_DOT] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(503),
    [anon_sym_QMARK] = ACTIONS(503),
    [anon_sym_AT] = ACTIONS(503),
    [anon_sym_LT] = ACTIONS(503),
    [anon_sym_LT_EQ] = ACTIONS(503),
    [anon_sym_EQ_EQ] = ACTIONS(503),
    [anon_sym_TILDE_EQ] = ACTIONS(503),
    [anon_sym_GT_EQ] = ACTIONS(503),
    [anon_sym_GT] = ACTIONS(503),
    [anon_sym_AMP_AMP] = ACTIONS(503),
    [anon_sym_PIPE_PIPE] = ACTIONS(503),
    [anon_sym_DOT_SQUOTE] = ACTIONS(503),
    [anon_sym_SQUOTE] = ACTIONS(503),
    [anon_sym_LBRACK] = ACTIONS(503),
    [anon_sym_LF] = ACTIONS(503),
    [anon_sym_LBRACE] = ACTIONS(503),
    [anon_sym_COLON] = ACTIONS(503),
    [sym_return_statement] = ACTIONS(503),
    [sym_continue_statement] = ACTIONS(503),
    [sym_break_statement] = ACTIONS(503),
    [anon_sym_elseif] = ACTIONS(503),
    [anon_sym_else] = ACTIONS(503),
    [anon_sym_if] = ACTIONS(503),
    [anon_sym_for] = ACTIONS(503),
    [anon_sym_parfor] = ACTIONS(503),
    [anon_sym_while] = ACTIONS(503),
    [anon_sym_switch] = ACTIONS(503),
    [anon_sym_global] = ACTIONS(503),
    [anon_sym_persistent] = ACTIONS(503),
    [anon_sym_function] = ACTIONS(503),
    [anon_sym_classdef] = ACTIONS(503),
    [anon_sym_try] = ACTIONS(503),
    [anon_sym_spmd] = ACTIONS(503),
    [sym_number] = ACTIONS(503),
    [anon_sym_true] = ACTIONS(503),
    [anon_sym_false] = ACTIONS(503),
    [anon_sym_CR] = ACTIONS(503),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(505),
    [sym__single_quote_string_start] = ACTIONS(505),
    [sym__double_quote_string_start] = ACTIONS(505),
    [sym__multioutput_variable_start] = ACTIONS(505),
    [sym__external_identifier] = ACTIONS(505),
  },
  [STATE(92)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(92),
    [anon_sym_SEMI] = ACTIONS(507),
    [anon_sym_COMMA] = ACTIONS(507),
    [anon_sym_get] = ACTIONS(507),
    [anon_sym_set] = ACTIONS(507),
    [anon_sym_properties] = ACTIONS(507),
    [anon_sym_LPAREN] = ACTIONS(507),
    [anon_sym_PLUS] = ACTIONS(507),
    [anon_sym_DOT_PLUS] = ACTIONS(507),
    [anon_sym_DASH] = ACTIONS(507),
    [anon_sym_DOT_DASH] = ACTIONS(507),
    [anon_sym_STAR] = ACTIONS(507),
    [anon_sym_DOT_STAR] = ACTIONS(507),
    [anon_sym_SLASH] = ACTIONS(507),
    [anon_sym_DOT_SLASH] = ACTIONS(507),
    [anon_sym_BSLASH] = ACTIONS(507),
    [anon_sym_DOT_BSLASH] = ACTIONS(507),
    [anon_sym_CARET] = ACTIONS(507),
    [anon_sym_DOT_CARET] = ACTIONS(507),
    [anon_sym_PIPE] = ACTIONS(507),
    [anon_sym_AMP] = ACTIONS(507),
    [anon_sym_end] = ACTIONS(507),
    [anon_sym_DOT] = ACTIONS(509),
    [anon_sym_TILDE] = ACTIONS(507),
    [anon_sym_QMARK] = ACTIONS(507),
    [anon_sym_AT] = ACTIONS(507),
    [anon_sym_LT] = ACTIONS(507),
    [anon_sym_LT_EQ] = ACTIONS(507),
    [anon_sym_EQ_EQ] = ACTIONS(507),
    [anon_sym_TILDE_EQ] = ACTIONS(507),
    [anon_sym_GT_EQ] = ACTIONS(507),
    [anon_sym_GT] = ACTIONS(507),
    [anon_sym_AMP_AMP] = ACTIONS(507),
    [anon_sym_PIPE_PIPE] = ACTIONS(507),
    [anon_sym_DOT_SQUOTE] = ACTIONS(507),
    [anon_sym_SQUOTE] = ACTIONS(507),
    [anon_sym_LBRACK] = ACTIONS(507),
    [anon_sym_LF] = ACTIONS(507),
    [anon_sym_LBRACE] = ACTIONS(507),
    [anon_sym_COLON] = ACTIONS(507),
    [sym_return_statement] = ACTIONS(507),
    [sym_continue_statement] = ACTIONS(507),
    [sym_break_statement] = ACTIONS(507),
    [anon_sym_elseif] = ACTIONS(507),
    [anon_sym_else] = ACTIONS(507),
    [anon_sym_if] = ACTIONS(507),
    [anon_sym_for] = ACTIONS(507),
    [anon_sym_parfor] = ACTIONS(507),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_switch] = ACTIONS(507),
    [anon_sym_global] = ACTIONS(507),
    [anon_sym_persistent] = ACTIONS(507),
    [anon_sym_function] = ACTIONS(507),
    [anon_sym_classdef] = ACTIONS(507),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_spmd] = ACTIONS(507),
    [sym_number] = ACTIONS(507),
    [anon_sym_true] = ACTIONS(507),
    [anon_sym_false] = ACTIONS(507),
    [anon_sym_CR] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(512),
    [sym__single_quote_string_start] = ACTIONS(512),
    [sym__double_quote_string_start] = ACTIONS(512),
    [sym__multioutput_variable_start] = ACTIONS(512),
    [sym__external_identifier] = ACTIONS(512),
  },
  [STATE(93)] = {
    [aux_sym_field_expression_repeat1] = STATE(94),
    [anon_sym_SEMI] = ACTIONS(514),
    [anon_sym_COMMA] = ACTIONS(514),
    [anon_sym_get] = ACTIONS(514),
    [anon_sym_set] = ACTIONS(514),
    [anon_sym_properties] = ACTIONS(514),
    [anon_sym_LPAREN] = ACTIONS(514),
    [anon_sym_PLUS] = ACTIONS(514),
    [anon_sym_DOT_PLUS] = ACTIONS(514),
    [anon_sym_DASH] = ACTIONS(514),
    [anon_sym_DOT_DASH] = ACTIONS(514),
    [anon_sym_STAR] = ACTIONS(514),
    [anon_sym_DOT_STAR] = ACTIONS(514),
    [anon_sym_SLASH] = ACTIONS(514),
    [anon_sym_DOT_SLASH] = ACTIONS(514),
    [anon_sym_BSLASH] = ACTIONS(514),
    [anon_sym_DOT_BSLASH] = ACTIONS(514),
    [anon_sym_CARET] = ACTIONS(514),
    [anon_sym_DOT_CARET] = ACTIONS(514),
    [anon_sym_PIPE] = ACTIONS(514),
    [anon_sym_AMP] = ACTIONS(514),
    [anon_sym_end] = ACTIONS(514),
    [anon_sym_DOT] = ACTIONS(468),
    [anon_sym_TILDE] = ACTIONS(514),
    [anon_sym_QMARK] = ACTIONS(514),
    [anon_sym_AT] = ACTIONS(514),
    [anon_sym_LT] = ACTIONS(514),
    [anon_sym_LT_EQ] = ACTIONS(514),
    [anon_sym_EQ_EQ] = ACTIONS(514),
    [anon_sym_TILDE_EQ] = ACTIONS(514),
    [anon_sym_GT_EQ] = ACTIONS(514),
    [anon_sym_GT] = ACTIONS(514),
    [anon_sym_AMP_AMP] = ACTIONS(514),
    [anon_sym_PIPE_PIPE] = ACTIONS(514),
    [anon_sym_DOT_SQUOTE] = ACTIONS(514),
    [anon_sym_SQUOTE] = ACTIONS(514),
    [anon_sym_LBRACK] = ACTIONS(514),
    [anon_sym_LF] = ACTIONS(514),
    [anon_sym_LBRACE] = ACTIONS(514),
    [anon_sym_COLON] = ACTIONS(514),
    [sym_return_statement] = ACTIONS(514),
    [sym_continue_statement] = ACTIONS(514),
    [sym_break_statement] = ACTIONS(514),
    [anon_sym_elseif] = ACTIONS(514),
    [anon_sym_else] = ACTIONS(514),
    [anon_sym_if] = ACTIONS(514),
    [anon_sym_for] = ACTIONS(514),
    [anon_sym_parfor] = ACTIONS(514),
    [anon_sym_while] = ACTIONS(514),
    [anon_sym_switch] = ACTIONS(514),
    [anon_sym_global] = ACTIONS(514),
    [anon_sym_persistent] = ACTIONS(514),
    [anon_sym_function] = ACTIONS(514),
    [anon_sym_classdef] = ACTIONS(514),
    [anon_sym_try] = ACTIONS(514),
    [anon_sym_spmd] = ACTIONS(514),
    [sym_number] = ACTIONS(514),
    [anon_sym_true] = ACTIONS(514),
    [anon_sym_false] = ACTIONS(514),
    [anon_sym_CR] = ACTIONS(514),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(516),
    [sym__single_quote_string_start] = ACTIONS(516),
    [sym__double_quote_string_start] = ACTIONS(516),
    [sym__multioutput_variable_start] = ACTIONS(516),
    [sym__external_identifier] = ACTIONS(516),
  },
  [STATE(94)] = {
    [aux_sym_field_expression_repeat1] = STATE(94),
    [anon_sym_SEMI] = ACTIONS(518),
    [anon_sym_COMMA] = ACTIONS(518),
    [anon_sym_get] = ACTIONS(518),
    [anon_sym_set] = ACTIONS(518),
    [anon_sym_properties] = ACTIONS(518),
    [anon_sym_LPAREN] = ACTIONS(518),
    [anon_sym_PLUS] = ACTIONS(518),
    [anon_sym_DOT_PLUS] = ACTIONS(518),
    [anon_sym_DASH] = ACTIONS(518),
    [anon_sym_DOT_DASH] = ACTIONS(518),
    [anon_sym_STAR] = ACTIONS(518),
    [anon_sym_DOT_STAR] = ACTIONS(518),
    [anon_sym_SLASH] = ACTIONS(518),
    [anon_sym_DOT_SLASH] = ACTIONS(518),
    [anon_sym_BSLASH] = ACTIONS(518),
    [anon_sym_DOT_BSLASH] = ACTIONS(518),
    [anon_sym_CARET] = ACTIONS(518),
    [anon_sym_DOT_CARET] = ACTIONS(518),
    [anon_sym_PIPE] = ACTIONS(518),
    [anon_sym_AMP] = ACTIONS(518),
    [anon_sym_end] = ACTIONS(518),
    [anon_sym_DOT] = ACTIONS(520),
    [anon_sym_TILDE] = ACTIONS(518),
    [anon_sym_QMARK] = ACTIONS(518),
    [anon_sym_AT] = ACTIONS(518),
    [anon_sym_LT] = ACTIONS(518),
    [anon_sym_LT_EQ] = ACTIONS(518),
    [anon_sym_EQ_EQ] = ACTIONS(518),
    [anon_sym_TILDE_EQ] = ACTIONS(518),
    [anon_sym_GT_EQ] = ACTIONS(518),
    [anon_sym_GT] = ACTIONS(518),
    [anon_sym_AMP_AMP] = ACTIONS(518),
    [anon_sym_PIPE_PIPE] = ACTIONS(518),
    [anon_sym_DOT_SQUOTE] = ACTIONS(518),
    [anon_sym_SQUOTE] = ACTIONS(518),
    [anon_sym_LBRACK] = ACTIONS(518),
    [anon_sym_LF] = ACTIONS(518),
    [anon_sym_LBRACE] = ACTIONS(518),
    [anon_sym_COLON] = ACTIONS(518),
    [sym_return_statement] = ACTIONS(518),
    [sym_continue_statement] = ACTIONS(518),
    [sym_break_statement] = ACTIONS(518),
    [anon_sym_elseif] = ACTIONS(518),
    [anon_sym_else] = ACTIONS(518),
    [anon_sym_if] = ACTIONS(518),
    [anon_sym_for] = ACTIONS(518),
    [anon_sym_parfor] = ACTIONS(518),
    [anon_sym_while] = ACTIONS(518),
    [anon_sym_switch] = ACTIONS(518),
    [anon_sym_global] = ACTIONS(518),
    [anon_sym_persistent] = ACTIONS(518),
    [anon_sym_function] = ACTIONS(518),
    [anon_sym_classdef] = ACTIONS(518),
    [anon_sym_try] = ACTIONS(518),
    [anon_sym_spmd] = ACTIONS(518),
    [sym_number] = ACTIONS(518),
    [anon_sym_true] = ACTIONS(518),
    [anon_sym_false] = ACTIONS(518),
    [anon_sym_CR] = ACTIONS(518),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(523),
    [sym__single_quote_string_start] = ACTIONS(523),
    [sym__double_quote_string_start] = ACTIONS(523),
    [sym__multioutput_variable_start] = ACTIONS(523),
    [sym__external_identifier] = ACTIONS(523),
  },
  [STATE(95)] = {
    [sym__args] = STATE(100),
    [anon_sym_SEMI] = ACTIONS(525),
    [anon_sym_COMMA] = ACTIONS(525),
    [anon_sym_get] = ACTIONS(525),
    [anon_sym_set] = ACTIONS(525),
    [anon_sym_properties] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(466),
    [anon_sym_PLUS] = ACTIONS(525),
    [anon_sym_DOT_PLUS] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(525),
    [anon_sym_DOT_DASH] = ACTIONS(525),
    [anon_sym_STAR] = ACTIONS(525),
    [anon_sym_DOT_STAR] = ACTIONS(525),
    [anon_sym_SLASH] = ACTIONS(525),
    [anon_sym_DOT_SLASH] = ACTIONS(525),
    [anon_sym_BSLASH] = ACTIONS(525),
    [anon_sym_DOT_BSLASH] = ACTIONS(525),
    [anon_sym_CARET] = ACTIONS(525),
    [anon_sym_DOT_CARET] = ACTIONS(525),
    [anon_sym_PIPE] = ACTIONS(525),
    [anon_sym_AMP] = ACTIONS(525),
    [anon_sym_end] = ACTIONS(525),
    [anon_sym_DOT] = ACTIONS(525),
    [anon_sym_TILDE] = ACTIONS(525),
    [anon_sym_QMARK] = ACTIONS(525),
    [anon_sym_AT] = ACTIONS(470),
    [anon_sym_LT] = ACTIONS(525),
    [anon_sym_LT_EQ] = ACTIONS(525),
    [anon_sym_EQ_EQ] = ACTIONS(525),
    [anon_sym_TILDE_EQ] = ACTIONS(525),
    [anon_sym_GT_EQ] = ACTIONS(525),
    [anon_sym_GT] = ACTIONS(525),
    [anon_sym_AMP_AMP] = ACTIONS(525),
    [anon_sym_PIPE_PIPE] = ACTIONS(525),
    [anon_sym_DOT_SQUOTE] = ACTIONS(525),
    [anon_sym_SQUOTE] = ACTIONS(525),
    [anon_sym_LBRACK] = ACTIONS(525),
    [anon_sym_LF] = ACTIONS(525),
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_COLON] = ACTIONS(525),
    [sym_return_statement] = ACTIONS(525),
    [sym_continue_statement] = ACTIONS(525),
    [sym_break_statement] = ACTIONS(525),
    [anon_sym_elseif] = ACTIONS(525),
    [anon_sym_else] = ACTIONS(525),
    [anon_sym_if] = ACTIONS(525),
    [anon_sym_for] = ACTIONS(525),
    [anon_sym_parfor] = ACTIONS(525),
    [anon_sym_while] = ACTIONS(525),
    [anon_sym_switch] = ACTIONS(525),
    [anon_sym_global] = ACTIONS(525),
    [anon_sym_persistent] = ACTIONS(525),
    [anon_sym_function] = ACTIONS(525),
    [anon_sym_classdef] = ACTIONS(525),
    [anon_sym_try] = ACTIONS(525),
    [anon_sym_spmd] = ACTIONS(525),
    [sym_number] = ACTIONS(525),
    [anon_sym_true] = ACTIONS(525),
    [anon_sym_false] = ACTIONS(525),
    [anon_sym_CR] = ACTIONS(525),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(527),
    [sym__single_quote_string_start] = ACTIONS(527),
    [sym__double_quote_string_start] = ACTIONS(527),
    [sym__multioutput_variable_start] = ACTIONS(527),
    [sym__external_identifier] = ACTIONS(527),
  },
  [STATE(96)] = {
    [aux_sym_metaclass_operator_repeat1] = STATE(91),
    [anon_sym_SEMI] = ACTIONS(529),
    [anon_sym_COMMA] = ACTIONS(529),
    [anon_sym_get] = ACTIONS(529),
    [anon_sym_set] = ACTIONS(529),
    [anon_sym_properties] = ACTIONS(529),
    [anon_sym_LPAREN] = ACTIONS(529),
    [anon_sym_PLUS] = ACTIONS(529),
    [anon_sym_DOT_PLUS] = ACTIONS(529),
    [anon_sym_DASH] = ACTIONS(529),
    [anon_sym_DOT_DASH] = ACTIONS(529),
    [anon_sym_STAR] = ACTIONS(529),
    [anon_sym_DOT_STAR] = ACTIONS(529),
    [anon_sym_SLASH] = ACTIONS(529),
    [anon_sym_DOT_SLASH] = ACTIONS(529),
    [anon_sym_BSLASH] = ACTIONS(529),
    [anon_sym_DOT_BSLASH] = ACTIONS(529),
    [anon_sym_CARET] = ACTIONS(529),
    [anon_sym_DOT_CARET] = ACTIONS(529),
    [anon_sym_PIPE] = ACTIONS(529),
    [anon_sym_AMP] = ACTIONS(529),
    [anon_sym_end] = ACTIONS(529),
    [anon_sym_DOT] = ACTIONS(495),
    [anon_sym_TILDE] = ACTIONS(529),
    [anon_sym_QMARK] = ACTIONS(529),
    [anon_sym_AT] = ACTIONS(529),
    [anon_sym_LT] = ACTIONS(529),
    [anon_sym_LT_EQ] = ACTIONS(529),
    [anon_sym_EQ_EQ] = ACTIONS(529),
    [anon_sym_TILDE_EQ] = ACTIONS(529),
    [anon_sym_GT_EQ] = ACTIONS(529),
    [anon_sym_GT] = ACTIONS(529),
    [anon_sym_AMP_AMP] = ACTIONS(529),
    [anon_sym_PIPE_PIPE] = ACTIONS(529),
    [anon_sym_DOT_SQUOTE] = ACTIONS(529),
    [anon_sym_SQUOTE] = ACTIONS(529),
    [anon_sym_LBRACK] = ACTIONS(529),
    [anon_sym_LF] = ACTIONS(529),
    [anon_sym_LBRACE] = ACTIONS(529),
    [anon_sym_COLON] = ACTIONS(529),
    [sym_return_statement] = ACTIONS(529),
    [sym_continue_statement] = ACTIONS(529),
    [sym_break_statement] = ACTIONS(529),
    [anon_sym_elseif] = ACTIONS(529),
    [anon_sym_else] = ACTIONS(529),
    [anon_sym_if] = ACTIONS(529),
    [anon_sym_for] = ACTIONS(529),
    [anon_sym_parfor] = ACTIONS(529),
    [anon_sym_while] = ACTIONS(529),
    [anon_sym_switch] = ACTIONS(529),
    [anon_sym_global] = ACTIONS(529),
    [anon_sym_persistent] = ACTIONS(529),
    [anon_sym_function] = ACTIONS(529),
    [anon_sym_classdef] = ACTIONS(529),
    [anon_sym_try] = ACTIONS(529),
    [anon_sym_spmd] = ACTIONS(529),
    [sym_number] = ACTIONS(529),
    [anon_sym_true] = ACTIONS(529),
    [anon_sym_false] = ACTIONS(529),
    [anon_sym_CR] = ACTIONS(529),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(531),
    [sym__single_quote_string_start] = ACTIONS(531),
    [sym__double_quote_string_start] = ACTIONS(531),
    [sym__multioutput_variable_start] = ACTIONS(531),
    [sym__external_identifier] = ACTIONS(531),
  },
  [STATE(97)] = {
    [anon_sym_SEMI] = ACTIONS(533),
    [anon_sym_COMMA] = ACTIONS(533),
    [anon_sym_get] = ACTIONS(533),
    [anon_sym_set] = ACTIONS(533),
    [anon_sym_properties] = ACTIONS(533),
    [anon_sym_LPAREN] = ACTIONS(533),
    [anon_sym_PLUS] = ACTIONS(533),
    [anon_sym_DOT_PLUS] = ACTIONS(533),
    [anon_sym_DASH] = ACTIONS(533),
    [anon_sym_DOT_DASH] = ACTIONS(533),
    [anon_sym_STAR] = ACTIONS(533),
    [anon_sym_DOT_STAR] = ACTIONS(533),
    [anon_sym_SLASH] = ACTIONS(533),
    [anon_sym_DOT_SLASH] = ACTIONS(533),
    [anon_sym_BSLASH] = ACTIONS(533),
    [anon_sym_DOT_BSLASH] = ACTIONS(533),
    [anon_sym_CARET] = ACTIONS(533),
    [anon_sym_DOT_CARET] = ACTIONS(533),
    [anon_sym_PIPE] = ACTIONS(533),
    [anon_sym_AMP] = ACTIONS(533),
    [anon_sym_end] = ACTIONS(533),
    [anon_sym_DOT] = ACTIONS(533),
    [anon_sym_TILDE] = ACTIONS(533),
    [anon_sym_QMARK] = ACTIONS(533),
    [anon_sym_AT] = ACTIONS(533),
    [anon_sym_LT] = ACTIONS(533),
    [anon_sym_LT_EQ] = ACTIONS(533),
    [anon_sym_EQ_EQ] = ACTIONS(533),
    [anon_sym_TILDE_EQ] = ACTIONS(533),
    [anon_sym_GT_EQ] = ACTIONS(533),
    [anon_sym_GT] = ACTIONS(533),
    [anon_sym_AMP_AMP] = ACTIONS(533),
    [anon_sym_PIPE_PIPE] = ACTIONS(533),
    [anon_sym_DOT_SQUOTE] = ACTIONS(533),
    [anon_sym_SQUOTE] = ACTIONS(533),
    [anon_sym_LBRACK] = ACTIONS(533),
    [anon_sym_LF] = ACTIONS(533),
    [anon_sym_LBRACE] = ACTIONS(533),
    [anon_sym_COLON] = ACTIONS(533),
    [sym_return_statement] = ACTIONS(533),
    [sym_continue_statement] = ACTIONS(533),
    [sym_break_statement] = ACTIONS(533),
    [anon_sym_elseif] = ACTIONS(533),
    [anon_sym_else] = ACTIONS(533),
    [anon_sym_if] = ACTIONS(533),
    [anon_sym_for] = ACTIONS(533),
    [anon_sym_parfor] = ACTIONS(533),
    [anon_sym_while] = ACTIONS(533),
    [anon_sym_switch] = ACTIONS(533),
    [anon_sym_global] = ACTIONS(533),
    [anon_sym_persistent] = ACTIONS(533),
    [anon_sym_function] = ACTIONS(533),
    [anon_sym_classdef] = ACTIONS(533),
    [anon_sym_try] = ACTIONS(533),
    [anon_sym_spmd] = ACTIONS(533),
    [sym_number] = ACTIONS(533),
    [anon_sym_true] = ACTIONS(533),
    [anon_sym_false] = ACTIONS(533),
    [anon_sym_CR] = ACTIONS(533),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(535),
    [sym__single_quote_string_start] = ACTIONS(535),
    [sym__double_quote_string_start] = ACTIONS(535),
    [sym__multioutput_variable_start] = ACTIONS(535),
    [sym__external_identifier] = ACTIONS(535),
  },
  [STATE(98)] = {
    [sym__args] = STATE(97),
    [anon_sym_SEMI] = ACTIONS(489),
    [anon_sym_COMMA] = ACTIONS(489),
    [anon_sym_get] = ACTIONS(489),
    [anon_sym_set] = ACTIONS(489),
    [anon_sym_properties] = ACTIONS(489),
    [anon_sym_LPAREN] = ACTIONS(466),
    [anon_sym_PLUS] = ACTIONS(489),
    [anon_sym_DOT_PLUS] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(489),
    [anon_sym_DOT_DASH] = ACTIONS(489),
    [anon_sym_STAR] = ACTIONS(489),
    [anon_sym_DOT_STAR] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(489),
    [anon_sym_DOT_SLASH] = ACTIONS(489),
    [anon_sym_BSLASH] = ACTIONS(489),
    [anon_sym_DOT_BSLASH] = ACTIONS(489),
    [anon_sym_CARET] = ACTIONS(489),
    [anon_sym_DOT_CARET] = ACTIONS(489),
    [anon_sym_PIPE] = ACTIONS(489),
    [anon_sym_AMP] = ACTIONS(489),
    [anon_sym_end] = ACTIONS(489),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_QMARK] = ACTIONS(489),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT] = ACTIONS(489),
    [anon_sym_LT_EQ] = ACTIONS(489),
    [anon_sym_EQ_EQ] = ACTIONS(489),
    [anon_sym_TILDE_EQ] = ACTIONS(489),
    [anon_sym_GT_EQ] = ACTIONS(489),
    [anon_sym_GT] = ACTIONS(489),
    [anon_sym_AMP_AMP] = ACTIONS(489),
    [anon_sym_PIPE_PIPE] = ACTIONS(489),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_LF] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_COLON] = ACTIONS(489),
    [sym_return_statement] = ACTIONS(489),
    [sym_continue_statement] = ACTIONS(489),
    [sym_break_statement] = ACTIONS(489),
    [anon_sym_elseif] = ACTIONS(489),
    [anon_sym_else] = ACTIONS(489),
    [anon_sym_if] = ACTIONS(489),
    [anon_sym_for] = ACTIONS(489),
    [anon_sym_parfor] = ACTIONS(489),
    [anon_sym_while] = ACTIONS(489),
    [anon_sym_switch] = ACTIONS(489),
    [anon_sym_global] = ACTIONS(489),
    [anon_sym_persistent] = ACTIONS(489),
    [anon_sym_function] = ACTIONS(489),
    [anon_sym_classdef] = ACTIONS(489),
    [anon_sym_try] = ACTIONS(489),
    [anon_sym_spmd] = ACTIONS(489),
    [sym_number] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(489),
    [anon_sym_false] = ACTIONS(489),
    [anon_sym_CR] = ACTIONS(489),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(491),
    [sym__single_quote_string_start] = ACTIONS(491),
    [sym__double_quote_string_start] = ACTIONS(491),
    [sym__multioutput_variable_start] = ACTIONS(491),
    [sym__external_identifier] = ACTIONS(491),
  },
  [STATE(99)] = {
    [sym__args] = STATE(97),
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(466),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_COLON] = ACTIONS(478),
    [sym_return_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
  [STATE(100)] = {
    [anon_sym_SEMI] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(539),
    [anon_sym_get] = ACTIONS(539),
    [anon_sym_set] = ACTIONS(539),
    [anon_sym_properties] = ACTIONS(539),
    [anon_sym_LPAREN] = ACTIONS(539),
    [anon_sym_PLUS] = ACTIONS(539),
    [anon_sym_DOT_PLUS] = ACTIONS(539),
    [anon_sym_DASH] = ACTIONS(539),
    [anon_sym_DOT_DASH] = ACTIONS(539),
    [anon_sym_STAR] = ACTIONS(539),
    [anon_sym_DOT_STAR] = ACTIONS(539),
    [anon_sym_SLASH] = ACTIONS(539),
    [anon_sym_DOT_SLASH] = ACTIONS(539),
    [anon_sym_BSLASH] = ACTIONS(539),
    [anon_sym_DOT_BSLASH] = ACTIONS(539),
    [anon_sym_CARET] = ACTIONS(539),
    [anon_sym_DOT_CARET] = ACTIONS(539),
    [anon_sym_PIPE] = ACTIONS(539),
    [anon_sym_AMP] = ACTIONS(539),
    [anon_sym_end] = ACTIONS(539),
    [anon_sym_DOT] = ACTIONS(539),
    [anon_sym_TILDE] = ACTIONS(539),
    [anon_sym_QMARK] = ACTIONS(539),
    [anon_sym_AT] = ACTIONS(539),
    [anon_sym_LT] = ACTIONS(539),
    [anon_sym_LT_EQ] = ACTIONS(539),
    [anon_sym_EQ_EQ] = ACTIONS(539),
    [anon_sym_TILDE_EQ] = ACTIONS(539),
    [anon_sym_GT_EQ] = ACTIONS(539),
    [anon_sym_GT] = ACTIONS(539),
    [anon_sym_AMP_AMP] = ACTIONS(539),
    [anon_sym_PIPE_PIPE] = ACTIONS(539),
    [anon_sym_DOT_SQUOTE] = ACTIONS(539),
    [anon_sym_SQUOTE] = ACTIONS(539),
    [anon_sym_LBRACK] = ACTIONS(539),
    [anon_sym_LF] = ACTIONS(539),
    [anon_sym_LBRACE] = ACTIONS(539),
    [anon_sym_COLON] = ACTIONS(539),
    [sym_return_statement] = ACTIONS(539),
    [sym_continue_statement] = ACTIONS(539),
    [sym_break_statement] = ACTIONS(539),
    [anon_sym_elseif] = ACTIONS(539),
    [anon_sym_else] = ACTIONS(539),
    [anon_sym_if] = ACTIONS(539),
    [anon_sym_for] = ACTIONS(539),
    [anon_sym_parfor] = ACTIONS(539),
    [anon_sym_while] = ACTIONS(539),
    [anon_sym_switch] = ACTIONS(539),
    [anon_sym_global] = ACTIONS(539),
    [anon_sym_persistent] = ACTIONS(539),
    [anon_sym_function] = ACTIONS(539),
    [anon_sym_classdef] = ACTIONS(539),
    [anon_sym_try] = ACTIONS(539),
    [anon_sym_spmd] = ACTIONS(539),
    [sym_number] = ACTIONS(539),
    [anon_sym_true] = ACTIONS(539),
    [anon_sym_false] = ACTIONS(539),
    [anon_sym_CR] = ACTIONS(539),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(541),
    [sym__single_quote_string_start] = ACTIONS(541),
    [sym__double_quote_string_start] = ACTIONS(541),
    [sym__multioutput_variable_start] = ACTIONS(541),
    [sym__external_identifier] = ACTIONS(541),
  },
  [STATE(101)] = {
    [anon_sym_SEMI] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(543),
    [anon_sym_get] = ACTIONS(543),
    [anon_sym_set] = ACTIONS(543),
    [anon_sym_properties] = ACTIONS(543),
    [anon_sym_LPAREN] = ACTIONS(543),
    [anon_sym_PLUS] = ACTIONS(543),
    [anon_sym_DOT_PLUS] = ACTIONS(543),
    [anon_sym_DASH] = ACTIONS(543),
    [anon_sym_DOT_DASH] = ACTIONS(543),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_DOT_STAR] = ACTIONS(543),
    [anon_sym_SLASH] = ACTIONS(543),
    [anon_sym_DOT_SLASH] = ACTIONS(543),
    [anon_sym_BSLASH] = ACTIONS(543),
    [anon_sym_DOT_BSLASH] = ACTIONS(543),
    [anon_sym_CARET] = ACTIONS(543),
    [anon_sym_DOT_CARET] = ACTIONS(543),
    [anon_sym_PIPE] = ACTIONS(543),
    [anon_sym_AMP] = ACTIONS(543),
    [anon_sym_end] = ACTIONS(543),
    [anon_sym_DOT] = ACTIONS(543),
    [anon_sym_TILDE] = ACTIONS(543),
    [anon_sym_QMARK] = ACTIONS(543),
    [anon_sym_AT] = ACTIONS(543),
    [anon_sym_LT] = ACTIONS(543),
    [anon_sym_LT_EQ] = ACTIONS(543),
    [anon_sym_EQ_EQ] = ACTIONS(543),
    [anon_sym_TILDE_EQ] = ACTIONS(543),
    [anon_sym_GT_EQ] = ACTIONS(543),
    [anon_sym_GT] = ACTIONS(543),
    [anon_sym_AMP_AMP] = ACTIONS(543),
    [anon_sym_PIPE_PIPE] = ACTIONS(543),
    [anon_sym_DOT_SQUOTE] = ACTIONS(543),
    [anon_sym_SQUOTE] = ACTIONS(543),
    [anon_sym_LBRACK] = ACTIONS(543),
    [anon_sym_LF] = ACTIONS(543),
    [anon_sym_LBRACE] = ACTIONS(543),
    [anon_sym_COLON] = ACTIONS(543),
    [sym_return_statement] = ACTIONS(543),
    [sym_continue_statement] = ACTIONS(543),
    [sym_break_statement] = ACTIONS(543),
    [anon_sym_elseif] = ACTIONS(543),
    [anon_sym_else] = ACTIONS(543),
    [anon_sym_if] = ACTIONS(543),
    [anon_sym_for] = ACTIONS(543),
    [anon_sym_parfor] = ACTIONS(543),
    [anon_sym_while] = ACTIONS(543),
    [anon_sym_switch] = ACTIONS(543),
    [anon_sym_global] = ACTIONS(543),
    [anon_sym_persistent] = ACTIONS(543),
    [anon_sym_function] = ACTIONS(543),
    [anon_sym_classdef] = ACTIONS(543),
    [anon_sym_try] = ACTIONS(543),
    [anon_sym_spmd] = ACTIONS(543),
    [sym_number] = ACTIONS(543),
    [anon_sym_true] = ACTIONS(543),
    [anon_sym_false] = ACTIONS(543),
    [anon_sym_CR] = ACTIONS(543),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(545),
    [sym__single_quote_string_start] = ACTIONS(545),
    [sym__double_quote_string_start] = ACTIONS(545),
    [sym__multioutput_variable_start] = ACTIONS(545),
    [sym__external_identifier] = ACTIONS(545),
  },
  [STATE(102)] = {
    [anon_sym_SEMI] = ACTIONS(547),
    [anon_sym_COMMA] = ACTIONS(547),
    [anon_sym_get] = ACTIONS(547),
    [anon_sym_set] = ACTIONS(547),
    [anon_sym_properties] = ACTIONS(547),
    [anon_sym_LPAREN] = ACTIONS(547),
    [anon_sym_PLUS] = ACTIONS(547),
    [anon_sym_DOT_PLUS] = ACTIONS(547),
    [anon_sym_DASH] = ACTIONS(547),
    [anon_sym_DOT_DASH] = ACTIONS(547),
    [anon_sym_STAR] = ACTIONS(547),
    [anon_sym_DOT_STAR] = ACTIONS(547),
    [anon_sym_SLASH] = ACTIONS(547),
    [anon_sym_DOT_SLASH] = ACTIONS(547),
    [anon_sym_BSLASH] = ACTIONS(547),
    [anon_sym_DOT_BSLASH] = ACTIONS(547),
    [anon_sym_CARET] = ACTIONS(547),
    [anon_sym_DOT_CARET] = ACTIONS(547),
    [anon_sym_PIPE] = ACTIONS(547),
    [anon_sym_AMP] = ACTIONS(547),
    [anon_sym_end] = ACTIONS(547),
    [anon_sym_DOT] = ACTIONS(547),
    [anon_sym_TILDE] = ACTIONS(547),
    [anon_sym_QMARK] = ACTIONS(547),
    [anon_sym_AT] = ACTIONS(547),
    [anon_sym_LT] = ACTIONS(547),
    [anon_sym_LT_EQ] = ACTIONS(547),
    [anon_sym_EQ_EQ] = ACTIONS(547),
    [anon_sym_TILDE_EQ] = ACTIONS(547),
    [anon_sym_GT_EQ] = ACTIONS(547),
    [anon_sym_GT] = ACTIONS(547),
    [anon_sym_AMP_AMP] = ACTIONS(547),
    [anon_sym_PIPE_PIPE] = ACTIONS(547),
    [anon_sym_DOT_SQUOTE] = ACTIONS(547),
    [anon_sym_SQUOTE] = ACTIONS(547),
    [anon_sym_LBRACK] = ACTIONS(547),
    [anon_sym_LF] = ACTIONS(547),
    [anon_sym_LBRACE] = ACTIONS(547),
    [anon_sym_COLON] = ACTIONS(547),
    [sym_return_statement] = ACTIONS(547),
    [sym_continue_statement] = ACTIONS(547),
    [sym_break_statement] = ACTIONS(547),
    [anon_sym_elseif] = ACTIONS(547),
    [anon_sym_else] = ACTIONS(547),
    [anon_sym_if] = ACTIONS(547),
    [anon_sym_for] = ACTIONS(547),
    [anon_sym_parfor] = ACTIONS(547),
    [anon_sym_while] = ACTIONS(547),
    [anon_sym_switch] = ACTIONS(547),
    [anon_sym_global] = ACTIONS(547),
    [anon_sym_persistent] = ACTIONS(547),
    [anon_sym_function] = ACTIONS(547),
    [anon_sym_classdef] = ACTIONS(547),
    [anon_sym_try] = ACTIONS(547),
    [anon_sym_spmd] = ACTIONS(547),
    [sym_number] = ACTIONS(547),
    [anon_sym_true] = ACTIONS(547),
    [anon_sym_false] = ACTIONS(547),
    [anon_sym_CR] = ACTIONS(547),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(549),
    [sym__single_quote_string_start] = ACTIONS(549),
    [sym__double_quote_string_start] = ACTIONS(549),
    [sym__multioutput_variable_start] = ACTIONS(549),
    [sym__external_identifier] = ACTIONS(549),
  },
  [STATE(103)] = {
    [anon_sym_SEMI] = ACTIONS(551),
    [anon_sym_COMMA] = ACTIONS(551),
    [anon_sym_get] = ACTIONS(551),
    [anon_sym_set] = ACTIONS(551),
    [anon_sym_properties] = ACTIONS(551),
    [anon_sym_LPAREN] = ACTIONS(551),
    [anon_sym_PLUS] = ACTIONS(551),
    [anon_sym_DOT_PLUS] = ACTIONS(551),
    [anon_sym_DASH] = ACTIONS(551),
    [anon_sym_DOT_DASH] = ACTIONS(551),
    [anon_sym_STAR] = ACTIONS(551),
    [anon_sym_DOT_STAR] = ACTIONS(551),
    [anon_sym_SLASH] = ACTIONS(551),
    [anon_sym_DOT_SLASH] = ACTIONS(551),
    [anon_sym_BSLASH] = ACTIONS(551),
    [anon_sym_DOT_BSLASH] = ACTIONS(551),
    [anon_sym_CARET] = ACTIONS(551),
    [anon_sym_DOT_CARET] = ACTIONS(551),
    [anon_sym_PIPE] = ACTIONS(551),
    [anon_sym_AMP] = ACTIONS(551),
    [anon_sym_end] = ACTIONS(551),
    [anon_sym_DOT] = ACTIONS(551),
    [anon_sym_TILDE] = ACTIONS(551),
    [anon_sym_QMARK] = ACTIONS(551),
    [anon_sym_AT] = ACTIONS(551),
    [anon_sym_LT] = ACTIONS(551),
    [anon_sym_LT_EQ] = ACTIONS(551),
    [anon_sym_EQ_EQ] = ACTIONS(551),
    [anon_sym_TILDE_EQ] = ACTIONS(551),
    [anon_sym_GT_EQ] = ACTIONS(551),
    [anon_sym_GT] = ACTIONS(551),
    [anon_sym_AMP_AMP] = ACTIONS(551),
    [anon_sym_PIPE_PIPE] = ACTIONS(551),
    [anon_sym_DOT_SQUOTE] = ACTIONS(551),
    [anon_sym_SQUOTE] = ACTIONS(551),
    [anon_sym_LBRACK] = ACTIONS(551),
    [anon_sym_LF] = ACTIONS(551),
    [anon_sym_LBRACE] = ACTIONS(551),
    [anon_sym_COLON] = ACTIONS(551),
    [sym_return_statement] = ACTIONS(551),
    [sym_continue_statement] = ACTIONS(551),
    [sym_break_statement] = ACTIONS(551),
    [anon_sym_elseif] = ACTIONS(551),
    [anon_sym_else] = ACTIONS(551),
    [anon_sym_if] = ACTIONS(551),
    [anon_sym_for] = ACTIONS(551),
    [anon_sym_parfor] = ACTIONS(551),
    [anon_sym_while] = ACTIONS(551),
    [anon_sym_switch] = ACTIONS(551),
    [anon_sym_global] = ACTIONS(551),
    [anon_sym_persistent] = ACTIONS(551),
    [anon_sym_function] = ACTIONS(551),
    [anon_sym_classdef] = ACTIONS(551),
    [anon_sym_try] = ACTIONS(551),
    [anon_sym_spmd] = ACTIONS(551),
    [sym_number] = ACTIONS(551),
    [anon_sym_true] = ACTIONS(551),
    [anon_sym_false] = ACTIONS(551),
    [anon_sym_CR] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(553),
    [sym__single_quote_string_start] = ACTIONS(553),
    [sym__double_quote_string_start] = ACTIONS(553),
    [sym__multioutput_variable_start] = ACTIONS(553),
    [sym__external_identifier] = ACTIONS(553),
  },
  [STATE(104)] = {
    [anon_sym_SEMI] = ACTIONS(555),
    [anon_sym_COMMA] = ACTIONS(555),
    [anon_sym_get] = ACTIONS(555),
    [anon_sym_set] = ACTIONS(555),
    [anon_sym_properties] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(555),
    [anon_sym_PLUS] = ACTIONS(555),
    [anon_sym_DOT_PLUS] = ACTIONS(555),
    [anon_sym_DASH] = ACTIONS(555),
    [anon_sym_DOT_DASH] = ACTIONS(555),
    [anon_sym_STAR] = ACTIONS(555),
    [anon_sym_DOT_STAR] = ACTIONS(555),
    [anon_sym_SLASH] = ACTIONS(555),
    [anon_sym_DOT_SLASH] = ACTIONS(555),
    [anon_sym_BSLASH] = ACTIONS(555),
    [anon_sym_DOT_BSLASH] = ACTIONS(555),
    [anon_sym_CARET] = ACTIONS(555),
    [anon_sym_DOT_CARET] = ACTIONS(555),
    [anon_sym_PIPE] = ACTIONS(555),
    [anon_sym_AMP] = ACTIONS(555),
    [anon_sym_end] = ACTIONS(555),
    [anon_sym_DOT] = ACTIONS(555),
    [anon_sym_TILDE] = ACTIONS(555),
    [anon_sym_QMARK] = ACTIONS(555),
    [anon_sym_AT] = ACTIONS(555),
    [anon_sym_LT] = ACTIONS(555),
    [anon_sym_LT_EQ] = ACTIONS(555),
    [anon_sym_EQ_EQ] = ACTIONS(555),
    [anon_sym_TILDE_EQ] = ACTIONS(555),
    [anon_sym_GT_EQ] = ACTIONS(555),
    [anon_sym_GT] = ACTIONS(555),
    [anon_sym_AMP_AMP] = ACTIONS(555),
    [anon_sym_PIPE_PIPE] = ACTIONS(555),
    [anon_sym_DOT_SQUOTE] = ACTIONS(555),
    [anon_sym_SQUOTE] = ACTIONS(555),
    [anon_sym_LBRACK] = ACTIONS(555),
    [anon_sym_LF] = ACTIONS(555),
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_COLON] = ACTIONS(555),
    [sym_return_statement] = ACTIONS(555),
    [sym_continue_statement] = ACTIONS(555),
    [sym_break_statement] = ACTIONS(555),
    [anon_sym_elseif] = ACTIONS(555),
    [anon_sym_else] = ACTIONS(555),
    [anon_sym_if] = ACTIONS(555),
    [anon_sym_for] = ACTIONS(555),
    [anon_sym_parfor] = ACTIONS(555),
    [anon_sym_while] = ACTIONS(555),
    [anon_sym_switch] = ACTIONS(555),
    [anon_sym_global] = ACTIONS(555),
    [anon_sym_persistent] = ACTIONS(555),
    [anon_sym_function] = ACTIONS(555),
    [anon_sym_classdef] = ACTIONS(555),
    [anon_sym_try] = ACTIONS(555),
    [anon_sym_spmd] = ACTIONS(555),
    [sym_number] = ACTIONS(555),
    [anon_sym_true] = ACTIONS(555),
    [anon_sym_false] = ACTIONS(555),
    [anon_sym_CR] = ACTIONS(555),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(557),
    [sym__single_quote_string_start] = ACTIONS(557),
    [sym__double_quote_string_start] = ACTIONS(557),
    [sym__multioutput_variable_start] = ACTIONS(557),
    [sym__external_identifier] = ACTIONS(557),
  },
  [STATE(105)] = {
    [anon_sym_SEMI] = ACTIONS(559),
    [anon_sym_COMMA] = ACTIONS(559),
    [anon_sym_get] = ACTIONS(559),
    [anon_sym_set] = ACTIONS(559),
    [anon_sym_properties] = ACTIONS(559),
    [anon_sym_LPAREN] = ACTIONS(559),
    [anon_sym_PLUS] = ACTIONS(559),
    [anon_sym_DOT_PLUS] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(559),
    [anon_sym_DOT_DASH] = ACTIONS(559),
    [anon_sym_STAR] = ACTIONS(559),
    [anon_sym_DOT_STAR] = ACTIONS(559),
    [anon_sym_SLASH] = ACTIONS(559),
    [anon_sym_DOT_SLASH] = ACTIONS(559),
    [anon_sym_BSLASH] = ACTIONS(559),
    [anon_sym_DOT_BSLASH] = ACTIONS(559),
    [anon_sym_CARET] = ACTIONS(559),
    [anon_sym_DOT_CARET] = ACTIONS(559),
    [anon_sym_PIPE] = ACTIONS(559),
    [anon_sym_AMP] = ACTIONS(559),
    [anon_sym_end] = ACTIONS(559),
    [anon_sym_DOT] = ACTIONS(559),
    [anon_sym_TILDE] = ACTIONS(559),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_AT] = ACTIONS(559),
    [anon_sym_LT] = ACTIONS(559),
    [anon_sym_LT_EQ] = ACTIONS(559),
    [anon_sym_EQ_EQ] = ACTIONS(559),
    [anon_sym_TILDE_EQ] = ACTIONS(559),
    [anon_sym_GT_EQ] = ACTIONS(559),
    [anon_sym_GT] = ACTIONS(559),
    [anon_sym_AMP_AMP] = ACTIONS(559),
    [anon_sym_PIPE_PIPE] = ACTIONS(559),
    [anon_sym_DOT_SQUOTE] = ACTIONS(559),
    [anon_sym_SQUOTE] = ACTIONS(559),
    [anon_sym_LBRACK] = ACTIONS(559),
    [anon_sym_LF] = ACTIONS(559),
    [anon_sym_LBRACE] = ACTIONS(559),
    [anon_sym_COLON] = ACTIONS(559),
    [sym_return_statement] = ACTIONS(559),
    [sym_continue_statement] = ACTIONS(559),
    [sym_break_statement] = ACTIONS(559),
    [anon_sym_elseif] = ACTIONS(559),
    [anon_sym_else] = ACTIONS(559),
    [anon_sym_if] = ACTIONS(559),
    [anon_sym_for] = ACTIONS(559),
    [anon_sym_parfor] = ACTIONS(559),
    [anon_sym_while] = ACTIONS(559),
    [anon_sym_switch] = ACTIONS(559),
    [anon_sym_global] = ACTIONS(559),
    [anon_sym_persistent] = ACTIONS(559),
    [anon_sym_function] = ACTIONS(559),
    [anon_sym_classdef] = ACTIONS(559),
    [anon_sym_try] = ACTIONS(559),
    [anon_sym_spmd] = ACTIONS(559),
    [sym_number] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(559),
    [anon_sym_false] = ACTIONS(559),
    [anon_sym_CR] = ACTIONS(559),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(561),
    [sym__single_quote_string_start] = ACTIONS(561),
    [sym__double_quote_string_start] = ACTIONS(561),
    [sym__multioutput_variable_start] = ACTIONS(561),
    [sym__external_identifier] = ACTIONS(561),
  },
  [STATE(106)] = {
    [anon_sym_SEMI] = ACTIONS(563),
    [anon_sym_COMMA] = ACTIONS(563),
    [anon_sym_get] = ACTIONS(563),
    [anon_sym_set] = ACTIONS(563),
    [anon_sym_properties] = ACTIONS(563),
    [anon_sym_LPAREN] = ACTIONS(563),
    [anon_sym_PLUS] = ACTIONS(563),
    [anon_sym_DOT_PLUS] = ACTIONS(563),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_DOT_DASH] = ACTIONS(563),
    [anon_sym_STAR] = ACTIONS(563),
    [anon_sym_DOT_STAR] = ACTIONS(563),
    [anon_sym_SLASH] = ACTIONS(563),
    [anon_sym_DOT_SLASH] = ACTIONS(563),
    [anon_sym_BSLASH] = ACTIONS(563),
    [anon_sym_DOT_BSLASH] = ACTIONS(563),
    [anon_sym_CARET] = ACTIONS(563),
    [anon_sym_DOT_CARET] = ACTIONS(563),
    [anon_sym_PIPE] = ACTIONS(563),
    [anon_sym_AMP] = ACTIONS(563),
    [anon_sym_end] = ACTIONS(563),
    [anon_sym_DOT] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(563),
    [anon_sym_QMARK] = ACTIONS(563),
    [anon_sym_AT] = ACTIONS(563),
    [anon_sym_LT] = ACTIONS(563),
    [anon_sym_LT_EQ] = ACTIONS(563),
    [anon_sym_EQ_EQ] = ACTIONS(563),
    [anon_sym_TILDE_EQ] = ACTIONS(563),
    [anon_sym_GT_EQ] = ACTIONS(563),
    [anon_sym_GT] = ACTIONS(563),
    [anon_sym_AMP_AMP] = ACTIONS(563),
    [anon_sym_PIPE_PIPE] = ACTIONS(563),
    [anon_sym_DOT_SQUOTE] = ACTIONS(563),
    [anon_sym_SQUOTE] = ACTIONS(563),
    [anon_sym_LBRACK] = ACTIONS(563),
    [anon_sym_LF] = ACTIONS(563),
    [anon_sym_LBRACE] = ACTIONS(563),
    [anon_sym_COLON] = ACTIONS(563),
    [sym_return_statement] = ACTIONS(563),
    [sym_continue_statement] = ACTIONS(563),
    [sym_break_statement] = ACTIONS(563),
    [anon_sym_elseif] = ACTIONS(563),
    [anon_sym_else] = ACTIONS(563),
    [anon_sym_if] = ACTIONS(563),
    [anon_sym_for] = ACTIONS(563),
    [anon_sym_parfor] = ACTIONS(563),
    [anon_sym_while] = ACTIONS(563),
    [anon_sym_switch] = ACTIONS(563),
    [anon_sym_global] = ACTIONS(563),
    [anon_sym_persistent] = ACTIONS(563),
    [anon_sym_function] = ACTIONS(563),
    [anon_sym_classdef] = ACTIONS(563),
    [anon_sym_try] = ACTIONS(563),
    [anon_sym_spmd] = ACTIONS(563),
    [sym_number] = ACTIONS(563),
    [anon_sym_true] = ACTIONS(563),
    [anon_sym_false] = ACTIONS(563),
    [anon_sym_CR] = ACTIONS(563),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(565),
    [sym__single_quote_string_start] = ACTIONS(565),
    [sym__double_quote_string_start] = ACTIONS(565),
    [sym__multioutput_variable_start] = ACTIONS(565),
    [sym__external_identifier] = ACTIONS(565),
  },
  [STATE(107)] = {
    [sym__args] = STATE(97),
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(466),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_COLON] = ACTIONS(480),
    [sym_return_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
  [STATE(108)] = {
    [anon_sym_SEMI] = ACTIONS(507),
    [anon_sym_COMMA] = ACTIONS(507),
    [anon_sym_get] = ACTIONS(507),
    [anon_sym_set] = ACTIONS(507),
    [anon_sym_properties] = ACTIONS(507),
    [anon_sym_LPAREN] = ACTIONS(507),
    [anon_sym_PLUS] = ACTIONS(507),
    [anon_sym_DOT_PLUS] = ACTIONS(507),
    [anon_sym_DASH] = ACTIONS(507),
    [anon_sym_DOT_DASH] = ACTIONS(507),
    [anon_sym_STAR] = ACTIONS(507),
    [anon_sym_DOT_STAR] = ACTIONS(507),
    [anon_sym_SLASH] = ACTIONS(507),
    [anon_sym_DOT_SLASH] = ACTIONS(507),
    [anon_sym_BSLASH] = ACTIONS(507),
    [anon_sym_DOT_BSLASH] = ACTIONS(507),
    [anon_sym_CARET] = ACTIONS(507),
    [anon_sym_DOT_CARET] = ACTIONS(507),
    [anon_sym_PIPE] = ACTIONS(507),
    [anon_sym_AMP] = ACTIONS(507),
    [anon_sym_end] = ACTIONS(507),
    [anon_sym_DOT] = ACTIONS(507),
    [anon_sym_TILDE] = ACTIONS(507),
    [anon_sym_QMARK] = ACTIONS(507),
    [anon_sym_AT] = ACTIONS(507),
    [anon_sym_LT] = ACTIONS(507),
    [anon_sym_LT_EQ] = ACTIONS(507),
    [anon_sym_EQ_EQ] = ACTIONS(507),
    [anon_sym_TILDE_EQ] = ACTIONS(507),
    [anon_sym_GT_EQ] = ACTIONS(507),
    [anon_sym_GT] = ACTIONS(507),
    [anon_sym_AMP_AMP] = ACTIONS(507),
    [anon_sym_PIPE_PIPE] = ACTIONS(507),
    [anon_sym_DOT_SQUOTE] = ACTIONS(507),
    [anon_sym_SQUOTE] = ACTIONS(507),
    [anon_sym_LBRACK] = ACTIONS(507),
    [anon_sym_LF] = ACTIONS(507),
    [anon_sym_LBRACE] = ACTIONS(507),
    [anon_sym_COLON] = ACTIONS(507),
    [sym_return_statement] = ACTIONS(507),
    [sym_continue_statement] = ACTIONS(507),
    [sym_break_statement] = ACTIONS(507),
    [anon_sym_elseif] = ACTIONS(507),
    [anon_sym_else] = ACTIONS(507),
    [anon_sym_if] = ACTIONS(507),
    [anon_sym_for] = ACTIONS(507),
    [anon_sym_parfor] = ACTIONS(507),
    [anon_sym_while] = ACTIONS(507),
    [anon_sym_switch] = ACTIONS(507),
    [anon_sym_global] = ACTIONS(507),
    [anon_sym_persistent] = ACTIONS(507),
    [anon_sym_function] = ACTIONS(507),
    [anon_sym_classdef] = ACTIONS(507),
    [anon_sym_try] = ACTIONS(507),
    [anon_sym_spmd] = ACTIONS(507),
    [sym_number] = ACTIONS(507),
    [anon_sym_true] = ACTIONS(507),
    [anon_sym_false] = ACTIONS(507),
    [anon_sym_CR] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(512),
    [sym__single_quote_string_start] = ACTIONS(512),
    [sym__double_quote_string_start] = ACTIONS(512),
    [sym__multioutput_variable_start] = ACTIONS(512),
    [sym__external_identifier] = ACTIONS(512),
  },
  [STATE(109)] = {
    [sym__args] = STATE(97),
    [anon_sym_SEMI] = ACTIONS(464),
    [anon_sym_COMMA] = ACTIONS(464),
    [anon_sym_get] = ACTIONS(464),
    [anon_sym_set] = ACTIONS(464),
    [anon_sym_properties] = ACTIONS(464),
    [anon_sym_LPAREN] = ACTIONS(466),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(464),
    [anon_sym_TILDE] = ACTIONS(464),
    [anon_sym_QMARK] = ACTIONS(464),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT] = ACTIONS(464),
    [anon_sym_LT_EQ] = ACTIONS(464),
    [anon_sym_EQ_EQ] = ACTIONS(464),
    [anon_sym_TILDE_EQ] = ACTIONS(464),
    [anon_sym_GT_EQ] = ACTIONS(464),
    [anon_sym_GT] = ACTIONS(464),
    [anon_sym_AMP_AMP] = ACTIONS(464),
    [anon_sym_PIPE_PIPE] = ACTIONS(464),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(464),
    [anon_sym_LF] = ACTIONS(464),
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_COLON] = ACTIONS(464),
    [sym_return_statement] = ACTIONS(464),
    [sym_continue_statement] = ACTIONS(464),
    [sym_break_statement] = ACTIONS(464),
    [anon_sym_elseif] = ACTIONS(464),
    [anon_sym_else] = ACTIONS(464),
    [anon_sym_if] = ACTIONS(464),
    [anon_sym_for] = ACTIONS(464),
    [anon_sym_parfor] = ACTIONS(464),
    [anon_sym_while] = ACTIONS(464),
    [anon_sym_switch] = ACTIONS(464),
    [anon_sym_global] = ACTIONS(464),
    [anon_sym_persistent] = ACTIONS(464),
    [anon_sym_function] = ACTIONS(464),
    [anon_sym_classdef] = ACTIONS(464),
    [anon_sym_try] = ACTIONS(464),
    [anon_sym_spmd] = ACTIONS(464),
    [sym_number] = ACTIONS(464),
    [anon_sym_true] = ACTIONS(464),
    [anon_sym_false] = ACTIONS(464),
    [anon_sym_CR] = ACTIONS(464),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(476),
    [sym__single_quote_string_start] = ACTIONS(476),
    [sym__double_quote_string_start] = ACTIONS(476),
    [sym__multioutput_variable_start] = ACTIONS(476),
    [sym__external_identifier] = ACTIONS(476),
  },
  [STATE(110)] = {
    [sym__args] = STATE(97),
    [anon_sym_SEMI] = ACTIONS(478),
    [anon_sym_COMMA] = ACTIONS(478),
    [anon_sym_get] = ACTIONS(478),
    [anon_sym_set] = ACTIONS(478),
    [anon_sym_properties] = ACTIONS(478),
    [anon_sym_LPAREN] = ACTIONS(466),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(478),
    [anon_sym_TILDE] = ACTIONS(478),
    [anon_sym_QMARK] = ACTIONS(478),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT] = ACTIONS(480),
    [anon_sym_LT_EQ] = ACTIONS(480),
    [anon_sym_EQ_EQ] = ACTIONS(480),
    [anon_sym_TILDE_EQ] = ACTIONS(480),
    [anon_sym_GT_EQ] = ACTIONS(480),
    [anon_sym_GT] = ACTIONS(480),
    [anon_sym_AMP_AMP] = ACTIONS(480),
    [anon_sym_PIPE_PIPE] = ACTIONS(480),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(478),
    [anon_sym_LF] = ACTIONS(478),
    [anon_sym_LBRACE] = ACTIONS(474),
    [anon_sym_COLON] = ACTIONS(478),
    [sym_return_statement] = ACTIONS(478),
    [sym_continue_statement] = ACTIONS(478),
    [sym_break_statement] = ACTIONS(478),
    [anon_sym_elseif] = ACTIONS(478),
    [anon_sym_else] = ACTIONS(478),
    [anon_sym_if] = ACTIONS(478),
    [anon_sym_for] = ACTIONS(478),
    [anon_sym_parfor] = ACTIONS(478),
    [anon_sym_while] = ACTIONS(478),
    [anon_sym_switch] = ACTIONS(478),
    [anon_sym_global] = ACTIONS(478),
    [anon_sym_persistent] = ACTIONS(478),
    [anon_sym_function] = ACTIONS(478),
    [anon_sym_classdef] = ACTIONS(478),
    [anon_sym_try] = ACTIONS(478),
    [anon_sym_spmd] = ACTIONS(478),
    [sym_number] = ACTIONS(478),
    [anon_sym_true] = ACTIONS(478),
    [anon_sym_false] = ACTIONS(478),
    [anon_sym_CR] = ACTIONS(478),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(483),
    [sym__single_quote_string_start] = ACTIONS(483),
    [sym__double_quote_string_start] = ACTIONS(483),
    [sym__multioutput_variable_start] = ACTIONS(483),
    [sym__external_identifier] = ACTIONS(483),
  },
  [STATE(111)] = {
    [anon_sym_SEMI] = ACTIONS(567),
    [anon_sym_COMMA] = ACTIONS(567),
    [anon_sym_get] = ACTIONS(567),
    [anon_sym_set] = ACTIONS(567),
    [anon_sym_properties] = ACTIONS(567),
    [anon_sym_LPAREN] = ACTIONS(567),
    [anon_sym_PLUS] = ACTIONS(567),
    [anon_sym_DOT_PLUS] = ACTIONS(567),
    [anon_sym_DASH] = ACTIONS(567),
    [anon_sym_DOT_DASH] = ACTIONS(567),
    [anon_sym_STAR] = ACTIONS(567),
    [anon_sym_DOT_STAR] = ACTIONS(567),
    [anon_sym_SLASH] = ACTIONS(567),
    [anon_sym_DOT_SLASH] = ACTIONS(567),
    [anon_sym_BSLASH] = ACTIONS(567),
    [anon_sym_DOT_BSLASH] = ACTIONS(567),
    [anon_sym_CARET] = ACTIONS(567),
    [anon_sym_DOT_CARET] = ACTIONS(567),
    [anon_sym_PIPE] = ACTIONS(567),
    [anon_sym_AMP] = ACTIONS(567),
    [anon_sym_end] = ACTIONS(567),
    [anon_sym_TILDE] = ACTIONS(567),
    [anon_sym_QMARK] = ACTIONS(567),
    [anon_sym_AT] = ACTIONS(567),
    [anon_sym_LT] = ACTIONS(569),
    [anon_sym_LT_EQ] = ACTIONS(569),
    [anon_sym_EQ_EQ] = ACTIONS(569),
    [anon_sym_TILDE_EQ] = ACTIONS(569),
    [anon_sym_GT_EQ] = ACTIONS(569),
    [anon_sym_GT] = ACTIONS(569),
    [anon_sym_AMP_AMP] = ACTIONS(571),
    [anon_sym_PIPE_PIPE] = ACTIONS(573),
    [anon_sym_DOT_SQUOTE] = ACTIONS(567),
    [anon_sym_SQUOTE] = ACTIONS(567),
    [anon_sym_LBRACK] = ACTIONS(567),
    [anon_sym_LF] = ACTIONS(567),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_COLON] = ACTIONS(567),
    [sym_return_statement] = ACTIONS(567),
    [sym_continue_statement] = ACTIONS(567),
    [sym_break_statement] = ACTIONS(567),
    [anon_sym_elseif] = ACTIONS(567),
    [anon_sym_else] = ACTIONS(567),
    [anon_sym_if] = ACTIONS(567),
    [anon_sym_for] = ACTIONS(567),
    [anon_sym_parfor] = ACTIONS(567),
    [anon_sym_while] = ACTIONS(567),
    [anon_sym_switch] = ACTIONS(567),
    [anon_sym_global] = ACTIONS(567),
    [anon_sym_persistent] = ACTIONS(567),
    [anon_sym_function] = ACTIONS(567),
    [anon_sym_classdef] = ACTIONS(567),
    [anon_sym_try] = ACTIONS(567),
    [anon_sym_spmd] = ACTIONS(567),
    [sym_number] = ACTIONS(567),
    [anon_sym_true] = ACTIONS(567),
    [anon_sym_false] = ACTIONS(567),
    [anon_sym_CR] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(575),
    [sym__single_quote_string_start] = ACTIONS(575),
    [sym__double_quote_string_start] = ACTIONS(575),
    [sym__multioutput_variable_start] = ACTIONS(575),
    [sym__external_identifier] = ACTIONS(575),
  },
  [STATE(112)] = {
    [anon_sym_SEMI] = ACTIONS(577),
    [anon_sym_COMMA] = ACTIONS(577),
    [anon_sym_get] = ACTIONS(577),
    [anon_sym_set] = ACTIONS(577),
    [anon_sym_properties] = ACTIONS(577),
    [anon_sym_LPAREN] = ACTIONS(577),
    [anon_sym_PLUS] = ACTIONS(577),
    [anon_sym_DOT_PLUS] = ACTIONS(577),
    [anon_sym_DASH] = ACTIONS(577),
    [anon_sym_DOT_DASH] = ACTIONS(577),
    [anon_sym_STAR] = ACTIONS(577),
    [anon_sym_DOT_STAR] = ACTIONS(577),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_DOT_SLASH] = ACTIONS(577),
    [anon_sym_BSLASH] = ACTIONS(577),
    [anon_sym_DOT_BSLASH] = ACTIONS(577),
    [anon_sym_CARET] = ACTIONS(579),
    [anon_sym_DOT_CARET] = ACTIONS(579),
    [anon_sym_PIPE] = ACTIONS(577),
    [anon_sym_AMP] = ACTIONS(577),
    [anon_sym_end] = ACTIONS(577),
    [anon_sym_TILDE] = ACTIONS(577),
    [anon_sym_QMARK] = ACTIONS(577),
    [anon_sym_AT] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(577),
    [anon_sym_LT_EQ] = ACTIONS(577),
    [anon_sym_EQ_EQ] = ACTIONS(577),
    [anon_sym_TILDE_EQ] = ACTIONS(577),
    [anon_sym_GT_EQ] = ACTIONS(577),
    [anon_sym_GT] = ACTIONS(577),
    [anon_sym_AMP_AMP] = ACTIONS(577),
    [anon_sym_PIPE_PIPE] = ACTIONS(577),
    [anon_sym_DOT_SQUOTE] = ACTIONS(577),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_LBRACK] = ACTIONS(577),
    [anon_sym_LF] = ACTIONS(577),
    [anon_sym_LBRACE] = ACTIONS(577),
    [anon_sym_COLON] = ACTIONS(577),
    [sym_return_statement] = ACTIONS(577),
    [sym_continue_statement] = ACTIONS(577),
    [sym_break_statement] = ACTIONS(577),
    [anon_sym_elseif] = ACTIONS(577),
    [anon_sym_else] = ACTIONS(577),
    [anon_sym_if] = ACTIONS(577),
    [anon_sym_for] = ACTIONS(577),
    [anon_sym_parfor] = ACTIONS(577),
    [anon_sym_while] = ACTIONS(577),
    [anon_sym_switch] = ACTIONS(577),
    [anon_sym_global] = ACTIONS(577),
    [anon_sym_persistent] = ACTIONS(577),
    [anon_sym_function] = ACTIONS(577),
    [anon_sym_classdef] = ACTIONS(577),
    [anon_sym_try] = ACTIONS(577),
    [anon_sym_spmd] = ACTIONS(577),
    [sym_number] = ACTIONS(577),
    [anon_sym_true] = ACTIONS(577),
    [anon_sym_false] = ACTIONS(577),
    [anon_sym_CR] = ACTIONS(577),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(581),
    [sym__single_quote_string_start] = ACTIONS(581),
    [sym__double_quote_string_start] = ACTIONS(581),
    [sym__multioutput_variable_start] = ACTIONS(581),
    [sym__external_identifier] = ACTIONS(581),
  },
  [STATE(113)] = {
    [anon_sym_SEMI] = ACTIONS(577),
    [anon_sym_COMMA] = ACTIONS(577),
    [anon_sym_get] = ACTIONS(577),
    [anon_sym_set] = ACTIONS(577),
    [anon_sym_properties] = ACTIONS(577),
    [anon_sym_LPAREN] = ACTIONS(577),
    [anon_sym_PLUS] = ACTIONS(577),
    [anon_sym_DOT_PLUS] = ACTIONS(577),
    [anon_sym_DASH] = ACTIONS(577),
    [anon_sym_DOT_DASH] = ACTIONS(577),
    [anon_sym_STAR] = ACTIONS(577),
    [anon_sym_DOT_STAR] = ACTIONS(577),
    [anon_sym_SLASH] = ACTIONS(577),
    [anon_sym_DOT_SLASH] = ACTIONS(577),
    [anon_sym_BSLASH] = ACTIONS(577),
    [anon_sym_DOT_BSLASH] = ACTIONS(577),
    [anon_sym_CARET] = ACTIONS(579),
    [anon_sym_DOT_CARET] = ACTIONS(579),
    [anon_sym_PIPE] = ACTIONS(577),
    [anon_sym_AMP] = ACTIONS(577),
    [anon_sym_end] = ACTIONS(577),
    [anon_sym_TILDE] = ACTIONS(577),
    [anon_sym_QMARK] = ACTIONS(577),
    [anon_sym_AT] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(577),
    [anon_sym_LT_EQ] = ACTIONS(577),
    [anon_sym_EQ_EQ] = ACTIONS(577),
    [anon_sym_TILDE_EQ] = ACTIONS(577),
    [anon_sym_GT_EQ] = ACTIONS(577),
    [anon_sym_GT] = ACTIONS(577),
    [anon_sym_AMP_AMP] = ACTIONS(577),
    [anon_sym_PIPE_PIPE] = ACTIONS(577),
    [anon_sym_DOT_SQUOTE] = ACTIONS(577),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_LBRACK] = ACTIONS(577),
    [anon_sym_LF] = ACTIONS(577),
    [anon_sym_LBRACE] = ACTIONS(577),
    [anon_sym_COLON] = ACTIONS(577),
    [sym_return_statement] = ACTIONS(577),
    [sym_continue_statement] = ACTIONS(577),
    [sym_break_statement] = ACTIONS(577),
    [anon_sym_elseif] = ACTIONS(577),
    [anon_sym_else] = ACTIONS(577),
    [anon_sym_if] = ACTIONS(577),
    [anon_sym_for] = ACTIONS(577),
    [anon_sym_parfor] = ACTIONS(577),
    [anon_sym_while] = ACTIONS(577),
    [anon_sym_switch] = ACTIONS(577),
    [anon_sym_global] = ACTIONS(577),
    [anon_sym_persistent] = ACTIONS(577),
    [anon_sym_function] = ACTIONS(577),
    [anon_sym_classdef] = ACTIONS(577),
    [anon_sym_try] = ACTIONS(577),
    [anon_sym_spmd] = ACTIONS(577),
    [sym_number] = ACTIONS(577),
    [anon_sym_true] = ACTIONS(577),
    [anon_sym_false] = ACTIONS(577),
    [anon_sym_CR] = ACTIONS(577),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(581),
    [sym__single_quote_string_start] = ACTIONS(581),
    [sym__double_quote_string_start] = ACTIONS(581),
    [sym__multioutput_variable_start] = ACTIONS(581),
    [sym__external_identifier] = ACTIONS(581),
  },
  [STATE(114)] = {
    [anon_sym_SEMI] = ACTIONS(577),
    [anon_sym_COMMA] = ACTIONS(577),
    [anon_sym_get] = ACTIONS(577),
    [anon_sym_set] = ACTIONS(577),
    [anon_sym_properties] = ACTIONS(577),
    [anon_sym_LPAREN] = ACTIONS(577),
    [anon_sym_PLUS] = ACTIONS(583),
    [anon_sym_DOT_PLUS] = ACTIONS(583),
    [anon_sym_DASH] = ACTIONS(583),
    [anon_sym_DOT_DASH] = ACTIONS(583),
    [anon_sym_STAR] = ACTIONS(585),
    [anon_sym_DOT_STAR] = ACTIONS(585),
    [anon_sym_SLASH] = ACTIONS(585),
    [anon_sym_DOT_SLASH] = ACTIONS(585),
    [anon_sym_BSLASH] = ACTIONS(585),
    [anon_sym_DOT_BSLASH] = ACTIONS(585),
    [anon_sym_CARET] = ACTIONS(579),
    [anon_sym_DOT_CARET] = ACTIONS(579),
    [anon_sym_PIPE] = ACTIONS(577),
    [anon_sym_AMP] = ACTIONS(587),
    [anon_sym_end] = ACTIONS(577),
    [anon_sym_TILDE] = ACTIONS(577),
    [anon_sym_QMARK] = ACTIONS(577),
    [anon_sym_AT] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(577),
    [anon_sym_LT_EQ] = ACTIONS(577),
    [anon_sym_EQ_EQ] = ACTIONS(577),
    [anon_sym_TILDE_EQ] = ACTIONS(577),
    [anon_sym_GT_EQ] = ACTIONS(577),
    [anon_sym_GT] = ACTIONS(577),
    [anon_sym_AMP_AMP] = ACTIONS(577),
    [anon_sym_PIPE_PIPE] = ACTIONS(577),
    [anon_sym_DOT_SQUOTE] = ACTIONS(577),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_LBRACK] = ACTIONS(577),
    [anon_sym_LF] = ACTIONS(577),
    [anon_sym_LBRACE] = ACTIONS(577),
    [anon_sym_COLON] = ACTIONS(577),
    [sym_return_statement] = ACTIONS(577),
    [sym_continue_statement] = ACTIONS(577),
    [sym_break_statement] = ACTIONS(577),
    [anon_sym_elseif] = ACTIONS(577),
    [anon_sym_else] = ACTIONS(577),
    [anon_sym_if] = ACTIONS(577),
    [anon_sym_for] = ACTIONS(577),
    [anon_sym_parfor] = ACTIONS(577),
    [anon_sym_while] = ACTIONS(577),
    [anon_sym_switch] = ACTIONS(577),
    [anon_sym_global] = ACTIONS(577),
    [anon_sym_persistent] = ACTIONS(577),
    [anon_sym_function] = ACTIONS(577),
    [anon_sym_classdef] = ACTIONS(577),
    [anon_sym_try] = ACTIONS(577),
    [anon_sym_spmd] = ACTIONS(577),
    [sym_number] = ACTIONS(577),
    [anon_sym_true] = ACTIONS(577),
    [anon_sym_false] = ACTIONS(577),
    [anon_sym_CR] = ACTIONS(577),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(581),
    [sym__single_quote_string_start] = ACTIONS(581),
    [sym__double_quote_string_start] = ACTIONS(581),
    [sym__multioutput_variable_start] = ACTIONS(581),
    [sym__external_identifier] = ACTIONS(581),
  },
  [STATE(115)] = {
    [anon_sym_SEMI] = ACTIONS(577),
    [anon_sym_COMMA] = ACTIONS(577),
    [anon_sym_get] = ACTIONS(577),
    [anon_sym_set] = ACTIONS(577),
    [anon_sym_properties] = ACTIONS(577),
    [anon_sym_LPAREN] = ACTIONS(577),
    [anon_sym_PLUS] = ACTIONS(583),
    [anon_sym_DOT_PLUS] = ACTIONS(583),
    [anon_sym_DASH] = ACTIONS(583),
    [anon_sym_DOT_DASH] = ACTIONS(583),
    [anon_sym_STAR] = ACTIONS(585),
    [anon_sym_DOT_STAR] = ACTIONS(585),
    [anon_sym_SLASH] = ACTIONS(585),
    [anon_sym_DOT_SLASH] = ACTIONS(585),
    [anon_sym_BSLASH] = ACTIONS(585),
    [anon_sym_DOT_BSLASH] = ACTIONS(585),
    [anon_sym_CARET] = ACTIONS(579),
    [anon_sym_DOT_CARET] = ACTIONS(579),
    [anon_sym_PIPE] = ACTIONS(577),
    [anon_sym_AMP] = ACTIONS(577),
    [anon_sym_end] = ACTIONS(577),
    [anon_sym_TILDE] = ACTIONS(577),
    [anon_sym_QMARK] = ACTIONS(577),
    [anon_sym_AT] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(577),
    [anon_sym_LT_EQ] = ACTIONS(577),
    [anon_sym_EQ_EQ] = ACTIONS(577),
    [anon_sym_TILDE_EQ] = ACTIONS(577),
    [anon_sym_GT_EQ] = ACTIONS(577),
    [anon_sym_GT] = ACTIONS(577),
    [anon_sym_AMP_AMP] = ACTIONS(577),
    [anon_sym_PIPE_PIPE] = ACTIONS(577),
    [anon_sym_DOT_SQUOTE] = ACTIONS(577),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_LBRACK] = ACTIONS(577),
    [anon_sym_LF] = ACTIONS(577),
    [anon_sym_LBRACE] = ACTIONS(577),
    [anon_sym_COLON] = ACTIONS(577),
    [sym_return_statement] = ACTIONS(577),
    [sym_continue_statement] = ACTIONS(577),
    [sym_break_statement] = ACTIONS(577),
    [anon_sym_elseif] = ACTIONS(577),
    [anon_sym_else] = ACTIONS(577),
    [anon_sym_if] = ACTIONS(577),
    [anon_sym_for] = ACTIONS(577),
    [anon_sym_parfor] = ACTIONS(577),
    [anon_sym_while] = ACTIONS(577),
    [anon_sym_switch] = ACTIONS(577),
    [anon_sym_global] = ACTIONS(577),
    [anon_sym_persistent] = ACTIONS(577),
    [anon_sym_function] = ACTIONS(577),
    [anon_sym_classdef] = ACTIONS(577),
    [anon_sym_try] = ACTIONS(577),
    [anon_sym_spmd] = ACTIONS(577),
    [sym_number] = ACTIONS(577),
    [anon_sym_true] = ACTIONS(577),
    [anon_sym_false] = ACTIONS(577),
    [anon_sym_CR] = ACTIONS(577),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(581),
    [sym__single_quote_string_start] = ACTIONS(581),
    [sym__double_quote_string_start] = ACTIONS(581),
    [sym__multioutput_variable_start] = ACTIONS(581),
    [sym__external_identifier] = ACTIONS(581),
  },
  [STATE(116)] = {
    [anon_sym_SEMI] = ACTIONS(589),
    [anon_sym_COMMA] = ACTIONS(589),
    [anon_sym_get] = ACTIONS(589),
    [anon_sym_set] = ACTIONS(589),
    [anon_sym_properties] = ACTIONS(589),
    [anon_sym_LPAREN] = ACTIONS(589),
    [anon_sym_PLUS] = ACTIONS(589),
    [anon_sym_DOT_PLUS] = ACTIONS(589),
    [anon_sym_DASH] = ACTIONS(589),
    [anon_sym_DOT_DASH] = ACTIONS(589),
    [anon_sym_STAR] = ACTIONS(589),
    [anon_sym_DOT_STAR] = ACTIONS(589),
    [anon_sym_SLASH] = ACTIONS(589),
    [anon_sym_DOT_SLASH] = ACTIONS(589),
    [anon_sym_BSLASH] = ACTIONS(589),
    [anon_sym_DOT_BSLASH] = ACTIONS(589),
    [anon_sym_CARET] = ACTIONS(589),
    [anon_sym_DOT_CARET] = ACTIONS(589),
    [anon_sym_PIPE] = ACTIONS(589),
    [anon_sym_AMP] = ACTIONS(589),
    [anon_sym_end] = ACTIONS(589),
    [anon_sym_TILDE] = ACTIONS(589),
    [anon_sym_QMARK] = ACTIONS(589),
    [anon_sym_AT] = ACTIONS(589),
    [anon_sym_LT] = ACTIONS(589),
    [anon_sym_LT_EQ] = ACTIONS(589),
    [anon_sym_EQ_EQ] = ACTIONS(589),
    [anon_sym_TILDE_EQ] = ACTIONS(589),
    [anon_sym_GT_EQ] = ACTIONS(589),
    [anon_sym_GT] = ACTIONS(589),
    [anon_sym_AMP_AMP] = ACTIONS(589),
    [anon_sym_PIPE_PIPE] = ACTIONS(589),
    [anon_sym_DOT_SQUOTE] = ACTIONS(589),
    [anon_sym_SQUOTE] = ACTIONS(589),
    [anon_sym_LBRACK] = ACTIONS(589),
    [anon_sym_LF] = ACTIONS(589),
    [anon_sym_LBRACE] = ACTIONS(589),
    [anon_sym_COLON] = ACTIONS(591),
    [sym_return_statement] = ACTIONS(589),
    [sym_continue_statement] = ACTIONS(589),
    [sym_break_statement] = ACTIONS(589),
    [anon_sym_elseif] = ACTIONS(589),
    [anon_sym_else] = ACTIONS(589),
    [anon_sym_if] = ACTIONS(589),
    [anon_sym_for] = ACTIONS(589),
    [anon_sym_parfor] = ACTIONS(589),
    [anon_sym_while] = ACTIONS(589),
    [anon_sym_switch] = ACTIONS(589),
    [anon_sym_global] = ACTIONS(589),
    [anon_sym_persistent] = ACTIONS(589),
    [anon_sym_function] = ACTIONS(589),
    [anon_sym_classdef] = ACTIONS(589),
    [anon_sym_try] = ACTIONS(589),
    [anon_sym_spmd] = ACTIONS(589),
    [sym_number] = ACTIONS(589),
    [anon_sym_true] = ACTIONS(589),
    [anon_sym_false] = ACTIONS(589),
    [anon_sym_CR] = ACTIONS(589),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(593),
    [sym__single_quote_string_start] = ACTIONS(593),
    [sym__double_quote_string_start] = ACTIONS(593),
    [sym__multioutput_variable_start] = ACTIONS(593),
    [sym__external_identifier] = ACTIONS(593),
  },
  [STATE(117)] = {
    [anon_sym_SEMI] = ACTIONS(595),
    [anon_sym_COMMA] = ACTIONS(595),
    [anon_sym_get] = ACTIONS(595),
    [anon_sym_set] = ACTIONS(595),
    [anon_sym_properties] = ACTIONS(595),
    [anon_sym_LPAREN] = ACTIONS(595),
    [anon_sym_PLUS] = ACTIONS(595),
    [anon_sym_DOT_PLUS] = ACTIONS(595),
    [anon_sym_DASH] = ACTIONS(595),
    [anon_sym_DOT_DASH] = ACTIONS(595),
    [anon_sym_STAR] = ACTIONS(595),
    [anon_sym_DOT_STAR] = ACTIONS(595),
    [anon_sym_SLASH] = ACTIONS(595),
    [anon_sym_DOT_SLASH] = ACTIONS(595),
    [anon_sym_BSLASH] = ACTIONS(595),
    [anon_sym_DOT_BSLASH] = ACTIONS(595),
    [anon_sym_CARET] = ACTIONS(595),
    [anon_sym_DOT_CARET] = ACTIONS(595),
    [anon_sym_PIPE] = ACTIONS(595),
    [anon_sym_AMP] = ACTIONS(595),
    [anon_sym_end] = ACTIONS(595),
    [anon_sym_TILDE] = ACTIONS(595),
    [anon_sym_QMARK] = ACTIONS(595),
    [anon_sym_AT] = ACTIONS(595),
    [anon_sym_LT] = ACTIONS(595),
    [anon_sym_LT_EQ] = ACTIONS(595),
    [anon_sym_EQ_EQ] = ACTIONS(595),
    [anon_sym_TILDE_EQ] = ACTIONS(595),
    [anon_sym_GT_EQ] = ACTIONS(595),
    [anon_sym_GT] = ACTIONS(595),
    [anon_sym_AMP_AMP] = ACTIONS(595),
    [anon_sym_PIPE_PIPE] = ACTIONS(595),
    [anon_sym_DOT_SQUOTE] = ACTIONS(595),
    [anon_sym_SQUOTE] = ACTIONS(595),
    [anon_sym_LBRACK] = ACTIONS(595),
    [anon_sym_LF] = ACTIONS(595),
    [anon_sym_LBRACE] = ACTIONS(595),
    [anon_sym_COLON] = ACTIONS(595),
    [sym_return_statement] = ACTIONS(595),
    [sym_continue_statement] = ACTIONS(595),
    [sym_break_statement] = ACTIONS(595),
    [anon_sym_elseif] = ACTIONS(595),
    [anon_sym_else] = ACTIONS(595),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_for] = ACTIONS(595),
    [anon_sym_parfor] = ACTIONS(595),
    [anon_sym_while] = ACTIONS(595),
    [anon_sym_switch] = ACTIONS(595),
    [anon_sym_global] = ACTIONS(595),
    [anon_sym_persistent] = ACTIONS(595),
    [anon_sym_function] = ACTIONS(595),
    [anon_sym_classdef] = ACTIONS(595),
    [anon_sym_try] = ACTIONS(595),
    [anon_sym_spmd] = ACTIONS(595),
    [sym_number] = ACTIONS(595),
    [anon_sym_true] = ACTIONS(595),
    [anon_sym_false] = ACTIONS(595),
    [anon_sym_CR] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(597),
    [sym__single_quote_string_start] = ACTIONS(597),
    [sym__double_quote_string_start] = ACTIONS(597),
    [sym__multioutput_variable_start] = ACTIONS(597),
    [sym__external_identifier] = ACTIONS(597),
  },
  [STATE(118)] = {
    [anon_sym_SEMI] = ACTIONS(599),
    [anon_sym_COMMA] = ACTIONS(599),
    [anon_sym_get] = ACTIONS(599),
    [anon_sym_set] = ACTIONS(599),
    [anon_sym_properties] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(599),
    [anon_sym_PLUS] = ACTIONS(599),
    [anon_sym_DOT_PLUS] = ACTIONS(599),
    [anon_sym_DASH] = ACTIONS(599),
    [anon_sym_DOT_DASH] = ACTIONS(599),
    [anon_sym_STAR] = ACTIONS(599),
    [anon_sym_DOT_STAR] = ACTIONS(599),
    [anon_sym_SLASH] = ACTIONS(599),
    [anon_sym_DOT_SLASH] = ACTIONS(599),
    [anon_sym_BSLASH] = ACTIONS(599),
    [anon_sym_DOT_BSLASH] = ACTIONS(599),
    [anon_sym_CARET] = ACTIONS(599),
    [anon_sym_DOT_CARET] = ACTIONS(599),
    [anon_sym_PIPE] = ACTIONS(599),
    [anon_sym_AMP] = ACTIONS(599),
    [anon_sym_end] = ACTIONS(599),
    [anon_sym_TILDE] = ACTIONS(599),
    [anon_sym_QMARK] = ACTIONS(599),
    [anon_sym_AT] = ACTIONS(599),
    [anon_sym_LT] = ACTIONS(599),
    [anon_sym_LT_EQ] = ACTIONS(599),
    [anon_sym_EQ_EQ] = ACTIONS(599),
    [anon_sym_TILDE_EQ] = ACTIONS(599),
    [anon_sym_GT_EQ] = ACTIONS(599),
    [anon_sym_GT] = ACTIONS(599),
    [anon_sym_AMP_AMP] = ACTIONS(599),
    [anon_sym_PIPE_PIPE] = ACTIONS(599),
    [anon_sym_DOT_SQUOTE] = ACTIONS(599),
    [anon_sym_SQUOTE] = ACTIONS(599),
    [anon_sym_LBRACK] = ACTIONS(599),
    [anon_sym_LF] = ACTIONS(599),
    [anon_sym_LBRACE] = ACTIONS(599),
    [anon_sym_COLON] = ACTIONS(599),
    [sym_return_statement] = ACTIONS(599),
    [sym_continue_statement] = ACTIONS(599),
    [sym_break_statement] = ACTIONS(599),
    [anon_sym_elseif] = ACTIONS(599),
    [anon_sym_else] = ACTIONS(599),
    [anon_sym_if] = ACTIONS(599),
    [anon_sym_for] = ACTIONS(599),
    [anon_sym_parfor] = ACTIONS(599),
    [anon_sym_while] = ACTIONS(599),
    [anon_sym_switch] = ACTIONS(599),
    [anon_sym_global] = ACTIONS(599),
    [anon_sym_persistent] = ACTIONS(599),
    [anon_sym_function] = ACTIONS(599),
    [anon_sym_classdef] = ACTIONS(599),
    [anon_sym_try] = ACTIONS(599),
    [anon_sym_spmd] = ACTIONS(599),
    [sym_number] = ACTIONS(599),
    [anon_sym_true] = ACTIONS(599),
    [anon_sym_false] = ACTIONS(599),
    [anon_sym_CR] = ACTIONS(599),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(601),
    [sym__single_quote_string_start] = ACTIONS(601),
    [sym__double_quote_string_start] = ACTIONS(601),
    [sym__multioutput_variable_start] = ACTIONS(601),
    [sym__external_identifier] = ACTIONS(601),
  },
  [STATE(119)] = {
    [anon_sym_SEMI] = ACTIONS(603),
    [anon_sym_COMMA] = ACTIONS(603),
    [anon_sym_get] = ACTIONS(603),
    [anon_sym_set] = ACTIONS(603),
    [anon_sym_properties] = ACTIONS(603),
    [anon_sym_LPAREN] = ACTIONS(603),
    [anon_sym_PLUS] = ACTIONS(603),
    [anon_sym_DOT_PLUS] = ACTIONS(603),
    [anon_sym_DASH] = ACTIONS(603),
    [anon_sym_DOT_DASH] = ACTIONS(603),
    [anon_sym_STAR] = ACTIONS(603),
    [anon_sym_DOT_STAR] = ACTIONS(603),
    [anon_sym_SLASH] = ACTIONS(603),
    [anon_sym_DOT_SLASH] = ACTIONS(603),
    [anon_sym_BSLASH] = ACTIONS(603),
    [anon_sym_DOT_BSLASH] = ACTIONS(603),
    [anon_sym_CARET] = ACTIONS(603),
    [anon_sym_DOT_CARET] = ACTIONS(603),
    [anon_sym_PIPE] = ACTIONS(603),
    [anon_sym_AMP] = ACTIONS(603),
    [anon_sym_end] = ACTIONS(603),
    [anon_sym_TILDE] = ACTIONS(603),
    [anon_sym_QMARK] = ACTIONS(603),
    [anon_sym_AT] = ACTIONS(603),
    [anon_sym_LT] = ACTIONS(603),
    [anon_sym_LT_EQ] = ACTIONS(603),
    [anon_sym_EQ_EQ] = ACTIONS(603),
    [anon_sym_TILDE_EQ] = ACTIONS(603),
    [anon_sym_GT_EQ] = ACTIONS(603),
    [anon_sym_GT] = ACTIONS(603),
    [anon_sym_AMP_AMP] = ACTIONS(603),
    [anon_sym_PIPE_PIPE] = ACTIONS(603),
    [anon_sym_DOT_SQUOTE] = ACTIONS(603),
    [anon_sym_SQUOTE] = ACTIONS(603),
    [anon_sym_LBRACK] = ACTIONS(603),
    [anon_sym_LF] = ACTIONS(603),
    [anon_sym_LBRACE] = ACTIONS(603),
    [anon_sym_COLON] = ACTIONS(603),
    [sym_return_statement] = ACTIONS(603),
    [sym_continue_statement] = ACTIONS(603),
    [sym_break_statement] = ACTIONS(603),
    [anon_sym_elseif] = ACTIONS(603),
    [anon_sym_else] = ACTIONS(603),
    [anon_sym_if] = ACTIONS(603),
    [anon_sym_for] = ACTIONS(603),
    [anon_sym_parfor] = ACTIONS(603),
    [anon_sym_while] = ACTIONS(603),
    [anon_sym_switch] = ACTIONS(603),
    [anon_sym_global] = ACTIONS(603),
    [anon_sym_persistent] = ACTIONS(603),
    [anon_sym_function] = ACTIONS(603),
    [anon_sym_classdef] = ACTIONS(603),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_spmd] = ACTIONS(603),
    [sym_number] = ACTIONS(603),
    [anon_sym_true] = ACTIONS(603),
    [anon_sym_false] = ACTIONS(603),
    [anon_sym_CR] = ACTIONS(603),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(605),
    [sym__single_quote_string_start] = ACTIONS(605),
    [sym__double_quote_string_start] = ACTIONS(605),
    [sym__multioutput_variable_start] = ACTIONS(605),
    [sym__external_identifier] = ACTIONS(605),
  },
  [STATE(120)] = {
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(485),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_COLON] = ACTIONS(607),
    [sym_return_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
  [STATE(121)] = {
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(485),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_COLON] = ACTIONS(480),
    [sym_return_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
  [STATE(122)] = {
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(485),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(485),
    [anon_sym_SQUOTE] = ACTIONS(485),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_COLON] = ACTIONS(480),
    [sym_return_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
  [STATE(123)] = {
    [anon_sym_SEMI] = ACTIONS(610),
    [anon_sym_COMMA] = ACTIONS(610),
    [anon_sym_get] = ACTIONS(610),
    [anon_sym_set] = ACTIONS(610),
    [anon_sym_properties] = ACTIONS(610),
    [anon_sym_LPAREN] = ACTIONS(610),
    [anon_sym_PLUS] = ACTIONS(610),
    [anon_sym_DOT_PLUS] = ACTIONS(610),
    [anon_sym_DASH] = ACTIONS(610),
    [anon_sym_DOT_DASH] = ACTIONS(610),
    [anon_sym_STAR] = ACTIONS(610),
    [anon_sym_DOT_STAR] = ACTIONS(610),
    [anon_sym_SLASH] = ACTIONS(610),
    [anon_sym_DOT_SLASH] = ACTIONS(610),
    [anon_sym_BSLASH] = ACTIONS(610),
    [anon_sym_DOT_BSLASH] = ACTIONS(610),
    [anon_sym_CARET] = ACTIONS(610),
    [anon_sym_DOT_CARET] = ACTIONS(610),
    [anon_sym_PIPE] = ACTIONS(610),
    [anon_sym_AMP] = ACTIONS(610),
    [anon_sym_end] = ACTIONS(610),
    [anon_sym_TILDE] = ACTIONS(610),
    [anon_sym_QMARK] = ACTIONS(610),
    [anon_sym_AT] = ACTIONS(610),
    [anon_sym_LT] = ACTIONS(610),
    [anon_sym_LT_EQ] = ACTIONS(610),
    [anon_sym_EQ_EQ] = ACTIONS(610),
    [anon_sym_TILDE_EQ] = ACTIONS(610),
    [anon_sym_GT_EQ] = ACTIONS(610),
    [anon_sym_GT] = ACTIONS(610),
    [anon_sym_AMP_AMP] = ACTIONS(610),
    [anon_sym_PIPE_PIPE] = ACTIONS(610),
    [anon_sym_DOT_SQUOTE] = ACTIONS(610),
    [anon_sym_SQUOTE] = ACTIONS(610),
    [anon_sym_LBRACK] = ACTIONS(610),
    [anon_sym_LF] = ACTIONS(610),
    [anon_sym_LBRACE] = ACTIONS(610),
    [anon_sym_COLON] = ACTIONS(610),
    [sym_return_statement] = ACTIONS(610),
    [sym_continue_statement] = ACTIONS(610),
    [sym_break_statement] = ACTIONS(610),
    [anon_sym_elseif] = ACTIONS(610),
    [anon_sym_else] = ACTIONS(610),
    [anon_sym_if] = ACTIONS(610),
    [anon_sym_for] = ACTIONS(610),
    [anon_sym_parfor] = ACTIONS(610),
    [anon_sym_while] = ACTIONS(610),
    [anon_sym_switch] = ACTIONS(610),
    [anon_sym_global] = ACTIONS(610),
    [anon_sym_persistent] = ACTIONS(610),
    [anon_sym_function] = ACTIONS(610),
    [anon_sym_classdef] = ACTIONS(610),
    [anon_sym_try] = ACTIONS(610),
    [anon_sym_spmd] = ACTIONS(610),
    [sym_number] = ACTIONS(610),
    [anon_sym_true] = ACTIONS(610),
    [anon_sym_false] = ACTIONS(610),
    [anon_sym_CR] = ACTIONS(610),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(612),
    [sym__single_quote_string_start] = ACTIONS(612),
    [sym__double_quote_string_start] = ACTIONS(612),
    [sym__multioutput_variable_start] = ACTIONS(612),
    [sym__external_identifier] = ACTIONS(612),
  },
  [STATE(124)] = {
    [anon_sym_SEMI] = ACTIONS(614),
    [anon_sym_COMMA] = ACTIONS(614),
    [anon_sym_get] = ACTIONS(614),
    [anon_sym_set] = ACTIONS(614),
    [anon_sym_properties] = ACTIONS(614),
    [anon_sym_LPAREN] = ACTIONS(614),
    [anon_sym_PLUS] = ACTIONS(614),
    [anon_sym_DOT_PLUS] = ACTIONS(614),
    [anon_sym_DASH] = ACTIONS(614),
    [anon_sym_DOT_DASH] = ACTIONS(614),
    [anon_sym_STAR] = ACTIONS(614),
    [anon_sym_DOT_STAR] = ACTIONS(614),
    [anon_sym_SLASH] = ACTIONS(614),
    [anon_sym_DOT_SLASH] = ACTIONS(614),
    [anon_sym_BSLASH] = ACTIONS(614),
    [anon_sym_DOT_BSLASH] = ACTIONS(614),
    [anon_sym_CARET] = ACTIONS(614),
    [anon_sym_DOT_CARET] = ACTIONS(614),
    [anon_sym_PIPE] = ACTIONS(614),
    [anon_sym_AMP] = ACTIONS(614),
    [anon_sym_end] = ACTIONS(614),
    [anon_sym_TILDE] = ACTIONS(614),
    [anon_sym_QMARK] = ACTIONS(614),
    [anon_sym_AT] = ACTIONS(614),
    [anon_sym_LT] = ACTIONS(614),
    [anon_sym_LT_EQ] = ACTIONS(614),
    [anon_sym_EQ_EQ] = ACTIONS(614),
    [anon_sym_TILDE_EQ] = ACTIONS(614),
    [anon_sym_GT_EQ] = ACTIONS(614),
    [anon_sym_GT] = ACTIONS(614),
    [anon_sym_AMP_AMP] = ACTIONS(614),
    [anon_sym_PIPE_PIPE] = ACTIONS(614),
    [anon_sym_DOT_SQUOTE] = ACTIONS(614),
    [anon_sym_SQUOTE] = ACTIONS(614),
    [anon_sym_LBRACK] = ACTIONS(614),
    [anon_sym_LF] = ACTIONS(614),
    [anon_sym_LBRACE] = ACTIONS(614),
    [anon_sym_COLON] = ACTIONS(614),
    [sym_return_statement] = ACTIONS(614),
    [sym_continue_statement] = ACTIONS(614),
    [sym_break_statement] = ACTIONS(614),
    [anon_sym_elseif] = ACTIONS(614),
    [anon_sym_else] = ACTIONS(614),
    [anon_sym_if] = ACTIONS(614),
    [anon_sym_for] = ACTIONS(614),
    [anon_sym_parfor] = ACTIONS(614),
    [anon_sym_while] = ACTIONS(614),
    [anon_sym_switch] = ACTIONS(614),
    [anon_sym_global] = ACTIONS(614),
    [anon_sym_persistent] = ACTIONS(614),
    [anon_sym_function] = ACTIONS(614),
    [anon_sym_classdef] = ACTIONS(614),
    [anon_sym_try] = ACTIONS(614),
    [anon_sym_spmd] = ACTIONS(614),
    [sym_number] = ACTIONS(614),
    [anon_sym_true] = ACTIONS(614),
    [anon_sym_false] = ACTIONS(614),
    [anon_sym_CR] = ACTIONS(614),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(616),
    [sym__single_quote_string_start] = ACTIONS(616),
    [sym__double_quote_string_start] = ACTIONS(616),
    [sym__multioutput_variable_start] = ACTIONS(616),
    [sym__external_identifier] = ACTIONS(616),
  },
  [STATE(125)] = {
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(485),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_COLON] = ACTIONS(618),
    [sym_return_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
  [STATE(126)] = {
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(485),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(485),
    [anon_sym_SQUOTE] = ACTIONS(485),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_COLON] = ACTIONS(485),
    [sym_return_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
  [STATE(127)] = {
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(485),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_COLON] = ACTIONS(485),
    [sym_return_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
  [STATE(128)] = {
    [anon_sym_SEMI] = ACTIONS(620),
    [anon_sym_COMMA] = ACTIONS(620),
    [anon_sym_get] = ACTIONS(620),
    [anon_sym_set] = ACTIONS(620),
    [anon_sym_properties] = ACTIONS(620),
    [anon_sym_LPAREN] = ACTIONS(620),
    [anon_sym_PLUS] = ACTIONS(620),
    [anon_sym_DOT_PLUS] = ACTIONS(620),
    [anon_sym_DASH] = ACTIONS(620),
    [anon_sym_DOT_DASH] = ACTIONS(620),
    [anon_sym_STAR] = ACTIONS(620),
    [anon_sym_DOT_STAR] = ACTIONS(620),
    [anon_sym_SLASH] = ACTIONS(620),
    [anon_sym_DOT_SLASH] = ACTIONS(620),
    [anon_sym_BSLASH] = ACTIONS(620),
    [anon_sym_DOT_BSLASH] = ACTIONS(620),
    [anon_sym_CARET] = ACTIONS(620),
    [anon_sym_DOT_CARET] = ACTIONS(620),
    [anon_sym_PIPE] = ACTIONS(620),
    [anon_sym_AMP] = ACTIONS(620),
    [anon_sym_end] = ACTIONS(620),
    [anon_sym_TILDE] = ACTIONS(620),
    [anon_sym_QMARK] = ACTIONS(620),
    [anon_sym_AT] = ACTIONS(620),
    [anon_sym_LT] = ACTIONS(569),
    [anon_sym_LT_EQ] = ACTIONS(569),
    [anon_sym_EQ_EQ] = ACTIONS(569),
    [anon_sym_TILDE_EQ] = ACTIONS(569),
    [anon_sym_GT_EQ] = ACTIONS(569),
    [anon_sym_GT] = ACTIONS(569),
    [anon_sym_AMP_AMP] = ACTIONS(620),
    [anon_sym_PIPE_PIPE] = ACTIONS(620),
    [anon_sym_DOT_SQUOTE] = ACTIONS(620),
    [anon_sym_SQUOTE] = ACTIONS(620),
    [anon_sym_LBRACK] = ACTIONS(620),
    [anon_sym_LF] = ACTIONS(620),
    [anon_sym_LBRACE] = ACTIONS(620),
    [anon_sym_COLON] = ACTIONS(620),
    [sym_return_statement] = ACTIONS(620),
    [sym_continue_statement] = ACTIONS(620),
    [sym_break_statement] = ACTIONS(620),
    [anon_sym_elseif] = ACTIONS(620),
    [anon_sym_else] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(620),
    [anon_sym_for] = ACTIONS(620),
    [anon_sym_parfor] = ACTIONS(620),
    [anon_sym_while] = ACTIONS(620),
    [anon_sym_switch] = ACTIONS(620),
    [anon_sym_global] = ACTIONS(620),
    [anon_sym_persistent] = ACTIONS(620),
    [anon_sym_function] = ACTIONS(620),
    [anon_sym_classdef] = ACTIONS(620),
    [anon_sym_try] = ACTIONS(620),
    [anon_sym_spmd] = ACTIONS(620),
    [sym_number] = ACTIONS(620),
    [anon_sym_true] = ACTIONS(620),
    [anon_sym_false] = ACTIONS(620),
    [anon_sym_CR] = ACTIONS(620),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(622),
    [sym__single_quote_string_start] = ACTIONS(622),
    [sym__double_quote_string_start] = ACTIONS(622),
    [sym__multioutput_variable_start] = ACTIONS(622),
    [sym__external_identifier] = ACTIONS(622),
  },
  [STATE(129)] = {
    [anon_sym_SEMI] = ACTIONS(620),
    [anon_sym_COMMA] = ACTIONS(620),
    [anon_sym_get] = ACTIONS(620),
    [anon_sym_set] = ACTIONS(620),
    [anon_sym_properties] = ACTIONS(620),
    [anon_sym_LPAREN] = ACTIONS(620),
    [anon_sym_PLUS] = ACTIONS(620),
    [anon_sym_DOT_PLUS] = ACTIONS(620),
    [anon_sym_DASH] = ACTIONS(620),
    [anon_sym_DOT_DASH] = ACTIONS(620),
    [anon_sym_STAR] = ACTIONS(620),
    [anon_sym_DOT_STAR] = ACTIONS(620),
    [anon_sym_SLASH] = ACTIONS(620),
    [anon_sym_DOT_SLASH] = ACTIONS(620),
    [anon_sym_BSLASH] = ACTIONS(620),
    [anon_sym_DOT_BSLASH] = ACTIONS(620),
    [anon_sym_CARET] = ACTIONS(620),
    [anon_sym_DOT_CARET] = ACTIONS(620),
    [anon_sym_PIPE] = ACTIONS(620),
    [anon_sym_AMP] = ACTIONS(620),
    [anon_sym_end] = ACTIONS(620),
    [anon_sym_TILDE] = ACTIONS(620),
    [anon_sym_QMARK] = ACTIONS(620),
    [anon_sym_AT] = ACTIONS(620),
    [anon_sym_LT] = ACTIONS(569),
    [anon_sym_LT_EQ] = ACTIONS(569),
    [anon_sym_EQ_EQ] = ACTIONS(569),
    [anon_sym_TILDE_EQ] = ACTIONS(569),
    [anon_sym_GT_EQ] = ACTIONS(569),
    [anon_sym_GT] = ACTIONS(569),
    [anon_sym_AMP_AMP] = ACTIONS(571),
    [anon_sym_PIPE_PIPE] = ACTIONS(620),
    [anon_sym_DOT_SQUOTE] = ACTIONS(620),
    [anon_sym_SQUOTE] = ACTIONS(620),
    [anon_sym_LBRACK] = ACTIONS(620),
    [anon_sym_LF] = ACTIONS(620),
    [anon_sym_LBRACE] = ACTIONS(620),
    [anon_sym_COLON] = ACTIONS(620),
    [sym_return_statement] = ACTIONS(620),
    [sym_continue_statement] = ACTIONS(620),
    [sym_break_statement] = ACTIONS(620),
    [anon_sym_elseif] = ACTIONS(620),
    [anon_sym_else] = ACTIONS(620),
    [anon_sym_if] = ACTIONS(620),
    [anon_sym_for] = ACTIONS(620),
    [anon_sym_parfor] = ACTIONS(620),
    [anon_sym_while] = ACTIONS(620),
    [anon_sym_switch] = ACTIONS(620),
    [anon_sym_global] = ACTIONS(620),
    [anon_sym_persistent] = ACTIONS(620),
    [anon_sym_function] = ACTIONS(620),
    [anon_sym_classdef] = ACTIONS(620),
    [anon_sym_try] = ACTIONS(620),
    [anon_sym_spmd] = ACTIONS(620),
    [sym_number] = ACTIONS(620),
    [anon_sym_true] = ACTIONS(620),
    [anon_sym_false] = ACTIONS(620),
    [anon_sym_CR] = ACTIONS(620),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(622),
    [sym__single_quote_string_start] = ACTIONS(622),
    [sym__double_quote_string_start] = ACTIONS(622),
    [sym__multioutput_variable_start] = ACTIONS(622),
    [sym__external_identifier] = ACTIONS(622),
  },
  [STATE(130)] = {
    [anon_sym_SEMI] = ACTIONS(624),
    [anon_sym_COMMA] = ACTIONS(624),
    [anon_sym_get] = ACTIONS(624),
    [anon_sym_set] = ACTIONS(624),
    [anon_sym_properties] = ACTIONS(624),
    [anon_sym_LPAREN] = ACTIONS(624),
    [anon_sym_PLUS] = ACTIONS(624),
    [anon_sym_DOT_PLUS] = ACTIONS(624),
    [anon_sym_DASH] = ACTIONS(624),
    [anon_sym_DOT_DASH] = ACTIONS(624),
    [anon_sym_STAR] = ACTIONS(624),
    [anon_sym_DOT_STAR] = ACTIONS(624),
    [anon_sym_SLASH] = ACTIONS(624),
    [anon_sym_DOT_SLASH] = ACTIONS(624),
    [anon_sym_BSLASH] = ACTIONS(624),
    [anon_sym_DOT_BSLASH] = ACTIONS(624),
    [anon_sym_CARET] = ACTIONS(624),
    [anon_sym_DOT_CARET] = ACTIONS(624),
    [anon_sym_PIPE] = ACTIONS(624),
    [anon_sym_AMP] = ACTIONS(624),
    [anon_sym_end] = ACTIONS(624),
    [anon_sym_TILDE] = ACTIONS(624),
    [anon_sym_QMARK] = ACTIONS(624),
    [anon_sym_AT] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(626),
    [anon_sym_LT_EQ] = ACTIONS(626),
    [anon_sym_EQ_EQ] = ACTIONS(626),
    [anon_sym_TILDE_EQ] = ACTIONS(626),
    [anon_sym_GT_EQ] = ACTIONS(626),
    [anon_sym_GT] = ACTIONS(626),
    [anon_sym_AMP_AMP] = ACTIONS(626),
    [anon_sym_PIPE_PIPE] = ACTIONS(626),
    [anon_sym_DOT_SQUOTE] = ACTIONS(624),
    [anon_sym_SQUOTE] = ACTIONS(624),
    [anon_sym_LBRACK] = ACTIONS(624),
    [anon_sym_LF] = ACTIONS(624),
    [anon_sym_LBRACE] = ACTIONS(624),
    [anon_sym_COLON] = ACTIONS(629),
    [sym_return_statement] = ACTIONS(624),
    [sym_continue_statement] = ACTIONS(624),
    [sym_break_statement] = ACTIONS(624),
    [anon_sym_elseif] = ACTIONS(624),
    [anon_sym_else] = ACTIONS(624),
    [anon_sym_if] = ACTIONS(624),
    [anon_sym_for] = ACTIONS(624),
    [anon_sym_parfor] = ACTIONS(624),
    [anon_sym_while] = ACTIONS(624),
    [anon_sym_switch] = ACTIONS(624),
    [anon_sym_global] = ACTIONS(624),
    [anon_sym_persistent] = ACTIONS(624),
    [anon_sym_function] = ACTIONS(624),
    [anon_sym_classdef] = ACTIONS(624),
    [anon_sym_try] = ACTIONS(624),
    [anon_sym_spmd] = ACTIONS(624),
    [sym_number] = ACTIONS(624),
    [anon_sym_true] = ACTIONS(624),
    [anon_sym_false] = ACTIONS(624),
    [anon_sym_CR] = ACTIONS(624),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(631),
    [sym__single_quote_string_start] = ACTIONS(631),
    [sym__double_quote_string_start] = ACTIONS(631),
    [sym__multioutput_variable_start] = ACTIONS(631),
    [sym__external_identifier] = ACTIONS(631),
  },
  [STATE(131)] = {
    [anon_sym_SEMI] = ACTIONS(633),
    [anon_sym_COMMA] = ACTIONS(633),
    [anon_sym_get] = ACTIONS(633),
    [anon_sym_set] = ACTIONS(633),
    [anon_sym_properties] = ACTIONS(633),
    [anon_sym_LPAREN] = ACTIONS(633),
    [anon_sym_PLUS] = ACTIONS(633),
    [anon_sym_DOT_PLUS] = ACTIONS(633),
    [anon_sym_DASH] = ACTIONS(633),
    [anon_sym_DOT_DASH] = ACTIONS(633),
    [anon_sym_STAR] = ACTIONS(633),
    [anon_sym_DOT_STAR] = ACTIONS(633),
    [anon_sym_SLASH] = ACTIONS(633),
    [anon_sym_DOT_SLASH] = ACTIONS(633),
    [anon_sym_BSLASH] = ACTIONS(633),
    [anon_sym_DOT_BSLASH] = ACTIONS(633),
    [anon_sym_CARET] = ACTIONS(633),
    [anon_sym_DOT_CARET] = ACTIONS(633),
    [anon_sym_PIPE] = ACTIONS(633),
    [anon_sym_AMP] = ACTIONS(633),
    [anon_sym_end] = ACTIONS(633),
    [anon_sym_TILDE] = ACTIONS(633),
    [anon_sym_QMARK] = ACTIONS(633),
    [anon_sym_AT] = ACTIONS(633),
    [anon_sym_LT] = ACTIONS(633),
    [anon_sym_LT_EQ] = ACTIONS(633),
    [anon_sym_EQ_EQ] = ACTIONS(633),
    [anon_sym_TILDE_EQ] = ACTIONS(633),
    [anon_sym_GT_EQ] = ACTIONS(633),
    [anon_sym_GT] = ACTIONS(633),
    [anon_sym_AMP_AMP] = ACTIONS(633),
    [anon_sym_PIPE_PIPE] = ACTIONS(633),
    [anon_sym_DOT_SQUOTE] = ACTIONS(633),
    [anon_sym_SQUOTE] = ACTIONS(633),
    [anon_sym_LBRACK] = ACTIONS(633),
    [anon_sym_LF] = ACTIONS(633),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_COLON] = ACTIONS(633),
    [sym_return_statement] = ACTIONS(633),
    [sym_continue_statement] = ACTIONS(633),
    [sym_break_statement] = ACTIONS(633),
    [anon_sym_elseif] = ACTIONS(633),
    [anon_sym_else] = ACTIONS(633),
    [anon_sym_if] = ACTIONS(633),
    [anon_sym_for] = ACTIONS(633),
    [anon_sym_parfor] = ACTIONS(633),
    [anon_sym_while] = ACTIONS(633),
    [anon_sym_switch] = ACTIONS(633),
    [anon_sym_global] = ACTIONS(633),
    [anon_sym_persistent] = ACTIONS(633),
    [anon_sym_function] = ACTIONS(633),
    [anon_sym_classdef] = ACTIONS(633),
    [anon_sym_try] = ACTIONS(633),
    [anon_sym_spmd] = ACTIONS(633),
    [sym_number] = ACTIONS(633),
    [anon_sym_true] = ACTIONS(633),
    [anon_sym_false] = ACTIONS(633),
    [anon_sym_CR] = ACTIONS(633),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(635),
    [sym__single_quote_string_start] = ACTIONS(635),
    [sym__double_quote_string_start] = ACTIONS(635),
    [sym__multioutput_variable_start] = ACTIONS(635),
    [sym__external_identifier] = ACTIONS(635),
  },
  [STATE(132)] = {
    [anon_sym_SEMI] = ACTIONS(637),
    [anon_sym_COMMA] = ACTIONS(637),
    [anon_sym_get] = ACTIONS(637),
    [anon_sym_set] = ACTIONS(637),
    [anon_sym_properties] = ACTIONS(637),
    [anon_sym_LPAREN] = ACTIONS(637),
    [anon_sym_PLUS] = ACTIONS(637),
    [anon_sym_DOT_PLUS] = ACTIONS(637),
    [anon_sym_DASH] = ACTIONS(637),
    [anon_sym_DOT_DASH] = ACTIONS(637),
    [anon_sym_STAR] = ACTIONS(637),
    [anon_sym_DOT_STAR] = ACTIONS(637),
    [anon_sym_SLASH] = ACTIONS(637),
    [anon_sym_DOT_SLASH] = ACTIONS(637),
    [anon_sym_BSLASH] = ACTIONS(637),
    [anon_sym_DOT_BSLASH] = ACTIONS(637),
    [anon_sym_CARET] = ACTIONS(637),
    [anon_sym_DOT_CARET] = ACTIONS(637),
    [anon_sym_PIPE] = ACTIONS(637),
    [anon_sym_AMP] = ACTIONS(637),
    [anon_sym_end] = ACTIONS(637),
    [anon_sym_TILDE] = ACTIONS(637),
    [anon_sym_QMARK] = ACTIONS(637),
    [anon_sym_AT] = ACTIONS(637),
    [anon_sym_LT] = ACTIONS(569),
    [anon_sym_LT_EQ] = ACTIONS(569),
    [anon_sym_EQ_EQ] = ACTIONS(569),
    [anon_sym_TILDE_EQ] = ACTIONS(569),
    [anon_sym_GT_EQ] = ACTIONS(569),
    [anon_sym_GT] = ACTIONS(569),
    [anon_sym_AMP_AMP] = ACTIONS(571),
    [anon_sym_PIPE_PIPE] = ACTIONS(573),
    [anon_sym_DOT_SQUOTE] = ACTIONS(637),
    [anon_sym_SQUOTE] = ACTIONS(637),
    [anon_sym_LBRACK] = ACTIONS(637),
    [anon_sym_LF] = ACTIONS(637),
    [anon_sym_LBRACE] = ACTIONS(637),
    [anon_sym_COLON] = ACTIONS(637),
    [sym_return_statement] = ACTIONS(637),
    [sym_continue_statement] = ACTIONS(637),
    [sym_break_statement] = ACTIONS(637),
    [anon_sym_elseif] = ACTIONS(637),
    [anon_sym_else] = ACTIONS(637),
    [anon_sym_if] = ACTIONS(637),
    [anon_sym_for] = ACTIONS(637),
    [anon_sym_parfor] = ACTIONS(637),
    [anon_sym_while] = ACTIONS(637),
    [anon_sym_switch] = ACTIONS(637),
    [anon_sym_global] = ACTIONS(637),
    [anon_sym_persistent] = ACTIONS(637),
    [anon_sym_function] = ACTIONS(637),
    [anon_sym_classdef] = ACTIONS(637),
    [anon_sym_try] = ACTIONS(637),
    [anon_sym_spmd] = ACTIONS(637),
    [sym_number] = ACTIONS(637),
    [anon_sym_true] = ACTIONS(637),
    [anon_sym_false] = ACTIONS(637),
    [anon_sym_CR] = ACTIONS(637),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(639),
    [sym__single_quote_string_start] = ACTIONS(639),
    [sym__double_quote_string_start] = ACTIONS(639),
    [sym__multioutput_variable_start] = ACTIONS(639),
    [sym__external_identifier] = ACTIONS(639),
  },
  [STATE(133)] = {
    [anon_sym_SEMI] = ACTIONS(641),
    [anon_sym_COMMA] = ACTIONS(641),
    [anon_sym_get] = ACTIONS(641),
    [anon_sym_set] = ACTIONS(641),
    [anon_sym_properties] = ACTIONS(641),
    [anon_sym_LPAREN] = ACTIONS(641),
    [anon_sym_PLUS] = ACTIONS(641),
    [anon_sym_DOT_PLUS] = ACTIONS(641),
    [anon_sym_DASH] = ACTIONS(641),
    [anon_sym_DOT_DASH] = ACTIONS(641),
    [anon_sym_STAR] = ACTIONS(641),
    [anon_sym_DOT_STAR] = ACTIONS(641),
    [anon_sym_SLASH] = ACTIONS(641),
    [anon_sym_DOT_SLASH] = ACTIONS(641),
    [anon_sym_BSLASH] = ACTIONS(641),
    [anon_sym_DOT_BSLASH] = ACTIONS(641),
    [anon_sym_CARET] = ACTIONS(641),
    [anon_sym_DOT_CARET] = ACTIONS(641),
    [anon_sym_PIPE] = ACTIONS(641),
    [anon_sym_AMP] = ACTIONS(641),
    [anon_sym_end] = ACTIONS(641),
    [anon_sym_TILDE] = ACTIONS(641),
    [anon_sym_QMARK] = ACTIONS(641),
    [anon_sym_AT] = ACTIONS(641),
    [anon_sym_LT] = ACTIONS(641),
    [anon_sym_LT_EQ] = ACTIONS(641),
    [anon_sym_EQ_EQ] = ACTIONS(641),
    [anon_sym_TILDE_EQ] = ACTIONS(641),
    [anon_sym_GT_EQ] = ACTIONS(641),
    [anon_sym_GT] = ACTIONS(641),
    [anon_sym_AMP_AMP] = ACTIONS(641),
    [anon_sym_PIPE_PIPE] = ACTIONS(641),
    [anon_sym_DOT_SQUOTE] = ACTIONS(641),
    [anon_sym_SQUOTE] = ACTIONS(641),
    [anon_sym_LBRACK] = ACTIONS(641),
    [anon_sym_LF] = ACTIONS(641),
    [anon_sym_LBRACE] = ACTIONS(641),
    [anon_sym_COLON] = ACTIONS(641),
    [sym_return_statement] = ACTIONS(641),
    [sym_continue_statement] = ACTIONS(641),
    [sym_break_statement] = ACTIONS(641),
    [anon_sym_elseif] = ACTIONS(641),
    [anon_sym_else] = ACTIONS(641),
    [anon_sym_if] = ACTIONS(641),
    [anon_sym_for] = ACTIONS(641),
    [anon_sym_parfor] = ACTIONS(641),
    [anon_sym_while] = ACTIONS(641),
    [anon_sym_switch] = ACTIONS(641),
    [anon_sym_global] = ACTIONS(641),
    [anon_sym_persistent] = ACTIONS(641),
    [anon_sym_function] = ACTIONS(641),
    [anon_sym_classdef] = ACTIONS(641),
    [anon_sym_try] = ACTIONS(641),
    [anon_sym_spmd] = ACTIONS(641),
    [sym_number] = ACTIONS(641),
    [anon_sym_true] = ACTIONS(641),
    [anon_sym_false] = ACTIONS(641),
    [anon_sym_CR] = ACTIONS(641),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(643),
    [sym__single_quote_string_start] = ACTIONS(643),
    [sym__double_quote_string_start] = ACTIONS(643),
    [sym__multioutput_variable_start] = ACTIONS(643),
    [sym__external_identifier] = ACTIONS(643),
  },
  [STATE(134)] = {
    [anon_sym_SEMI] = ACTIONS(464),
    [anon_sym_COMMA] = ACTIONS(464),
    [anon_sym_get] = ACTIONS(464),
    [anon_sym_set] = ACTIONS(464),
    [anon_sym_properties] = ACTIONS(464),
    [anon_sym_LPAREN] = ACTIONS(464),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(464),
    [anon_sym_TILDE] = ACTIONS(464),
    [anon_sym_QMARK] = ACTIONS(464),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_LT] = ACTIONS(464),
    [anon_sym_LT_EQ] = ACTIONS(464),
    [anon_sym_EQ_EQ] = ACTIONS(464),
    [anon_sym_TILDE_EQ] = ACTIONS(464),
    [anon_sym_GT_EQ] = ACTIONS(464),
    [anon_sym_GT] = ACTIONS(464),
    [anon_sym_AMP_AMP] = ACTIONS(464),
    [anon_sym_PIPE_PIPE] = ACTIONS(464),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(464),
    [anon_sym_LF] = ACTIONS(464),
    [anon_sym_LBRACE] = ACTIONS(464),
    [anon_sym_COLON] = ACTIONS(464),
    [sym_return_statement] = ACTIONS(464),
    [sym_continue_statement] = ACTIONS(464),
    [sym_break_statement] = ACTIONS(464),
    [anon_sym_elseif] = ACTIONS(464),
    [anon_sym_else] = ACTIONS(464),
    [anon_sym_if] = ACTIONS(464),
    [anon_sym_for] = ACTIONS(464),
    [anon_sym_parfor] = ACTIONS(464),
    [anon_sym_while] = ACTIONS(464),
    [anon_sym_switch] = ACTIONS(464),
    [anon_sym_global] = ACTIONS(464),
    [anon_sym_persistent] = ACTIONS(464),
    [anon_sym_function] = ACTIONS(464),
    [anon_sym_classdef] = ACTIONS(464),
    [anon_sym_try] = ACTIONS(464),
    [anon_sym_spmd] = ACTIONS(464),
    [sym_number] = ACTIONS(464),
    [anon_sym_true] = ACTIONS(464),
    [anon_sym_false] = ACTIONS(464),
    [anon_sym_CR] = ACTIONS(464),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(476),
    [sym__single_quote_string_start] = ACTIONS(476),
    [sym__double_quote_string_start] = ACTIONS(476),
    [sym__multioutput_variable_start] = ACTIONS(476),
    [sym__external_identifier] = ACTIONS(476),
  },
  [STATE(135)] = {
    [anon_sym_SEMI] = ACTIONS(577),
    [anon_sym_COMMA] = ACTIONS(577),
    [anon_sym_get] = ACTIONS(577),
    [anon_sym_set] = ACTIONS(577),
    [anon_sym_properties] = ACTIONS(577),
    [anon_sym_LPAREN] = ACTIONS(577),
    [anon_sym_PLUS] = ACTIONS(577),
    [anon_sym_DOT_PLUS] = ACTIONS(577),
    [anon_sym_DASH] = ACTIONS(577),
    [anon_sym_DOT_DASH] = ACTIONS(577),
    [anon_sym_STAR] = ACTIONS(585),
    [anon_sym_DOT_STAR] = ACTIONS(585),
    [anon_sym_SLASH] = ACTIONS(585),
    [anon_sym_DOT_SLASH] = ACTIONS(585),
    [anon_sym_BSLASH] = ACTIONS(585),
    [anon_sym_DOT_BSLASH] = ACTIONS(585),
    [anon_sym_CARET] = ACTIONS(579),
    [anon_sym_DOT_CARET] = ACTIONS(579),
    [anon_sym_PIPE] = ACTIONS(577),
    [anon_sym_AMP] = ACTIONS(577),
    [anon_sym_end] = ACTIONS(577),
    [anon_sym_TILDE] = ACTIONS(577),
    [anon_sym_QMARK] = ACTIONS(577),
    [anon_sym_AT] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(577),
    [anon_sym_LT_EQ] = ACTIONS(577),
    [anon_sym_EQ_EQ] = ACTIONS(577),
    [anon_sym_TILDE_EQ] = ACTIONS(577),
    [anon_sym_GT_EQ] = ACTIONS(577),
    [anon_sym_GT] = ACTIONS(577),
    [anon_sym_AMP_AMP] = ACTIONS(577),
    [anon_sym_PIPE_PIPE] = ACTIONS(577),
    [anon_sym_DOT_SQUOTE] = ACTIONS(577),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_LBRACK] = ACTIONS(577),
    [anon_sym_LF] = ACTIONS(577),
    [anon_sym_LBRACE] = ACTIONS(577),
    [anon_sym_COLON] = ACTIONS(577),
    [sym_return_statement] = ACTIONS(577),
    [sym_continue_statement] = ACTIONS(577),
    [sym_break_statement] = ACTIONS(577),
    [anon_sym_elseif] = ACTIONS(577),
    [anon_sym_else] = ACTIONS(577),
    [anon_sym_if] = ACTIONS(577),
    [anon_sym_for] = ACTIONS(577),
    [anon_sym_parfor] = ACTIONS(577),
    [anon_sym_while] = ACTIONS(577),
    [anon_sym_switch] = ACTIONS(577),
    [anon_sym_global] = ACTIONS(577),
    [anon_sym_persistent] = ACTIONS(577),
    [anon_sym_function] = ACTIONS(577),
    [anon_sym_classdef] = ACTIONS(577),
    [anon_sym_try] = ACTIONS(577),
    [anon_sym_spmd] = ACTIONS(577),
    [sym_number] = ACTIONS(577),
    [anon_sym_true] = ACTIONS(577),
    [anon_sym_false] = ACTIONS(577),
    [anon_sym_CR] = ACTIONS(577),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(581),
    [sym__single_quote_string_start] = ACTIONS(581),
    [sym__double_quote_string_start] = ACTIONS(581),
    [sym__multioutput_variable_start] = ACTIONS(581),
    [sym__external_identifier] = ACTIONS(581),
  },
  [STATE(136)] = {
    [anon_sym_SEMI] = ACTIONS(464),
    [anon_sym_COMMA] = ACTIONS(464),
    [anon_sym_get] = ACTIONS(464),
    [anon_sym_set] = ACTIONS(464),
    [anon_sym_properties] = ACTIONS(464),
    [anon_sym_LPAREN] = ACTIONS(464),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(464),
    [anon_sym_TILDE] = ACTIONS(464),
    [anon_sym_QMARK] = ACTIONS(464),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_LT] = ACTIONS(464),
    [anon_sym_LT_EQ] = ACTIONS(464),
    [anon_sym_EQ_EQ] = ACTIONS(464),
    [anon_sym_TILDE_EQ] = ACTIONS(464),
    [anon_sym_GT_EQ] = ACTIONS(464),
    [anon_sym_GT] = ACTIONS(464),
    [anon_sym_AMP_AMP] = ACTIONS(464),
    [anon_sym_PIPE_PIPE] = ACTIONS(464),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(464),
    [anon_sym_LF] = ACTIONS(464),
    [anon_sym_LBRACE] = ACTIONS(464),
    [anon_sym_COLON] = ACTIONS(464),
    [sym_return_statement] = ACTIONS(464),
    [sym_continue_statement] = ACTIONS(464),
    [sym_break_statement] = ACTIONS(464),
    [anon_sym_elseif] = ACTIONS(464),
    [anon_sym_else] = ACTIONS(464),
    [anon_sym_if] = ACTIONS(464),
    [anon_sym_for] = ACTIONS(464),
    [anon_sym_parfor] = ACTIONS(464),
    [anon_sym_while] = ACTIONS(464),
    [anon_sym_switch] = ACTIONS(464),
    [anon_sym_global] = ACTIONS(464),
    [anon_sym_persistent] = ACTIONS(464),
    [anon_sym_function] = ACTIONS(464),
    [anon_sym_classdef] = ACTIONS(464),
    [anon_sym_try] = ACTIONS(464),
    [anon_sym_spmd] = ACTIONS(464),
    [sym_number] = ACTIONS(464),
    [anon_sym_true] = ACTIONS(464),
    [anon_sym_false] = ACTIONS(464),
    [anon_sym_CR] = ACTIONS(464),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(476),
    [sym__single_quote_string_start] = ACTIONS(476),
    [sym__double_quote_string_start] = ACTIONS(476),
    [sym__multioutput_variable_start] = ACTIONS(476),
    [sym__external_identifier] = ACTIONS(476),
  },
  [STATE(137)] = {
    [anon_sym_SEMI] = ACTIONS(464),
    [anon_sym_COMMA] = ACTIONS(464),
    [anon_sym_get] = ACTIONS(464),
    [anon_sym_set] = ACTIONS(464),
    [anon_sym_properties] = ACTIONS(464),
    [anon_sym_LPAREN] = ACTIONS(464),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(464),
    [anon_sym_TILDE] = ACTIONS(464),
    [anon_sym_QMARK] = ACTIONS(464),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_LT] = ACTIONS(464),
    [anon_sym_LT_EQ] = ACTIONS(464),
    [anon_sym_EQ_EQ] = ACTIONS(464),
    [anon_sym_TILDE_EQ] = ACTIONS(464),
    [anon_sym_GT_EQ] = ACTIONS(464),
    [anon_sym_GT] = ACTIONS(464),
    [anon_sym_AMP_AMP] = ACTIONS(464),
    [anon_sym_PIPE_PIPE] = ACTIONS(464),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(464),
    [anon_sym_LF] = ACTIONS(464),
    [anon_sym_LBRACE] = ACTIONS(464),
    [anon_sym_COLON] = ACTIONS(464),
    [sym_return_statement] = ACTIONS(464),
    [sym_continue_statement] = ACTIONS(464),
    [sym_break_statement] = ACTIONS(464),
    [anon_sym_elseif] = ACTIONS(464),
    [anon_sym_else] = ACTIONS(464),
    [anon_sym_if] = ACTIONS(464),
    [anon_sym_for] = ACTIONS(464),
    [anon_sym_parfor] = ACTIONS(464),
    [anon_sym_while] = ACTIONS(464),
    [anon_sym_switch] = ACTIONS(464),
    [anon_sym_global] = ACTIONS(464),
    [anon_sym_persistent] = ACTIONS(464),
    [anon_sym_function] = ACTIONS(464),
    [anon_sym_classdef] = ACTIONS(464),
    [anon_sym_try] = ACTIONS(464),
    [anon_sym_spmd] = ACTIONS(464),
    [sym_number] = ACTIONS(464),
    [anon_sym_true] = ACTIONS(464),
    [anon_sym_false] = ACTIONS(464),
    [anon_sym_CR] = ACTIONS(464),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(476),
    [sym__single_quote_string_start] = ACTIONS(476),
    [sym__double_quote_string_start] = ACTIONS(476),
    [sym__multioutput_variable_start] = ACTIONS(476),
    [sym__external_identifier] = ACTIONS(476),
  },
  [STATE(138)] = {
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(485),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_COLON] = ACTIONS(478),
    [sym_return_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
  [STATE(139)] = {
    [anon_sym_SEMI] = ACTIONS(489),
    [anon_sym_COMMA] = ACTIONS(489),
    [anon_sym_get] = ACTIONS(489),
    [anon_sym_set] = ACTIONS(489),
    [anon_sym_properties] = ACTIONS(489),
    [anon_sym_LPAREN] = ACTIONS(489),
    [anon_sym_PLUS] = ACTIONS(489),
    [anon_sym_DOT_PLUS] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(489),
    [anon_sym_DOT_DASH] = ACTIONS(489),
    [anon_sym_STAR] = ACTIONS(489),
    [anon_sym_DOT_STAR] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(489),
    [anon_sym_DOT_SLASH] = ACTIONS(489),
    [anon_sym_BSLASH] = ACTIONS(489),
    [anon_sym_DOT_BSLASH] = ACTIONS(489),
    [anon_sym_CARET] = ACTIONS(489),
    [anon_sym_DOT_CARET] = ACTIONS(489),
    [anon_sym_PIPE] = ACTIONS(489),
    [anon_sym_AMP] = ACTIONS(489),
    [anon_sym_end] = ACTIONS(489),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_QMARK] = ACTIONS(489),
    [anon_sym_AT] = ACTIONS(489),
    [anon_sym_LT] = ACTIONS(489),
    [anon_sym_LT_EQ] = ACTIONS(489),
    [anon_sym_EQ_EQ] = ACTIONS(489),
    [anon_sym_TILDE_EQ] = ACTIONS(489),
    [anon_sym_GT_EQ] = ACTIONS(489),
    [anon_sym_GT] = ACTIONS(489),
    [anon_sym_AMP_AMP] = ACTIONS(489),
    [anon_sym_PIPE_PIPE] = ACTIONS(489),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_LF] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(489),
    [sym_return_statement] = ACTIONS(489),
    [sym_continue_statement] = ACTIONS(489),
    [sym_break_statement] = ACTIONS(489),
    [anon_sym_elseif] = ACTIONS(489),
    [anon_sym_else] = ACTIONS(489),
    [anon_sym_if] = ACTIONS(489),
    [anon_sym_for] = ACTIONS(489),
    [anon_sym_parfor] = ACTIONS(489),
    [anon_sym_while] = ACTIONS(489),
    [anon_sym_switch] = ACTIONS(489),
    [anon_sym_global] = ACTIONS(489),
    [anon_sym_persistent] = ACTIONS(489),
    [anon_sym_function] = ACTIONS(489),
    [anon_sym_classdef] = ACTIONS(489),
    [anon_sym_try] = ACTIONS(489),
    [anon_sym_spmd] = ACTIONS(489),
    [sym_number] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(489),
    [anon_sym_false] = ACTIONS(489),
    [anon_sym_CR] = ACTIONS(489),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(491),
    [sym__single_quote_string_start] = ACTIONS(491),
    [sym__double_quote_string_start] = ACTIONS(491),
    [sym__multioutput_variable_start] = ACTIONS(491),
    [sym__external_identifier] = ACTIONS(491),
  },
  [STATE(140)] = {
    [anon_sym_SEMI] = ACTIONS(478),
    [anon_sym_COMMA] = ACTIONS(478),
    [anon_sym_get] = ACTIONS(478),
    [anon_sym_set] = ACTIONS(478),
    [anon_sym_properties] = ACTIONS(478),
    [anon_sym_LPAREN] = ACTIONS(478),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(478),
    [anon_sym_TILDE] = ACTIONS(478),
    [anon_sym_QMARK] = ACTIONS(478),
    [anon_sym_AT] = ACTIONS(478),
    [anon_sym_LT] = ACTIONS(480),
    [anon_sym_LT_EQ] = ACTIONS(480),
    [anon_sym_EQ_EQ] = ACTIONS(480),
    [anon_sym_TILDE_EQ] = ACTIONS(480),
    [anon_sym_GT_EQ] = ACTIONS(480),
    [anon_sym_GT] = ACTIONS(480),
    [anon_sym_AMP_AMP] = ACTIONS(480),
    [anon_sym_PIPE_PIPE] = ACTIONS(480),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(478),
    [anon_sym_LF] = ACTIONS(478),
    [anon_sym_LBRACE] = ACTIONS(478),
    [anon_sym_COLON] = ACTIONS(478),
    [sym_return_statement] = ACTIONS(478),
    [sym_continue_statement] = ACTIONS(478),
    [sym_break_statement] = ACTIONS(478),
    [anon_sym_elseif] = ACTIONS(478),
    [anon_sym_else] = ACTIONS(478),
    [anon_sym_if] = ACTIONS(478),
    [anon_sym_for] = ACTIONS(478),
    [anon_sym_parfor] = ACTIONS(478),
    [anon_sym_while] = ACTIONS(478),
    [anon_sym_switch] = ACTIONS(478),
    [anon_sym_global] = ACTIONS(478),
    [anon_sym_persistent] = ACTIONS(478),
    [anon_sym_function] = ACTIONS(478),
    [anon_sym_classdef] = ACTIONS(478),
    [anon_sym_try] = ACTIONS(478),
    [anon_sym_spmd] = ACTIONS(478),
    [sym_number] = ACTIONS(478),
    [anon_sym_true] = ACTIONS(478),
    [anon_sym_false] = ACTIONS(478),
    [anon_sym_CR] = ACTIONS(478),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(483),
    [sym__single_quote_string_start] = ACTIONS(483),
    [sym__double_quote_string_start] = ACTIONS(483),
    [sym__multioutput_variable_start] = ACTIONS(483),
    [sym__external_identifier] = ACTIONS(483),
  },
  [STATE(141)] = {
    [anon_sym_SEMI] = ACTIONS(618),
    [anon_sym_COMMA] = ACTIONS(618),
    [anon_sym_get] = ACTIONS(618),
    [anon_sym_set] = ACTIONS(618),
    [anon_sym_properties] = ACTIONS(618),
    [anon_sym_LPAREN] = ACTIONS(618),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(618),
    [anon_sym_TILDE] = ACTIONS(618),
    [anon_sym_QMARK] = ACTIONS(618),
    [anon_sym_AT] = ACTIONS(618),
    [anon_sym_LT] = ACTIONS(607),
    [anon_sym_LT_EQ] = ACTIONS(607),
    [anon_sym_EQ_EQ] = ACTIONS(607),
    [anon_sym_TILDE_EQ] = ACTIONS(607),
    [anon_sym_GT_EQ] = ACTIONS(607),
    [anon_sym_GT] = ACTIONS(607),
    [anon_sym_AMP_AMP] = ACTIONS(607),
    [anon_sym_PIPE_PIPE] = ACTIONS(607),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(618),
    [anon_sym_LF] = ACTIONS(618),
    [anon_sym_LBRACE] = ACTIONS(618),
    [anon_sym_COLON] = ACTIONS(618),
    [sym_return_statement] = ACTIONS(618),
    [sym_continue_statement] = ACTIONS(618),
    [sym_break_statement] = ACTIONS(618),
    [anon_sym_elseif] = ACTIONS(618),
    [anon_sym_else] = ACTIONS(618),
    [anon_sym_if] = ACTIONS(618),
    [anon_sym_for] = ACTIONS(618),
    [anon_sym_parfor] = ACTIONS(618),
    [anon_sym_while] = ACTIONS(618),
    [anon_sym_switch] = ACTIONS(618),
    [anon_sym_global] = ACTIONS(618),
    [anon_sym_persistent] = ACTIONS(618),
    [anon_sym_function] = ACTIONS(618),
    [anon_sym_classdef] = ACTIONS(618),
    [anon_sym_try] = ACTIONS(618),
    [anon_sym_spmd] = ACTIONS(618),
    [sym_number] = ACTIONS(618),
    [anon_sym_true] = ACTIONS(618),
    [anon_sym_false] = ACTIONS(618),
    [anon_sym_CR] = ACTIONS(618),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(645),
    [sym__single_quote_string_start] = ACTIONS(645),
    [sym__double_quote_string_start] = ACTIONS(645),
    [sym__multioutput_variable_start] = ACTIONS(645),
    [sym__external_identifier] = ACTIONS(645),
  },
  [STATE(142)] = {
    [anon_sym_SEMI] = ACTIONS(478),
    [anon_sym_COMMA] = ACTIONS(478),
    [anon_sym_get] = ACTIONS(478),
    [anon_sym_set] = ACTIONS(478),
    [anon_sym_properties] = ACTIONS(478),
    [anon_sym_LPAREN] = ACTIONS(478),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(478),
    [anon_sym_TILDE] = ACTIONS(478),
    [anon_sym_QMARK] = ACTIONS(478),
    [anon_sym_AT] = ACTIONS(478),
    [anon_sym_LT] = ACTIONS(480),
    [anon_sym_LT_EQ] = ACTIONS(480),
    [anon_sym_EQ_EQ] = ACTIONS(480),
    [anon_sym_TILDE_EQ] = ACTIONS(480),
    [anon_sym_GT_EQ] = ACTIONS(480),
    [anon_sym_GT] = ACTIONS(480),
    [anon_sym_AMP_AMP] = ACTIONS(480),
    [anon_sym_PIPE_PIPE] = ACTIONS(480),
    [anon_sym_DOT_SQUOTE] = ACTIONS(478),
    [anon_sym_SQUOTE] = ACTIONS(478),
    [anon_sym_LBRACK] = ACTIONS(478),
    [anon_sym_LF] = ACTIONS(478),
    [anon_sym_LBRACE] = ACTIONS(478),
    [anon_sym_COLON] = ACTIONS(478),
    [sym_return_statement] = ACTIONS(478),
    [sym_continue_statement] = ACTIONS(478),
    [sym_break_statement] = ACTIONS(478),
    [anon_sym_elseif] = ACTIONS(478),
    [anon_sym_else] = ACTIONS(478),
    [anon_sym_if] = ACTIONS(478),
    [anon_sym_for] = ACTIONS(478),
    [anon_sym_parfor] = ACTIONS(478),
    [anon_sym_while] = ACTIONS(478),
    [anon_sym_switch] = ACTIONS(478),
    [anon_sym_global] = ACTIONS(478),
    [anon_sym_persistent] = ACTIONS(478),
    [anon_sym_function] = ACTIONS(478),
    [anon_sym_classdef] = ACTIONS(478),
    [anon_sym_try] = ACTIONS(478),
    [anon_sym_spmd] = ACTIONS(478),
    [sym_number] = ACTIONS(478),
    [anon_sym_true] = ACTIONS(478),
    [anon_sym_false] = ACTIONS(478),
    [anon_sym_CR] = ACTIONS(478),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(483),
    [sym__single_quote_string_start] = ACTIONS(483),
    [sym__double_quote_string_start] = ACTIONS(483),
    [sym__multioutput_variable_start] = ACTIONS(483),
    [sym__external_identifier] = ACTIONS(483),
  },
  [STATE(143)] = {
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(485),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_COLON] = ACTIONS(647),
    [sym_return_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
  [STATE(144)] = {
    [anon_sym_SEMI] = ACTIONS(464),
    [anon_sym_COMMA] = ACTIONS(464),
    [anon_sym_get] = ACTIONS(464),
    [anon_sym_set] = ACTIONS(464),
    [anon_sym_properties] = ACTIONS(464),
    [anon_sym_LPAREN] = ACTIONS(464),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(464),
    [anon_sym_TILDE] = ACTIONS(464),
    [anon_sym_QMARK] = ACTIONS(464),
    [anon_sym_AT] = ACTIONS(464),
    [anon_sym_LT] = ACTIONS(464),
    [anon_sym_LT_EQ] = ACTIONS(464),
    [anon_sym_EQ_EQ] = ACTIONS(464),
    [anon_sym_TILDE_EQ] = ACTIONS(464),
    [anon_sym_GT_EQ] = ACTIONS(464),
    [anon_sym_GT] = ACTIONS(464),
    [anon_sym_AMP_AMP] = ACTIONS(464),
    [anon_sym_PIPE_PIPE] = ACTIONS(464),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(464),
    [anon_sym_LF] = ACTIONS(464),
    [anon_sym_LBRACE] = ACTIONS(464),
    [anon_sym_COLON] = ACTIONS(464),
    [sym_return_statement] = ACTIONS(464),
    [sym_continue_statement] = ACTIONS(464),
    [sym_break_statement] = ACTIONS(464),
    [anon_sym_elseif] = ACTIONS(464),
    [anon_sym_else] = ACTIONS(464),
    [anon_sym_if] = ACTIONS(464),
    [anon_sym_for] = ACTIONS(464),
    [anon_sym_parfor] = ACTIONS(464),
    [anon_sym_while] = ACTIONS(464),
    [anon_sym_switch] = ACTIONS(464),
    [anon_sym_global] = ACTIONS(464),
    [anon_sym_persistent] = ACTIONS(464),
    [anon_sym_function] = ACTIONS(464),
    [anon_sym_classdef] = ACTIONS(464),
    [anon_sym_try] = ACTIONS(464),
    [anon_sym_spmd] = ACTIONS(464),
    [sym_number] = ACTIONS(464),
    [anon_sym_true] = ACTIONS(464),
    [anon_sym_false] = ACTIONS(464),
    [anon_sym_CR] = ACTIONS(464),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(476),
    [sym__single_quote_string_start] = ACTIONS(476),
    [sym__double_quote_string_start] = ACTIONS(476),
    [sym__multioutput_variable_start] = ACTIONS(476),
    [sym__external_identifier] = ACTIONS(476),
  },
  [STATE(145)] = {
    [anon_sym_SEMI] = ACTIONS(647),
    [anon_sym_COMMA] = ACTIONS(647),
    [anon_sym_get] = ACTIONS(647),
    [anon_sym_set] = ACTIONS(647),
    [anon_sym_properties] = ACTIONS(647),
    [anon_sym_LPAREN] = ACTIONS(647),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(647),
    [anon_sym_TILDE] = ACTIONS(647),
    [anon_sym_QMARK] = ACTIONS(647),
    [anon_sym_AT] = ACTIONS(647),
    [anon_sym_LT] = ACTIONS(649),
    [anon_sym_LT_EQ] = ACTIONS(649),
    [anon_sym_EQ_EQ] = ACTIONS(649),
    [anon_sym_TILDE_EQ] = ACTIONS(649),
    [anon_sym_GT_EQ] = ACTIONS(649),
    [anon_sym_GT] = ACTIONS(649),
    [anon_sym_AMP_AMP] = ACTIONS(649),
    [anon_sym_PIPE_PIPE] = ACTIONS(649),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(647),
    [anon_sym_LF] = ACTIONS(647),
    [anon_sym_LBRACE] = ACTIONS(647),
    [anon_sym_COLON] = ACTIONS(647),
    [sym_return_statement] = ACTIONS(647),
    [sym_continue_statement] = ACTIONS(647),
    [sym_break_statement] = ACTIONS(647),
    [anon_sym_elseif] = ACTIONS(647),
    [anon_sym_else] = ACTIONS(647),
    [anon_sym_if] = ACTIONS(647),
    [anon_sym_for] = ACTIONS(647),
    [anon_sym_parfor] = ACTIONS(647),
    [anon_sym_while] = ACTIONS(647),
    [anon_sym_switch] = ACTIONS(647),
    [anon_sym_global] = ACTIONS(647),
    [anon_sym_persistent] = ACTIONS(647),
    [anon_sym_function] = ACTIONS(647),
    [anon_sym_classdef] = ACTIONS(647),
    [anon_sym_try] = ACTIONS(647),
    [anon_sym_spmd] = ACTIONS(647),
    [sym_number] = ACTIONS(647),
    [anon_sym_true] = ACTIONS(647),
    [anon_sym_false] = ACTIONS(647),
    [anon_sym_CR] = ACTIONS(647),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(652),
    [sym__single_quote_string_start] = ACTIONS(652),
    [sym__double_quote_string_start] = ACTIONS(652),
    [sym__multioutput_variable_start] = ACTIONS(652),
    [sym__external_identifier] = ACTIONS(652),
  },
  [STATE(146)] = {
    [anon_sym_SEMI] = ACTIONS(489),
    [anon_sym_COMMA] = ACTIONS(489),
    [anon_sym_get] = ACTIONS(489),
    [anon_sym_set] = ACTIONS(489),
    [anon_sym_properties] = ACTIONS(489),
    [anon_sym_LPAREN] = ACTIONS(489),
    [anon_sym_PLUS] = ACTIONS(489),
    [anon_sym_DOT_PLUS] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(489),
    [anon_sym_DOT_DASH] = ACTIONS(489),
    [anon_sym_STAR] = ACTIONS(489),
    [anon_sym_DOT_STAR] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(489),
    [anon_sym_DOT_SLASH] = ACTIONS(489),
    [anon_sym_BSLASH] = ACTIONS(489),
    [anon_sym_DOT_BSLASH] = ACTIONS(489),
    [anon_sym_CARET] = ACTIONS(489),
    [anon_sym_DOT_CARET] = ACTIONS(489),
    [anon_sym_PIPE] = ACTIONS(489),
    [anon_sym_AMP] = ACTIONS(489),
    [anon_sym_end] = ACTIONS(489),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_QMARK] = ACTIONS(489),
    [anon_sym_AT] = ACTIONS(489),
    [anon_sym_LT] = ACTIONS(489),
    [anon_sym_LT_EQ] = ACTIONS(489),
    [anon_sym_EQ_EQ] = ACTIONS(489),
    [anon_sym_TILDE_EQ] = ACTIONS(489),
    [anon_sym_GT_EQ] = ACTIONS(489),
    [anon_sym_GT] = ACTIONS(489),
    [anon_sym_AMP_AMP] = ACTIONS(489),
    [anon_sym_PIPE_PIPE] = ACTIONS(489),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_LF] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(489),
    [sym_return_statement] = ACTIONS(489),
    [sym_continue_statement] = ACTIONS(489),
    [sym_break_statement] = ACTIONS(489),
    [anon_sym_elseif] = ACTIONS(489),
    [anon_sym_else] = ACTIONS(489),
    [anon_sym_if] = ACTIONS(489),
    [anon_sym_for] = ACTIONS(489),
    [anon_sym_parfor] = ACTIONS(489),
    [anon_sym_while] = ACTIONS(489),
    [anon_sym_switch] = ACTIONS(489),
    [anon_sym_global] = ACTIONS(489),
    [anon_sym_persistent] = ACTIONS(489),
    [anon_sym_function] = ACTIONS(489),
    [anon_sym_classdef] = ACTIONS(489),
    [anon_sym_try] = ACTIONS(489),
    [anon_sym_spmd] = ACTIONS(489),
    [sym_number] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(489),
    [anon_sym_false] = ACTIONS(489),
    [anon_sym_CR] = ACTIONS(489),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(491),
    [sym__single_quote_string_start] = ACTIONS(491),
    [sym__double_quote_string_start] = ACTIONS(491),
    [sym__multioutput_variable_start] = ACTIONS(491),
    [sym__external_identifier] = ACTIONS(491),
  },
  [STATE(147)] = {
    [anon_sym_SEMI] = ACTIONS(489),
    [anon_sym_COMMA] = ACTIONS(489),
    [anon_sym_get] = ACTIONS(489),
    [anon_sym_set] = ACTIONS(489),
    [anon_sym_properties] = ACTIONS(489),
    [anon_sym_LPAREN] = ACTIONS(489),
    [anon_sym_PLUS] = ACTIONS(489),
    [anon_sym_DOT_PLUS] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(489),
    [anon_sym_DOT_DASH] = ACTIONS(489),
    [anon_sym_STAR] = ACTIONS(489),
    [anon_sym_DOT_STAR] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(489),
    [anon_sym_DOT_SLASH] = ACTIONS(489),
    [anon_sym_BSLASH] = ACTIONS(489),
    [anon_sym_DOT_BSLASH] = ACTIONS(489),
    [anon_sym_CARET] = ACTIONS(489),
    [anon_sym_DOT_CARET] = ACTIONS(489),
    [anon_sym_PIPE] = ACTIONS(489),
    [anon_sym_AMP] = ACTIONS(489),
    [anon_sym_end] = ACTIONS(489),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_QMARK] = ACTIONS(489),
    [anon_sym_AT] = ACTIONS(489),
    [anon_sym_LT] = ACTIONS(489),
    [anon_sym_LT_EQ] = ACTIONS(489),
    [anon_sym_EQ_EQ] = ACTIONS(489),
    [anon_sym_TILDE_EQ] = ACTIONS(489),
    [anon_sym_GT_EQ] = ACTIONS(489),
    [anon_sym_GT] = ACTIONS(489),
    [anon_sym_AMP_AMP] = ACTIONS(489),
    [anon_sym_PIPE_PIPE] = ACTIONS(489),
    [anon_sym_DOT_SQUOTE] = ACTIONS(489),
    [anon_sym_SQUOTE] = ACTIONS(489),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_LF] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(489),
    [sym_return_statement] = ACTIONS(489),
    [sym_continue_statement] = ACTIONS(489),
    [sym_break_statement] = ACTIONS(489),
    [anon_sym_elseif] = ACTIONS(489),
    [anon_sym_else] = ACTIONS(489),
    [anon_sym_if] = ACTIONS(489),
    [anon_sym_for] = ACTIONS(489),
    [anon_sym_parfor] = ACTIONS(489),
    [anon_sym_while] = ACTIONS(489),
    [anon_sym_switch] = ACTIONS(489),
    [anon_sym_global] = ACTIONS(489),
    [anon_sym_persistent] = ACTIONS(489),
    [anon_sym_function] = ACTIONS(489),
    [anon_sym_classdef] = ACTIONS(489),
    [anon_sym_try] = ACTIONS(489),
    [anon_sym_spmd] = ACTIONS(489),
    [sym_number] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(489),
    [anon_sym_false] = ACTIONS(489),
    [anon_sym_CR] = ACTIONS(489),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(491),
    [sym__single_quote_string_start] = ACTIONS(491),
    [sym__double_quote_string_start] = ACTIONS(491),
    [sym__multioutput_variable_start] = ACTIONS(491),
    [sym__external_identifier] = ACTIONS(491),
  },
  [STATE(148)] = {
    [anon_sym_SEMI] = ACTIONS(489),
    [anon_sym_COMMA] = ACTIONS(489),
    [anon_sym_get] = ACTIONS(489),
    [anon_sym_set] = ACTIONS(489),
    [anon_sym_properties] = ACTIONS(489),
    [anon_sym_LPAREN] = ACTIONS(489),
    [anon_sym_PLUS] = ACTIONS(489),
    [anon_sym_DOT_PLUS] = ACTIONS(489),
    [anon_sym_DASH] = ACTIONS(489),
    [anon_sym_DOT_DASH] = ACTIONS(489),
    [anon_sym_STAR] = ACTIONS(489),
    [anon_sym_DOT_STAR] = ACTIONS(489),
    [anon_sym_SLASH] = ACTIONS(489),
    [anon_sym_DOT_SLASH] = ACTIONS(489),
    [anon_sym_BSLASH] = ACTIONS(489),
    [anon_sym_DOT_BSLASH] = ACTIONS(489),
    [anon_sym_CARET] = ACTIONS(489),
    [anon_sym_DOT_CARET] = ACTIONS(489),
    [anon_sym_PIPE] = ACTIONS(489),
    [anon_sym_AMP] = ACTIONS(489),
    [anon_sym_end] = ACTIONS(489),
    [anon_sym_TILDE] = ACTIONS(489),
    [anon_sym_QMARK] = ACTIONS(489),
    [anon_sym_AT] = ACTIONS(489),
    [anon_sym_LT] = ACTIONS(489),
    [anon_sym_LT_EQ] = ACTIONS(489),
    [anon_sym_EQ_EQ] = ACTIONS(489),
    [anon_sym_TILDE_EQ] = ACTIONS(489),
    [anon_sym_GT_EQ] = ACTIONS(489),
    [anon_sym_GT] = ACTIONS(489),
    [anon_sym_AMP_AMP] = ACTIONS(489),
    [anon_sym_PIPE_PIPE] = ACTIONS(489),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(489),
    [anon_sym_LF] = ACTIONS(489),
    [anon_sym_LBRACE] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(489),
    [sym_return_statement] = ACTIONS(489),
    [sym_continue_statement] = ACTIONS(489),
    [sym_break_statement] = ACTIONS(489),
    [anon_sym_elseif] = ACTIONS(489),
    [anon_sym_else] = ACTIONS(489),
    [anon_sym_if] = ACTIONS(489),
    [anon_sym_for] = ACTIONS(489),
    [anon_sym_parfor] = ACTIONS(489),
    [anon_sym_while] = ACTIONS(489),
    [anon_sym_switch] = ACTIONS(489),
    [anon_sym_global] = ACTIONS(489),
    [anon_sym_persistent] = ACTIONS(489),
    [anon_sym_function] = ACTIONS(489),
    [anon_sym_classdef] = ACTIONS(489),
    [anon_sym_try] = ACTIONS(489),
    [anon_sym_spmd] = ACTIONS(489),
    [sym_number] = ACTIONS(489),
    [anon_sym_true] = ACTIONS(489),
    [anon_sym_false] = ACTIONS(489),
    [anon_sym_CR] = ACTIONS(489),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(491),
    [sym__single_quote_string_start] = ACTIONS(491),
    [sym__double_quote_string_start] = ACTIONS(491),
    [sym__multioutput_variable_start] = ACTIONS(491),
    [sym__external_identifier] = ACTIONS(491),
  },
  [STATE(149)] = {
    [anon_sym_SEMI] = ACTIONS(654),
    [anon_sym_COMMA] = ACTIONS(654),
    [anon_sym_get] = ACTIONS(654),
    [anon_sym_set] = ACTIONS(654),
    [anon_sym_properties] = ACTIONS(654),
    [anon_sym_LPAREN] = ACTIONS(654),
    [anon_sym_PLUS] = ACTIONS(654),
    [anon_sym_DOT_PLUS] = ACTIONS(654),
    [anon_sym_DASH] = ACTIONS(654),
    [anon_sym_DOT_DASH] = ACTIONS(654),
    [anon_sym_STAR] = ACTIONS(654),
    [anon_sym_DOT_STAR] = ACTIONS(654),
    [anon_sym_SLASH] = ACTIONS(654),
    [anon_sym_DOT_SLASH] = ACTIONS(654),
    [anon_sym_BSLASH] = ACTIONS(654),
    [anon_sym_DOT_BSLASH] = ACTIONS(654),
    [anon_sym_CARET] = ACTIONS(654),
    [anon_sym_DOT_CARET] = ACTIONS(654),
    [anon_sym_PIPE] = ACTIONS(654),
    [anon_sym_AMP] = ACTIONS(654),
    [anon_sym_end] = ACTIONS(654),
    [anon_sym_TILDE] = ACTIONS(654),
    [anon_sym_QMARK] = ACTIONS(654),
    [anon_sym_AT] = ACTIONS(654),
    [anon_sym_LT] = ACTIONS(569),
    [anon_sym_LT_EQ] = ACTIONS(569),
    [anon_sym_EQ_EQ] = ACTIONS(569),
    [anon_sym_TILDE_EQ] = ACTIONS(569),
    [anon_sym_GT_EQ] = ACTIONS(569),
    [anon_sym_GT] = ACTIONS(569),
    [anon_sym_AMP_AMP] = ACTIONS(654),
    [anon_sym_PIPE_PIPE] = ACTIONS(654),
    [anon_sym_DOT_SQUOTE] = ACTIONS(654),
    [anon_sym_SQUOTE] = ACTIONS(654),
    [anon_sym_LBRACK] = ACTIONS(654),
    [anon_sym_LF] = ACTIONS(654),
    [anon_sym_LBRACE] = ACTIONS(654),
    [anon_sym_COLON] = ACTIONS(654),
    [sym_return_statement] = ACTIONS(654),
    [sym_continue_statement] = ACTIONS(654),
    [sym_break_statement] = ACTIONS(654),
    [anon_sym_elseif] = ACTIONS(654),
    [anon_sym_else] = ACTIONS(654),
    [anon_sym_if] = ACTIONS(654),
    [anon_sym_for] = ACTIONS(654),
    [anon_sym_parfor] = ACTIONS(654),
    [anon_sym_while] = ACTIONS(654),
    [anon_sym_switch] = ACTIONS(654),
    [anon_sym_global] = ACTIONS(654),
    [anon_sym_persistent] = ACTIONS(654),
    [anon_sym_function] = ACTIONS(654),
    [anon_sym_classdef] = ACTIONS(654),
    [anon_sym_try] = ACTIONS(654),
    [anon_sym_spmd] = ACTIONS(654),
    [sym_number] = ACTIONS(654),
    [anon_sym_true] = ACTIONS(654),
    [anon_sym_false] = ACTIONS(654),
    [anon_sym_CR] = ACTIONS(654),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(656),
    [sym__single_quote_string_start] = ACTIONS(656),
    [sym__double_quote_string_start] = ACTIONS(656),
    [sym__multioutput_variable_start] = ACTIONS(656),
    [sym__external_identifier] = ACTIONS(656),
  },
  [STATE(150)] = {
    [anon_sym_SEMI] = ACTIONS(658),
    [anon_sym_COMMA] = ACTIONS(658),
    [anon_sym_get] = ACTIONS(658),
    [anon_sym_set] = ACTIONS(658),
    [anon_sym_properties] = ACTIONS(658),
    [anon_sym_LPAREN] = ACTIONS(658),
    [anon_sym_PLUS] = ACTIONS(658),
    [anon_sym_DOT_PLUS] = ACTIONS(658),
    [anon_sym_DASH] = ACTIONS(658),
    [anon_sym_DOT_DASH] = ACTIONS(658),
    [anon_sym_STAR] = ACTIONS(658),
    [anon_sym_DOT_STAR] = ACTIONS(658),
    [anon_sym_SLASH] = ACTIONS(658),
    [anon_sym_DOT_SLASH] = ACTIONS(658),
    [anon_sym_BSLASH] = ACTIONS(658),
    [anon_sym_DOT_BSLASH] = ACTIONS(658),
    [anon_sym_CARET] = ACTIONS(658),
    [anon_sym_DOT_CARET] = ACTIONS(658),
    [anon_sym_PIPE] = ACTIONS(658),
    [anon_sym_AMP] = ACTIONS(658),
    [anon_sym_end] = ACTIONS(658),
    [anon_sym_TILDE] = ACTIONS(658),
    [anon_sym_QMARK] = ACTIONS(658),
    [anon_sym_AT] = ACTIONS(658),
    [anon_sym_LT] = ACTIONS(658),
    [anon_sym_LT_EQ] = ACTIONS(658),
    [anon_sym_EQ_EQ] = ACTIONS(658),
    [anon_sym_TILDE_EQ] = ACTIONS(658),
    [anon_sym_GT_EQ] = ACTIONS(658),
    [anon_sym_GT] = ACTIONS(658),
    [anon_sym_AMP_AMP] = ACTIONS(658),
    [anon_sym_PIPE_PIPE] = ACTIONS(658),
    [anon_sym_DOT_SQUOTE] = ACTIONS(658),
    [anon_sym_SQUOTE] = ACTIONS(658),
    [anon_sym_LBRACK] = ACTIONS(658),
    [anon_sym_LF] = ACTIONS(658),
    [anon_sym_LBRACE] = ACTIONS(658),
    [anon_sym_COLON] = ACTIONS(658),
    [sym_return_statement] = ACTIONS(658),
    [sym_continue_statement] = ACTIONS(658),
    [sym_break_statement] = ACTIONS(658),
    [anon_sym_elseif] = ACTIONS(658),
    [anon_sym_else] = ACTIONS(658),
    [anon_sym_if] = ACTIONS(658),
    [anon_sym_for] = ACTIONS(658),
    [anon_sym_parfor] = ACTIONS(658),
    [anon_sym_while] = ACTIONS(658),
    [anon_sym_switch] = ACTIONS(658),
    [anon_sym_global] = ACTIONS(658),
    [anon_sym_persistent] = ACTIONS(658),
    [anon_sym_function] = ACTIONS(658),
    [anon_sym_classdef] = ACTIONS(658),
    [anon_sym_try] = ACTIONS(658),
    [anon_sym_spmd] = ACTIONS(658),
    [sym_number] = ACTIONS(658),
    [anon_sym_true] = ACTIONS(658),
    [anon_sym_false] = ACTIONS(658),
    [anon_sym_CR] = ACTIONS(658),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(660),
    [sym__single_quote_string_start] = ACTIONS(660),
    [sym__double_quote_string_start] = ACTIONS(660),
    [sym__multioutput_variable_start] = ACTIONS(660),
    [sym__external_identifier] = ACTIONS(660),
  },
  [STATE(151)] = {
    [anon_sym_SEMI] = ACTIONS(662),
    [anon_sym_COMMA] = ACTIONS(662),
    [anon_sym_get] = ACTIONS(662),
    [anon_sym_set] = ACTIONS(662),
    [anon_sym_properties] = ACTIONS(662),
    [anon_sym_LPAREN] = ACTIONS(662),
    [anon_sym_PLUS] = ACTIONS(662),
    [anon_sym_DOT_PLUS] = ACTIONS(662),
    [anon_sym_DASH] = ACTIONS(662),
    [anon_sym_DOT_DASH] = ACTIONS(662),
    [anon_sym_STAR] = ACTIONS(662),
    [anon_sym_DOT_STAR] = ACTIONS(662),
    [anon_sym_SLASH] = ACTIONS(662),
    [anon_sym_DOT_SLASH] = ACTIONS(662),
    [anon_sym_BSLASH] = ACTIONS(662),
    [anon_sym_DOT_BSLASH] = ACTIONS(662),
    [anon_sym_CARET] = ACTIONS(662),
    [anon_sym_DOT_CARET] = ACTIONS(662),
    [anon_sym_PIPE] = ACTIONS(662),
    [anon_sym_AMP] = ACTIONS(662),
    [anon_sym_end] = ACTIONS(662),
    [anon_sym_TILDE] = ACTIONS(662),
    [anon_sym_QMARK] = ACTIONS(662),
    [anon_sym_AT] = ACTIONS(662),
    [anon_sym_LT] = ACTIONS(662),
    [anon_sym_LT_EQ] = ACTIONS(662),
    [anon_sym_EQ_EQ] = ACTIONS(662),
    [anon_sym_TILDE_EQ] = ACTIONS(662),
    [anon_sym_GT_EQ] = ACTIONS(662),
    [anon_sym_GT] = ACTIONS(662),
    [anon_sym_AMP_AMP] = ACTIONS(662),
    [anon_sym_PIPE_PIPE] = ACTIONS(662),
    [anon_sym_DOT_SQUOTE] = ACTIONS(662),
    [anon_sym_SQUOTE] = ACTIONS(662),
    [anon_sym_LBRACK] = ACTIONS(662),
    [anon_sym_LF] = ACTIONS(662),
    [anon_sym_LBRACE] = ACTIONS(662),
    [anon_sym_COLON] = ACTIONS(662),
    [sym_return_statement] = ACTIONS(662),
    [sym_continue_statement] = ACTIONS(662),
    [sym_break_statement] = ACTIONS(662),
    [anon_sym_elseif] = ACTIONS(662),
    [anon_sym_else] = ACTIONS(662),
    [anon_sym_if] = ACTIONS(662),
    [anon_sym_for] = ACTIONS(662),
    [anon_sym_parfor] = ACTIONS(662),
    [anon_sym_while] = ACTIONS(662),
    [anon_sym_switch] = ACTIONS(662),
    [anon_sym_global] = ACTIONS(662),
    [anon_sym_persistent] = ACTIONS(662),
    [anon_sym_function] = ACTIONS(662),
    [anon_sym_classdef] = ACTIONS(662),
    [anon_sym_try] = ACTIONS(662),
    [anon_sym_spmd] = ACTIONS(662),
    [sym_number] = ACTIONS(662),
    [anon_sym_true] = ACTIONS(662),
    [anon_sym_false] = ACTIONS(662),
    [anon_sym_CR] = ACTIONS(662),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(664),
    [sym__single_quote_string_start] = ACTIONS(664),
    [sym__double_quote_string_start] = ACTIONS(664),
    [sym__multioutput_variable_start] = ACTIONS(664),
    [sym__external_identifier] = ACTIONS(664),
  },
  [STATE(152)] = {
    [anon_sym_SEMI] = ACTIONS(666),
    [anon_sym_COMMA] = ACTIONS(666),
    [anon_sym_get] = ACTIONS(666),
    [anon_sym_set] = ACTIONS(666),
    [anon_sym_properties] = ACTIONS(666),
    [anon_sym_LPAREN] = ACTIONS(666),
    [anon_sym_PLUS] = ACTIONS(666),
    [anon_sym_DOT_PLUS] = ACTIONS(666),
    [anon_sym_DASH] = ACTIONS(666),
    [anon_sym_DOT_DASH] = ACTIONS(666),
    [anon_sym_STAR] = ACTIONS(666),
    [anon_sym_DOT_STAR] = ACTIONS(666),
    [anon_sym_SLASH] = ACTIONS(666),
    [anon_sym_DOT_SLASH] = ACTIONS(666),
    [anon_sym_BSLASH] = ACTIONS(666),
    [anon_sym_DOT_BSLASH] = ACTIONS(666),
    [anon_sym_CARET] = ACTIONS(666),
    [anon_sym_DOT_CARET] = ACTIONS(666),
    [anon_sym_PIPE] = ACTIONS(666),
    [anon_sym_AMP] = ACTIONS(666),
    [anon_sym_end] = ACTIONS(666),
    [anon_sym_TILDE] = ACTIONS(666),
    [anon_sym_QMARK] = ACTIONS(666),
    [anon_sym_AT] = ACTIONS(666),
    [anon_sym_LT] = ACTIONS(666),
    [anon_sym_LT_EQ] = ACTIONS(666),
    [anon_sym_EQ_EQ] = ACTIONS(666),
    [anon_sym_TILDE_EQ] = ACTIONS(666),
    [anon_sym_GT_EQ] = ACTIONS(666),
    [anon_sym_GT] = ACTIONS(666),
    [anon_sym_AMP_AMP] = ACTIONS(666),
    [anon_sym_PIPE_PIPE] = ACTIONS(666),
    [anon_sym_DOT_SQUOTE] = ACTIONS(666),
    [anon_sym_SQUOTE] = ACTIONS(666),
    [anon_sym_LBRACK] = ACTIONS(666),
    [anon_sym_LF] = ACTIONS(666),
    [anon_sym_LBRACE] = ACTIONS(666),
    [anon_sym_COLON] = ACTIONS(666),
    [sym_return_statement] = ACTIONS(666),
    [sym_continue_statement] = ACTIONS(666),
    [sym_break_statement] = ACTIONS(666),
    [anon_sym_elseif] = ACTIONS(666),
    [anon_sym_else] = ACTIONS(666),
    [anon_sym_if] = ACTIONS(666),
    [anon_sym_for] = ACTIONS(666),
    [anon_sym_parfor] = ACTIONS(666),
    [anon_sym_while] = ACTIONS(666),
    [anon_sym_switch] = ACTIONS(666),
    [anon_sym_global] = ACTIONS(666),
    [anon_sym_persistent] = ACTIONS(666),
    [anon_sym_function] = ACTIONS(666),
    [anon_sym_classdef] = ACTIONS(666),
    [anon_sym_try] = ACTIONS(666),
    [anon_sym_spmd] = ACTIONS(666),
    [sym_number] = ACTIONS(666),
    [anon_sym_true] = ACTIONS(666),
    [anon_sym_false] = ACTIONS(666),
    [anon_sym_CR] = ACTIONS(666),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(668),
    [sym__single_quote_string_start] = ACTIONS(668),
    [sym__double_quote_string_start] = ACTIONS(668),
    [sym__multioutput_variable_start] = ACTIONS(668),
    [sym__external_identifier] = ACTIONS(668),
  },
  [STATE(153)] = {
    [anon_sym_SEMI] = ACTIONS(670),
    [anon_sym_COMMA] = ACTIONS(670),
    [anon_sym_get] = ACTIONS(670),
    [anon_sym_set] = ACTIONS(670),
    [anon_sym_properties] = ACTIONS(670),
    [anon_sym_LPAREN] = ACTIONS(670),
    [anon_sym_PLUS] = ACTIONS(670),
    [anon_sym_DOT_PLUS] = ACTIONS(670),
    [anon_sym_DASH] = ACTIONS(670),
    [anon_sym_DOT_DASH] = ACTIONS(670),
    [anon_sym_STAR] = ACTIONS(670),
    [anon_sym_DOT_STAR] = ACTIONS(670),
    [anon_sym_SLASH] = ACTIONS(670),
    [anon_sym_DOT_SLASH] = ACTIONS(670),
    [anon_sym_BSLASH] = ACTIONS(670),
    [anon_sym_DOT_BSLASH] = ACTIONS(670),
    [anon_sym_CARET] = ACTIONS(670),
    [anon_sym_DOT_CARET] = ACTIONS(670),
    [anon_sym_PIPE] = ACTIONS(670),
    [anon_sym_AMP] = ACTIONS(670),
    [anon_sym_end] = ACTIONS(670),
    [anon_sym_TILDE] = ACTIONS(670),
    [anon_sym_QMARK] = ACTIONS(670),
    [anon_sym_AT] = ACTIONS(670),
    [anon_sym_LT] = ACTIONS(670),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_EQ_EQ] = ACTIONS(670),
    [anon_sym_TILDE_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_GT] = ACTIONS(670),
    [anon_sym_AMP_AMP] = ACTIONS(670),
    [anon_sym_PIPE_PIPE] = ACTIONS(670),
    [anon_sym_DOT_SQUOTE] = ACTIONS(670),
    [anon_sym_SQUOTE] = ACTIONS(670),
    [anon_sym_LBRACK] = ACTIONS(670),
    [anon_sym_LF] = ACTIONS(670),
    [anon_sym_LBRACE] = ACTIONS(670),
    [anon_sym_COLON] = ACTIONS(670),
    [sym_return_statement] = ACTIONS(670),
    [sym_continue_statement] = ACTIONS(670),
    [sym_break_statement] = ACTIONS(670),
    [anon_sym_elseif] = ACTIONS(670),
    [anon_sym_else] = ACTIONS(670),
    [anon_sym_if] = ACTIONS(670),
    [anon_sym_for] = ACTIONS(670),
    [anon_sym_parfor] = ACTIONS(670),
    [anon_sym_while] = ACTIONS(670),
    [anon_sym_switch] = ACTIONS(670),
    [anon_sym_global] = ACTIONS(670),
    [anon_sym_persistent] = ACTIONS(670),
    [anon_sym_function] = ACTIONS(670),
    [anon_sym_classdef] = ACTIONS(670),
    [anon_sym_try] = ACTIONS(670),
    [anon_sym_spmd] = ACTIONS(670),
    [sym_number] = ACTIONS(670),
    [anon_sym_true] = ACTIONS(670),
    [anon_sym_false] = ACTIONS(670),
    [anon_sym_CR] = ACTIONS(670),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(672),
    [sym__single_quote_string_start] = ACTIONS(672),
    [sym__double_quote_string_start] = ACTIONS(672),
    [sym__multioutput_variable_start] = ACTIONS(672),
    [sym__external_identifier] = ACTIONS(672),
  },
  [STATE(154)] = {
    [anon_sym_SEMI] = ACTIONS(67),
    [anon_sym_COMMA] = ACTIONS(67),
    [anon_sym_get] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(67),
    [anon_sym_properties] = ACTIONS(67),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DOT_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_DOT_DASH] = ACTIONS(67),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_DOT_STAR] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(67),
    [anon_sym_DOT_SLASH] = ACTIONS(67),
    [anon_sym_BSLASH] = ACTIONS(67),
    [anon_sym_DOT_BSLASH] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_DOT_CARET] = ACTIONS(67),
    [anon_sym_PIPE] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [anon_sym_end] = ACTIONS(67),
    [anon_sym_TILDE] = ACTIONS(67),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LT] = ACTIONS(67),
    [anon_sym_LT_EQ] = ACTIONS(67),
    [anon_sym_EQ_EQ] = ACTIONS(67),
    [anon_sym_TILDE_EQ] = ACTIONS(67),
    [anon_sym_GT_EQ] = ACTIONS(67),
    [anon_sym_GT] = ACTIONS(67),
    [anon_sym_AMP_AMP] = ACTIONS(67),
    [anon_sym_PIPE_PIPE] = ACTIONS(67),
    [anon_sym_DOT_SQUOTE] = ACTIONS(67),
    [anon_sym_SQUOTE] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(67),
    [anon_sym_LF] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(67),
    [anon_sym_COLON] = ACTIONS(67),
    [sym_return_statement] = ACTIONS(67),
    [sym_continue_statement] = ACTIONS(67),
    [sym_break_statement] = ACTIONS(67),
    [anon_sym_elseif] = ACTIONS(67),
    [anon_sym_else] = ACTIONS(67),
    [anon_sym_if] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(67),
    [anon_sym_parfor] = ACTIONS(67),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_switch] = ACTIONS(67),
    [anon_sym_global] = ACTIONS(67),
    [anon_sym_persistent] = ACTIONS(67),
    [anon_sym_function] = ACTIONS(67),
    [anon_sym_classdef] = ACTIONS(67),
    [anon_sym_try] = ACTIONS(67),
    [anon_sym_spmd] = ACTIONS(67),
    [sym_number] = ACTIONS(67),
    [anon_sym_true] = ACTIONS(67),
    [anon_sym_false] = ACTIONS(67),
    [anon_sym_CR] = ACTIONS(67),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(674),
    [sym__single_quote_string_start] = ACTIONS(674),
    [sym__double_quote_string_start] = ACTIONS(674),
    [sym__multioutput_variable_start] = ACTIONS(674),
    [sym__external_identifier] = ACTIONS(674),
  },
  [STATE(155)] = {
    [anon_sym_SEMI] = ACTIONS(676),
    [anon_sym_COMMA] = ACTIONS(676),
    [anon_sym_get] = ACTIONS(676),
    [anon_sym_set] = ACTIONS(676),
    [anon_sym_properties] = ACTIONS(676),
    [anon_sym_LPAREN] = ACTIONS(676),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DOT_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_DOT_DASH] = ACTIONS(676),
    [anon_sym_STAR] = ACTIONS(676),
    [anon_sym_DOT_STAR] = ACTIONS(676),
    [anon_sym_SLASH] = ACTIONS(676),
    [anon_sym_DOT_SLASH] = ACTIONS(676),
    [anon_sym_BSLASH] = ACTIONS(676),
    [anon_sym_DOT_BSLASH] = ACTIONS(676),
    [anon_sym_CARET] = ACTIONS(676),
    [anon_sym_DOT_CARET] = ACTIONS(676),
    [anon_sym_PIPE] = ACTIONS(676),
    [anon_sym_AMP] = ACTIONS(676),
    [anon_sym_end] = ACTIONS(676),
    [anon_sym_TILDE] = ACTIONS(676),
    [anon_sym_QMARK] = ACTIONS(676),
    [anon_sym_AT] = ACTIONS(676),
    [anon_sym_LT] = ACTIONS(676),
    [anon_sym_LT_EQ] = ACTIONS(676),
    [anon_sym_EQ_EQ] = ACTIONS(676),
    [anon_sym_TILDE_EQ] = ACTIONS(676),
    [anon_sym_GT_EQ] = ACTIONS(676),
    [anon_sym_GT] = ACTIONS(676),
    [anon_sym_AMP_AMP] = ACTIONS(676),
    [anon_sym_PIPE_PIPE] = ACTIONS(676),
    [anon_sym_DOT_SQUOTE] = ACTIONS(676),
    [anon_sym_SQUOTE] = ACTIONS(676),
    [anon_sym_LBRACK] = ACTIONS(676),
    [anon_sym_LF] = ACTIONS(676),
    [anon_sym_LBRACE] = ACTIONS(676),
    [anon_sym_COLON] = ACTIONS(676),
    [sym_return_statement] = ACTIONS(676),
    [sym_continue_statement] = ACTIONS(676),
    [sym_break_statement] = ACTIONS(676),
    [anon_sym_elseif] = ACTIONS(676),
    [anon_sym_else] = ACTIONS(676),
    [anon_sym_if] = ACTIONS(676),
    [anon_sym_for] = ACTIONS(676),
    [anon_sym_parfor] = ACTIONS(676),
    [anon_sym_while] = ACTIONS(676),
    [anon_sym_switch] = ACTIONS(676),
    [anon_sym_global] = ACTIONS(676),
    [anon_sym_persistent] = ACTIONS(676),
    [anon_sym_function] = ACTIONS(676),
    [anon_sym_classdef] = ACTIONS(676),
    [anon_sym_try] = ACTIONS(676),
    [anon_sym_spmd] = ACTIONS(676),
    [sym_number] = ACTIONS(676),
    [anon_sym_true] = ACTIONS(676),
    [anon_sym_false] = ACTIONS(676),
    [anon_sym_CR] = ACTIONS(676),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(678),
    [sym__single_quote_string_start] = ACTIONS(678),
    [sym__double_quote_string_start] = ACTIONS(678),
    [sym__multioutput_variable_start] = ACTIONS(678),
    [sym__external_identifier] = ACTIONS(678),
  },
  [STATE(156)] = {
    [anon_sym_SEMI] = ACTIONS(680),
    [anon_sym_COMMA] = ACTIONS(680),
    [anon_sym_get] = ACTIONS(680),
    [anon_sym_set] = ACTIONS(680),
    [anon_sym_properties] = ACTIONS(680),
    [anon_sym_LPAREN] = ACTIONS(680),
    [anon_sym_PLUS] = ACTIONS(680),
    [anon_sym_DOT_PLUS] = ACTIONS(680),
    [anon_sym_DASH] = ACTIONS(680),
    [anon_sym_DOT_DASH] = ACTIONS(680),
    [anon_sym_STAR] = ACTIONS(680),
    [anon_sym_DOT_STAR] = ACTIONS(680),
    [anon_sym_SLASH] = ACTIONS(680),
    [anon_sym_DOT_SLASH] = ACTIONS(680),
    [anon_sym_BSLASH] = ACTIONS(680),
    [anon_sym_DOT_BSLASH] = ACTIONS(680),
    [anon_sym_CARET] = ACTIONS(680),
    [anon_sym_DOT_CARET] = ACTIONS(680),
    [anon_sym_PIPE] = ACTIONS(680),
    [anon_sym_AMP] = ACTIONS(680),
    [anon_sym_end] = ACTIONS(680),
    [anon_sym_TILDE] = ACTIONS(680),
    [anon_sym_QMARK] = ACTIONS(680),
    [anon_sym_AT] = ACTIONS(680),
    [anon_sym_LT] = ACTIONS(680),
    [anon_sym_LT_EQ] = ACTIONS(680),
    [anon_sym_EQ_EQ] = ACTIONS(680),
    [anon_sym_TILDE_EQ] = ACTIONS(680),
    [anon_sym_GT_EQ] = ACTIONS(680),
    [anon_sym_GT] = ACTIONS(680),
    [anon_sym_AMP_AMP] = ACTIONS(680),
    [anon_sym_PIPE_PIPE] = ACTIONS(680),
    [anon_sym_DOT_SQUOTE] = ACTIONS(680),
    [anon_sym_SQUOTE] = ACTIONS(680),
    [anon_sym_LBRACK] = ACTIONS(680),
    [anon_sym_LF] = ACTIONS(680),
    [anon_sym_LBRACE] = ACTIONS(680),
    [anon_sym_COLON] = ACTIONS(680),
    [sym_return_statement] = ACTIONS(680),
    [sym_continue_statement] = ACTIONS(680),
    [sym_break_statement] = ACTIONS(680),
    [anon_sym_elseif] = ACTIONS(680),
    [anon_sym_else] = ACTIONS(680),
    [anon_sym_if] = ACTIONS(680),
    [anon_sym_for] = ACTIONS(680),
    [anon_sym_parfor] = ACTIONS(680),
    [anon_sym_while] = ACTIONS(680),
    [anon_sym_switch] = ACTIONS(680),
    [anon_sym_global] = ACTIONS(680),
    [anon_sym_persistent] = ACTIONS(680),
    [anon_sym_function] = ACTIONS(680),
    [anon_sym_classdef] = ACTIONS(680),
    [anon_sym_try] = ACTIONS(680),
    [anon_sym_spmd] = ACTIONS(680),
    [sym_number] = ACTIONS(680),
    [anon_sym_true] = ACTIONS(680),
    [anon_sym_false] = ACTIONS(680),
    [anon_sym_CR] = ACTIONS(680),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(682),
    [sym__single_quote_string_start] = ACTIONS(682),
    [sym__double_quote_string_start] = ACTIONS(682),
    [sym__multioutput_variable_start] = ACTIONS(682),
    [sym__external_identifier] = ACTIONS(682),
  },
  [STATE(157)] = {
    [anon_sym_SEMI] = ACTIONS(485),
    [anon_sym_COMMA] = ACTIONS(485),
    [anon_sym_get] = ACTIONS(485),
    [anon_sym_set] = ACTIONS(485),
    [anon_sym_properties] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(464),
    [anon_sym_DOT_PLUS] = ACTIONS(464),
    [anon_sym_DASH] = ACTIONS(464),
    [anon_sym_DOT_DASH] = ACTIONS(464),
    [anon_sym_STAR] = ACTIONS(464),
    [anon_sym_DOT_STAR] = ACTIONS(464),
    [anon_sym_SLASH] = ACTIONS(464),
    [anon_sym_DOT_SLASH] = ACTIONS(464),
    [anon_sym_BSLASH] = ACTIONS(464),
    [anon_sym_DOT_BSLASH] = ACTIONS(464),
    [anon_sym_CARET] = ACTIONS(464),
    [anon_sym_DOT_CARET] = ACTIONS(464),
    [anon_sym_PIPE] = ACTIONS(464),
    [anon_sym_AMP] = ACTIONS(464),
    [anon_sym_end] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_QMARK] = ACTIONS(485),
    [anon_sym_AT] = ACTIONS(485),
    [anon_sym_LT] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_TILDE_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_GT] = ACTIONS(485),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_DOT_SQUOTE] = ACTIONS(472),
    [anon_sym_SQUOTE] = ACTIONS(472),
    [anon_sym_LBRACK] = ACTIONS(485),
    [anon_sym_LF] = ACTIONS(485),
    [anon_sym_LBRACE] = ACTIONS(485),
    [anon_sym_COLON] = ACTIONS(649),
    [sym_return_statement] = ACTIONS(485),
    [sym_continue_statement] = ACTIONS(485),
    [sym_break_statement] = ACTIONS(485),
    [anon_sym_elseif] = ACTIONS(485),
    [anon_sym_else] = ACTIONS(485),
    [anon_sym_if] = ACTIONS(485),
    [anon_sym_for] = ACTIONS(485),
    [anon_sym_parfor] = ACTIONS(485),
    [anon_sym_while] = ACTIONS(485),
    [anon_sym_switch] = ACTIONS(485),
    [anon_sym_global] = ACTIONS(485),
    [anon_sym_persistent] = ACTIONS(485),
    [anon_sym_function] = ACTIONS(485),
    [anon_sym_classdef] = ACTIONS(485),
    [anon_sym_try] = ACTIONS(485),
    [anon_sym_spmd] = ACTIONS(485),
    [sym_number] = ACTIONS(485),
    [anon_sym_true] = ACTIONS(485),
    [anon_sym_false] = ACTIONS(485),
    [anon_sym_CR] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(487),
    [sym__single_quote_string_start] = ACTIONS(487),
    [sym__double_quote_string_start] = ACTIONS(487),
    [sym__multioutput_variable_start] = ACTIONS(487),
    [sym__external_identifier] = ACTIONS(487),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 5,
    ACTIONS(478), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 41,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [74] = 5,
    ACTIONS(115), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(622), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(113), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(620), 48,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [147] = 6,
    ACTIONS(115), 1,
      anon_sym_AMP_AMP,
    ACTIONS(117), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(575), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(113), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(567), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [222] = 6,
    ACTIONS(115), 1,
      anon_sym_AMP_AMP,
    ACTIONS(117), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(639), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(113), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(637), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [297] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(622), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(113), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(620), 49,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [368] = 5,
    ACTIONS(684), 1,
      anon_sym_DOT,
    STATE(163), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(512), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(507), 43,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [431] = 5,
    ACTIONS(687), 1,
      anon_sym_DOT,
    STATE(166), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(497), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(493), 43,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [494] = 5,
    ACTIONS(687), 1,
      anon_sym_DOT,
    STATE(163), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(505), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(503), 43,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [557] = 5,
    ACTIONS(687), 1,
      anon_sym_DOT,
    STATE(163), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(501), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(499), 43,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [620] = 5,
    ACTIONS(687), 1,
      anon_sym_DOT,
    STATE(165), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(531), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(529), 43,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [683] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(512), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(507), 44,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [741] = 35,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(707), 1,
      anon_sym_RBRACE,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    STATE(376), 1,
      sym_identifier,
    STATE(382), 1,
      sym_function_call,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    STATE(1409), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1168), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [863] = 35,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(719), 1,
      anon_sym_RPAREN,
    STATE(376), 1,
      sym_identifier,
    STATE(382), 1,
      sym_function_call,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1348), 1,
      sym_arguments,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1168), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [985] = 35,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(719), 1,
      anon_sym_RBRACE,
    STATE(376), 1,
      sym_identifier,
    STATE(382), 1,
      sym_function_call,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1350), 1,
      sym_arguments,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1168), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [1107] = 35,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(707), 1,
      anon_sym_RPAREN,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    STATE(376), 1,
      sym_identifier,
    STATE(382), 1,
      sym_function_call,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1381), 1,
      sym_arguments,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1168), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [1229] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(565), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(563), 44,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [1287] = 35,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(721), 1,
      anon_sym_RBRACE,
    STATE(376), 1,
      sym_identifier,
    STATE(382), 1,
      sym_function_call,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    STATE(1403), 1,
      sym_arguments,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1168), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [1409] = 35,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(723), 1,
      anon_sym_RPAREN,
    STATE(376), 1,
      sym_identifier,
    STATE(382), 1,
      sym_function_call,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    STATE(1412), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1168), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [1531] = 35,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(719), 1,
      anon_sym_RPAREN,
    STATE(384), 1,
      sym_identifier,
    STATE(413), 1,
      sym_function_call,
    STATE(438), 1,
      sym_boolean,
    STATE(613), 1,
      sym_cell,
    STATE(619), 1,
      sym_unary_operator,
    STATE(632), 1,
      sym_binary_operator,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1348), 1,
      sym_arguments,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1168), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(618), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [1653] = 35,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(721), 1,
      anon_sym_RPAREN,
    STATE(376), 1,
      sym_identifier,
    STATE(382), 1,
      sym_function_call,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    STATE(1400), 1,
      sym_arguments,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1168), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [1775] = 35,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(723), 1,
      anon_sym_RBRACE,
    STATE(376), 1,
      sym_identifier,
    STATE(382), 1,
      sym_function_call,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    STATE(1387), 1,
      sym_arguments,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1168), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [1897] = 35,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(725), 1,
      anon_sym_RPAREN,
    STATE(376), 1,
      sym_identifier,
    STATE(382), 1,
      sym_function_call,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1352), 1,
      sym_arguments,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1168), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [2019] = 35,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(725), 1,
      anon_sym_RBRACE,
    STATE(376), 1,
      sym_identifier,
    STATE(382), 1,
      sym_function_call,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1354), 1,
      sym_arguments,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1168), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [2141] = 33,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    STATE(374), 1,
      sym_identifier,
    STATE(382), 1,
      sym_function_call,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1273), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [2257] = 32,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(382), 2,
      sym_identifier,
      sym_function_call,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1273), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [2371] = 33,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    STATE(379), 1,
      sym_identifier,
    STATE(382), 1,
      sym_function_call,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    STATE(1273), 3,
      sym__expression_with_end,
      sym_spread_operator,
      sym__range_with_end,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [2487] = 31,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(745), 1,
      aux_sym_matrix_token1,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1202), 1,
      sym_row,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(727), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [2598] = 6,
    ACTIONS(115), 1,
      anon_sym_AMP_AMP,
    ACTIONS(117), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(761), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(113), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(759), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LF,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      anon_sym_CR,
  [2659] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(763), 1,
      anon_sym_LF,
    ACTIONS(765), 1,
      anon_sym_RBRACK,
    STATE(204), 1,
      aux_sym_matrix_repeat1,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1204), 1,
      sym_row,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [2771] = 31,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(382), 2,
      sym_identifier,
      sym_function_call,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(1282), 2,
      sym__expression_with_end,
      sym__range_with_end,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [2881] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(767), 1,
      anon_sym_LF,
    ACTIONS(769), 1,
      anon_sym_RBRACK,
    STATE(190), 1,
      aux_sym_matrix_repeat1,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1131), 1,
      sym_row,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [2993] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(771), 1,
      anon_sym_LF,
    ACTIONS(773), 1,
      anon_sym_RBRACE,
    STATE(191), 1,
      aux_sym_matrix_repeat1,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1133), 1,
      sym_row,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [3105] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(775), 1,
      anon_sym_LF,
    ACTIONS(777), 1,
      anon_sym_RBRACK,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(655), 1,
      aux_sym_matrix_repeat1,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1138), 1,
      sym_row,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [3217] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(775), 1,
      anon_sym_LF,
    ACTIONS(779), 1,
      anon_sym_RBRACE,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(655), 1,
      aux_sym_matrix_repeat1,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1140), 1,
      sym_row,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [3329] = 31,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(382), 2,
      sym_identifier,
      sym_function_call,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(1200), 2,
      sym__expression_with_end,
      sym__range_with_end,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [3439] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(781), 1,
      anon_sym_LF,
    ACTIONS(783), 1,
      anon_sym_RBRACK,
    STATE(194), 1,
      aux_sym_matrix_repeat1,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1175), 1,
      sym_row,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [3551] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(775), 1,
      anon_sym_LF,
    ACTIONS(785), 1,
      anon_sym_RBRACK,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(655), 1,
      aux_sym_matrix_repeat1,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1146), 1,
      sym_row,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [3663] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(775), 1,
      anon_sym_LF,
    ACTIONS(787), 1,
      anon_sym_RBRACE,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(655), 1,
      aux_sym_matrix_repeat1,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1150), 1,
      sym_row,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [3775] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(196), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(789), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(794), 5,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
    ACTIONS(792), 34,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [3833] = 31,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(382), 2,
      sym_identifier,
      sym_function_call,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(1224), 2,
      sym__expression_with_end,
      sym__range_with_end,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [3943] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(796), 1,
      anon_sym_LF,
    ACTIONS(798), 1,
      anon_sym_RBRACK,
    STATE(200), 1,
      aux_sym_matrix_repeat1,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1178), 1,
      sym_row,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [4055] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(800), 1,
      anon_sym_LF,
    ACTIONS(802), 1,
      anon_sym_RBRACE,
    STATE(201), 1,
      aux_sym_matrix_repeat1,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1180), 1,
      sym_row,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [4167] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(775), 1,
      anon_sym_LF,
    ACTIONS(804), 1,
      anon_sym_RBRACK,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(655), 1,
      aux_sym_matrix_repeat1,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1184), 1,
      sym_row,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [4279] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(775), 1,
      anon_sym_LF,
    ACTIONS(806), 1,
      anon_sym_RBRACE,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(655), 1,
      aux_sym_matrix_repeat1,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1186), 1,
      sym_row,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [4391] = 31,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(711), 1,
      sym_number,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    STATE(438), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym_unary_operator,
    STATE(613), 1,
      sym_cell,
    STATE(636), 1,
      sym_not_operator,
    STATE(671), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    STATE(1405), 1,
      sym__range_element_with_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(382), 2,
      sym_identifier,
      sym_function_call,
    STATE(643), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(884), 2,
      sym__expression,
      sym_range,
    STATE(1120), 2,
      sym__expression_with_end,
      sym__range_with_end,
    STATE(801), 3,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_lambda,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(579), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [4501] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(808), 1,
      anon_sym_LF,
    ACTIONS(810), 1,
      anon_sym_RBRACE,
    STATE(205), 1,
      aux_sym_matrix_repeat1,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1205), 1,
      sym_row,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [4613] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(775), 1,
      anon_sym_LF,
    ACTIONS(812), 1,
      anon_sym_RBRACK,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(655), 1,
      aux_sym_matrix_repeat1,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1211), 1,
      sym_row,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [4725] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(775), 1,
      anon_sym_LF,
    ACTIONS(814), 1,
      anon_sym_RBRACE,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(655), 1,
      aux_sym_matrix_repeat1,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1213), 1,
      sym_row,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [4837] = 32,
    ACTIONS(729), 1,
      anon_sym_COMMA,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(816), 1,
      anon_sym_LF,
    ACTIONS(818), 1,
      anon_sym_RBRACE,
    STATE(195), 1,
      aux_sym_matrix_repeat1,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(994), 1,
      sym_ignored_argument,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1240), 1,
      sym_row,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(735), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [4949] = 29,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(822), 1,
      aux_sym_matrix_token1,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1082), 1,
      sym_ignored_argument,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(820), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(746), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [5054] = 29,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(826), 1,
      aux_sym_matrix_token1,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1082), 1,
      sym_ignored_argument,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(824), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(746), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [5159] = 29,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(737), 1,
      anon_sym_TILDE,
    ACTIONS(739), 1,
      anon_sym_QMARK,
    ACTIONS(741), 1,
      anon_sym_AT,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(749), 1,
      sym_number,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(830), 1,
      aux_sym_matrix_token1,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1082), 1,
      sym_ignored_argument,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(828), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(746), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [5264] = 28,
    ACTIONS(733), 1,
      anon_sym_LPAREN,
    ACTIONS(743), 1,
      anon_sym_LBRACK,
    ACTIONS(747), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(757), 1,
      sym__external_identifier,
    ACTIONS(834), 1,
      anon_sym_TILDE,
    ACTIONS(836), 1,
      anon_sym_QMARK,
    ACTIONS(838), 1,
      anon_sym_AT,
    ACTIONS(842), 1,
      sym_number,
    STATE(390), 1,
      sym_boolean,
    STATE(521), 1,
      sym_unary_operator,
    STATE(528), 1,
      sym_not_operator,
    STATE(536), 1,
      sym_binary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(735), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(751), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(840), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    STATE(364), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(731), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(832), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(497), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [5367] = 5,
    ACTIONS(848), 1,
      anon_sym_else,
    STATE(215), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(846), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(844), 39,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [5423] = 29,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(850), 1,
      sym_number,
    STATE(454), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(557), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_cell,
    STATE(637), 1,
      sym_not_operator,
    STATE(667), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(731), 1,
      sym__binary_expression_with_end,
    STATE(1155), 1,
      sym__range_element_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(408), 2,
      sym_identifier,
      sym_function_call,
    STATE(633), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(592), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [5527] = 5,
    ACTIONS(368), 1,
      anon_sym_else,
    STATE(211), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(852), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(348), 39,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [5583] = 5,
    ACTIONS(858), 1,
      anon_sym_else,
    STATE(216), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(856), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(854), 39,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [5639] = 5,
    ACTIONS(865), 1,
      anon_sym_else,
    STATE(215), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(862), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(860), 39,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [5695] = 5,
    ACTIONS(869), 1,
      anon_sym_else,
    STATE(215), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(846), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(867), 39,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_end,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [5751] = 29,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(695), 1,
      anon_sym_end,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(871), 1,
      sym_number,
    STATE(474), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(566), 1,
      sym_cell,
    STATE(609), 1,
      sym_unary_operator,
    STATE(641), 1,
      sym_not_operator,
    STATE(667), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(738), 1,
      sym__binary_expression_with_end,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1283), 1,
      sym__range_element_with_end,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(402), 2,
      sym_identifier,
      sym_function_call,
    STATE(633), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(608), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [5855] = 28,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(873), 1,
      anon_sym_end,
    ACTIONS(875), 1,
      sym_number,
    STATE(487), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(561), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_cell,
    STATE(624), 1,
      sym_not_operator,
    STATE(672), 1,
      sym__binary_operator_with_end,
    STATE(675), 1,
      sym__binary_expression_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(406), 2,
      sym_identifier,
      sym_function_call,
    STATE(633), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(559), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(879), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [5956] = 28,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(873), 1,
      anon_sym_end,
    ACTIONS(875), 1,
      sym_number,
    STATE(487), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(561), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_cell,
    STATE(624), 1,
      sym_not_operator,
    STATE(668), 1,
      sym__binary_expression_with_end,
    STATE(672), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(406), 2,
      sym_identifier,
      sym_function_call,
    STATE(633), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(559), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(879), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6057] = 28,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(873), 1,
      anon_sym_end,
    ACTIONS(877), 1,
      sym_number,
    STATE(472), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(566), 1,
      sym_cell,
    STATE(607), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_not_operator,
    STATE(672), 1,
      sym__binary_operator_with_end,
    STATE(690), 1,
      sym__binary_expression_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(401), 2,
      sym_identifier,
      sym_function_call,
    STATE(633), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(606), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6158] = 28,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(873), 1,
      anon_sym_end,
    ACTIONS(875), 1,
      sym_number,
    STATE(487), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(561), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_cell,
    STATE(624), 1,
      sym_not_operator,
    STATE(669), 1,
      sym__binary_expression_with_end,
    STATE(672), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(406), 2,
      sym_identifier,
      sym_function_call,
    STATE(633), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(559), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(879), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6259] = 28,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(873), 1,
      anon_sym_end,
    ACTIONS(877), 1,
      sym_number,
    STATE(472), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(566), 1,
      sym_cell,
    STATE(607), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_not_operator,
    STATE(672), 1,
      sym__binary_operator_with_end,
    STATE(692), 1,
      sym__binary_expression_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(401), 2,
      sym_identifier,
      sym_function_call,
    STATE(633), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(606), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6360] = 28,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(873), 1,
      anon_sym_end,
    ACTIONS(877), 1,
      sym_number,
    STATE(472), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(566), 1,
      sym_cell,
    STATE(607), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_not_operator,
    STATE(672), 1,
      sym__binary_operator_with_end,
    STATE(693), 1,
      sym__binary_expression_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(401), 2,
      sym_identifier,
      sym_function_call,
    STATE(633), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(606), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6461] = 28,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(873), 1,
      anon_sym_end,
    ACTIONS(877), 1,
      sym_number,
    STATE(472), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(566), 1,
      sym_cell,
    STATE(607), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_not_operator,
    STATE(672), 1,
      sym__binary_operator_with_end,
    STATE(694), 1,
      sym__binary_expression_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(401), 2,
      sym_identifier,
      sym_function_call,
    STATE(633), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(606), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6562] = 28,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(873), 1,
      anon_sym_end,
    ACTIONS(877), 1,
      sym_number,
    STATE(472), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(566), 1,
      sym_cell,
    STATE(607), 1,
      sym_unary_operator,
    STATE(639), 1,
      sym_not_operator,
    STATE(672), 1,
      sym__binary_operator_with_end,
    STATE(691), 1,
      sym__binary_expression_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(401), 2,
      sym_identifier,
      sym_function_call,
    STATE(633), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(606), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6663] = 28,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(873), 1,
      anon_sym_end,
    ACTIONS(875), 1,
      sym_number,
    STATE(487), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(561), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_cell,
    STATE(624), 1,
      sym_not_operator,
    STATE(666), 1,
      sym__binary_expression_with_end,
    STATE(672), 1,
      sym__binary_operator_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(406), 2,
      sym_identifier,
      sym_function_call,
    STATE(633), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(559), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(879), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6764] = 28,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(873), 1,
      anon_sym_end,
    ACTIONS(875), 1,
      sym_number,
    STATE(487), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(561), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_cell,
    STATE(624), 1,
      sym_not_operator,
    STATE(672), 1,
      sym__binary_operator_with_end,
    STATE(674), 1,
      sym__binary_expression_with_end,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(406), 2,
      sym_identifier,
      sym_function_call,
    STATE(633), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(559), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(879), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6865] = 26,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_QMARK,
    ACTIONS(887), 1,
      anon_sym_AT,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(893), 1,
      sym_number,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(966), 1,
      sym_ignored_argument,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(715), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6960] = 26,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(883), 1,
      anon_sym_TILDE,
    ACTIONS(885), 1,
      anon_sym_QMARK,
    ACTIONS(887), 1,
      anon_sym_AT,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(893), 1,
      sym_number,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1082), 1,
      sym_ignored_argument,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(746), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7055] = 26,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(897), 1,
      anon_sym_RPAREN,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(570), 1,
      sym_cell,
    STATE(611), 1,
      sym_unary_operator,
    STATE(612), 1,
      sym_binary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(411), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(617), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(808), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7150] = 26,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(840), 1,
      anon_sym_EQ,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(903), 1,
      anon_sym_QMARK,
    ACTIONS(905), 1,
      anon_sym_AT,
    ACTIONS(907), 1,
      sym_number,
    STATE(365), 1,
      sym_boolean,
    STATE(439), 1,
      sym_unary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(479), 1,
      sym_binary_operator,
    STATE(481), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(346), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(443), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(476), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [7245] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(563), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_vector,
      anon_sym_matrix,
      anon_sym_scalar,
      anon_sym_CR,
  [7292] = 23,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(921), 1,
      sym_number,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    STATE(109), 1,
      sym_boolean,
    STATE(134), 1,
      sym_cell,
    STATE(137), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(84), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(112), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(136), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(885), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7380] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(570), 1,
      sym_cell,
    STATE(611), 1,
      sym_unary_operator,
    STATE(612), 1,
      sym_binary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(411), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(617), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(847), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7472] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(903), 1,
      anon_sym_QMARK,
    ACTIONS(905), 1,
      anon_sym_AT,
    ACTIONS(907), 1,
      sym_number,
    STATE(365), 1,
      sym_boolean,
    STATE(439), 1,
      sym_unary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(479), 1,
      sym_binary_operator,
    STATE(481), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(346), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(459), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(476), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [7564] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(903), 1,
      anon_sym_QMARK,
    ACTIONS(905), 1,
      anon_sym_AT,
    ACTIONS(907), 1,
      sym_number,
    STATE(365), 1,
      sym_boolean,
    STATE(439), 1,
      sym_unary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(479), 1,
      sym_binary_operator,
    STATE(481), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(346), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(476), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(482), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7656] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(903), 1,
      anon_sym_QMARK,
    ACTIONS(905), 1,
      anon_sym_AT,
    ACTIONS(907), 1,
      sym_number,
    STATE(365), 1,
      sym_boolean,
    STATE(439), 1,
      sym_unary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(479), 1,
      sym_binary_operator,
    STATE(481), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(346), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(476), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(486), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7748] = 23,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(931), 1,
      sym_number,
    STATE(381), 1,
      sym_boolean,
    STATE(535), 1,
      sym_cell,
    STATE(538), 1,
      sym_unary_operator,
    STATE(541), 1,
      sym_binary_operator,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(369), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(508), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(537), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(891), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7836] = 23,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(931), 1,
      sym_number,
    STATE(381), 1,
      sym_boolean,
    STATE(535), 1,
      sym_cell,
    STATE(538), 1,
      sym_unary_operator,
    STATE(541), 1,
      sym_binary_operator,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(369), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(509), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(537), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(891), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7924] = 23,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(931), 1,
      sym_number,
    STATE(381), 1,
      sym_boolean,
    STATE(535), 1,
      sym_cell,
    STATE(538), 1,
      sym_unary_operator,
    STATE(541), 1,
      sym_binary_operator,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(369), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(510), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(537), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(891), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8012] = 23,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(931), 1,
      sym_number,
    STATE(381), 1,
      sym_boolean,
    STATE(535), 1,
      sym_cell,
    STATE(538), 1,
      sym_unary_operator,
    STATE(541), 1,
      sym_binary_operator,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(369), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(511), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(537), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(891), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8100] = 23,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(931), 1,
      sym_number,
    STATE(381), 1,
      sym_boolean,
    STATE(535), 1,
      sym_cell,
    STATE(538), 1,
      sym_unary_operator,
    STATE(541), 1,
      sym_binary_operator,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(369), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(512), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(537), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(891), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8188] = 25,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(933), 1,
      sym_number,
    STATE(383), 1,
      sym_boolean,
    STATE(513), 1,
      sym__range_element,
    STATE(539), 1,
      sym_unary_operator,
    STATE(540), 1,
      sym_not_operator,
    STATE(543), 1,
      sym_binary_operator,
    STATE(651), 1,
      sym_cell,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(370), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(492), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8280] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(903), 1,
      anon_sym_QMARK,
    ACTIONS(905), 1,
      anon_sym_AT,
    ACTIONS(907), 1,
      sym_number,
    STATE(365), 1,
      sym_boolean,
    STATE(439), 1,
      sym_unary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(479), 1,
      sym_binary_operator,
    STATE(481), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(346), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(435), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(476), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [8372] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(903), 1,
      anon_sym_QMARK,
    ACTIONS(905), 1,
      anon_sym_AT,
    ACTIONS(907), 1,
      sym_number,
    STATE(365), 1,
      sym_boolean,
    STATE(439), 1,
      sym_unary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(479), 1,
      sym_binary_operator,
    STATE(481), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(346), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(441), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(476), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [8464] = 25,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(933), 1,
      sym_number,
    STATE(383), 1,
      sym_boolean,
    STATE(518), 1,
      sym__range_element,
    STATE(539), 1,
      sym_unary_operator,
    STATE(540), 1,
      sym_not_operator,
    STATE(543), 1,
      sym_binary_operator,
    STATE(651), 1,
      sym_cell,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(370), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(492), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8556] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(935), 1,
      anon_sym_QMARK,
    ACTIONS(937), 1,
      anon_sym_AT,
    ACTIONS(939), 1,
      sym_number,
    STATE(99), 1,
      sym_boolean,
    STATE(125), 1,
      sym_unary_operator,
    STATE(127), 1,
      sym_cell,
    STATE(143), 1,
      sym_binary_operator,
    STATE(158), 1,
      sym_not_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(86), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(3), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(138), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [8648] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(583), 1,
      sym_unary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(404), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(560), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(809), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8740] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(583), 1,
      sym_unary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(404), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(560), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(839), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8832] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(47), 1,
      sym_number,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    STATE(371), 1,
      sym_boolean,
    STATE(449), 1,
      sym_binary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(489), 1,
      sym_unary_operator,
    STATE(529), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(349), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(448), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(768), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8924] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(47), 1,
      sym_number,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(903), 1,
      anon_sym_QMARK,
    ACTIONS(941), 1,
      anon_sym_AT,
    STATE(371), 1,
      sym_boolean,
    STATE(449), 1,
      sym_binary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(489), 1,
      sym_unary_operator,
    STATE(529), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(349), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(448), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(459), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9016] = 25,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(893), 1,
      sym_number,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(943), 1,
      anon_sym_QMARK,
    ACTIONS(945), 1,
      anon_sym_AT,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(507), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [9108] = 25,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(893), 1,
      sym_number,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(943), 1,
      anon_sym_QMARK,
    ACTIONS(945), 1,
      anon_sym_AT,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(614), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9200] = 25,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(893), 1,
      sym_number,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(943), 1,
      anon_sym_QMARK,
    ACTIONS(945), 1,
      anon_sym_AT,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(615), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9292] = 23,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(921), 1,
      sym_number,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    STATE(109), 1,
      sym_boolean,
    STATE(134), 1,
      sym_cell,
    STATE(137), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(84), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(135), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(136), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(885), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9380] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(570), 1,
      sym_cell,
    STATE(611), 1,
      sym_unary_operator,
    STATE(612), 1,
      sym_binary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(411), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(617), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(856), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9472] = 23,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(921), 1,
      sym_number,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    STATE(109), 1,
      sym_boolean,
    STATE(134), 1,
      sym_cell,
    STATE(137), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(84), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(113), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(136), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(885), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9560] = 23,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(921), 1,
      sym_number,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    STATE(109), 1,
      sym_boolean,
    STATE(134), 1,
      sym_cell,
    STATE(137), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(84), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(114), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(136), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(885), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9648] = 23,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(921), 1,
      sym_number,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    STATE(109), 1,
      sym_boolean,
    STATE(134), 1,
      sym_cell,
    STATE(137), 1,
      sym_unary_operator,
    STATE(144), 1,
      sym_binary_operator,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(84), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(115), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(136), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(885), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9736] = 25,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(947), 1,
      sym_number,
    STATE(110), 1,
      sym_boolean,
    STATE(116), 1,
      sym__range_element,
    STATE(141), 1,
      sym_unary_operator,
    STATE(142), 1,
      sym_not_operator,
    STATE(145), 1,
      sym_binary_operator,
    STATE(652), 1,
      sym_cell,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(85), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(140), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9828] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(47), 1,
      sym_number,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(903), 1,
      anon_sym_QMARK,
    ACTIONS(941), 1,
      anon_sym_AT,
    STATE(371), 1,
      sym_boolean,
    STATE(449), 1,
      sym_binary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(489), 1,
      sym_unary_operator,
    STATE(529), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(349), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(448), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(549), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9920] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(47), 1,
      sym_number,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(903), 1,
      anon_sym_QMARK,
    ACTIONS(941), 1,
      anon_sym_AT,
    STATE(371), 1,
      sym_boolean,
    STATE(449), 1,
      sym_binary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(489), 1,
      sym_unary_operator,
    STATE(529), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(349), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(448), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(550), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10012] = 25,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(885), 1,
      anon_sym_QMARK,
    ACTIONS(887), 1,
      anon_sym_AT,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(893), 1,
      sym_number,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(616), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10104] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(949), 1,
      sym_number,
    STATE(363), 1,
      sym_boolean,
    STATE(417), 1,
      sym_unary_operator,
    STATE(464), 1,
      sym_cell,
    STATE(488), 1,
      sym_binary_operator,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(347), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(483), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(456), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(888), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10192] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(949), 1,
      sym_number,
    STATE(363), 1,
      sym_boolean,
    STATE(417), 1,
      sym_unary_operator,
    STATE(464), 1,
      sym_cell,
    STATE(488), 1,
      sym_binary_operator,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(347), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(421), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(456), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(888), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10280] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(951), 1,
      sym_number,
    STATE(366), 1,
      sym_boolean,
    STATE(418), 1,
      sym_binary_operator,
    STATE(434), 1,
      sym__range_element,
    STATE(458), 1,
      sym_unary_operator,
    STATE(478), 1,
      sym_not_operator,
    STATE(653), 1,
      sym_cell,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(350), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(475), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10372] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(949), 1,
      sym_number,
    STATE(363), 1,
      sym_boolean,
    STATE(417), 1,
      sym_unary_operator,
    STATE(464), 1,
      sym_cell,
    STATE(488), 1,
      sym_binary_operator,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(347), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(415), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(456), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(888), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10460] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(949), 1,
      sym_number,
    STATE(363), 1,
      sym_boolean,
    STATE(417), 1,
      sym_unary_operator,
    STATE(464), 1,
      sym_cell,
    STATE(488), 1,
      sym_binary_operator,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(347), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(425), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(456), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(888), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10548] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(949), 1,
      sym_number,
    STATE(363), 1,
      sym_boolean,
    STATE(417), 1,
      sym_unary_operator,
    STATE(464), 1,
      sym_cell,
    STATE(488), 1,
      sym_binary_operator,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(347), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(426), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(456), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(888), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10636] = 25,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(885), 1,
      anon_sym_QMARK,
    ACTIONS(887), 1,
      anon_sym_AT,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(893), 1,
      sym_number,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(620), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10728] = 25,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(947), 1,
      sym_number,
    STATE(110), 1,
      sym_boolean,
    STATE(130), 1,
      sym__range_element,
    STATE(141), 1,
      sym_unary_operator,
    STATE(142), 1,
      sym_not_operator,
    STATE(145), 1,
      sym_binary_operator,
    STATE(652), 1,
      sym_cell,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(85), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(140), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10820] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(951), 1,
      sym_number,
    STATE(366), 1,
      sym_boolean,
    STATE(418), 1,
      sym_binary_operator,
    STATE(427), 1,
      sym__range_element,
    STATE(458), 1,
      sym_unary_operator,
    STATE(478), 1,
      sym_not_operator,
    STATE(653), 1,
      sym_cell,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(350), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(475), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10912] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(570), 1,
      sym_cell,
    STATE(626), 1,
      sym_not_operator,
    STATE(632), 1,
      sym_binary_operator,
    STATE(634), 1,
      sym_unary_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(442), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(631), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11004] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(953), 1,
      anon_sym_QMARK,
    ACTIONS(955), 1,
      anon_sym_AT,
    ACTIONS(957), 1,
      sym_number,
    STATE(452), 1,
      sym_boolean,
    STATE(554), 1,
      sym_unary_operator,
    STATE(558), 1,
      sym_not_operator,
    STATE(567), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(400), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(555), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(576), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11096] = 5,
    ACTIONS(961), 1,
      anon_sym_end,
    ACTIONS(963), 1,
      anon_sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(275), 2,
      sym_arguments_statement,
      aux_sym_function_definition_repeat1,
    ACTIONS(959), 35,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [11148] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(47), 1,
      sym_number,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    STATE(371), 1,
      sym_boolean,
    STATE(449), 1,
      sym_binary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(489), 1,
      sym_unary_operator,
    STATE(529), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(349), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(448), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(552), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11240] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(939), 1,
      sym_number,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(968), 1,
      anon_sym_AT,
    STATE(99), 1,
      sym_boolean,
    STATE(125), 1,
      sym_unary_operator,
    STATE(127), 1,
      sym_cell,
    STATE(143), 1,
      sym_binary_operator,
    STATE(158), 1,
      sym_not_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(86), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(133), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(138), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [11332] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(939), 1,
      sym_number,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(968), 1,
      anon_sym_AT,
    STATE(99), 1,
      sym_boolean,
    STATE(125), 1,
      sym_unary_operator,
    STATE(127), 1,
      sym_cell,
    STATE(143), 1,
      sym_binary_operator,
    STATE(158), 1,
      sym_not_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(86), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(138), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(162), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11424] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(939), 1,
      sym_number,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(968), 1,
      anon_sym_AT,
    STATE(99), 1,
      sym_boolean,
    STATE(125), 1,
      sym_unary_operator,
    STATE(127), 1,
      sym_cell,
    STATE(143), 1,
      sym_binary_operator,
    STATE(158), 1,
      sym_not_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(86), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(138), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(159), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11516] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(935), 1,
      anon_sym_QMARK,
    ACTIONS(937), 1,
      anon_sym_AT,
    ACTIONS(939), 1,
      sym_number,
    STATE(99), 1,
      sym_boolean,
    STATE(125), 1,
      sym_unary_operator,
    STATE(127), 1,
      sym_cell,
    STATE(143), 1,
      sym_binary_operator,
    STATE(158), 1,
      sym_not_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(86), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(138), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(161), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11608] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(935), 1,
      anon_sym_QMARK,
    ACTIONS(937), 1,
      anon_sym_AT,
    ACTIONS(939), 1,
      sym_number,
    STATE(99), 1,
      sym_boolean,
    STATE(125), 1,
      sym_unary_operator,
    STATE(127), 1,
      sym_cell,
    STATE(143), 1,
      sym_binary_operator,
    STATE(158), 1,
      sym_not_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(86), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(4), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(138), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [11700] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(935), 1,
      anon_sym_QMARK,
    ACTIONS(937), 1,
      anon_sym_AT,
    ACTIONS(939), 1,
      sym_number,
    STATE(99), 1,
      sym_boolean,
    STATE(125), 1,
      sym_unary_operator,
    STATE(127), 1,
      sym_cell,
    STATE(143), 1,
      sym_binary_operator,
    STATE(158), 1,
      sym_not_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(86), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(138), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(185), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11792] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(935), 1,
      anon_sym_QMARK,
    ACTIONS(937), 1,
      anon_sym_AT,
    ACTIONS(939), 1,
      sym_number,
    STATE(99), 1,
      sym_boolean,
    STATE(125), 1,
      sym_unary_operator,
    STATE(127), 1,
      sym_cell,
    STATE(143), 1,
      sym_binary_operator,
    STATE(158), 1,
      sym_not_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(86), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(138), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(160), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11884] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(47), 1,
      sym_number,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    STATE(371), 1,
      sym_boolean,
    STATE(449), 1,
      sym_binary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(489), 1,
      sym_unary_operator,
    STATE(529), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(349), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(448), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(719), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11976] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(953), 1,
      anon_sym_QMARK,
    ACTIONS(955), 1,
      anon_sym_AT,
    ACTIONS(957), 1,
      sym_number,
    STATE(452), 1,
      sym_boolean,
    STATE(554), 1,
      sym_unary_operator,
    STATE(558), 1,
      sym_not_operator,
    STATE(567), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(400), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(555), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(562), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12068] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(953), 1,
      anon_sym_QMARK,
    ACTIONS(955), 1,
      anon_sym_AT,
    ACTIONS(957), 1,
      sym_number,
    STATE(452), 1,
      sym_boolean,
    STATE(554), 1,
      sym_unary_operator,
    STATE(558), 1,
      sym_not_operator,
    STATE(567), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(400), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(555), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(563), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12160] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(953), 1,
      anon_sym_QMARK,
    ACTIONS(955), 1,
      anon_sym_AT,
    ACTIONS(957), 1,
      sym_number,
    STATE(452), 1,
      sym_boolean,
    STATE(554), 1,
      sym_unary_operator,
    STATE(558), 1,
      sym_not_operator,
    STATE(567), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(400), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(555), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(564), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12252] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(953), 1,
      anon_sym_QMARK,
    ACTIONS(955), 1,
      anon_sym_AT,
    ACTIONS(957), 1,
      sym_number,
    STATE(452), 1,
      sym_boolean,
    STATE(554), 1,
      sym_unary_operator,
    STATE(558), 1,
      sym_not_operator,
    STATE(567), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(400), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(555), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(565), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12344] = 25,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(943), 1,
      anon_sym_QMARK,
    ACTIONS(970), 1,
      anon_sym_AT,
    ACTIONS(972), 1,
      sym_number,
    STATE(390), 1,
      sym_boolean,
    STATE(521), 1,
      sym_unary_operator,
    STATE(528), 1,
      sym_not_operator,
    STATE(536), 1,
      sym_binary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(364), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(507), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [12436] = 25,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(943), 1,
      anon_sym_QMARK,
    ACTIONS(970), 1,
      anon_sym_AT,
    ACTIONS(972), 1,
      sym_number,
    STATE(390), 1,
      sym_boolean,
    STATE(521), 1,
      sym_unary_operator,
    STATE(528), 1,
      sym_not_operator,
    STATE(536), 1,
      sym_binary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(364), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(531), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12528] = 25,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(943), 1,
      anon_sym_QMARK,
    ACTIONS(970), 1,
      anon_sym_AT,
    ACTIONS(972), 1,
      sym_number,
    STATE(390), 1,
      sym_boolean,
    STATE(521), 1,
      sym_unary_operator,
    STATE(528), 1,
      sym_not_operator,
    STATE(536), 1,
      sym_binary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(364), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(532), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12620] = 25,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(943), 1,
      anon_sym_QMARK,
    ACTIONS(970), 1,
      anon_sym_AT,
    ACTIONS(972), 1,
      sym_number,
    STATE(390), 1,
      sym_boolean,
    STATE(521), 1,
      sym_unary_operator,
    STATE(528), 1,
      sym_not_operator,
    STATE(536), 1,
      sym_binary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(364), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(533), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12712] = 25,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(943), 1,
      anon_sym_QMARK,
    ACTIONS(970), 1,
      anon_sym_AT,
    ACTIONS(972), 1,
      sym_number,
    STATE(390), 1,
      sym_boolean,
    STATE(521), 1,
      sym_unary_operator,
    STATE(528), 1,
      sym_not_operator,
    STATE(536), 1,
      sym_binary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(364), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(534), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12804] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(935), 1,
      anon_sym_QMARK,
    ACTIONS(937), 1,
      anon_sym_AT,
    ACTIONS(939), 1,
      sym_number,
    STATE(99), 1,
      sym_boolean,
    STATE(125), 1,
      sym_unary_operator,
    STATE(127), 1,
      sym_cell,
    STATE(143), 1,
      sym_binary_operator,
    STATE(158), 1,
      sym_not_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(86), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(5), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(138), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [12896] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(974), 1,
      anon_sym_AT,
    ACTIONS(976), 1,
      sym_number,
    STATE(107), 1,
      sym_boolean,
    STATE(120), 1,
      sym_unary_operator,
    STATE(122), 1,
      sym_not_operator,
    STATE(127), 1,
      sym_cell,
    STATE(157), 1,
      sym_binary_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(87), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(121), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(133), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12988] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(974), 1,
      anon_sym_AT,
    ACTIONS(976), 1,
      sym_number,
    STATE(107), 1,
      sym_boolean,
    STATE(120), 1,
      sym_unary_operator,
    STATE(122), 1,
      sym_not_operator,
    STATE(127), 1,
      sym_cell,
    STATE(157), 1,
      sym_binary_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(87), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(121), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(128), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13080] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(974), 1,
      anon_sym_AT,
    ACTIONS(976), 1,
      sym_number,
    STATE(107), 1,
      sym_boolean,
    STATE(120), 1,
      sym_unary_operator,
    STATE(122), 1,
      sym_not_operator,
    STATE(127), 1,
      sym_cell,
    STATE(157), 1,
      sym_binary_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(87), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(121), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(129), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13172] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(974), 1,
      anon_sym_AT,
    ACTIONS(976), 1,
      sym_number,
    STATE(107), 1,
      sym_boolean,
    STATE(120), 1,
      sym_unary_operator,
    STATE(122), 1,
      sym_not_operator,
    STATE(127), 1,
      sym_cell,
    STATE(157), 1,
      sym_binary_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(87), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(121), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(132), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13264] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(47), 1,
      sym_number,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    STATE(371), 1,
      sym_boolean,
    STATE(449), 1,
      sym_binary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(489), 1,
      sym_unary_operator,
    STATE(529), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(349), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(448), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(660), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13356] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(47), 1,
      sym_number,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    STATE(371), 1,
      sym_boolean,
    STATE(449), 1,
      sym_binary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(489), 1,
      sym_unary_operator,
    STATE(529), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(349), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(448), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(765), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13448] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(974), 1,
      anon_sym_AT,
    ACTIONS(976), 1,
      sym_number,
    STATE(107), 1,
      sym_boolean,
    STATE(120), 1,
      sym_unary_operator,
    STATE(122), 1,
      sym_not_operator,
    STATE(127), 1,
      sym_cell,
    STATE(157), 1,
      sym_binary_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(87), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(111), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(121), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [13540] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(47), 1,
      sym_number,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(903), 1,
      anon_sym_QMARK,
    ACTIONS(941), 1,
      anon_sym_AT,
    STATE(371), 1,
      sym_boolean,
    STATE(449), 1,
      sym_binary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(489), 1,
      sym_unary_operator,
    STATE(529), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(349), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(448), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(552), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13632] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(47), 1,
      sym_number,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(903), 1,
      anon_sym_QMARK,
    ACTIONS(941), 1,
      anon_sym_AT,
    STATE(371), 1,
      sym_boolean,
    STATE(449), 1,
      sym_binary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(489), 1,
      sym_unary_operator,
    STATE(529), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(349), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(448), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(551), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13724] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(583), 1,
      sym_unary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(404), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(560), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(787), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13816] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(47), 1,
      sym_number,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    STATE(371), 1,
      sym_boolean,
    STATE(449), 1,
      sym_binary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(489), 1,
      sym_unary_operator,
    STATE(529), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(349), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(448), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(551), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13908] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(978), 1,
      sym_number,
    STATE(362), 1,
      sym_boolean,
    STATE(422), 1,
      sym_unary_operator,
    STATE(429), 1,
      sym_not_operator,
    STATE(431), 1,
      sym_cell,
    STATE(650), 1,
      sym_binary_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(345), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(473), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14000] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(583), 1,
      sym_unary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(404), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(560), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(823), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14092] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(980), 1,
      sym_number,
    STATE(445), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(573), 1,
      sym_unary_operator,
    STATE(574), 1,
      sym_not_operator,
    STATE(575), 1,
      sym_cell,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(391), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(572), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14184] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(570), 1,
      sym_cell,
    STATE(626), 1,
      sym_not_operator,
    STATE(627), 1,
      sym_unary_operator,
    STATE(630), 1,
      sym_binary_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(424), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(625), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14276] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(974), 1,
      anon_sym_AT,
    ACTIONS(976), 1,
      sym_number,
    STATE(107), 1,
      sym_boolean,
    STATE(120), 1,
      sym_unary_operator,
    STATE(122), 1,
      sym_not_operator,
    STATE(127), 1,
      sym_cell,
    STATE(157), 1,
      sym_binary_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(87), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(121), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(149), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14368] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(53), 1,
      sym__single_quote_string_start,
    ACTIONS(55), 1,
      sym__double_quote_string_start,
    ACTIONS(901), 1,
      anon_sym_TILDE,
    ACTIONS(903), 1,
      anon_sym_QMARK,
    ACTIONS(905), 1,
      anon_sym_AT,
    ACTIONS(907), 1,
      sym_number,
    STATE(365), 1,
      sym_boolean,
    STATE(439), 1,
      sym_unary_operator,
    STATE(477), 1,
      sym_cell,
    STATE(479), 1,
      sym_binary_operator,
    STATE(481), 1,
      sym_not_operator,
    STATE(717), 1,
      sym__binary_expression,
    STATE(1152), 1,
      sym_indirect_access,
    STATE(1388), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(49), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(346), 2,
      sym_identifier,
      sym_function_call,
    STATE(469), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(443), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(476), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [14460] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(583), 1,
      sym_unary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(404), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(560), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(868), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14552] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(570), 1,
      sym_cell,
    STATE(611), 1,
      sym_unary_operator,
    STATE(612), 1,
      sym_binary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(411), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(617), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(869), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14644] = 5,
    ACTIONS(368), 1,
      anon_sym_end,
    STATE(327), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(982), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(348), 35,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [14696] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    ACTIONS(953), 1,
      anon_sym_QMARK,
    ACTIONS(984), 1,
      anon_sym_AT,
    STATE(440), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(583), 1,
      sym_unary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(404), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(560), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(594), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14788] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    ACTIONS(953), 1,
      anon_sym_QMARK,
    ACTIONS(984), 1,
      anon_sym_AT,
    STATE(440), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(583), 1,
      sym_unary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(404), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(560), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(646), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14880] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    ACTIONS(953), 1,
      anon_sym_QMARK,
    ACTIONS(984), 1,
      anon_sym_AT,
    STATE(440), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(583), 1,
      sym_unary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(404), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(560), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(648), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14972] = 23,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(986), 1,
      sym_number,
    STATE(485), 1,
      sym_boolean,
    STATE(568), 1,
      sym_cell,
    STATE(586), 1,
      sym_unary_operator,
    STATE(593), 1,
      sym_binary_operator,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(405), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(596), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(585), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(879), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15060] = 23,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(986), 1,
      sym_number,
    STATE(485), 1,
      sym_boolean,
    STATE(568), 1,
      sym_cell,
    STATE(586), 1,
      sym_unary_operator,
    STATE(593), 1,
      sym_binary_operator,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(405), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(597), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(585), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(879), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15148] = 23,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(986), 1,
      sym_number,
    STATE(485), 1,
      sym_boolean,
    STATE(568), 1,
      sym_cell,
    STATE(586), 1,
      sym_unary_operator,
    STATE(593), 1,
      sym_binary_operator,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(405), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(598), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(585), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(879), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15236] = 23,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(986), 1,
      sym_number,
    STATE(485), 1,
      sym_boolean,
    STATE(568), 1,
      sym_cell,
    STATE(586), 1,
      sym_unary_operator,
    STATE(593), 1,
      sym_binary_operator,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(405), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(599), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(585), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(879), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15324] = 23,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(986), 1,
      sym_number,
    STATE(485), 1,
      sym_boolean,
    STATE(568), 1,
      sym_cell,
    STATE(586), 1,
      sym_unary_operator,
    STATE(593), 1,
      sym_binary_operator,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(405), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(600), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(585), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(879), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15412] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(988), 1,
      sym_number,
    STATE(416), 1,
      sym_boolean,
    STATE(553), 1,
      sym__range_element,
    STATE(570), 1,
      sym_cell,
    STATE(589), 1,
      sym_unary_operator,
    STATE(590), 1,
      sym_not_operator,
    STATE(595), 1,
      sym_binary_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(380), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(587), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15504] = 5,
    ACTIONS(858), 1,
      anon_sym_end,
    STATE(330), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(990), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(854), 35,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [15556] = 25,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(992), 1,
      sym_number,
    STATE(407), 1,
      sym_boolean,
    STATE(494), 1,
      sym_unary_operator,
    STATE(495), 1,
      sym_not_operator,
    STATE(496), 1,
      sym_cell,
    STATE(649), 1,
      sym_binary_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(372), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(493), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15648] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(583), 1,
      sym_unary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(404), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(560), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(645), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15740] = 5,
    ACTIONS(848), 1,
      anon_sym_end,
    STATE(332), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(994), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(844), 35,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [15792] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(570), 1,
      sym_cell,
    STATE(621), 1,
      sym_unary_operator,
    STATE(622), 1,
      sym_binary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(462), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(642), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15884] = 25,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(943), 1,
      anon_sym_QMARK,
    ACTIONS(970), 1,
      anon_sym_AT,
    ACTIONS(972), 1,
      sym_number,
    STATE(390), 1,
      sym_boolean,
    STATE(521), 1,
      sym_unary_operator,
    STATE(528), 1,
      sym_not_operator,
    STATE(536), 1,
      sym_binary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(364), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(497), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(527), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [15976] = 5,
    ACTIONS(869), 1,
      anon_sym_end,
    STATE(332), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(994), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(867), 35,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [16028] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(583), 1,
      sym_unary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(404), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(560), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(647), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16120] = 5,
    ACTIONS(865), 1,
      anon_sym_end,
    STATE(332), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(996), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(860), 35,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [16172] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(988), 1,
      sym_number,
    STATE(416), 1,
      sym_boolean,
    STATE(570), 1,
      sym_cell,
    STATE(581), 1,
      sym__range_element,
    STATE(589), 1,
      sym_unary_operator,
    STATE(590), 1,
      sym_not_operator,
    STATE(595), 1,
      sym_binary_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(380), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(587), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16264] = 25,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(999), 1,
      sym_number,
    STATE(98), 1,
      sym_boolean,
    STATE(146), 1,
      sym_unary_operator,
    STATE(147), 1,
      sym_not_operator,
    STATE(148), 1,
      sym_cell,
    STATE(644), 1,
      sym_binary_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(88), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(139), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16356] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(570), 1,
      sym_cell,
    STATE(623), 1,
      sym_unary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(640), 1,
      sym_binary_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(466), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(638), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16448] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(570), 1,
      sym_cell,
    STATE(626), 1,
      sym_not_operator,
    STATE(629), 1,
      sym_binary_operator,
    STATE(635), 1,
      sym_unary_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(467), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(628), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(884), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16540] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(699), 1,
      anon_sym_QMARK,
    ACTIONS(701), 1,
      anon_sym_AT,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    STATE(440), 1,
      sym_boolean,
    STATE(570), 1,
      sym_cell,
    STATE(611), 1,
      sym_unary_operator,
    STATE(612), 1,
      sym_binary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(411), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(617), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(870), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16632] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    ACTIONS(953), 1,
      anon_sym_QMARK,
    ACTIONS(984), 1,
      anon_sym_AT,
    STATE(440), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(583), 1,
      sym_unary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(404), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(560), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(645), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16724] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(899), 1,
      sym_number,
    ACTIONS(953), 1,
      anon_sym_QMARK,
    ACTIONS(984), 1,
      anon_sym_AT,
    STATE(440), 1,
      sym_boolean,
    STATE(556), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(583), 1,
      sym_unary_operator,
    STATE(626), 1,
      sym_not_operator,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(404), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(560), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(647), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16816] = 25,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(893), 1,
      sym_number,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(943), 1,
      anon_sym_QMARK,
    ACTIONS(945), 1,
      anon_sym_AT,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(616), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16908] = 25,
    ACTIONS(753), 1,
      sym__single_quote_string_start,
    ACTIONS(755), 1,
      sym__double_quote_string_start,
    ACTIONS(879), 1,
      anon_sym_LPAREN,
    ACTIONS(889), 1,
      anon_sym_LBRACK,
    ACTIONS(891), 1,
      anon_sym_LBRACE,
    ACTIONS(893), 1,
      sym_number,
    ACTIONS(929), 1,
      anon_sym_TILDE,
    ACTIONS(943), 1,
      anon_sym_QMARK,
    ACTIONS(945), 1,
      anon_sym_AT,
    STATE(396), 1,
      sym_boolean,
    STATE(519), 1,
      sym_binary_operator,
    STATE(544), 1,
      sym_unary_operator,
    STATE(546), 1,
      sym_cell,
    STATE(601), 1,
      sym_not_operator,
    STATE(736), 1,
      sym__binary_expression,
    STATE(1197), 1,
      sym_indirect_access,
    STATE(1362), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(881), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(895), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(367), 2,
      sym_identifier,
      sym_function_call,
    STATE(545), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(620), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17000] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(939), 1,
      sym_number,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(968), 1,
      anon_sym_AT,
    STATE(99), 1,
      sym_boolean,
    STATE(125), 1,
      sym_unary_operator,
    STATE(127), 1,
      sym_cell,
    STATE(143), 1,
      sym_binary_operator,
    STATE(158), 1,
      sym_not_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(86), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(138), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(161), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17092] = 25,
    ACTIONS(911), 1,
      anon_sym_LPAREN,
    ACTIONS(915), 1,
      anon_sym_TILDE,
    ACTIONS(917), 1,
      anon_sym_LBRACK,
    ACTIONS(919), 1,
      anon_sym_LBRACE,
    ACTIONS(925), 1,
      sym__single_quote_string_start,
    ACTIONS(927), 1,
      sym__double_quote_string_start,
    ACTIONS(939), 1,
      sym_number,
    ACTIONS(966), 1,
      anon_sym_QMARK,
    ACTIONS(968), 1,
      anon_sym_AT,
    STATE(99), 1,
      sym_boolean,
    STATE(125), 1,
      sym_unary_operator,
    STATE(127), 1,
      sym_cell,
    STATE(143), 1,
      sym_binary_operator,
    STATE(158), 1,
      sym_not_operator,
    STATE(737), 1,
      sym__binary_expression,
    STATE(1217), 1,
      sym_indirect_access,
    STATE(1401), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(923), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(86), 2,
      sym_identifier,
      sym_function_call,
    STATE(126), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(138), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(160), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17184] = 25,
    ACTIONS(691), 1,
      anon_sym_LPAREN,
    ACTIONS(697), 1,
      anon_sym_TILDE,
    ACTIONS(703), 1,
      anon_sym_LBRACK,
    ACTIONS(705), 1,
      anon_sym_LBRACE,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(953), 1,
      anon_sym_QMARK,
    ACTIONS(955), 1,
      anon_sym_AT,
    ACTIONS(957), 1,
      sym_number,
    STATE(452), 1,
      sym_boolean,
    STATE(554), 1,
      sym_unary_operator,
    STATE(558), 1,
      sym_not_operator,
    STATE(567), 1,
      sym_binary_operator,
    STATE(570), 1,
      sym_cell,
    STATE(726), 1,
      sym__binary_expression,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1382), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(693), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(400), 2,
      sym_identifier,
      sym_function_call,
    STATE(569), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(555), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(594), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17276] = 9,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DOT,
    ACTIONS(1005), 1,
      anon_sym_AT,
    ACTIONS(1009), 1,
      anon_sym_LBRACE,
    STATE(353), 1,
      sym__args,
    STATE(373), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [17335] = 11,
    ACTIONS(480), 1,
      anon_sym_COLON,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DOT,
    ACTIONS(1005), 1,
      anon_sym_AT,
    ACTIONS(1009), 1,
      anon_sym_LBRACE,
    STATE(353), 1,
      sym__args,
    STATE(373), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [17398] = 9,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DOT,
    ACTIONS(1005), 1,
      anon_sym_AT,
    ACTIONS(1009), 1,
      anon_sym_LBRACE,
    STATE(353), 1,
      sym__args,
    STATE(373), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [17457] = 6,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1005), 1,
      anon_sym_AT,
    ACTIONS(1009), 1,
      anon_sym_LBRACE,
    STATE(353), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(525), 34,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [17510] = 11,
    ACTIONS(478), 1,
      anon_sym_COLON,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DOT,
    ACTIONS(1005), 1,
      anon_sym_AT,
    ACTIONS(1009), 1,
      anon_sym_LBRACE,
    STATE(353), 1,
      sym__args,
    STATE(373), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [17573] = 11,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DOT,
    ACTIONS(1005), 1,
      anon_sym_AT,
    ACTIONS(1009), 1,
      anon_sym_LBRACE,
    STATE(353), 1,
      sym__args,
    STATE(373), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(478), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(480), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [17636] = 3,
    ACTIONS(1013), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1011), 36,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [17682] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(551), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [17726] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(539), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [17770] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(547), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [17814] = 3,
    ACTIONS(1017), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1015), 36,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [17860] = 3,
    ACTIONS(1021), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1019), 36,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [17906] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(555), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [17950] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(543), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [17994] = 3,
    ACTIONS(1025), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1023), 36,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      sym__external_identifier,
      ts_builtin_sym_end,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_spmd,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [18040] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(533), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [18084] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(559), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [18128] = 7,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1009), 1,
      anon_sym_LBRACE,
    ACTIONS(1027), 1,
      anon_sym_AT,
    STATE(360), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [18181] = 7,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1009), 1,
      anon_sym_LBRACE,
    ACTIONS(1027), 1,
      anon_sym_AT,
    STATE(360), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [18234] = 12,
    ACTIONS(480), 1,
      anon_sym_COLON,
    ACTIONS(1029), 1,
      anon_sym_LPAREN,
    ACTIONS(1031), 1,
      anon_sym_DOT,
    ACTIONS(1033), 1,
      anon_sym_AT,
    ACTIONS(1037), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    STATE(430), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(485), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [18297] = 9,
    ACTIONS(480), 1,
      anon_sym_COLON,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1009), 1,
      anon_sym_LBRACE,
    ACTIONS(1027), 1,
      anon_sym_AT,
    STATE(360), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [18354] = 9,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1009), 1,
      anon_sym_LBRACE,
    ACTIONS(1027), 1,
      anon_sym_AT,
    STATE(360), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(478), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(480), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [18411] = 12,
    ACTIONS(478), 1,
      anon_sym_COLON,
    ACTIONS(1029), 1,
      anon_sym_LPAREN,
    ACTIONS(1031), 1,
      anon_sym_DOT,
    ACTIONS(1033), 1,
      anon_sym_AT,
    ACTIONS(1037), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    STATE(430), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(485), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [18474] = 12,
    ACTIONS(478), 1,
      anon_sym_COLON,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DOT,
    ACTIONS(1005), 1,
      anon_sym_AT,
    ACTIONS(1009), 1,
      anon_sym_LBRACE,
    ACTIONS(1039), 1,
      anon_sym_EQ,
    STATE(353), 1,
      sym__args,
    STATE(373), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(485), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [18537] = 10,
    ACTIONS(1029), 1,
      anon_sym_LPAREN,
    ACTIONS(1031), 1,
      anon_sym_DOT,
    ACTIONS(1033), 1,
      anon_sym_AT,
    ACTIONS(1037), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    STATE(430), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(476), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [18596] = 12,
    ACTIONS(1029), 1,
      anon_sym_LPAREN,
    ACTIONS(1031), 1,
      anon_sym_DOT,
    ACTIONS(1033), 1,
      anon_sym_AT,
    ACTIONS(1037), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    STATE(430), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(483), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(478), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(480), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [18659] = 9,
    ACTIONS(478), 1,
      anon_sym_COLON,
    ACTIONS(1001), 1,
      anon_sym_LPAREN,
    ACTIONS(1009), 1,
      anon_sym_LBRACE,
    ACTIONS(1027), 1,
      anon_sym_AT,
    STATE(360), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [18716] = 10,
    ACTIONS(1029), 1,
      anon_sym_LPAREN,
    ACTIONS(1031), 1,
      anon_sym_DOT,
    ACTIONS(1033), 1,
      anon_sym_AT,
    ACTIONS(1037), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    STATE(430), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(491), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [18775] = 4,
    ACTIONS(1003), 1,
      anon_sym_DOT,
    STATE(375), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(514), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [18821] = 15,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1057), 1,
      anon_sym_EQ,
    ACTIONS(1059), 1,
      anon_sym_COLON,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1041), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [18889] = 4,
    ACTIONS(1061), 1,
      anon_sym_DOT,
    STATE(375), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(518), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [18935] = 15,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1059), 1,
      anon_sym_COLON,
    ACTIONS(1064), 1,
      anon_sym_EQ,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1041), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [19003] = 7,
    ACTIONS(1029), 1,
      anon_sym_LPAREN,
    ACTIONS(1033), 1,
      anon_sym_AT,
    ACTIONS(1037), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(527), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(525), 29,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [19055] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(614), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [19097] = 15,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1059), 1,
      anon_sym_COLON,
    ACTIONS(1066), 1,
      anon_sym_EQ,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1041), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [19165] = 13,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(480), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(483), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1068), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [19228] = 8,
    ACTIONS(1029), 1,
      anon_sym_LPAREN,
    ACTIONS(1037), 1,
      anon_sym_LBRACE,
    ACTIONS(1071), 1,
      anon_sym_AT,
    STATE(403), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(476), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [19281] = 14,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1059), 1,
      anon_sym_COLON,
    STATE(457), 1,
      sym__args,
    STATE(530), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1041), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [19346] = 10,
    ACTIONS(1029), 1,
      anon_sym_LPAREN,
    ACTIONS(1037), 1,
      anon_sym_LBRACE,
    ACTIONS(1071), 1,
      anon_sym_AT,
    STATE(403), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(483), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(478), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(480), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [19403] = 15,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1059), 1,
      anon_sym_COLON,
    ACTIONS(1064), 1,
      anon_sym_EQ,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1041), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [19470] = 4,
    ACTIONS(1073), 1,
      anon_sym_DOT,
    STATE(397), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(503), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [19515] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(545), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(543), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [19558] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(541), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(539), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [19601] = 4,
    ACTIONS(1073), 1,
      anon_sym_DOT,
    STATE(392), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [19646] = 4,
    ACTIONS(1073), 1,
      anon_sym_DOT,
    STATE(385), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(529), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [19691] = 10,
    ACTIONS(480), 1,
      anon_sym_COLON,
    ACTIONS(1029), 1,
      anon_sym_LPAREN,
    ACTIONS(1037), 1,
      anon_sym_LBRACE,
    ACTIONS(1071), 1,
      anon_sym_AT,
    STATE(403), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(485), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [19748] = 10,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(491), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [19805] = 4,
    ACTIONS(1073), 1,
      anon_sym_DOT,
    STATE(397), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(499), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [19850] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(553), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(551), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [19893] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(557), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(555), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [19936] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(561), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(559), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [19979] = 10,
    ACTIONS(478), 1,
      anon_sym_COLON,
    ACTIONS(1029), 1,
      anon_sym_LPAREN,
    ACTIONS(1037), 1,
      anon_sym_LBRACE,
    ACTIONS(1071), 1,
      anon_sym_AT,
    STATE(403), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(485), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [20036] = 4,
    ACTIONS(1075), 1,
      anon_sym_DOT,
    STATE(397), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(507), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [20081] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(565), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(563), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [20124] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(549), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(547), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [20167] = 13,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1068), 1,
      anon_sym_COLON,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [20230] = 13,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [20293] = 14,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1059), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [20358] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(535), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(533), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [20401] = 13,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [20464] = 10,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(476), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [20521] = 12,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [20582] = 8,
    ACTIONS(1029), 1,
      anon_sym_LPAREN,
    ACTIONS(1037), 1,
      anon_sym_LBRACE,
    ACTIONS(1071), 1,
      anon_sym_AT,
    STATE(403), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(491), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [20635] = 13,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1059), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [20698] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(616), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(614), 31,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [20740] = 7,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    STATE(457), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(525), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(527), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [20790] = 13,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [20852] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(507), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [20892] = 14,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1059), 1,
      anon_sym_COLON,
    STATE(457), 1,
      sym__args,
    STATE(530), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1041), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [20956] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(563), 6,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_EQ,
    ACTIONS(565), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [20998] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1078), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(577), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21039] = 11,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1080), 1,
      anon_sym_AT,
    STATE(423), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(480), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(483), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1068), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [21096] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21137] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(647), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(649), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [21182] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(658), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21221] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(680), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21260] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1078), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(577), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21301] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21342] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(533), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(535), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21383] = 14,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1082), 1,
      anon_sym_RPAREN,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [21446] = 6,
    ACTIONS(1088), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1078), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1084), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1086), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(577), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21493] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1078), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1084), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1086), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(577), 20,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21538] = 3,
    ACTIONS(1090), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(589), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21579] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(662), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21618] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(489), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21657] = 5,
    ACTIONS(1031), 1,
      anon_sym_DOT,
    STATE(433), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(516), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(514), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21702] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21743] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(633), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21782] = 5,
    ACTIONS(1092), 1,
      anon_sym_DOT,
    STATE(433), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(523), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(518), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21827] = 4,
    ACTIONS(629), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(626), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(624), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21870] = 5,
    ACTIONS(1097), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1099), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1095), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(637), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21915] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [21954] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(559), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(561), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21995] = 12,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1059), 1,
      anon_sym_COLON,
    ACTIONS(1080), 1,
      anon_sym_AT,
    STATE(423), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1041), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22054] = 5,
    ACTIONS(607), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22099] = 11,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1080), 1,
      anon_sym_AT,
    STATE(423), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22156] = 5,
    ACTIONS(1097), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1099), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1095), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(567), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22201] = 14,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1101), 1,
      anon_sym_RPAREN,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22264] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1095), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(654), 26,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22305] = 5,
    ACTIONS(1103), 1,
      anon_sym_DOT,
    STATE(460), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(531), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(529), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22350] = 8,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1080), 1,
      anon_sym_AT,
    STATE(423), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(491), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22401] = 5,
    ACTIONS(1103), 1,
      anon_sym_DOT,
    STATE(470), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(497), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(493), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22446] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(599), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22485] = 5,
    ACTIONS(478), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22530] = 5,
    ACTIONS(647), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22575] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(603), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22614] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(610), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22653] = 11,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1068), 1,
      anon_sym_COLON,
    ACTIONS(1080), 1,
      anon_sym_AT,
    STATE(423), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22710] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(551), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(553), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22751] = 11,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1080), 1,
      anon_sym_AT,
    STATE(423), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1059), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22808] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(547), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(549), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22849] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [22890] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(539), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(541), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22931] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(607), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(618), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [22976] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(641), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23015] = 5,
    ACTIONS(1103), 1,
      anon_sym_DOT,
    STATE(480), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(505), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(503), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23060] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(670), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23099] = 14,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1105), 1,
      anon_sym_RPAREN,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23162] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(666), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23201] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23242] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(543), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(545), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23283] = 14,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1107), 1,
      anon_sym_RPAREN,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23346] = 14,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1109), 1,
      anon_sym_RPAREN,
    STATE(457), 1,
      sym__args,
    STATE(501), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23409] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(67), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23448] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 18,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23489] = 5,
    ACTIONS(1103), 1,
      anon_sym_DOT,
    STATE(480), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(501), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(499), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23534] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(555), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(557), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23575] = 11,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1080), 1,
      anon_sym_AT,
    STATE(423), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [23632] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23673] = 12,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1080), 1,
      anon_sym_AT,
    STATE(423), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1059), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23732] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(478), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(480), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23777] = 5,
    ACTIONS(480), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23822] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 16,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23865] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(480), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(478), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23908] = 5,
    ACTIONS(649), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [23953] = 5,
    ACTIONS(1111), 1,
      anon_sym_DOT,
    STATE(480), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(512), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(507), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23998] = 4,
    ACTIONS(480), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 17,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [24041] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1095), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(620), 26,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [24082] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1078), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1086), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(577), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [24125] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(676), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [24164] = 8,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1080), 1,
      anon_sym_AT,
    STATE(423), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(476), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24215] = 4,
    ACTIONS(1097), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1095), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(620), 25,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [24258] = 10,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1080), 1,
      anon_sym_AT,
    STATE(423), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24313] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_COLON,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [24354] = 5,
    ACTIONS(618), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [24399] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(512), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(507), 29,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24439] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(614), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(616), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24479] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(483), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(478), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(480), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [24524] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(491), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24565] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(491), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24606] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(491), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(489), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24645] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(491), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24686] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(656), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1114), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(654), 22,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24727] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(660), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(658), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24766] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(664), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(662), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24805] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(668), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(666), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24844] = 5,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    STATE(506), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(514), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(516), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24887] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(672), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(670), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24926] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(674), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(67), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24965] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(678), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(676), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25004] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(682), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(680), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25043] = 5,
    ACTIONS(1116), 1,
      anon_sym_DOT,
    STATE(506), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(518), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(523), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25086] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(641), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25125] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(581), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1121), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1119), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(577), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25168] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(581), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1121), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(577), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25209] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(581), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1121), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(577), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25250] = 7,
    ACTIONS(1125), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(581), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1121), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1123), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1119), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(577), 15,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25297] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(581), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1121), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1123), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1119), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(577), 16,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25342] = 4,
    ACTIONS(1127), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(593), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(589), 27,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [25383] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(597), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(595), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25422] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(601), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(599), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25461] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(605), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(603), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25500] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(612), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(610), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25539] = 5,
    ACTIONS(629), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(631), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(626), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(624), 19,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [25582] = 6,
    ACTIONS(647), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(485), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [25627] = 6,
    ACTIONS(478), 1,
      anon_sym_COLON,
    ACTIONS(1039), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1007), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(485), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [25672] = 6,
    ACTIONS(607), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(485), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [25717] = 5,
    ACTIONS(1129), 1,
      anon_sym_DOT,
    STATE(524), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(529), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(531), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25760] = 5,
    ACTIONS(1129), 1,
      anon_sym_DOT,
    STATE(525), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(497), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25803] = 5,
    ACTIONS(1129), 1,
      anon_sym_DOT,
    STATE(526), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(503), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(505), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25846] = 5,
    ACTIONS(1129), 1,
      anon_sym_DOT,
    STATE(526), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(499), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(501), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25889] = 5,
    ACTIONS(1131), 1,
      anon_sym_DOT,
    STATE(526), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(507), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(512), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25932] = 6,
    ACTIONS(480), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(485), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [25977] = 5,
    ACTIONS(480), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(485), 13,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26020] = 4,
    ACTIONS(478), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26061] = 5,
    ACTIONS(1049), 1,
      anon_sym_DOT,
    STATE(506), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(514), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(516), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26104] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(622), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1114), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(620), 22,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26145] = 5,
    ACTIONS(1134), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(622), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1114), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(620), 21,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26188] = 6,
    ACTIONS(1134), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1136), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(639), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1114), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(637), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26233] = 6,
    ACTIONS(1134), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1136), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(575), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1114), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(567), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26278] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(476), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26319] = 6,
    ACTIONS(649), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(485), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26364] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(476), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26405] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(476), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26446] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(645), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(618), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(607), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26491] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(483), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(478), 6,
      anon_sym_SEMI,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(480), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26534] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(476), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26575] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(635), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(633), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26614] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(652), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(647), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(649), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26659] = 6,
    ACTIONS(618), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(485), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26704] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 14,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26745] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(485), 12,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26788] = 6,
    ACTIONS(478), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1035), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(485), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26833] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(507), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(512), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26871] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1138), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(620), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26909] = 4,
    ACTIONS(1140), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1138), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(620), 22,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26949] = 5,
    ACTIONS(1140), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1142), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1138), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(567), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [26991] = 5,
    ACTIONS(1140), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1142), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1138), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(637), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [27033] = 4,
    ACTIONS(1144), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(589), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(593), 23,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
  [27072] = 7,
    ACTIONS(1146), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [27117] = 7,
    ACTIONS(1068), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [27162] = 7,
    ACTIONS(652), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [27207] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [27252] = 6,
    ACTIONS(1068), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(487), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [27295] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27338] = 7,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [27383] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27426] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(620), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1151), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1153), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(622), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27467] = 6,
    ACTIONS(1155), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(620), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1151), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1153), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(622), 19,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27510] = 7,
    ACTIONS(1155), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1157), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1151), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1153), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(639), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27555] = 7,
    ACTIONS(1155), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1157), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(567), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1151), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1153), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(575), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27600] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27643] = 7,
    ACTIONS(1159), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [27688] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(476), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27727] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(487), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27768] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [27811] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(633), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(635), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27848] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(491), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27887] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(491), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27926] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(489), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(491), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27963] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(489), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(491), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28002] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(654), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1151), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1153), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(656), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28043] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(658), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(660), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28080] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(662), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(664), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28117] = 8,
    ACTIONS(1059), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1041), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28164] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(666), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(668), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28201] = 6,
    ACTIONS(1144), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(624), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(626), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1162), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(631), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
  [28244] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(670), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(672), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28281] = 7,
    ACTIONS(645), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28326] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(67), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(674), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28363] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(476), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28402] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(476), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28441] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(480), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(483), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1068), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28486] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(676), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(678), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28523] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(607), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(645), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1146), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28568] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(480), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(483), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1068), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28611] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(680), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(682), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28648] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1059), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28693] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(464), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(476), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28732] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(641), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(643), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28769] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(649), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(652), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1159), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28814] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1167), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(577), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1165), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(581), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28855] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1167), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(577), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(581), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28894] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1167), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(577), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(581), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28933] = 7,
    ACTIONS(1171), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1167), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(577), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1169), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1165), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(581), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28978] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1167), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(577), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1169), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1165), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(581), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29021] = 5,
    ACTIONS(478), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(487), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(485), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(464), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [29062] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(595), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(597), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29099] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(599), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29136] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(603), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(605), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29173] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(610), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(612), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29210] = 7,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [29255] = 7,
    ACTIONS(645), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [29300] = 8,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1059), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29347] = 8,
    ACTIONS(645), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1149), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29394] = 8,
    ACTIONS(1149), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1041), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29441] = 7,
    ACTIONS(645), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29485] = 7,
    ACTIONS(652), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29529] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1041), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29573] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(622), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1173), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(620), 19,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [29611] = 5,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(622), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1173), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(620), 18,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [29651] = 6,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1177), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(639), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1173), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(637), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [29693] = 7,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29737] = 8,
    ACTIONS(1059), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1041), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29783] = 8,
    ACTIONS(1149), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1041), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29829] = 6,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1177), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(575), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1173), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(567), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [29871] = 8,
    ACTIONS(645), 1,
      anon_sym_COLON,
    ACTIONS(1105), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29916] = 8,
    ACTIONS(652), 1,
      anon_sym_COLON,
    ACTIONS(1105), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29961] = 8,
    ACTIONS(645), 1,
      anon_sym_COLON,
    ACTIONS(1107), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30006] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30045] = 8,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1082), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30090] = 6,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(487), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30131] = 8,
    ACTIONS(645), 1,
      anon_sym_COLON,
    ACTIONS(1082), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30176] = 8,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1109), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30221] = 8,
    ACTIONS(652), 1,
      anon_sym_COLON,
    ACTIONS(1109), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30266] = 8,
    ACTIONS(652), 1,
      anon_sym_COLON,
    ACTIONS(1082), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30311] = 8,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1101), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30356] = 8,
    ACTIONS(652), 1,
      anon_sym_COLON,
    ACTIONS(1101), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30401] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30440] = 8,
    ACTIONS(645), 1,
      anon_sym_COLON,
    ACTIONS(1101), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30485] = 8,
    ACTIONS(645), 1,
      anon_sym_COLON,
    ACTIONS(1109), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30530] = 7,
    ACTIONS(1059), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1041), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30573] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1059), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30614] = 8,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1107), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30659] = 6,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [30700] = 8,
    ACTIONS(652), 1,
      anon_sym_COLON,
    ACTIONS(1107), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30745] = 7,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1059), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30788] = 8,
    ACTIONS(483), 1,
      anon_sym_COLON,
    ACTIONS(1105), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1053), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30833] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1047), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1041), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1045), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30873] = 7,
    ACTIONS(652), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1179), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30915] = 7,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1187), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(639), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [30957] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(620), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(622), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [30995] = 7,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1187), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(567), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(575), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [31037] = 6,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(620), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(622), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [31077] = 7,
    ACTIONS(652), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1189), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31119] = 7,
    ACTIONS(652), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1191), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31161] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1189), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31200] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1179), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31239] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1191), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(476), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31278] = 16,
    ACTIONS(1193), 1,
      anon_sym_COMMA,
    ACTIONS(1197), 1,
      anon_sym_LPAREN,
    ACTIONS(1199), 1,
      anon_sym_DOT,
    ACTIONS(1201), 1,
      anon_sym_TILDE,
    ACTIONS(1203), 1,
      anon_sym_AT,
    ACTIONS(1205), 1,
      anon_sym_RBRACK,
    ACTIONS(1207), 1,
      anon_sym_LBRACE,
    STATE(730), 1,
      sym__args,
    STATE(775), 1,
      aux_sym_field_expression_repeat1,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(711), 2,
      sym_identifier,
      sym_function_call,
    STATE(678), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [31335] = 5,
    ACTIONS(1211), 1,
      anon_sym_LF,
    STATE(655), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1214), 3,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__external_identifier,
    ACTIONS(1209), 17,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_number,
      anon_sym_true,
      anon_sym_false,
  [31370] = 17,
    ACTIONS(1220), 1,
      anon_sym_LPAREN,
    ACTIONS(1222), 1,
      anon_sym_DOT,
    ACTIONS(1224), 1,
      anon_sym_AT,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    ACTIONS(1228), 1,
      anon_sym_EQ,
    ACTIONS(1230), 1,
      anon_sym_DOT_QMARK,
    ACTIONS(1232), 1,
      sym__external_identifier,
    STATE(696), 1,
      sym_dimensions,
    STATE(723), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(761), 1,
      sym_identifier,
    STATE(810), 1,
      sym_property_name,
    STATE(886), 1,
      sym_validation_functions,
    STATE(928), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(767), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1218), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1216), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [31429] = 16,
    ACTIONS(1197), 1,
      anon_sym_LPAREN,
    ACTIONS(1199), 1,
      anon_sym_DOT,
    ACTIONS(1201), 1,
      anon_sym_TILDE,
    ACTIONS(1203), 1,
      anon_sym_AT,
    ACTIONS(1207), 1,
      anon_sym_LBRACE,
    ACTIONS(1234), 1,
      anon_sym_COMMA,
    ACTIONS(1236), 1,
      anon_sym_RBRACK,
    STATE(730), 1,
      sym__args,
    STATE(775), 1,
      aux_sym_field_expression_repeat1,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(711), 2,
      sym_identifier,
      sym_function_call,
    STATE(680), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [31486] = 16,
    ACTIONS(1220), 1,
      anon_sym_LPAREN,
    ACTIONS(1222), 1,
      anon_sym_DOT,
    ACTIONS(1224), 1,
      anon_sym_AT,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    ACTIONS(1228), 1,
      anon_sym_EQ,
    ACTIONS(1232), 1,
      sym__external_identifier,
    STATE(696), 1,
      sym_dimensions,
    STATE(723), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(761), 1,
      sym_identifier,
    STATE(810), 1,
      sym_property_name,
    STATE(886), 1,
      sym_validation_functions,
    STATE(928), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(767), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1218), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1216), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [31542] = 4,
    ACTIONS(1238), 1,
      anon_sym_DOT,
    STATE(659), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(507), 18,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [31573] = 11,
    ACTIONS(1140), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1142), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1243), 1,
      anon_sym_end,
    ACTIONS(1245), 1,
      anon_sym_case,
    ACTIONS(1247), 1,
      anon_sym_otherwise,
    STATE(1355), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(773), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(1004), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
    ACTIONS(1241), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1138), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [31618] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(563), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [31644] = 14,
    ACTIONS(1220), 1,
      anon_sym_LPAREN,
    ACTIONS(1224), 1,
      anon_sym_AT,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    ACTIONS(1228), 1,
      anon_sym_EQ,
    ACTIONS(1232), 1,
      sym__external_identifier,
    STATE(696), 1,
      sym_dimensions,
    STATE(761), 1,
      sym_identifier,
    STATE(810), 1,
      sym_property_name,
    STATE(886), 1,
      sym_validation_functions,
    STATE(928), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(767), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1218), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1216), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [31694] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(507), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [31720] = 10,
    ACTIONS(1253), 1,
      anon_sym_end,
    ACTIONS(1255), 1,
      anon_sym_TILDE,
    ACTIONS(1257), 1,
      sym__external_identifier,
    STATE(656), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(662), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(763), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1251), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(770), 3,
      sym_class_property,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    ACTIONS(1249), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [31761] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1259), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31786] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1263), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1261), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31813] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1265), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1267), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31840] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1263), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1269), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1261), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1271), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [31871] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1263), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1261), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31898] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1273), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1259), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31925] = 4,
    ACTIONS(1265), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1275), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1267), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [31954] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1267), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [31979] = 10,
    ACTIONS(1255), 1,
      anon_sym_TILDE,
    ACTIONS(1257), 1,
      sym__external_identifier,
    ACTIONS(1277), 1,
      anon_sym_end,
    STATE(656), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(662), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(763), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1251), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    STATE(759), 3,
      sym_class_property,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    ACTIONS(1249), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [32020] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1263), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1271), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(1261), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [32049] = 6,
    ACTIONS(1279), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1263), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1269), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1261), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1271), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [32082] = 13,
    ACTIONS(1195), 1,
      sym__external_identifier,
    ACTIONS(1283), 1,
      anon_sym_LPAREN,
    ACTIONS(1285), 1,
      anon_sym_TILDE,
    ACTIONS(1287), 1,
      anon_sym_LF,
    ACTIONS(1289), 1,
      anon_sym_RBRACK,
    STATE(687), 1,
      aux_sym_matrix_repeat1,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1291), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(654), 2,
      sym_identifier,
      sym_function_call,
    STATE(684), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1281), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [32128] = 10,
    ACTIONS(1255), 1,
      anon_sym_TILDE,
    ACTIONS(1257), 1,
      sym__external_identifier,
    ACTIONS(1293), 1,
      anon_sym_end,
    STATE(658), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(662), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(763), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(796), 2,
      sym_property,
      aux_sym_properties_repeat1,
    ACTIONS(1251), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1249), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [32168] = 11,
    ACTIONS(1201), 1,
      anon_sym_TILDE,
    ACTIONS(1234), 1,
      anon_sym_COMMA,
    ACTIONS(1236), 1,
      anon_sym_RBRACK,
    ACTIONS(1295), 1,
      anon_sym_LPAREN,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(711), 2,
      sym_identifier,
      sym_function_call,
    STATE(679), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [32210] = 11,
    ACTIONS(1297), 1,
      anon_sym_COMMA,
    ACTIONS(1303), 1,
      anon_sym_LPAREN,
    ACTIONS(1306), 1,
      anon_sym_TILDE,
    ACTIONS(1309), 1,
      anon_sym_RBRACK,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1311), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(711), 2,
      sym_identifier,
      sym_function_call,
    STATE(679), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1300), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [32252] = 11,
    ACTIONS(1201), 1,
      anon_sym_TILDE,
    ACTIONS(1295), 1,
      anon_sym_LPAREN,
    ACTIONS(1314), 1,
      anon_sym_COMMA,
    ACTIONS(1316), 1,
      anon_sym_RBRACK,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(711), 2,
      sym_identifier,
      sym_function_call,
    STATE(679), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [32294] = 11,
    ACTIONS(1201), 1,
      anon_sym_TILDE,
    ACTIONS(1234), 1,
      anon_sym_COMMA,
    ACTIONS(1236), 1,
      anon_sym_RBRACK,
    ACTIONS(1295), 1,
      anon_sym_LPAREN,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(711), 2,
      sym_identifier,
      sym_function_call,
    STATE(680), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [32336] = 4,
    ACTIONS(1318), 1,
      anon_sym_DOT,
    STATE(659), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(503), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [32364] = 4,
    ACTIONS(1318), 1,
      anon_sym_DOT,
    STATE(659), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(499), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [32392] = 11,
    ACTIONS(1193), 1,
      anon_sym_COMMA,
    ACTIONS(1201), 1,
      anon_sym_TILDE,
    ACTIONS(1205), 1,
      anon_sym_RBRACK,
    ACTIONS(1295), 1,
      anon_sym_LPAREN,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(711), 2,
      sym_identifier,
      sym_function_call,
    STATE(678), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [32434] = 4,
    ACTIONS(1318), 1,
      anon_sym_DOT,
    STATE(682), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(529), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [32462] = 4,
    ACTIONS(1318), 1,
      anon_sym_DOT,
    STATE(683), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_end,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_CR,
  [32490] = 13,
    ACTIONS(1195), 1,
      sym__external_identifier,
    ACTIONS(1283), 1,
      anon_sym_LPAREN,
    ACTIONS(1285), 1,
      anon_sym_TILDE,
    ACTIONS(1320), 1,
      anon_sym_LF,
    ACTIONS(1322), 1,
      anon_sym_RBRACK,
    STATE(794), 1,
      aux_sym_matrix_repeat1,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1291), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(657), 2,
      sym_identifier,
      sym_function_call,
    STATE(681), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1281), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [32536] = 13,
    ACTIONS(1197), 1,
      anon_sym_LPAREN,
    ACTIONS(1203), 1,
      anon_sym_AT,
    ACTIONS(1207), 1,
      anon_sym_LBRACE,
    ACTIONS(1324), 1,
      anon_sym_COMMA,
    ACTIONS(1326), 1,
      anon_sym_RBRACE,
    STATE(730), 1,
      sym__args,
    STATE(734), 1,
      aux_sym_validation_functions_repeat1,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(777), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [32582] = 10,
    ACTIONS(1255), 1,
      anon_sym_TILDE,
    ACTIONS(1257), 1,
      sym__external_identifier,
    ACTIONS(1328), 1,
      anon_sym_end,
    STATE(658), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(662), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(763), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(788), 2,
      sym_property,
      aux_sym_properties_repeat1,
    ACTIONS(1251), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1249), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [32622] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1332), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1330), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(1261), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
  [32650] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1332), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1261), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
  [32676] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1332), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1261), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
  [32702] = 6,
    ACTIONS(1336), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1332), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1261), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_RBRACE,
    ACTIONS(1334), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1330), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [32734] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1332), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1334), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1261), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACE,
    ACTIONS(1330), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [32764] = 12,
    ACTIONS(715), 1,
      sym__single_quote_string_start,
    ACTIONS(717), 1,
      sym__double_quote_string_start,
    ACTIONS(1295), 1,
      anon_sym_LPAREN,
    ACTIONS(1338), 1,
      sym_number,
    STATE(1170), 1,
      sym_indirect_access,
    STATE(1174), 1,
      sym_boolean,
    STATE(1343), 1,
      sym_string,
    STATE(1349), 1,
      sym_parfor_options,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1036), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [32807] = 11,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    ACTIONS(1228), 1,
      anon_sym_EQ,
    ACTIONS(1232), 1,
      sym__external_identifier,
    STATE(755), 1,
      sym_identifier,
    STATE(829), 1,
      sym_property_name,
    STATE(881), 1,
      sym_validation_functions,
    STATE(927), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(766), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1218), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1340), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [32848] = 5,
    ACTIONS(1342), 1,
      anon_sym_DOT,
    STATE(699), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(501), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(499), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32876] = 12,
    ACTIONS(1350), 1,
      anon_sym_end,
    ACTIONS(1352), 1,
      anon_sym_function,
    ACTIONS(1358), 1,
      sym__multioutput_variable_start,
    STATE(841), 1,
      sym__function_definition_with_end,
    STATE(892), 1,
      sym_identifier,
    STATE(921), 1,
      sym_function_output,
    STATE(1404), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1344), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1347), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(1355), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(698), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [32918] = 5,
    ACTIONS(1361), 1,
      anon_sym_DOT,
    STATE(699), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(512), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(507), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32946] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(565), 15,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_true,
      anon_sym_false,
  [32968] = 12,
    ACTIONS(57), 1,
      sym__multioutput_variable_start,
    ACTIONS(1364), 1,
      anon_sym_end,
    ACTIONS(1366), 1,
      anon_sym_function,
    STATE(841), 1,
      sym__function_definition_with_end,
    STATE(892), 1,
      sym_identifier,
    STATE(921), 1,
      sym_function_output,
    STATE(1404), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(61), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1368), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(713), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [33010] = 12,
    ACTIONS(57), 1,
      sym__multioutput_variable_start,
    ACTIONS(1364), 1,
      anon_sym_end,
    ACTIONS(1366), 1,
      anon_sym_function,
    STATE(841), 1,
      sym__function_definition_with_end,
    STATE(892), 1,
      sym_identifier,
    STATE(921), 1,
      sym_function_output,
    STATE(1404), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(61), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1368), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(698), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [33052] = 5,
    ACTIONS(1342), 1,
      anon_sym_DOT,
    STATE(707), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(531), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(529), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [33080] = 5,
    ACTIONS(1342), 1,
      anon_sym_DOT,
    STATE(697), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(497), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(493), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [33108] = 8,
    ACTIONS(1199), 1,
      anon_sym_DOT,
    ACTIONS(1203), 1,
      anon_sym_AT,
    ACTIONS(1207), 1,
      anon_sym_LBRACE,
    ACTIONS(1370), 1,
      anon_sym_LPAREN,
    STATE(730), 1,
      sym__args,
    STATE(775), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1309), 9,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_true,
      anon_sym_false,
  [33142] = 5,
    ACTIONS(1372), 1,
      anon_sym_DOT,
    STATE(706), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(507), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(512), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33170] = 5,
    ACTIONS(1342), 1,
      anon_sym_DOT,
    STATE(699), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(505), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(503), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [33198] = 12,
    ACTIONS(57), 1,
      sym__multioutput_variable_start,
    ACTIONS(1366), 1,
      anon_sym_function,
    ACTIONS(1375), 1,
      anon_sym_end,
    STATE(841), 1,
      sym__function_definition_with_end,
    STATE(892), 1,
      sym_identifier,
    STATE(921), 1,
      sym_function_output,
    STATE(1404), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(61), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1368), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(702), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [33240] = 10,
    ACTIONS(1201), 1,
      anon_sym_TILDE,
    ACTIONS(1295), 1,
      anon_sym_LPAREN,
    ACTIONS(1316), 1,
      anon_sym_RBRACK,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(705), 2,
      sym_identifier,
      sym_function_call,
    STATE(834), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [33278] = 10,
    ACTIONS(1201), 1,
      anon_sym_TILDE,
    ACTIONS(1236), 1,
      anon_sym_RBRACK,
    ACTIONS(1295), 1,
      anon_sym_LPAREN,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(705), 2,
      sym_identifier,
      sym_function_call,
    STATE(834), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [33316] = 8,
    ACTIONS(1199), 1,
      anon_sym_DOT,
    ACTIONS(1203), 1,
      anon_sym_AT,
    ACTIONS(1207), 1,
      anon_sym_LBRACE,
    ACTIONS(1370), 1,
      anon_sym_LPAREN,
    STATE(730), 1,
      sym__args,
    STATE(775), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1377), 9,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_true,
      anon_sym_false,
  [33350] = 10,
    ACTIONS(1201), 1,
      anon_sym_TILDE,
    ACTIONS(1295), 1,
      anon_sym_LPAREN,
    ACTIONS(1379), 1,
      anon_sym_RBRACK,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(705), 2,
      sym_identifier,
      sym_function_call,
    STATE(834), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [33388] = 12,
    ACTIONS(57), 1,
      sym__multioutput_variable_start,
    ACTIONS(1366), 1,
      anon_sym_function,
    ACTIONS(1381), 1,
      anon_sym_end,
    STATE(841), 1,
      sym__function_definition_with_end,
    STATE(892), 1,
      sym_identifier,
    STATE(921), 1,
      sym_function_output,
    STATE(1404), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(61), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1368), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(698), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [33430] = 5,
    ACTIONS(512), 1,
      sym__external_identifier,
    ACTIONS(1383), 1,
      anon_sym_DOT,
    STATE(714), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(507), 11,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [33457] = 8,
    ACTIONS(826), 1,
      aux_sym_matrix_token1,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1177), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1386), 1,
      sym__entry_delimiter,
    STATE(983), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(824), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1173), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33490] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(512), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(507), 12,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [33513] = 6,
    ACTIONS(1394), 1,
      anon_sym_PIPE,
    ACTIONS(1396), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1392), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1388), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1390), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [33542] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(535), 14,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_true,
      anon_sym_false,
  [33563] = 6,
    ACTIONS(1140), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1142), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(10), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1398), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1138), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33592] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(549), 14,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_true,
      anon_sym_false,
  [33613] = 6,
    ACTIONS(1203), 1,
      anon_sym_AT,
    ACTIONS(1207), 1,
      anon_sym_LBRACE,
    ACTIONS(1370), 1,
      anon_sym_LPAREN,
    STATE(730), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(527), 10,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_true,
      anon_sym_false,
  [33642] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(563), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(565), 12,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33665] = 5,
    ACTIONS(1402), 1,
      anon_sym_DOT,
    ACTIONS(1404), 1,
      sym__external_identifier,
    STATE(714), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1400), 11,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [33692] = 3,
    ACTIONS(565), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(563), 13,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DOT_QMARK,
      anon_sym_CR,
  [33715] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(507), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(512), 12,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33738] = 6,
    ACTIONS(1406), 1,
      anon_sym_PIPE,
    ACTIONS(1408), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1167), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1169), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1165), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [33767] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(553), 14,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_true,
      anon_sym_false,
  [33788] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(557), 14,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_true,
      anon_sym_false,
  [33809] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(561), 14,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_true,
      anon_sym_false,
  [33830] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(541), 14,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_true,
      anon_sym_false,
  [33851] = 6,
    ACTIONS(1279), 1,
      anon_sym_AMP,
    ACTIONS(1410), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1263), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1269), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1271), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [33880] = 9,
    ACTIONS(1201), 1,
      anon_sym_TILDE,
    ACTIONS(1295), 1,
      anon_sym_LPAREN,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(705), 2,
      sym_identifier,
      sym_function_call,
    STATE(834), 2,
      sym_field_expression,
      sym_ignored_argument,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [33915] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(565), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(563), 12,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [33938] = 10,
    ACTIONS(1295), 1,
      anon_sym_LPAREN,
    ACTIONS(1324), 1,
      anon_sym_COMMA,
    ACTIONS(1412), 1,
      anon_sym_RBRACE,
    STATE(739), 1,
      aux_sym_validation_functions_repeat1,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(777), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [33975] = 8,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1177), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1416), 1,
      aux_sym_matrix_token1,
    ACTIONS(1418), 1,
      sym__entry_delimiter,
    STATE(968), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1414), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1173), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [34008] = 6,
    ACTIONS(1426), 1,
      anon_sym_PIPE,
    ACTIONS(1428), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1424), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1420), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1422), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [34037] = 6,
    ACTIONS(1436), 1,
      anon_sym_PIPE,
    ACTIONS(1438), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1434), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1430), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1432), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [34066] = 6,
    ACTIONS(1336), 1,
      anon_sym_AMP,
    ACTIONS(1440), 1,
      anon_sym_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1332), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1334), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1330), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [34095] = 10,
    ACTIONS(1442), 1,
      anon_sym_COMMA,
    ACTIONS(1448), 1,
      anon_sym_LPAREN,
    ACTIONS(1451), 1,
      anon_sym_RBRACE,
    STATE(739), 1,
      aux_sym_validation_functions_repeat1,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1453), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(777), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(1445), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [34132] = 6,
    ACTIONS(1140), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1142), 1,
      anon_sym_PIPE_PIPE,
    STATE(314), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1456), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1138), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [34160] = 5,
    ACTIONS(1458), 1,
      anon_sym_DOT,
    STATE(745), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(493), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(497), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [34186] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(545), 13,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_true,
      anon_sym_false,
  [34206] = 8,
    ACTIONS(7), 1,
      sym__external_identifier,
    ACTIONS(1462), 1,
      anon_sym_end,
    STATE(1103), 1,
      sym_identifier,
    STATE(1104), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(744), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(61), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1460), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34238] = 8,
    ACTIONS(1470), 1,
      anon_sym_end,
    ACTIONS(1472), 1,
      sym__external_identifier,
    STATE(1103), 1,
      sym_identifier,
    STATE(1104), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(744), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(1467), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1464), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34270] = 5,
    ACTIONS(1458), 1,
      anon_sym_DOT,
    STATE(706), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(499), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(501), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [34296] = 6,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1177), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1477), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1475), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1173), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [34324] = 8,
    ACTIONS(7), 1,
      sym__external_identifier,
    ACTIONS(1462), 1,
      anon_sym_end,
    STATE(1103), 1,
      sym_identifier,
    STATE(1104), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(753), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(61), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1479), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34356] = 5,
    ACTIONS(1458), 1,
      anon_sym_DOT,
    STATE(754), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(529), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(531), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [34382] = 8,
    ACTIONS(7), 1,
      sym__external_identifier,
    ACTIONS(1483), 1,
      anon_sym_end,
    STATE(1103), 1,
      sym_identifier,
    STATE(1104), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(743), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(61), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1481), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34414] = 6,
    ACTIONS(1140), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1142), 1,
      anon_sym_PIPE_PIPE,
    STATE(213), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1485), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1138), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [34442] = 6,
    ACTIONS(1140), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1142), 1,
      anon_sym_PIPE_PIPE,
    STATE(213), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1485), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1138), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [34470] = 3,
    ACTIONS(512), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(507), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [34492] = 8,
    ACTIONS(7), 1,
      sym__external_identifier,
    ACTIONS(1487), 1,
      anon_sym_end,
    STATE(1103), 1,
      sym_identifier,
    STATE(1104), 1,
      sym_enum,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(744), 2,
      sym__end_of_line,
      aux_sym_enumeration_repeat1,
    ACTIONS(61), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1460), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34524] = 5,
    ACTIONS(1458), 1,
      anon_sym_DOT,
    STATE(706), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(503), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(505), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [34550] = 9,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    ACTIONS(1228), 1,
      anon_sym_EQ,
    ACTIONS(1491), 1,
      anon_sym_DOT,
    STATE(838), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(878), 1,
      sym_validation_functions,
    STATE(940), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(774), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1489), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34583] = 6,
    ACTIONS(1203), 1,
      anon_sym_AT,
    ACTIONS(1207), 1,
      anon_sym_LBRACE,
    ACTIONS(1370), 1,
      anon_sym_LPAREN,
    STATE(730), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1451), 8,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_RBRACE,
      anon_sym_true,
      anon_sym_false,
  [34610] = 7,
    ACTIONS(7), 1,
      sym__external_identifier,
    ACTIONS(1495), 1,
      anon_sym_end,
    STATE(1101), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(758), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(61), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1493), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34639] = 7,
    ACTIONS(1503), 1,
      anon_sym_end,
    ACTIONS(1505), 1,
      sym__external_identifier,
    STATE(1101), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(758), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(1500), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1497), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34668] = 7,
    ACTIONS(1508), 1,
      anon_sym_end,
    ACTIONS(1510), 1,
      anon_sym_TILDE,
    STATE(656), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(662), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(769), 3,
      sym_class_property,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    ACTIONS(1257), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [34697] = 3,
    ACTIONS(1514), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1512), 11,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [34718] = 9,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    ACTIONS(1228), 1,
      anon_sym_EQ,
    ACTIONS(1491), 1,
      anon_sym_DOT,
    STATE(838), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(881), 1,
      sym_validation_functions,
    STATE(927), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(766), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1340), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34751] = 4,
    ACTIONS(1516), 1,
      anon_sym_DOT,
    STATE(762), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(523), 10,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_true,
      anon_sym_false,
  [34774] = 5,
    ACTIONS(794), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(763), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1519), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(792), 5,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_TILDE,
  [34799] = 3,
    ACTIONS(1524), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1522), 11,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [34820] = 5,
    ACTIONS(1140), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1142), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1526), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1138), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [34845] = 5,
    ACTIONS(1530), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(763), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1249), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1528), 5,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_TILDE,
  [34870] = 5,
    ACTIONS(1534), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(763), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1249), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1532), 5,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_TILDE,
  [34895] = 5,
    ACTIONS(1140), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1142), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1536), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1138), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [34920] = 7,
    ACTIONS(1541), 1,
      anon_sym_end,
    ACTIONS(1543), 1,
      anon_sym_TILDE,
    STATE(656), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(662), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(769), 3,
      sym_class_property,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    ACTIONS(1538), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [34949] = 7,
    ACTIONS(1510), 1,
      anon_sym_TILDE,
    ACTIONS(1546), 1,
      anon_sym_end,
    STATE(656), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(662), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(769), 3,
      sym_class_property,
      sym_property,
      aux_sym_arguments_statement_repeat1,
    ACTIONS(1257), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [34978] = 3,
    ACTIONS(840), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(832), 11,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [34999] = 5,
    ACTIONS(1550), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(763), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1249), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1548), 5,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_TILDE,
  [35024] = 8,
    ACTIONS(1245), 1,
      anon_sym_case,
    ACTIONS(1247), 1,
      anon_sym_otherwise,
    ACTIONS(1554), 1,
      anon_sym_end,
    STATE(1361), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(871), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(926), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
    ACTIONS(1552), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35055] = 5,
    ACTIONS(1558), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(763), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1249), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1556), 5,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_TILDE,
  [35080] = 4,
    ACTIONS(1199), 1,
      anon_sym_DOT,
    STATE(762), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(516), 10,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_true,
      anon_sym_false,
  [35103] = 7,
    ACTIONS(7), 1,
      sym__external_identifier,
    ACTIONS(1562), 1,
      anon_sym_end,
    STATE(1101), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(757), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(61), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1560), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35132] = 6,
    ACTIONS(1203), 1,
      anon_sym_AT,
    ACTIONS(1207), 1,
      anon_sym_LBRACE,
    ACTIONS(1370), 1,
      anon_sym_LPAREN,
    STATE(730), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1564), 8,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_RBRACE,
      anon_sym_true,
      anon_sym_false,
  [35159] = 7,
    ACTIONS(7), 1,
      sym__external_identifier,
    ACTIONS(1568), 1,
      anon_sym_end,
    STATE(1101), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(779), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(61), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1566), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35188] = 7,
    ACTIONS(7), 1,
      sym__external_identifier,
    ACTIONS(1562), 1,
      anon_sym_end,
    STATE(1101), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(758), 2,
      sym__end_of_line,
      aux_sym_events_repeat1,
    ACTIONS(61), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1493), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35217] = 5,
    ACTIONS(1572), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(763), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1249), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1570), 5,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_TILDE,
  [35242] = 7,
    ACTIONS(1295), 1,
      anon_sym_LPAREN,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(688), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [35270] = 8,
    ACTIONS(1574), 1,
      anon_sym_SEMI,
    ACTIONS(1576), 1,
      anon_sym_properties,
    ACTIONS(1578), 1,
      anon_sym_end,
    ACTIONS(1580), 1,
      anon_sym_methods,
    ACTIONS(1582), 1,
      anon_sym_events,
    ACTIONS(1584), 1,
      anon_sym_enumeration,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(804), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [35300] = 6,
    ACTIONS(1228), 1,
      anon_sym_EQ,
    STATE(940), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(774), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1586), 3,
      anon_sym_vector,
      anon_sym_matrix,
      anon_sym_scalar,
    ACTIONS(1489), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35326] = 6,
    ACTIONS(7), 1,
      sym__external_identifier,
    STATE(933), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(18), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(61), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1588), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35352] = 6,
    ACTIONS(1295), 1,
      anon_sym_LPAREN,
    STATE(1174), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(410), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [35378] = 6,
    ACTIONS(1590), 1,
      anon_sym_LPAREN,
    STATE(1201), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(377), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [35404] = 8,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1187), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1592), 1,
      anon_sym_COMMA,
    ACTIONS(1594), 1,
      anon_sym_RPAREN,
    STATE(1275), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [35434] = 7,
    ACTIONS(1510), 1,
      anon_sym_TILDE,
    ACTIONS(1596), 1,
      anon_sym_end,
    STATE(658), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(662), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(799), 2,
      sym_property,
      aux_sym_properties_repeat1,
    ACTIONS(1257), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [35462] = 8,
    ACTIONS(1576), 1,
      anon_sym_properties,
    ACTIONS(1580), 1,
      anon_sym_methods,
    ACTIONS(1582), 1,
      anon_sym_events,
    ACTIONS(1584), 1,
      anon_sym_enumeration,
    ACTIONS(1598), 1,
      anon_sym_SEMI,
    ACTIONS(1600), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(802), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [35492] = 6,
    ACTIONS(1602), 1,
      anon_sym_LPAREN,
    STATE(1127), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(348), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [35518] = 6,
    ACTIONS(1604), 1,
      anon_sym_LPAREN,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(721), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [35544] = 8,
    ACTIONS(1576), 1,
      anon_sym_properties,
    ACTIONS(1580), 1,
      anon_sym_methods,
    ACTIONS(1582), 1,
      anon_sym_events,
    ACTIONS(1584), 1,
      anon_sym_enumeration,
    ACTIONS(1606), 1,
      anon_sym_SEMI,
    ACTIONS(1608), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(797), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [35574] = 7,
    ACTIONS(1295), 1,
      anon_sym_LPAREN,
    STATE(1122), 1,
      sym_indirect_access,
    STATE(1144), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(756), 2,
      sym_identifier,
      sym_function_call,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [35602] = 5,
    ACTIONS(1214), 1,
      sym__external_identifier,
    ACTIONS(1610), 1,
      anon_sym_LF,
    STATE(794), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1209), 8,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_true,
      anon_sym_false,
  [35626] = 8,
    ACTIONS(1576), 1,
      anon_sym_properties,
    ACTIONS(1580), 1,
      anon_sym_methods,
    ACTIONS(1582), 1,
      anon_sym_events,
    ACTIONS(1584), 1,
      anon_sym_enumeration,
    ACTIONS(1613), 1,
      anon_sym_SEMI,
    ACTIONS(1615), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(789), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [35656] = 7,
    ACTIONS(1510), 1,
      anon_sym_TILDE,
    ACTIONS(1617), 1,
      anon_sym_end,
    STATE(658), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(662), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(799), 2,
      sym_property,
      aux_sym_properties_repeat1,
    ACTIONS(1257), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [35684] = 8,
    ACTIONS(1576), 1,
      anon_sym_properties,
    ACTIONS(1580), 1,
      anon_sym_methods,
    ACTIONS(1582), 1,
      anon_sym_events,
    ACTIONS(1584), 1,
      anon_sym_enumeration,
    ACTIONS(1598), 1,
      anon_sym_SEMI,
    ACTIONS(1615), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(802), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [35714] = 8,
    ACTIONS(1576), 1,
      anon_sym_properties,
    ACTIONS(1580), 1,
      anon_sym_methods,
    ACTIONS(1582), 1,
      anon_sym_events,
    ACTIONS(1584), 1,
      anon_sym_enumeration,
    ACTIONS(1598), 1,
      anon_sym_SEMI,
    ACTIONS(1619), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(802), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [35744] = 7,
    ACTIONS(1624), 1,
      anon_sym_end,
    ACTIONS(1626), 1,
      anon_sym_TILDE,
    STATE(658), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(662), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(799), 2,
      sym_property,
      aux_sym_properties_repeat1,
    ACTIONS(1621), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [35772] = 6,
    ACTIONS(1629), 1,
      anon_sym_LPAREN,
    STATE(1218), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(713), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(95), 3,
      sym_identifier,
      sym_indirect_access,
      sym_function_call,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [35798] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1041), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(487), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35820] = 8,
    ACTIONS(1631), 1,
      anon_sym_SEMI,
    ACTIONS(1634), 1,
      anon_sym_properties,
    ACTIONS(1637), 1,
      anon_sym_end,
    ACTIONS(1639), 1,
      anon_sym_methods,
    ACTIONS(1642), 1,
      anon_sym_events,
    ACTIONS(1645), 1,
      anon_sym_enumeration,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(802), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [35850] = 8,
    ACTIONS(1576), 1,
      anon_sym_properties,
    ACTIONS(1580), 1,
      anon_sym_methods,
    ACTIONS(1582), 1,
      anon_sym_events,
    ACTIONS(1584), 1,
      anon_sym_enumeration,
    ACTIONS(1648), 1,
      anon_sym_SEMI,
    ACTIONS(1650), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(798), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [35880] = 8,
    ACTIONS(1576), 1,
      anon_sym_properties,
    ACTIONS(1580), 1,
      anon_sym_methods,
    ACTIONS(1582), 1,
      anon_sym_events,
    ACTIONS(1584), 1,
      anon_sym_enumeration,
    ACTIONS(1598), 1,
      anon_sym_SEMI,
    ACTIONS(1650), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(802), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [35910] = 4,
    ACTIONS(1652), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1654), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1656), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35931] = 8,
    ACTIONS(57), 1,
      sym__multioutput_variable_start,
    STATE(887), 1,
      sym_identifier,
    STATE(908), 1,
      sym_function_output,
    STATE(1404), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(61), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1658), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35960] = 5,
    ACTIONS(1257), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(816), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1251), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1660), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35983] = 7,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1187), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1662), 1,
      anon_sym_COMMA,
    ACTIONS(1664), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [36010] = 6,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1187), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1666), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [36035] = 7,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    ACTIONS(1228), 1,
      anon_sym_EQ,
    STATE(881), 1,
      sym_validation_functions,
    STATE(927), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(766), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1340), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36062] = 5,
    ACTIONS(1257), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(816), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1251), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1668), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36085] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(840), 10,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_true,
      anon_sym_false,
  [36102] = 4,
    ACTIONS(1670), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1672), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1674), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36123] = 4,
    ACTIONS(1676), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1678), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1680), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36144] = 5,
    ACTIONS(1257), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(811), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1251), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1682), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36167] = 5,
    ACTIONS(1689), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(816), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1686), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1684), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36190] = 4,
    ACTIONS(1692), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1694), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1696), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36211] = 4,
    ACTIONS(1698), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1700), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1702), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36232] = 4,
    ACTIONS(1704), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1706), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1708), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36253] = 4,
    ACTIONS(1710), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1712), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1714), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36274] = 4,
    ACTIONS(1716), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1720), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36295] = 4,
    ACTIONS(1722), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1724), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1726), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36316] = 6,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1187), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1728), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [36341] = 8,
    ACTIONS(57), 1,
      sym__multioutput_variable_start,
    STATE(880), 1,
      sym_identifier,
    STATE(920), 1,
      sym_function_output,
    STATE(1404), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(61), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1730), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36370] = 4,
    ACTIONS(1732), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1734), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1736), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36391] = 4,
    ACTIONS(1738), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1740), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1742), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36412] = 3,
    ACTIONS(1746), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1744), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [36431] = 4,
    ACTIONS(1748), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1750), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1752), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36452] = 7,
    ACTIONS(1226), 1,
      anon_sym_LBRACE,
    ACTIONS(1228), 1,
      anon_sym_EQ,
    STATE(878), 1,
      sym_validation_functions,
    STATE(940), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(774), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1489), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36479] = 8,
    ACTIONS(57), 1,
      sym__multioutput_variable_start,
    STATE(893), 1,
      sym_identifier,
    STATE(905), 1,
      sym_function_output,
    STATE(1404), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(61), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1754), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36508] = 8,
    ACTIONS(57), 1,
      sym__multioutput_variable_start,
    STATE(889), 1,
      sym_identifier,
    STATE(915), 1,
      sym_function_output,
    STATE(1404), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(61), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1756), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36537] = 3,
    ACTIONS(1760), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1758), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [36556] = 5,
    ACTIONS(1257), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(807), 2,
      sym_identifier,
      aux_sym_global_operator_repeat1,
    ACTIONS(1251), 3,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
    ACTIONS(1762), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36579] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1309), 10,
      sym__external_identifier,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
      anon_sym_true,
      anon_sym_false,
  [36596] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1764), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1766), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36614] = 3,
    ACTIONS(1768), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1470), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_LF,
      anon_sym_CR,
  [36632] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1770), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1772), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36650] = 4,
    ACTIONS(1774), 1,
      anon_sym_DOT,
    STATE(659), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1400), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [36670] = 6,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1187), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1776), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [36694] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1678), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1680), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36712] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1778), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1780), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36730] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1694), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1696), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36748] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1782), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1784), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36766] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1786), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1788), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36784] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1700), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1702), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36802] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1790), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1792), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36820] = 6,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1187), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1794), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [36844] = 6,
    ACTIONS(1796), 1,
      anon_sym_RPAREN,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    STATE(1359), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1271), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [36868] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1712), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1714), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36886] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1800), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1802), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36904] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1718), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1720), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36922] = 6,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    ACTIONS(1804), 1,
      anon_sym_RPAREN,
    STATE(1410), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1271), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [36946] = 6,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    ACTIONS(1806), 1,
      anon_sym_RPAREN,
    STATE(1345), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1271), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [36970] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1724), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1726), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36988] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1654), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1656), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37006] = 6,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1187), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1808), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [37030] = 6,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    ACTIONS(1810), 1,
      anon_sym_RPAREN,
    STATE(1384), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1271), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [37054] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1812), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1814), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37072] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1734), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1736), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37090] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1816), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1818), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37108] = 6,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    ACTIONS(1820), 1,
      anon_sym_RPAREN,
    STATE(1351), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1271), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [37132] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1740), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1742), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37150] = 6,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    ACTIONS(1822), 1,
      anon_sym_RPAREN,
    STATE(1360), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1271), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [37174] = 6,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    ACTIONS(1824), 1,
      anon_sym_RPAREN,
    STATE(1365), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1271), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [37198] = 6,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    ACTIONS(1826), 1,
      anon_sym_RPAREN,
    STATE(1369), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1271), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [37222] = 6,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    ACTIONS(1828), 1,
      anon_sym_RPAREN,
    STATE(1373), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1271), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [37246] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1830), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1832), 7,
      sym__multioutput_variable_start,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_function,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37264] = 6,
    ACTIONS(761), 1,
      anon_sym_COMMA,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1187), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [37288] = 6,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1187), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1834), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [37312] = 6,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1187), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1836), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [37336] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(871), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(792), 3,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
    ACTIONS(1838), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37356] = 6,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    ACTIONS(1841), 1,
      anon_sym_RPAREN,
    STATE(1395), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1271), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [37380] = 6,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    ACTIONS(1843), 1,
      anon_sym_RPAREN,
    STATE(1397), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1271), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [37404] = 6,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    ACTIONS(1845), 1,
      anon_sym_RPAREN,
    STATE(1399), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1271), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [37428] = 6,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    ACTIONS(1847), 1,
      anon_sym_RPAREN,
    STATE(1407), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1271), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [37452] = 3,
    ACTIONS(1849), 1,
      sym__external_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1503), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_LF,
      anon_sym_CR,
  [37470] = 4,
    ACTIONS(1853), 1,
      anon_sym_DOT,
    STATE(894), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1851), 6,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_TILDE,
  [37489] = 5,
    ACTIONS(1228), 1,
      anon_sym_EQ,
    STATE(946), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(780), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1855), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37510] = 5,
    ACTIONS(1155), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1157), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1151), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1153), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [37531] = 6,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    ACTIONS(1861), 1,
      anon_sym_EQ,
    STATE(67), 1,
      sym__end_of_line,
    STATE(1098), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1857), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37554] = 5,
    ACTIONS(1228), 1,
      anon_sym_EQ,
    STATE(940), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(774), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1489), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37575] = 5,
    ACTIONS(1865), 1,
      anon_sym_LPAREN,
    STATE(961), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(689), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1863), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37596] = 5,
    ACTIONS(1869), 1,
      anon_sym_LPAREN,
    STATE(957), 1,
      sym__argument_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(664), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1867), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37617] = 5,
    ACTIONS(1185), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1187), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1181), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1183), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [37638] = 5,
    ACTIONS(1873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1875), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(569), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1871), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [37659] = 5,
    ACTIONS(1228), 1,
      anon_sym_EQ,
    STATE(927), 1,
      sym_default_value,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(766), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1340), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37680] = 6,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    ACTIONS(1861), 1,
      anon_sym_EQ,
    STATE(44), 1,
      sym__end_of_line,
    STATE(1063), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1877), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37703] = 5,
    ACTIONS(1881), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1883), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1095), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1879), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [37724] = 6,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    ACTIONS(1861), 1,
      anon_sym_EQ,
    STATE(39), 1,
      sym__end_of_line,
    STATE(1029), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1885), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37747] = 4,
    ACTIONS(1887), 1,
      anon_sym_DOT,
    STATE(890), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(512), 6,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_TILDE,
  [37766] = 5,
    ACTIONS(1892), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1894), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1114), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1890), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [37787] = 6,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    ACTIONS(1861), 1,
      anon_sym_EQ,
    STATE(844), 1,
      sym__end_of_line,
    STATE(1041), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1896), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37810] = 6,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    ACTIONS(1861), 1,
      anon_sym_EQ,
    STATE(56), 1,
      sym__end_of_line,
    STATE(1065), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1898), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37833] = 4,
    ACTIONS(1853), 1,
      anon_sym_DOT,
    STATE(890), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1900), 6,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_TILDE,
  [37852] = 5,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    STATE(73), 1,
      sym__end_of_line,
    STATE(1100), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1902), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37872] = 5,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    STATE(53), 1,
      sym__end_of_line,
    STATE(1099), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1904), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37892] = 5,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    STATE(30), 1,
      sym__end_of_line,
    STATE(1040), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1906), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37912] = 5,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    STATE(31), 1,
      sym__end_of_line,
    STATE(1061), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1908), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37932] = 5,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    STATE(846), 1,
      sym__end_of_line,
    STATE(1023), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1910), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37952] = 5,
    ACTIONS(1865), 1,
      anon_sym_LPAREN,
    STATE(708), 1,
      sym__end_of_line,
    STATE(1043), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1912), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37972] = 5,
    ACTIONS(1865), 1,
      anon_sym_LPAREN,
    STATE(778), 1,
      sym__end_of_line,
    STATE(1045), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1914), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37992] = 5,
    ACTIONS(1865), 1,
      anon_sym_LPAREN,
    STATE(749), 1,
      sym__end_of_line,
    STATE(1046), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1916), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38012] = 5,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    STATE(57), 1,
      sym__end_of_line,
    STATE(1050), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1918), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38032] = 5,
    ACTIONS(1922), 1,
      anon_sym_LT,
    STATE(782), 1,
      sym__end_of_line,
    STATE(1060), 1,
      sym_superclasses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1920), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38052] = 5,
    STATE(903), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(61), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1924), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [38072] = 5,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    STATE(835), 1,
      sym__end_of_line,
    STATE(1031), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1926), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38092] = 5,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    STATE(32), 1,
      sym__end_of_line,
    STATE(1068), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1928), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38112] = 5,
    STATE(898), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(61), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1930), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [38132] = 5,
    ACTIONS(1922), 1,
      anon_sym_LT,
    STATE(792), 1,
      sym__end_of_line,
    STATE(1105), 1,
      sym_superclasses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1932), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38152] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(512), 7,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_DOT,
      anon_sym_TILDE,
  [38166] = 5,
    ACTIONS(1934), 1,
      anon_sym_LPAREN,
    STATE(909), 1,
      sym_identifier,
    STATE(1039), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [38186] = 5,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    STATE(55), 1,
      sym__end_of_line,
    STATE(1021), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1936), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38206] = 4,
    ACTIONS(1491), 1,
      anon_sym_DOT,
    STATE(838), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1938), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_CR,
  [38224] = 5,
    ACTIONS(1940), 1,
      anon_sym_LPAREN,
    STATE(11), 1,
      sym_iterator,
    STATE(1367), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [38244] = 5,
    STATE(907), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(61), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1942), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [38264] = 4,
    ACTIONS(1798), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1335), 2,
      sym_identifier,
      sym_ignored_argument,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [38282] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1512), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [38296] = 5,
    ACTIONS(1859), 1,
      anon_sym_LPAREN,
    STATE(43), 1,
      sym__end_of_line,
    STATE(1097), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1944), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38316] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1522), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_CR,
  [38330] = 5,
    STATE(896), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(61), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1946), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [38350] = 5,
    STATE(899), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 2,
      sym__external_identifier,
      anon_sym_properties,
    ACTIONS(61), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(1948), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [38370] = 4,
    STATE(1244), 1,
      sym_identifier,
    STATE(1290), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [38387] = 4,
    ACTIONS(1952), 1,
      ts_builtin_sym_end,
    ACTIONS(1954), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1812), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38404] = 4,
    STATE(913), 1,
      sym_identifier,
    STATE(951), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1232), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [38421] = 4,
    STATE(1358), 1,
      sym_iterator,
    STATE(1376), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [38438] = 6,
    ACTIONS(1956), 1,
      anon_sym_end,
    ACTIONS(1958), 1,
      anon_sym_case,
    ACTIONS(1960), 1,
      anon_sym_otherwise,
    STATE(1389), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1053), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [38459] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(774), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1489), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38474] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(766), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1340), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38489] = 4,
    ACTIONS(1962), 1,
      ts_builtin_sym_end,
    ACTIONS(1964), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1734), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38506] = 5,
    ACTIONS(1962), 1,
      ts_builtin_sym_end,
    ACTIONS(1964), 1,
      anon_sym_function,
    ACTIONS(1966), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1734), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38525] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1968), 6,
      anon_sym_SEMI,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38538] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1970), 6,
      anon_sym_SEMI,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38551] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(21), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1972), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38566] = 4,
    ACTIONS(1976), 1,
      sym_command_argument,
    STATE(941), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1974), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38583] = 4,
    STATE(1296), 1,
      sym_identifier,
    STATE(1330), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [38600] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1978), 6,
      anon_sym_SEMI,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38613] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1980), 6,
      anon_sym_SEMI,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38626] = 4,
    ACTIONS(1982), 1,
      anon_sym_STAR,
    STATE(725), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [38643] = 4,
    ACTIONS(1984), 1,
      ts_builtin_sym_end,
    ACTIONS(1986), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1816), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38660] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(780), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1855), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38675] = 4,
    ACTIONS(1990), 1,
      sym_command_argument,
    STATE(948), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1988), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38692] = 5,
    ACTIONS(267), 1,
      ts_builtin_sym_end,
    ACTIONS(1992), 1,
      anon_sym_SEMI,
    ACTIONS(1994), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1724), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38711] = 4,
    ACTIONS(1996), 1,
      ts_builtin_sym_end,
    ACTIONS(1998), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1740), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38728] = 5,
    ACTIONS(1996), 1,
      ts_builtin_sym_end,
    ACTIONS(1998), 1,
      anon_sym_function,
    ACTIONS(2000), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1740), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38747] = 4,
    STATE(1244), 1,
      sym_identifier,
    STATE(1304), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [38764] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(772), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(2002), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38779] = 4,
    ACTIONS(2004), 1,
      ts_builtin_sym_end,
    ACTIONS(2006), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1830), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38796] = 4,
    ACTIONS(2010), 1,
      sym_command_argument,
    STATE(948), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2008), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38813] = 4,
    ACTIONS(2013), 1,
      anon_sym_LPAREN,
    STATE(388), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [38830] = 6,
    ACTIONS(121), 1,
      anon_sym_else,
    ACTIONS(2015), 1,
      anon_sym_end,
    ACTIONS(2017), 1,
      anon_sym_elseif,
    STATE(1375), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1102), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [38851] = 4,
    ACTIONS(2021), 1,
      anon_sym_AMP,
    STATE(960), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2019), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38868] = 5,
    ACTIONS(253), 1,
      ts_builtin_sym_end,
    ACTIONS(2023), 1,
      anon_sym_SEMI,
    ACTIONS(2025), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1672), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38887] = 4,
    STATE(1296), 1,
      sym_identifier,
    STATE(1301), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [38904] = 5,
    ACTIONS(197), 1,
      ts_builtin_sym_end,
    ACTIONS(2027), 1,
      anon_sym_SEMI,
    ACTIONS(2029), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1678), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38923] = 4,
    ACTIONS(267), 1,
      ts_builtin_sym_end,
    ACTIONS(1994), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1724), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38940] = 4,
    ACTIONS(197), 1,
      ts_builtin_sym_end,
    ACTIONS(2029), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1678), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38957] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(673), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(2031), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38972] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2033), 6,
      anon_sym_SEMI,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [38985] = 4,
    STATE(913), 1,
      sym_identifier,
    STATE(1086), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1232), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39002] = 4,
    ACTIONS(2021), 1,
      anon_sym_AMP,
    STATE(993), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2035), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39019] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(677), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(2037), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39034] = 4,
    ACTIONS(2039), 1,
      ts_builtin_sym_end,
    ACTIONS(2041), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1712), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39051] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2043), 6,
      anon_sym_SEMI,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39064] = 5,
    ACTIONS(2039), 1,
      ts_builtin_sym_end,
    ACTIONS(2041), 1,
      anon_sym_function,
    ACTIONS(2045), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1712), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39083] = 4,
    ACTIONS(2047), 1,
      anon_sym_LPAREN,
    STATE(741), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39100] = 5,
    ACTIONS(826), 1,
      aux_sym_matrix_token1,
    ACTIONS(1386), 1,
      sym__entry_delimiter,
    STATE(983), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(824), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [39119] = 4,
    STATE(11), 1,
      sym_iterator,
    STATE(1367), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39136] = 5,
    ACTIONS(826), 1,
      aux_sym_matrix_token1,
    ACTIONS(1386), 1,
      sym__entry_delimiter,
    STATE(990), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(824), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [39155] = 4,
    ACTIONS(2049), 1,
      ts_builtin_sym_end,
    ACTIONS(2051), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1718), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39172] = 5,
    ACTIONS(2049), 1,
      ts_builtin_sym_end,
    ACTIONS(2051), 1,
      anon_sym_function,
    ACTIONS(2053), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1718), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39191] = 4,
    ACTIONS(2055), 1,
      anon_sym_STAR,
    STATE(663), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1232), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39208] = 6,
    ACTIONS(121), 1,
      anon_sym_else,
    ACTIONS(2017), 1,
      anon_sym_elseif,
    ACTIONS(2057), 1,
      anon_sym_end,
    STATE(1385), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1008), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [39229] = 4,
    ACTIONS(2059), 1,
      anon_sym_STAR,
    STATE(663), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1232), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39246] = 4,
    ACTIONS(2061), 1,
      anon_sym_LPAREN,
    STATE(686), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1232), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39263] = 4,
    STATE(1244), 1,
      sym_identifier,
    STATE(1259), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39280] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2063), 6,
      anon_sym_SEMI,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39293] = 5,
    ACTIONS(225), 1,
      ts_builtin_sym_end,
    ACTIONS(2065), 1,
      anon_sym_SEMI,
    ACTIONS(2067), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1750), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39312] = 6,
    ACTIONS(121), 1,
      anon_sym_else,
    ACTIONS(2017), 1,
      anon_sym_elseif,
    ACTIONS(2057), 1,
      anon_sym_end,
    STATE(1385), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1102), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [39333] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2069), 2,
      anon_sym_get,
      anon_sym_set,
    ACTIONS(2071), 4,
      sym__external_identifier,
      anon_sym_properties,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [39348] = 4,
    ACTIONS(2075), 1,
      anon_sym_LPAREN,
    STATE(704), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2073), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39365] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2077), 6,
      anon_sym_SEMI,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39378] = 5,
    ACTIONS(235), 1,
      ts_builtin_sym_end,
    ACTIONS(2079), 1,
      anon_sym_SEMI,
    ACTIONS(2081), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1694), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39397] = 5,
    ACTIONS(830), 1,
      aux_sym_matrix_token1,
    ACTIONS(2083), 1,
      sym__entry_delimiter,
    STATE(990), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(828), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [39416] = 4,
    ACTIONS(235), 1,
      ts_builtin_sym_end,
    ACTIONS(2081), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1694), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39433] = 4,
    ACTIONS(2085), 1,
      ts_builtin_sym_end,
    ACTIONS(2087), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1700), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39450] = 4,
    ACTIONS(2089), 1,
      anon_sym_STAR,
    STATE(752), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1257), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39467] = 4,
    ACTIONS(2091), 1,
      anon_sym_STAR,
    STATE(752), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1257), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39484] = 5,
    ACTIONS(2085), 1,
      ts_builtin_sym_end,
    ACTIONS(2087), 1,
      anon_sym_function,
    ACTIONS(2093), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1700), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39503] = 4,
    ACTIONS(2097), 1,
      anon_sym_LPAREN,
    STATE(164), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2095), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39520] = 5,
    ACTIONS(1477), 1,
      aux_sym_matrix_token1,
    ACTIONS(2099), 1,
      sym__entry_delimiter,
    STATE(990), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1475), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [39539] = 5,
    ACTIONS(241), 1,
      ts_builtin_sym_end,
    ACTIONS(2102), 1,
      anon_sym_SEMI,
    ACTIONS(2104), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1706), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39558] = 4,
    ACTIONS(2106), 1,
      anon_sym_LPAREN,
    STATE(523), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39575] = 4,
    ACTIONS(2110), 1,
      anon_sym_AMP,
    STATE(993), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2108), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39592] = 5,
    ACTIONS(1416), 1,
      aux_sym_matrix_token1,
    ACTIONS(1418), 1,
      sym__entry_delimiter,
    STATE(968), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1414), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [39611] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2113), 6,
      anon_sym_SEMI,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39624] = 4,
    ACTIONS(2115), 1,
      anon_sym_LPAREN,
    STATE(446), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39641] = 4,
    ACTIONS(2117), 1,
      anon_sym_LPAREN,
    STATE(89), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39658] = 4,
    ACTIONS(2119), 1,
      anon_sym_LPAREN,
    STATE(523), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39675] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2121), 6,
      anon_sym_SEMI,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39688] = 4,
    ACTIONS(2123), 1,
      anon_sym_LPAREN,
    STATE(446), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39705] = 4,
    ACTIONS(2125), 1,
      anon_sym_LPAREN,
    STATE(89), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39722] = 4,
    STATE(1286), 1,
      sym_attribute,
    STATE(1296), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39739] = 4,
    STATE(1244), 1,
      sym_identifier,
    STATE(1287), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39756] = 6,
    ACTIONS(1958), 1,
      anon_sym_case,
    ACTIONS(1960), 1,
      anon_sym_otherwise,
    ACTIONS(2127), 1,
      anon_sym_end,
    STATE(1361), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1053), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [39777] = 4,
    ACTIONS(2129), 1,
      ts_builtin_sym_end,
    ACTIONS(2131), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1654), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39794] = 5,
    ACTIONS(2129), 1,
      ts_builtin_sym_end,
    ACTIONS(2131), 1,
      anon_sym_function,
    ACTIONS(2133), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1654), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39813] = 4,
    ACTIONS(2135), 1,
      anon_sym_LPAREN,
    STATE(388), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39830] = 6,
    ACTIONS(121), 1,
      anon_sym_else,
    ACTIONS(2017), 1,
      anon_sym_elseif,
    ACTIONS(2137), 1,
      anon_sym_end,
    STATE(1394), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1102), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [39851] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2139), 6,
      anon_sym_SEMI,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39864] = 6,
    ACTIONS(121), 1,
      anon_sym_else,
    ACTIONS(2017), 1,
      anon_sym_elseif,
    ACTIONS(2137), 1,
      anon_sym_end,
    STATE(1394), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(950), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [39885] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2141), 6,
      anon_sym_SEMI,
      anon_sym_properties,
      anon_sym_end,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [39898] = 4,
    STATE(1244), 1,
      sym_identifier,
    STATE(1268), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39915] = 4,
    STATE(1244), 1,
      sym_identifier,
    STATE(1269), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39932] = 4,
    STATE(1244), 1,
      sym_identifier,
    STATE(1280), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39949] = 4,
    STATE(1244), 1,
      sym_identifier,
    STATE(1281), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39966] = 4,
    STATE(1244), 1,
      sym_identifier,
    STATE(1288), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [39983] = 4,
    STATE(1244), 1,
      sym_identifier,
    STATE(1289), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40000] = 4,
    ACTIONS(2143), 1,
      anon_sym_STAR,
    STATE(725), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40017] = 4,
    ACTIONS(2145), 1,
      sym__single_quote_string_end,
    STATE(1058), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2147), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40033] = 3,
    STATE(214), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2149), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40047] = 3,
    STATE(62), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2151), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40061] = 3,
    STATE(1331), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40075] = 3,
    STATE(837), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2153), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40089] = 3,
    STATE(783), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40103] = 4,
    ACTIONS(2155), 1,
      sym__double_quote_string_end,
    STATE(1044), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2157), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40119] = 3,
    STATE(877), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40133] = 3,
    STATE(898), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40147] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2159), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_EQ,
      anon_sym_CR,
  [40159] = 3,
    STATE(33), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2161), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40173] = 3,
    STATE(918), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40187] = 3,
    STATE(843), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2163), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40201] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2165), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_EQ,
      anon_sym_CR,
  [40213] = 3,
    STATE(213), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1485), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40227] = 3,
    STATE(1411), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40241] = 3,
    STATE(389), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40255] = 6,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(2167), 1,
      anon_sym_RPAREN,
    STATE(457), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40275] = 4,
    ACTIONS(2169), 1,
      sym__single_quote_string_end,
    STATE(1037), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2171), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40291] = 3,
    STATE(1274), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40305] = 3,
    STATE(904), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40319] = 3,
    STATE(37), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2174), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40333] = 3,
    STATE(850), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2176), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40347] = 4,
    ACTIONS(2178), 1,
      sym__single_quote_string_end,
    STATE(1037), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2180), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40363] = 3,
    STATE(701), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2182), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40377] = 4,
    ACTIONS(2178), 1,
      sym__double_quote_string_end,
    STATE(1047), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2184), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40393] = 3,
    STATE(776), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2186), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40407] = 3,
    STATE(747), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2188), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40421] = 4,
    ACTIONS(2169), 1,
      sym__double_quote_string_end,
    STATE(1047), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2190), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40437] = 4,
    ACTIONS(2155), 1,
      sym__single_quote_string_end,
    STATE(1042), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2193), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40453] = 3,
    STATE(412), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40467] = 3,
    STATE(78), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2195), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40481] = 3,
    STATE(663), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1232), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40495] = 3,
    STATE(906), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40509] = 4,
    ACTIONS(2199), 1,
      anon_sym_case,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2197), 2,
      anon_sym_end,
      anon_sym_otherwise,
    STATE(1053), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [40525] = 4,
    ACTIONS(2145), 1,
      sym__double_quote_string_end,
    STATE(1059), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2202), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40541] = 3,
    STATE(748), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40555] = 3,
    STATE(213), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1485), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40569] = 3,
    STATE(214), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2149), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40583] = 4,
    ACTIONS(2204), 1,
      sym__single_quote_string_end,
    STATE(1037), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2180), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40599] = 4,
    ACTIONS(2204), 1,
      sym__double_quote_string_end,
    STATE(1047), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2184), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40615] = 3,
    STATE(803), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2206), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40629] = 3,
    STATE(46), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2208), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40643] = 3,
    STATE(907), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40657] = 3,
    STATE(35), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2210), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40671] = 3,
    STATE(725), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1950), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40685] = 3,
    STATE(58), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2212), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40699] = 3,
    STATE(685), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1232), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40713] = 3,
    STATE(903), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40727] = 3,
    STATE(40), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2214), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40741] = 3,
    STATE(912), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40755] = 4,
    ACTIONS(2216), 1,
      sym__single_quote_string_end,
    STATE(1076), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2218), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40771] = 4,
    ACTIONS(2216), 1,
      sym__double_quote_string_end,
    STATE(1077), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2220), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40787] = 3,
    STATE(703), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2073), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40801] = 3,
    STATE(314), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1456), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40815] = 3,
    STATE(897), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40829] = 3,
    STATE(324), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2222), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40843] = 4,
    ACTIONS(2224), 1,
      sym__single_quote_string_end,
    STATE(1037), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2180), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40859] = 4,
    ACTIONS(2224), 1,
      sym__double_quote_string_end,
    STATE(1047), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2184), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40875] = 3,
    STATE(716), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2073), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40889] = 4,
    ACTIONS(2226), 1,
      sym__single_quote_string_end,
    STATE(1083), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2228), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40905] = 4,
    ACTIONS(2226), 1,
      sym__double_quote_string_end,
    STATE(1084), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2230), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40921] = 3,
    STATE(167), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2095), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [40935] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1477), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1475), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [40949] = 4,
    ACTIONS(2232), 1,
      sym__single_quote_string_end,
    STATE(1037), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2180), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40965] = 4,
    ACTIONS(2232), 1,
      sym__double_quote_string_end,
    STATE(1047), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2184), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [40981] = 5,
    ACTIONS(2234), 1,
      anon_sym_SEMI,
    ACTIONS(2237), 1,
      aux_sym_matrix_token1,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2240), 2,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [40999] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2108), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_CR,
  [41011] = 3,
    STATE(168), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2095), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [41025] = 3,
    STATE(522), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [41039] = 3,
    STATE(548), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(689), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [41053] = 3,
    STATE(444), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [41067] = 3,
    STATE(490), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(757), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [41081] = 3,
    STATE(96), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [41095] = 3,
    STATE(108), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(909), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [41109] = 3,
    STATE(910), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1195), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [41123] = 3,
    STATE(899), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [41137] = 3,
    STATE(752), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1257), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [41151] = 3,
    STATE(48), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2242), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41165] = 3,
    STATE(68), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2244), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41179] = 3,
    STATE(70), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2246), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41193] = 3,
    STATE(75), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2248), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41207] = 3,
    STATE(876), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2250), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41221] = 5,
    ACTIONS(2252), 1,
      anon_sym_end,
    ACTIONS(2254), 1,
      anon_sym_elseif,
    ACTIONS(2257), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1102), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [41239] = 3,
    ACTIONS(2261), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2259), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41253] = 3,
    STATE(836), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2263), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41267] = 3,
    STATE(795), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2265), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41281] = 3,
    STATE(896), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [41295] = 3,
    STATE(895), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(7), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [41309] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2267), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41320] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2269), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41331] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2271), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41342] = 3,
    ACTIONS(2273), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1750), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41355] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2275), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41366] = 4,
    ACTIONS(255), 1,
      anon_sym_end,
    ACTIONS(257), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(253), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41381] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2277), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41392] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2279), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41403] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2281), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41414] = 3,
    ACTIONS(2283), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1672), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41427] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1712), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41438] = 3,
    ACTIONS(2285), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1712), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41451] = 4,
    ACTIONS(2287), 1,
      anon_sym_COMMA,
    STATE(1182), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2289), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [41466] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2291), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41477] = 5,
    ACTIONS(1203), 1,
      anon_sym_AT,
    ACTIONS(1207), 1,
      anon_sym_LBRACE,
    ACTIONS(1370), 1,
      anon_sym_LPAREN,
    STATE(730), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41494] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1654), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41505] = 3,
    ACTIONS(2293), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1654), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41518] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1812), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41529] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2295), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41540] = 5,
    ACTIONS(2297), 1,
      anon_sym_LPAREN,
    ACTIONS(2299), 1,
      anon_sym_AT,
    ACTIONS(2301), 1,
      anon_sym_LBRACE,
    STATE(360), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41557] = 4,
    ACTIONS(2303), 1,
      anon_sym_COMMA,
    STATE(1128), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2306), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [41572] = 4,
    ACTIONS(199), 1,
      anon_sym_end,
    ACTIONS(207), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(197), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41587] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1734), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41598] = 5,
    ACTIONS(777), 1,
      anon_sym_RBRACK,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    STATE(1137), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41615] = 3,
    ACTIONS(2312), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1734), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41628] = 5,
    ACTIONS(779), 1,
      anon_sym_RBRACE,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    STATE(1139), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41645] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2314), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41656] = 4,
    ACTIONS(2287), 1,
      anon_sym_COMMA,
    STATE(1194), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2316), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [41671] = 4,
    ACTIONS(2318), 1,
      anon_sym_end,
    ACTIONS(2320), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1962), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41686] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2322), 1,
      anon_sym_RBRACK,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41703] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2322), 1,
      anon_sym_RBRACK,
    STATE(1141), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41720] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2324), 1,
      anon_sym_RBRACE,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41737] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2324), 1,
      anon_sym_RBRACE,
    STATE(1142), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41754] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2326), 1,
      anon_sym_RBRACK,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41771] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2328), 1,
      anon_sym_RBRACE,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41788] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2330), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41799] = 5,
    ACTIONS(1207), 1,
      anon_sym_LBRACE,
    ACTIONS(1370), 1,
      anon_sym_LPAREN,
    ACTIONS(2332), 1,
      anon_sym_AT,
    STATE(718), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41816] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2334), 1,
      anon_sym_RBRACK,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41833] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2334), 1,
      anon_sym_RBRACK,
    STATE(1207), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41850] = 4,
    ACTIONS(2336), 1,
      ts_builtin_sym_end,
    ACTIONS(2338), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1166), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [41865] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2340), 1,
      anon_sym_RBRACE,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41882] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1718), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41893] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2340), 1,
      anon_sym_RBRACE,
    STATE(1222), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41910] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2342), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41921] = 5,
    ACTIONS(2297), 1,
      anon_sym_LPAREN,
    ACTIONS(2301), 1,
      anon_sym_LBRACE,
    ACTIONS(2344), 1,
      anon_sym_AT,
    STATE(353), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41938] = 3,
    ACTIONS(2346), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1718), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41951] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2348), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41962] = 3,
    ACTIONS(2352), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2350), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [41975] = 3,
    ACTIONS(2354), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1724), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [41988] = 3,
    ACTIONS(2356), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1694), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42001] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2358), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42012] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1816), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42023] = 4,
    ACTIONS(227), 1,
      anon_sym_end,
    ACTIONS(229), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(225), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [42038] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1694), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42049] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1700), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42060] = 3,
    ACTIONS(2360), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1700), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42073] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1740), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42084] = 3,
    ACTIONS(2362), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1740), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42097] = 4,
    ACTIONS(2364), 1,
      ts_builtin_sym_end,
    ACTIONS(2366), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1166), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [42112] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1830), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42123] = 4,
    ACTIONS(2369), 1,
      anon_sym_COMMA,
    STATE(1251), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2371), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [42138] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2373), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42149] = 5,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1051), 1,
      anon_sym_AT,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    STATE(457), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42166] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2375), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [42177] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1724), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42188] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2377), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42199] = 5,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    ACTIONS(1080), 1,
      anon_sym_AT,
    STATE(423), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42216] = 5,
    ACTIONS(785), 1,
      anon_sym_RBRACK,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    STATE(1145), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42233] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2379), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42244] = 3,
    ACTIONS(2381), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1706), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42257] = 5,
    ACTIONS(804), 1,
      anon_sym_RBRACK,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    STATE(1183), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42274] = 4,
    ACTIONS(237), 1,
      anon_sym_end,
    ACTIONS(239), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(235), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [42289] = 5,
    ACTIONS(806), 1,
      anon_sym_RBRACE,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    STATE(1185), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42306] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2383), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42317] = 4,
    ACTIONS(2287), 1,
      anon_sym_COMMA,
    STATE(1194), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2385), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [42332] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2387), 1,
      anon_sym_RBRACK,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42349] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2387), 1,
      anon_sym_RBRACK,
    STATE(1187), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42366] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2389), 1,
      anon_sym_RBRACE,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42383] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2389), 1,
      anon_sym_RBRACE,
    STATE(1254), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42400] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2391), 1,
      anon_sym_RBRACK,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42417] = 4,
    ACTIONS(231), 1,
      anon_sym_end,
    ACTIONS(233), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(225), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [42432] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2393), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42443] = 4,
    ACTIONS(2395), 1,
      anon_sym_end,
    ACTIONS(2397), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2085), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [42458] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2399), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42469] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2401), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42480] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2403), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42491] = 4,
    ACTIONS(2405), 1,
      anon_sym_COMMA,
    STATE(1194), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2408), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [42506] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2410), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42517] = 4,
    ACTIONS(269), 1,
      anon_sym_end,
    ACTIONS(271), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(267), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [42532] = 5,
    ACTIONS(2412), 1,
      anon_sym_LPAREN,
    ACTIONS(2414), 1,
      anon_sym_AT,
    ACTIONS(2416), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42549] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2418), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42560] = 4,
    ACTIONS(2420), 1,
      anon_sym_end,
    ACTIONS(2422), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1962), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [42575] = 4,
    ACTIONS(2287), 1,
      anon_sym_COMMA,
    STATE(1223), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2424), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [42590] = 5,
    ACTIONS(2412), 1,
      anon_sym_LPAREN,
    ACTIONS(2416), 1,
      anon_sym_LBRACE,
    ACTIONS(2426), 1,
      anon_sym_AT,
    STATE(403), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42607] = 3,
    ACTIONS(2428), 1,
      aux_sym_matrix_token1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2240), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [42620] = 4,
    ACTIONS(273), 1,
      anon_sym_end,
    ACTIONS(275), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(253), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [42635] = 5,
    ACTIONS(812), 1,
      anon_sym_RBRACK,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    STATE(1210), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42652] = 5,
    ACTIONS(814), 1,
      anon_sym_RBRACE,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    STATE(1212), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42669] = 4,
    ACTIONS(243), 1,
      anon_sym_end,
    ACTIONS(245), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(241), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [42684] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2430), 1,
      anon_sym_RBRACK,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42701] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2432), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42712] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2434), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42723] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2436), 1,
      anon_sym_RBRACK,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42740] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2436), 1,
      anon_sym_RBRACK,
    STATE(1214), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42757] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2438), 1,
      anon_sym_RBRACE,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42774] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2438), 1,
      anon_sym_RBRACE,
    STATE(1215), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42791] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2440), 1,
      anon_sym_RBRACK,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42808] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2442), 1,
      anon_sym_RBRACE,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42825] = 4,
    ACTIONS(289), 1,
      anon_sym_end,
    ACTIONS(291), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(197), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [42840] = 5,
    ACTIONS(2444), 1,
      anon_sym_LPAREN,
    ACTIONS(2446), 1,
      anon_sym_AT,
    ACTIONS(2448), 1,
      anon_sym_LBRACE,
    STATE(100), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42857] = 5,
    ACTIONS(2444), 1,
      anon_sym_LPAREN,
    ACTIONS(2448), 1,
      anon_sym_LBRACE,
    ACTIONS(2450), 1,
      anon_sym_AT,
    STATE(97), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42874] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2452), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42885] = 4,
    ACTIONS(277), 1,
      anon_sym_end,
    ACTIONS(279), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(235), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [42900] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2454), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42911] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2456), 1,
      anon_sym_RBRACE,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42928] = 4,
    ACTIONS(2287), 1,
      anon_sym_COMMA,
    STATE(1194), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2458), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [42943] = 4,
    ACTIONS(2287), 1,
      anon_sym_COMMA,
    STATE(1135), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2460), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [42958] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2462), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42969] = 4,
    ACTIONS(2464), 1,
      anon_sym_end,
    ACTIONS(2466), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2039), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [42984] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2468), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [42995] = 4,
    ACTIONS(2470), 1,
      anon_sym_end,
    ACTIONS(2472), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2085), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43010] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2474), 4,
      sym__external_identifier,
      anon_sym_get,
      anon_sym_set,
      anon_sym_properties,
  [43021] = 3,
    ACTIONS(2476), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1678), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43034] = 4,
    ACTIONS(285), 1,
      anon_sym_end,
    ACTIONS(287), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(267), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43049] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2478), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43060] = 4,
    ACTIONS(281), 1,
      anon_sym_end,
    ACTIONS(283), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(241), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43075] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2480), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43086] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2482), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43097] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2484), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43108] = 4,
    ACTIONS(2486), 1,
      anon_sym_DOT,
    STATE(706), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1404), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [43123] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2488), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43134] = 4,
    ACTIONS(459), 1,
      ts_builtin_sym_end,
    ACTIONS(2338), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1166), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [43149] = 5,
    ACTIONS(787), 1,
      anon_sym_RBRACE,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    STATE(1148), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43166] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2490), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43177] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2492), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43188] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2494), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43199] = 4,
    ACTIONS(2498), 1,
      anon_sym_DOT,
    STATE(1237), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2496), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [43214] = 4,
    ACTIONS(2500), 1,
      anon_sym_end,
    ACTIONS(2502), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2039), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43229] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1678), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43240] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2504), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43251] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2506), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43262] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2508), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43273] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2510), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43284] = 4,
    ACTIONS(2512), 1,
      anon_sym_COMMA,
    STATE(1128), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2514), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [43299] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2516), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43310] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2518), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [43321] = 5,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(2310), 1,
      aux_sym_matrix_token1,
    ACTIONS(2520), 1,
      anon_sym_RBRACE,
    STATE(1085), 1,
      aux_sym_matrix_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43338] = 3,
    ACTIONS(2522), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(225), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43350] = 4,
    ACTIONS(2524), 1,
      anon_sym_COMMA,
    ACTIONS(2527), 1,
      anon_sym_RPAREN,
    STATE(1256), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43364] = 3,
    ACTIONS(2529), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2039), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43376] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2531), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [43386] = 4,
    ACTIONS(2297), 1,
      anon_sym_LPAREN,
    ACTIONS(2301), 1,
      anon_sym_LBRACE,
    STATE(357), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43400] = 3,
    ACTIONS(2535), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2533), 2,
      anon_sym_end,
      anon_sym_elseif,
  [43412] = 4,
    ACTIONS(1728), 1,
      anon_sym_RPAREN,
    ACTIONS(2537), 1,
      anon_sym_COMMA,
    STATE(1261), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43426] = 4,
    ACTIONS(2540), 1,
      anon_sym_end,
    ACTIONS(2542), 1,
      anon_sym_catch,
    STATE(1344), 1,
      sym_catch_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43440] = 3,
    ACTIONS(2544), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2049), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43452] = 3,
    ACTIONS(2546), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(267), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43464] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2548), 3,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
  [43474] = 3,
    ACTIONS(2550), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1996), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43486] = 3,
    ACTIONS(143), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2552), 2,
      anon_sym_end,
      anon_sym_elseif,
  [43498] = 4,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    STATE(471), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43512] = 4,
    ACTIONS(1043), 1,
      anon_sym_LPAREN,
    ACTIONS(1055), 1,
      anon_sym_LBRACE,
    STATE(437), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43526] = 3,
    ACTIONS(2554), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(197), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43538] = 4,
    ACTIONS(2556), 1,
      anon_sym_COMMA,
    ACTIONS(2558), 1,
      anon_sym_RPAREN,
    STATE(1279), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43552] = 4,
    ACTIONS(2560), 1,
      anon_sym_COMMA,
    ACTIONS(2562), 1,
      anon_sym_RPAREN,
    STATE(1298), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43566] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2564), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [43576] = 4,
    ACTIONS(2566), 1,
      anon_sym_COMMA,
    ACTIONS(2568), 1,
      anon_sym_RPAREN,
    STATE(1297), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43590] = 4,
    ACTIONS(1592), 1,
      anon_sym_COMMA,
    ACTIONS(2570), 1,
      anon_sym_RPAREN,
    STATE(1261), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43604] = 4,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(2572), 1,
      sym_number,
    STATE(1328), 1,
      sym_spread_operator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43618] = 4,
    ACTIONS(2542), 1,
      anon_sym_catch,
    ACTIONS(2574), 1,
      anon_sym_end,
    STATE(1368), 1,
      sym_catch_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43632] = 4,
    ACTIONS(2576), 1,
      anon_sym_COMMA,
    ACTIONS(2578), 1,
      anon_sym_RPAREN,
    STATE(1299), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43646] = 4,
    ACTIONS(2556), 1,
      anon_sym_COMMA,
    ACTIONS(2580), 1,
      anon_sym_RPAREN,
    STATE(1256), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43660] = 4,
    ACTIONS(2412), 1,
      anon_sym_LPAREN,
    ACTIONS(2416), 1,
      anon_sym_LBRACE,
    STATE(394), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43674] = 4,
    ACTIONS(2412), 1,
      anon_sym_LPAREN,
    ACTIONS(2416), 1,
      anon_sym_LBRACE,
    STATE(395), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43688] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2582), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [43698] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2584), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [43708] = 4,
    ACTIONS(709), 1,
      anon_sym_COLON,
    ACTIONS(2586), 1,
      sym_number,
    STATE(1302), 1,
      sym_spread_operator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43722] = 3,
    ACTIONS(2588), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(235), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43734] = 4,
    ACTIONS(2560), 1,
      anon_sym_COMMA,
    ACTIONS(2590), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43748] = 4,
    ACTIONS(1207), 1,
      anon_sym_LBRACE,
    ACTIONS(1370), 1,
      anon_sym_LPAREN,
    STATE(728), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43762] = 4,
    ACTIONS(2444), 1,
      anon_sym_LPAREN,
    ACTIONS(2448), 1,
      anon_sym_LBRACE,
    STATE(104), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43776] = 4,
    ACTIONS(2444), 1,
      anon_sym_LPAREN,
    ACTIONS(2448), 1,
      anon_sym_LBRACE,
    STATE(105), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43790] = 4,
    ACTIONS(1207), 1,
      anon_sym_LBRACE,
    ACTIONS(1370), 1,
      anon_sym_LPAREN,
    STATE(729), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43804] = 3,
    ACTIONS(2592), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2129), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43816] = 4,
    ACTIONS(2560), 1,
      anon_sym_COMMA,
    ACTIONS(2594), 1,
      anon_sym_RPAREN,
    STATE(1298), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43830] = 3,
    ACTIONS(2596), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2085), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43842] = 3,
    ACTIONS(2598), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(241), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43854] = 3,
    ACTIONS(2600), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1962), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43866] = 3,
    ACTIONS(2604), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2602), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [43878] = 4,
    ACTIONS(2566), 1,
      anon_sym_COMMA,
    ACTIONS(2606), 1,
      anon_sym_RPAREN,
    STATE(1300), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43892] = 4,
    ACTIONS(2608), 1,
      anon_sym_COMMA,
    ACTIONS(2611), 1,
      anon_sym_RPAREN,
    STATE(1298), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43906] = 4,
    ACTIONS(2613), 1,
      anon_sym_COMMA,
    ACTIONS(2616), 1,
      anon_sym_RPAREN,
    STATE(1299), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43920] = 4,
    ACTIONS(2618), 1,
      anon_sym_COMMA,
    ACTIONS(2621), 1,
      anon_sym_RPAREN,
    STATE(1300), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43934] = 4,
    ACTIONS(2560), 1,
      anon_sym_COMMA,
    ACTIONS(2623), 1,
      anon_sym_RPAREN,
    STATE(1272), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43948] = 4,
    ACTIONS(2576), 1,
      anon_sym_COMMA,
    ACTIONS(2625), 1,
      anon_sym_RPAREN,
    STATE(1278), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43962] = 3,
    ACTIONS(2627), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(253), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [43974] = 4,
    ACTIONS(2297), 1,
      anon_sym_LPAREN,
    ACTIONS(2301), 1,
      anon_sym_LBRACE,
    STATE(361), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43988] = 3,
    ACTIONS(297), 1,
      anon_sym_end,
    ACTIONS(299), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [43999] = 3,
    ACTIONS(331), 1,
      anon_sym_end,
    ACTIONS(333), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44010] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2049), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [44019] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2039), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [44028] = 3,
    ACTIONS(2629), 1,
      anon_sym_end,
    ACTIONS(2631), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44039] = 3,
    ACTIONS(2633), 1,
      anon_sym_end,
    ACTIONS(2635), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44050] = 3,
    ACTIONS(449), 1,
      anon_sym_end,
    ACTIONS(451), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44061] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(840), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [44070] = 3,
    ACTIONS(2637), 1,
      anon_sym_end,
    ACTIONS(2639), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44081] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(197), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [44090] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1984), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [44099] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1996), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [44108] = 3,
    ACTIONS(313), 1,
      anon_sym_end,
    ACTIONS(315), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44119] = 3,
    ACTIONS(335), 1,
      anon_sym_end,
    ACTIONS(337), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44130] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2129), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [44139] = 3,
    ACTIONS(327), 1,
      anon_sym_end,
    ACTIONS(329), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44150] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2004), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [44159] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(235), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [44168] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2085), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [44177] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1952), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [44186] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1524), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [44195] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1962), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [44204] = 3,
    ACTIONS(2641), 1,
      anon_sym_end,
    ACTIONS(2643), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44215] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2616), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [44224] = 3,
    ACTIONS(425), 1,
      anon_sym_end,
    ACTIONS(427), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44235] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2611), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [44244] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2645), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [44253] = 3,
    ACTIONS(2647), 1,
      anon_sym_end,
    ACTIONS(2649), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44264] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1514), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [44273] = 3,
    ACTIONS(429), 1,
      anon_sym_end,
    ACTIONS(431), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44284] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2527), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [44293] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(267), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [44302] = 3,
    ACTIONS(433), 1,
      anon_sym_end,
    ACTIONS(435), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44313] = 3,
    ACTIONS(323), 1,
      anon_sym_end,
    ACTIONS(325), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44324] = 3,
    ACTIONS(441), 1,
      anon_sym_end,
    ACTIONS(443), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44335] = 3,
    ACTIONS(2651), 1,
      anon_sym_end,
    ACTIONS(2653), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44346] = 3,
    ACTIONS(445), 1,
      anon_sym_end,
    ACTIONS(447), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44357] = 2,
    ACTIONS(2655), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44365] = 2,
    ACTIONS(2167), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44373] = 2,
    ACTIONS(2574), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44381] = 2,
    ACTIONS(2657), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44389] = 2,
    ACTIONS(2659), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44397] = 2,
    ACTIONS(2661), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44405] = 2,
    ACTIONS(2663), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44413] = 2,
    ACTIONS(2665), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44421] = 2,
    ACTIONS(2663), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44429] = 2,
    ACTIONS(2667), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44437] = 2,
    ACTIONS(2669), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44445] = 2,
    ACTIONS(2671), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44453] = 2,
    ACTIONS(2669), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44461] = 2,
    ACTIONS(2127), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44469] = 2,
    ACTIONS(2673), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44477] = 2,
    ACTIONS(2675), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44485] = 2,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44493] = 2,
    ACTIONS(2679), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44501] = 2,
    ACTIONS(2681), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44509] = 2,
    ACTIONS(1956), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44517] = 2,
    ACTIONS(2683), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44525] = 2,
    ACTIONS(2685), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44533] = 2,
    ACTIONS(2687), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44541] = 2,
    ACTIONS(2689), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44549] = 2,
    ACTIONS(2691), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44557] = 2,
    ACTIONS(2693), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44565] = 2,
    ACTIONS(2695), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44573] = 2,
    ACTIONS(2697), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44581] = 2,
    ACTIONS(2699), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44589] = 2,
    ACTIONS(2701), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44597] = 2,
    ACTIONS(2703), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44605] = 2,
    ACTIONS(2705), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44613] = 2,
    ACTIONS(2707), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44621] = 2,
    ACTIONS(2709), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44629] = 2,
    ACTIONS(2711), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44637] = 2,
    ACTIONS(2713), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44645] = 2,
    ACTIONS(2715), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44653] = 2,
    ACTIONS(2717), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44661] = 2,
    ACTIONS(2719), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44669] = 2,
    ACTIONS(2721), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44677] = 2,
    ACTIONS(2723), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44685] = 2,
    ACTIONS(2540), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44693] = 2,
    ACTIONS(2725), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44701] = 2,
    ACTIONS(2137), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44709] = 2,
    ACTIONS(2727), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44717] = 2,
    ACTIONS(2729), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44725] = 2,
    ACTIONS(2731), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44733] = 2,
    ACTIONS(2733), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44741] = 2,
    ACTIONS(2735), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44749] = 2,
    ACTIONS(2057), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44757] = 2,
    ACTIONS(2737), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44765] = 2,
    ACTIONS(2739), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44773] = 2,
    ACTIONS(2015), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44781] = 2,
    ACTIONS(2741), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44789] = 2,
    ACTIONS(2743), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44797] = 2,
    ACTIONS(2745), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44805] = 2,
    ACTIONS(2747), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44813] = 2,
    ACTIONS(2749), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44821] = 2,
    ACTIONS(2751), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44829] = 2,
    ACTIONS(2753), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44837] = 2,
    ACTIONS(2755), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44845] = 2,
    ACTIONS(2751), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44853] = 2,
    ACTIONS(2757), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44861] = 2,
    ACTIONS(2759), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44869] = 2,
    ACTIONS(2761), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44877] = 2,
    ACTIONS(2763), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44885] = 2,
    ACTIONS(2765), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44893] = 2,
    ACTIONS(2721), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44901] = 2,
    ACTIONS(2767), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44909] = 2,
    ACTIONS(2769), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [44917] = 2,
    ACTIONS(2729), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(158)] = 0,
  [SMALL_STATE(159)] = 74,
  [SMALL_STATE(160)] = 147,
  [SMALL_STATE(161)] = 222,
  [SMALL_STATE(162)] = 297,
  [SMALL_STATE(163)] = 368,
  [SMALL_STATE(164)] = 431,
  [SMALL_STATE(165)] = 494,
  [SMALL_STATE(166)] = 557,
  [SMALL_STATE(167)] = 620,
  [SMALL_STATE(168)] = 683,
  [SMALL_STATE(169)] = 741,
  [SMALL_STATE(170)] = 863,
  [SMALL_STATE(171)] = 985,
  [SMALL_STATE(172)] = 1107,
  [SMALL_STATE(173)] = 1229,
  [SMALL_STATE(174)] = 1287,
  [SMALL_STATE(175)] = 1409,
  [SMALL_STATE(176)] = 1531,
  [SMALL_STATE(177)] = 1653,
  [SMALL_STATE(178)] = 1775,
  [SMALL_STATE(179)] = 1897,
  [SMALL_STATE(180)] = 2019,
  [SMALL_STATE(181)] = 2141,
  [SMALL_STATE(182)] = 2257,
  [SMALL_STATE(183)] = 2371,
  [SMALL_STATE(184)] = 2487,
  [SMALL_STATE(185)] = 2598,
  [SMALL_STATE(186)] = 2659,
  [SMALL_STATE(187)] = 2771,
  [SMALL_STATE(188)] = 2881,
  [SMALL_STATE(189)] = 2993,
  [SMALL_STATE(190)] = 3105,
  [SMALL_STATE(191)] = 3217,
  [SMALL_STATE(192)] = 3329,
  [SMALL_STATE(193)] = 3439,
  [SMALL_STATE(194)] = 3551,
  [SMALL_STATE(195)] = 3663,
  [SMALL_STATE(196)] = 3775,
  [SMALL_STATE(197)] = 3833,
  [SMALL_STATE(198)] = 3943,
  [SMALL_STATE(199)] = 4055,
  [SMALL_STATE(200)] = 4167,
  [SMALL_STATE(201)] = 4279,
  [SMALL_STATE(202)] = 4391,
  [SMALL_STATE(203)] = 4501,
  [SMALL_STATE(204)] = 4613,
  [SMALL_STATE(205)] = 4725,
  [SMALL_STATE(206)] = 4837,
  [SMALL_STATE(207)] = 4949,
  [SMALL_STATE(208)] = 5054,
  [SMALL_STATE(209)] = 5159,
  [SMALL_STATE(210)] = 5264,
  [SMALL_STATE(211)] = 5367,
  [SMALL_STATE(212)] = 5423,
  [SMALL_STATE(213)] = 5527,
  [SMALL_STATE(214)] = 5583,
  [SMALL_STATE(215)] = 5639,
  [SMALL_STATE(216)] = 5695,
  [SMALL_STATE(217)] = 5751,
  [SMALL_STATE(218)] = 5855,
  [SMALL_STATE(219)] = 5956,
  [SMALL_STATE(220)] = 6057,
  [SMALL_STATE(221)] = 6158,
  [SMALL_STATE(222)] = 6259,
  [SMALL_STATE(223)] = 6360,
  [SMALL_STATE(224)] = 6461,
  [SMALL_STATE(225)] = 6562,
  [SMALL_STATE(226)] = 6663,
  [SMALL_STATE(227)] = 6764,
  [SMALL_STATE(228)] = 6865,
  [SMALL_STATE(229)] = 6960,
  [SMALL_STATE(230)] = 7055,
  [SMALL_STATE(231)] = 7150,
  [SMALL_STATE(232)] = 7245,
  [SMALL_STATE(233)] = 7292,
  [SMALL_STATE(234)] = 7380,
  [SMALL_STATE(235)] = 7472,
  [SMALL_STATE(236)] = 7564,
  [SMALL_STATE(237)] = 7656,
  [SMALL_STATE(238)] = 7748,
  [SMALL_STATE(239)] = 7836,
  [SMALL_STATE(240)] = 7924,
  [SMALL_STATE(241)] = 8012,
  [SMALL_STATE(242)] = 8100,
  [SMALL_STATE(243)] = 8188,
  [SMALL_STATE(244)] = 8280,
  [SMALL_STATE(245)] = 8372,
  [SMALL_STATE(246)] = 8464,
  [SMALL_STATE(247)] = 8556,
  [SMALL_STATE(248)] = 8648,
  [SMALL_STATE(249)] = 8740,
  [SMALL_STATE(250)] = 8832,
  [SMALL_STATE(251)] = 8924,
  [SMALL_STATE(252)] = 9016,
  [SMALL_STATE(253)] = 9108,
  [SMALL_STATE(254)] = 9200,
  [SMALL_STATE(255)] = 9292,
  [SMALL_STATE(256)] = 9380,
  [SMALL_STATE(257)] = 9472,
  [SMALL_STATE(258)] = 9560,
  [SMALL_STATE(259)] = 9648,
  [SMALL_STATE(260)] = 9736,
  [SMALL_STATE(261)] = 9828,
  [SMALL_STATE(262)] = 9920,
  [SMALL_STATE(263)] = 10012,
  [SMALL_STATE(264)] = 10104,
  [SMALL_STATE(265)] = 10192,
  [SMALL_STATE(266)] = 10280,
  [SMALL_STATE(267)] = 10372,
  [SMALL_STATE(268)] = 10460,
  [SMALL_STATE(269)] = 10548,
  [SMALL_STATE(270)] = 10636,
  [SMALL_STATE(271)] = 10728,
  [SMALL_STATE(272)] = 10820,
  [SMALL_STATE(273)] = 10912,
  [SMALL_STATE(274)] = 11004,
  [SMALL_STATE(275)] = 11096,
  [SMALL_STATE(276)] = 11148,
  [SMALL_STATE(277)] = 11240,
  [SMALL_STATE(278)] = 11332,
  [SMALL_STATE(279)] = 11424,
  [SMALL_STATE(280)] = 11516,
  [SMALL_STATE(281)] = 11608,
  [SMALL_STATE(282)] = 11700,
  [SMALL_STATE(283)] = 11792,
  [SMALL_STATE(284)] = 11884,
  [SMALL_STATE(285)] = 11976,
  [SMALL_STATE(286)] = 12068,
  [SMALL_STATE(287)] = 12160,
  [SMALL_STATE(288)] = 12252,
  [SMALL_STATE(289)] = 12344,
  [SMALL_STATE(290)] = 12436,
  [SMALL_STATE(291)] = 12528,
  [SMALL_STATE(292)] = 12620,
  [SMALL_STATE(293)] = 12712,
  [SMALL_STATE(294)] = 12804,
  [SMALL_STATE(295)] = 12896,
  [SMALL_STATE(296)] = 12988,
  [SMALL_STATE(297)] = 13080,
  [SMALL_STATE(298)] = 13172,
  [SMALL_STATE(299)] = 13264,
  [SMALL_STATE(300)] = 13356,
  [SMALL_STATE(301)] = 13448,
  [SMALL_STATE(302)] = 13540,
  [SMALL_STATE(303)] = 13632,
  [SMALL_STATE(304)] = 13724,
  [SMALL_STATE(305)] = 13816,
  [SMALL_STATE(306)] = 13908,
  [SMALL_STATE(307)] = 14000,
  [SMALL_STATE(308)] = 14092,
  [SMALL_STATE(309)] = 14184,
  [SMALL_STATE(310)] = 14276,
  [SMALL_STATE(311)] = 14368,
  [SMALL_STATE(312)] = 14460,
  [SMALL_STATE(313)] = 14552,
  [SMALL_STATE(314)] = 14644,
  [SMALL_STATE(315)] = 14696,
  [SMALL_STATE(316)] = 14788,
  [SMALL_STATE(317)] = 14880,
  [SMALL_STATE(318)] = 14972,
  [SMALL_STATE(319)] = 15060,
  [SMALL_STATE(320)] = 15148,
  [SMALL_STATE(321)] = 15236,
  [SMALL_STATE(322)] = 15324,
  [SMALL_STATE(323)] = 15412,
  [SMALL_STATE(324)] = 15504,
  [SMALL_STATE(325)] = 15556,
  [SMALL_STATE(326)] = 15648,
  [SMALL_STATE(327)] = 15740,
  [SMALL_STATE(328)] = 15792,
  [SMALL_STATE(329)] = 15884,
  [SMALL_STATE(330)] = 15976,
  [SMALL_STATE(331)] = 16028,
  [SMALL_STATE(332)] = 16120,
  [SMALL_STATE(333)] = 16172,
  [SMALL_STATE(334)] = 16264,
  [SMALL_STATE(335)] = 16356,
  [SMALL_STATE(336)] = 16448,
  [SMALL_STATE(337)] = 16540,
  [SMALL_STATE(338)] = 16632,
  [SMALL_STATE(339)] = 16724,
  [SMALL_STATE(340)] = 16816,
  [SMALL_STATE(341)] = 16908,
  [SMALL_STATE(342)] = 17000,
  [SMALL_STATE(343)] = 17092,
  [SMALL_STATE(344)] = 17184,
  [SMALL_STATE(345)] = 17276,
  [SMALL_STATE(346)] = 17335,
  [SMALL_STATE(347)] = 17398,
  [SMALL_STATE(348)] = 17457,
  [SMALL_STATE(349)] = 17510,
  [SMALL_STATE(350)] = 17573,
  [SMALL_STATE(351)] = 17636,
  [SMALL_STATE(352)] = 17682,
  [SMALL_STATE(353)] = 17726,
  [SMALL_STATE(354)] = 17770,
  [SMALL_STATE(355)] = 17814,
  [SMALL_STATE(356)] = 17860,
  [SMALL_STATE(357)] = 17906,
  [SMALL_STATE(358)] = 17950,
  [SMALL_STATE(359)] = 17994,
  [SMALL_STATE(360)] = 18040,
  [SMALL_STATE(361)] = 18084,
  [SMALL_STATE(362)] = 18128,
  [SMALL_STATE(363)] = 18181,
  [SMALL_STATE(364)] = 18234,
  [SMALL_STATE(365)] = 18297,
  [SMALL_STATE(366)] = 18354,
  [SMALL_STATE(367)] = 18411,
  [SMALL_STATE(368)] = 18474,
  [SMALL_STATE(369)] = 18537,
  [SMALL_STATE(370)] = 18596,
  [SMALL_STATE(371)] = 18659,
  [SMALL_STATE(372)] = 18716,
  [SMALL_STATE(373)] = 18775,
  [SMALL_STATE(374)] = 18821,
  [SMALL_STATE(375)] = 18889,
  [SMALL_STATE(376)] = 18935,
  [SMALL_STATE(377)] = 19003,
  [SMALL_STATE(378)] = 19055,
  [SMALL_STATE(379)] = 19097,
  [SMALL_STATE(380)] = 19165,
  [SMALL_STATE(381)] = 19228,
  [SMALL_STATE(382)] = 19281,
  [SMALL_STATE(383)] = 19346,
  [SMALL_STATE(384)] = 19403,
  [SMALL_STATE(385)] = 19470,
  [SMALL_STATE(386)] = 19515,
  [SMALL_STATE(387)] = 19558,
  [SMALL_STATE(388)] = 19601,
  [SMALL_STATE(389)] = 19646,
  [SMALL_STATE(390)] = 19691,
  [SMALL_STATE(391)] = 19748,
  [SMALL_STATE(392)] = 19805,
  [SMALL_STATE(393)] = 19850,
  [SMALL_STATE(394)] = 19893,
  [SMALL_STATE(395)] = 19936,
  [SMALL_STATE(396)] = 19979,
  [SMALL_STATE(397)] = 20036,
  [SMALL_STATE(398)] = 20081,
  [SMALL_STATE(399)] = 20124,
  [SMALL_STATE(400)] = 20167,
  [SMALL_STATE(401)] = 20230,
  [SMALL_STATE(402)] = 20293,
  [SMALL_STATE(403)] = 20358,
  [SMALL_STATE(404)] = 20401,
  [SMALL_STATE(405)] = 20464,
  [SMALL_STATE(406)] = 20521,
  [SMALL_STATE(407)] = 20582,
  [SMALL_STATE(408)] = 20635,
  [SMALL_STATE(409)] = 20698,
  [SMALL_STATE(410)] = 20740,
  [SMALL_STATE(411)] = 20790,
  [SMALL_STATE(412)] = 20852,
  [SMALL_STATE(413)] = 20892,
  [SMALL_STATE(414)] = 20956,
  [SMALL_STATE(415)] = 20998,
  [SMALL_STATE(416)] = 21039,
  [SMALL_STATE(417)] = 21096,
  [SMALL_STATE(418)] = 21137,
  [SMALL_STATE(419)] = 21182,
  [SMALL_STATE(420)] = 21221,
  [SMALL_STATE(421)] = 21260,
  [SMALL_STATE(422)] = 21301,
  [SMALL_STATE(423)] = 21342,
  [SMALL_STATE(424)] = 21383,
  [SMALL_STATE(425)] = 21446,
  [SMALL_STATE(426)] = 21493,
  [SMALL_STATE(427)] = 21538,
  [SMALL_STATE(428)] = 21579,
  [SMALL_STATE(429)] = 21618,
  [SMALL_STATE(430)] = 21657,
  [SMALL_STATE(431)] = 21702,
  [SMALL_STATE(432)] = 21743,
  [SMALL_STATE(433)] = 21782,
  [SMALL_STATE(434)] = 21827,
  [SMALL_STATE(435)] = 21870,
  [SMALL_STATE(436)] = 21915,
  [SMALL_STATE(437)] = 21954,
  [SMALL_STATE(438)] = 21995,
  [SMALL_STATE(439)] = 22054,
  [SMALL_STATE(440)] = 22099,
  [SMALL_STATE(441)] = 22156,
  [SMALL_STATE(442)] = 22201,
  [SMALL_STATE(443)] = 22264,
  [SMALL_STATE(444)] = 22305,
  [SMALL_STATE(445)] = 22350,
  [SMALL_STATE(446)] = 22401,
  [SMALL_STATE(447)] = 22446,
  [SMALL_STATE(448)] = 22485,
  [SMALL_STATE(449)] = 22530,
  [SMALL_STATE(450)] = 22575,
  [SMALL_STATE(451)] = 22614,
  [SMALL_STATE(452)] = 22653,
  [SMALL_STATE(453)] = 22710,
  [SMALL_STATE(454)] = 22751,
  [SMALL_STATE(455)] = 22808,
  [SMALL_STATE(456)] = 22849,
  [SMALL_STATE(457)] = 22890,
  [SMALL_STATE(458)] = 22931,
  [SMALL_STATE(459)] = 22976,
  [SMALL_STATE(460)] = 23015,
  [SMALL_STATE(461)] = 23060,
  [SMALL_STATE(462)] = 23099,
  [SMALL_STATE(463)] = 23162,
  [SMALL_STATE(464)] = 23201,
  [SMALL_STATE(465)] = 23242,
  [SMALL_STATE(466)] = 23283,
  [SMALL_STATE(467)] = 23346,
  [SMALL_STATE(468)] = 23409,
  [SMALL_STATE(469)] = 23448,
  [SMALL_STATE(470)] = 23489,
  [SMALL_STATE(471)] = 23534,
  [SMALL_STATE(472)] = 23575,
  [SMALL_STATE(473)] = 23632,
  [SMALL_STATE(474)] = 23673,
  [SMALL_STATE(475)] = 23732,
  [SMALL_STATE(476)] = 23777,
  [SMALL_STATE(477)] = 23822,
  [SMALL_STATE(478)] = 23865,
  [SMALL_STATE(479)] = 23908,
  [SMALL_STATE(480)] = 23953,
  [SMALL_STATE(481)] = 23998,
  [SMALL_STATE(482)] = 24041,
  [SMALL_STATE(483)] = 24082,
  [SMALL_STATE(484)] = 24125,
  [SMALL_STATE(485)] = 24164,
  [SMALL_STATE(486)] = 24215,
  [SMALL_STATE(487)] = 24258,
  [SMALL_STATE(488)] = 24313,
  [SMALL_STATE(489)] = 24354,
  [SMALL_STATE(490)] = 24399,
  [SMALL_STATE(491)] = 24439,
  [SMALL_STATE(492)] = 24479,
  [SMALL_STATE(493)] = 24524,
  [SMALL_STATE(494)] = 24565,
  [SMALL_STATE(495)] = 24606,
  [SMALL_STATE(496)] = 24645,
  [SMALL_STATE(497)] = 24686,
  [SMALL_STATE(498)] = 24727,
  [SMALL_STATE(499)] = 24766,
  [SMALL_STATE(500)] = 24805,
  [SMALL_STATE(501)] = 24844,
  [SMALL_STATE(502)] = 24887,
  [SMALL_STATE(503)] = 24926,
  [SMALL_STATE(504)] = 24965,
  [SMALL_STATE(505)] = 25004,
  [SMALL_STATE(506)] = 25043,
  [SMALL_STATE(507)] = 25086,
  [SMALL_STATE(508)] = 25125,
  [SMALL_STATE(509)] = 25168,
  [SMALL_STATE(510)] = 25209,
  [SMALL_STATE(511)] = 25250,
  [SMALL_STATE(512)] = 25297,
  [SMALL_STATE(513)] = 25342,
  [SMALL_STATE(514)] = 25383,
  [SMALL_STATE(515)] = 25422,
  [SMALL_STATE(516)] = 25461,
  [SMALL_STATE(517)] = 25500,
  [SMALL_STATE(518)] = 25539,
  [SMALL_STATE(519)] = 25582,
  [SMALL_STATE(520)] = 25627,
  [SMALL_STATE(521)] = 25672,
  [SMALL_STATE(522)] = 25717,
  [SMALL_STATE(523)] = 25760,
  [SMALL_STATE(524)] = 25803,
  [SMALL_STATE(525)] = 25846,
  [SMALL_STATE(526)] = 25889,
  [SMALL_STATE(527)] = 25932,
  [SMALL_STATE(528)] = 25977,
  [SMALL_STATE(529)] = 26020,
  [SMALL_STATE(530)] = 26061,
  [SMALL_STATE(531)] = 26104,
  [SMALL_STATE(532)] = 26145,
  [SMALL_STATE(533)] = 26188,
  [SMALL_STATE(534)] = 26233,
  [SMALL_STATE(535)] = 26278,
  [SMALL_STATE(536)] = 26319,
  [SMALL_STATE(537)] = 26364,
  [SMALL_STATE(538)] = 26405,
  [SMALL_STATE(539)] = 26446,
  [SMALL_STATE(540)] = 26491,
  [SMALL_STATE(541)] = 26534,
  [SMALL_STATE(542)] = 26575,
  [SMALL_STATE(543)] = 26614,
  [SMALL_STATE(544)] = 26659,
  [SMALL_STATE(545)] = 26704,
  [SMALL_STATE(546)] = 26745,
  [SMALL_STATE(547)] = 26788,
  [SMALL_STATE(548)] = 26833,
  [SMALL_STATE(549)] = 26871,
  [SMALL_STATE(550)] = 26909,
  [SMALL_STATE(551)] = 26949,
  [SMALL_STATE(552)] = 26991,
  [SMALL_STATE(553)] = 27033,
  [SMALL_STATE(554)] = 27072,
  [SMALL_STATE(555)] = 27117,
  [SMALL_STATE(556)] = 27162,
  [SMALL_STATE(557)] = 27207,
  [SMALL_STATE(558)] = 27252,
  [SMALL_STATE(559)] = 27295,
  [SMALL_STATE(560)] = 27338,
  [SMALL_STATE(561)] = 27383,
  [SMALL_STATE(562)] = 27426,
  [SMALL_STATE(563)] = 27467,
  [SMALL_STATE(564)] = 27510,
  [SMALL_STATE(565)] = 27555,
  [SMALL_STATE(566)] = 27600,
  [SMALL_STATE(567)] = 27643,
  [SMALL_STATE(568)] = 27688,
  [SMALL_STATE(569)] = 27727,
  [SMALL_STATE(570)] = 27768,
  [SMALL_STATE(571)] = 27811,
  [SMALL_STATE(572)] = 27848,
  [SMALL_STATE(573)] = 27887,
  [SMALL_STATE(574)] = 27926,
  [SMALL_STATE(575)] = 27963,
  [SMALL_STATE(576)] = 28002,
  [SMALL_STATE(577)] = 28043,
  [SMALL_STATE(578)] = 28080,
  [SMALL_STATE(579)] = 28117,
  [SMALL_STATE(580)] = 28164,
  [SMALL_STATE(581)] = 28201,
  [SMALL_STATE(582)] = 28244,
  [SMALL_STATE(583)] = 28281,
  [SMALL_STATE(584)] = 28326,
  [SMALL_STATE(585)] = 28363,
  [SMALL_STATE(586)] = 28402,
  [SMALL_STATE(587)] = 28441,
  [SMALL_STATE(588)] = 28486,
  [SMALL_STATE(589)] = 28523,
  [SMALL_STATE(590)] = 28568,
  [SMALL_STATE(591)] = 28611,
  [SMALL_STATE(592)] = 28648,
  [SMALL_STATE(593)] = 28693,
  [SMALL_STATE(594)] = 28732,
  [SMALL_STATE(595)] = 28769,
  [SMALL_STATE(596)] = 28814,
  [SMALL_STATE(597)] = 28855,
  [SMALL_STATE(598)] = 28894,
  [SMALL_STATE(599)] = 28933,
  [SMALL_STATE(600)] = 28978,
  [SMALL_STATE(601)] = 29021,
  [SMALL_STATE(602)] = 29062,
  [SMALL_STATE(603)] = 29099,
  [SMALL_STATE(604)] = 29136,
  [SMALL_STATE(605)] = 29173,
  [SMALL_STATE(606)] = 29210,
  [SMALL_STATE(607)] = 29255,
  [SMALL_STATE(608)] = 29300,
  [SMALL_STATE(609)] = 29347,
  [SMALL_STATE(610)] = 29394,
  [SMALL_STATE(611)] = 29441,
  [SMALL_STATE(612)] = 29485,
  [SMALL_STATE(613)] = 29529,
  [SMALL_STATE(614)] = 29573,
  [SMALL_STATE(615)] = 29611,
  [SMALL_STATE(616)] = 29651,
  [SMALL_STATE(617)] = 29693,
  [SMALL_STATE(618)] = 29737,
  [SMALL_STATE(619)] = 29783,
  [SMALL_STATE(620)] = 29829,
  [SMALL_STATE(621)] = 29871,
  [SMALL_STATE(622)] = 29916,
  [SMALL_STATE(623)] = 29961,
  [SMALL_STATE(624)] = 30006,
  [SMALL_STATE(625)] = 30045,
  [SMALL_STATE(626)] = 30090,
  [SMALL_STATE(627)] = 30131,
  [SMALL_STATE(628)] = 30176,
  [SMALL_STATE(629)] = 30221,
  [SMALL_STATE(630)] = 30266,
  [SMALL_STATE(631)] = 30311,
  [SMALL_STATE(632)] = 30356,
  [SMALL_STATE(633)] = 30401,
  [SMALL_STATE(634)] = 30440,
  [SMALL_STATE(635)] = 30485,
  [SMALL_STATE(636)] = 30530,
  [SMALL_STATE(637)] = 30573,
  [SMALL_STATE(638)] = 30614,
  [SMALL_STATE(639)] = 30659,
  [SMALL_STATE(640)] = 30700,
  [SMALL_STATE(641)] = 30745,
  [SMALL_STATE(642)] = 30788,
  [SMALL_STATE(643)] = 30833,
  [SMALL_STATE(644)] = 30873,
  [SMALL_STATE(645)] = 30915,
  [SMALL_STATE(646)] = 30957,
  [SMALL_STATE(647)] = 30995,
  [SMALL_STATE(648)] = 31037,
  [SMALL_STATE(649)] = 31077,
  [SMALL_STATE(650)] = 31119,
  [SMALL_STATE(651)] = 31161,
  [SMALL_STATE(652)] = 31200,
  [SMALL_STATE(653)] = 31239,
  [SMALL_STATE(654)] = 31278,
  [SMALL_STATE(655)] = 31335,
  [SMALL_STATE(656)] = 31370,
  [SMALL_STATE(657)] = 31429,
  [SMALL_STATE(658)] = 31486,
  [SMALL_STATE(659)] = 31542,
  [SMALL_STATE(660)] = 31573,
  [SMALL_STATE(661)] = 31618,
  [SMALL_STATE(662)] = 31644,
  [SMALL_STATE(663)] = 31694,
  [SMALL_STATE(664)] = 31720,
  [SMALL_STATE(665)] = 31761,
  [SMALL_STATE(666)] = 31786,
  [SMALL_STATE(667)] = 31813,
  [SMALL_STATE(668)] = 31840,
  [SMALL_STATE(669)] = 31871,
  [SMALL_STATE(670)] = 31898,
  [SMALL_STATE(671)] = 31925,
  [SMALL_STATE(672)] = 31954,
  [SMALL_STATE(673)] = 31979,
  [SMALL_STATE(674)] = 32020,
  [SMALL_STATE(675)] = 32049,
  [SMALL_STATE(676)] = 32082,
  [SMALL_STATE(677)] = 32128,
  [SMALL_STATE(678)] = 32168,
  [SMALL_STATE(679)] = 32210,
  [SMALL_STATE(680)] = 32252,
  [SMALL_STATE(681)] = 32294,
  [SMALL_STATE(682)] = 32336,
  [SMALL_STATE(683)] = 32364,
  [SMALL_STATE(684)] = 32392,
  [SMALL_STATE(685)] = 32434,
  [SMALL_STATE(686)] = 32462,
  [SMALL_STATE(687)] = 32490,
  [SMALL_STATE(688)] = 32536,
  [SMALL_STATE(689)] = 32582,
  [SMALL_STATE(690)] = 32622,
  [SMALL_STATE(691)] = 32650,
  [SMALL_STATE(692)] = 32676,
  [SMALL_STATE(693)] = 32702,
  [SMALL_STATE(694)] = 32734,
  [SMALL_STATE(695)] = 32764,
  [SMALL_STATE(696)] = 32807,
  [SMALL_STATE(697)] = 32848,
  [SMALL_STATE(698)] = 32876,
  [SMALL_STATE(699)] = 32918,
  [SMALL_STATE(700)] = 32946,
  [SMALL_STATE(701)] = 32968,
  [SMALL_STATE(702)] = 33010,
  [SMALL_STATE(703)] = 33052,
  [SMALL_STATE(704)] = 33080,
  [SMALL_STATE(705)] = 33108,
  [SMALL_STATE(706)] = 33142,
  [SMALL_STATE(707)] = 33170,
  [SMALL_STATE(708)] = 33198,
  [SMALL_STATE(709)] = 33240,
  [SMALL_STATE(710)] = 33278,
  [SMALL_STATE(711)] = 33316,
  [SMALL_STATE(712)] = 33350,
  [SMALL_STATE(713)] = 33388,
  [SMALL_STATE(714)] = 33430,
  [SMALL_STATE(715)] = 33457,
  [SMALL_STATE(716)] = 33490,
  [SMALL_STATE(717)] = 33513,
  [SMALL_STATE(718)] = 33542,
  [SMALL_STATE(719)] = 33563,
  [SMALL_STATE(720)] = 33592,
  [SMALL_STATE(721)] = 33613,
  [SMALL_STATE(722)] = 33642,
  [SMALL_STATE(723)] = 33665,
  [SMALL_STATE(724)] = 33692,
  [SMALL_STATE(725)] = 33715,
  [SMALL_STATE(726)] = 33738,
  [SMALL_STATE(727)] = 33767,
  [SMALL_STATE(728)] = 33788,
  [SMALL_STATE(729)] = 33809,
  [SMALL_STATE(730)] = 33830,
  [SMALL_STATE(731)] = 33851,
  [SMALL_STATE(732)] = 33880,
  [SMALL_STATE(733)] = 33915,
  [SMALL_STATE(734)] = 33938,
  [SMALL_STATE(735)] = 33975,
  [SMALL_STATE(736)] = 34008,
  [SMALL_STATE(737)] = 34037,
  [SMALL_STATE(738)] = 34066,
  [SMALL_STATE(739)] = 34095,
  [SMALL_STATE(740)] = 34132,
  [SMALL_STATE(741)] = 34160,
  [SMALL_STATE(742)] = 34186,
  [SMALL_STATE(743)] = 34206,
  [SMALL_STATE(744)] = 34238,
  [SMALL_STATE(745)] = 34270,
  [SMALL_STATE(746)] = 34296,
  [SMALL_STATE(747)] = 34324,
  [SMALL_STATE(748)] = 34356,
  [SMALL_STATE(749)] = 34382,
  [SMALL_STATE(750)] = 34414,
  [SMALL_STATE(751)] = 34442,
  [SMALL_STATE(752)] = 34470,
  [SMALL_STATE(753)] = 34492,
  [SMALL_STATE(754)] = 34524,
  [SMALL_STATE(755)] = 34550,
  [SMALL_STATE(756)] = 34583,
  [SMALL_STATE(757)] = 34610,
  [SMALL_STATE(758)] = 34639,
  [SMALL_STATE(759)] = 34668,
  [SMALL_STATE(760)] = 34697,
  [SMALL_STATE(761)] = 34718,
  [SMALL_STATE(762)] = 34751,
  [SMALL_STATE(763)] = 34774,
  [SMALL_STATE(764)] = 34799,
  [SMALL_STATE(765)] = 34820,
  [SMALL_STATE(766)] = 34845,
  [SMALL_STATE(767)] = 34870,
  [SMALL_STATE(768)] = 34895,
  [SMALL_STATE(769)] = 34920,
  [SMALL_STATE(770)] = 34949,
  [SMALL_STATE(771)] = 34978,
  [SMALL_STATE(772)] = 34999,
  [SMALL_STATE(773)] = 35024,
  [SMALL_STATE(774)] = 35055,
  [SMALL_STATE(775)] = 35080,
  [SMALL_STATE(776)] = 35103,
  [SMALL_STATE(777)] = 35132,
  [SMALL_STATE(778)] = 35159,
  [SMALL_STATE(779)] = 35188,
  [SMALL_STATE(780)] = 35217,
  [SMALL_STATE(781)] = 35242,
  [SMALL_STATE(782)] = 35270,
  [SMALL_STATE(783)] = 35300,
  [SMALL_STATE(784)] = 35326,
  [SMALL_STATE(785)] = 35352,
  [SMALL_STATE(786)] = 35378,
  [SMALL_STATE(787)] = 35404,
  [SMALL_STATE(788)] = 35434,
  [SMALL_STATE(789)] = 35462,
  [SMALL_STATE(790)] = 35492,
  [SMALL_STATE(791)] = 35518,
  [SMALL_STATE(792)] = 35544,
  [SMALL_STATE(793)] = 35574,
  [SMALL_STATE(794)] = 35602,
  [SMALL_STATE(795)] = 35626,
  [SMALL_STATE(796)] = 35656,
  [SMALL_STATE(797)] = 35684,
  [SMALL_STATE(798)] = 35714,
  [SMALL_STATE(799)] = 35744,
  [SMALL_STATE(800)] = 35772,
  [SMALL_STATE(801)] = 35798,
  [SMALL_STATE(802)] = 35820,
  [SMALL_STATE(803)] = 35850,
  [SMALL_STATE(804)] = 35880,
  [SMALL_STATE(805)] = 35910,
  [SMALL_STATE(806)] = 35931,
  [SMALL_STATE(807)] = 35960,
  [SMALL_STATE(808)] = 35983,
  [SMALL_STATE(809)] = 36010,
  [SMALL_STATE(810)] = 36035,
  [SMALL_STATE(811)] = 36062,
  [SMALL_STATE(812)] = 36085,
  [SMALL_STATE(813)] = 36102,
  [SMALL_STATE(814)] = 36123,
  [SMALL_STATE(815)] = 36144,
  [SMALL_STATE(816)] = 36167,
  [SMALL_STATE(817)] = 36190,
  [SMALL_STATE(818)] = 36211,
  [SMALL_STATE(819)] = 36232,
  [SMALL_STATE(820)] = 36253,
  [SMALL_STATE(821)] = 36274,
  [SMALL_STATE(822)] = 36295,
  [SMALL_STATE(823)] = 36316,
  [SMALL_STATE(824)] = 36341,
  [SMALL_STATE(825)] = 36370,
  [SMALL_STATE(826)] = 36391,
  [SMALL_STATE(827)] = 36412,
  [SMALL_STATE(828)] = 36431,
  [SMALL_STATE(829)] = 36452,
  [SMALL_STATE(830)] = 36479,
  [SMALL_STATE(831)] = 36508,
  [SMALL_STATE(832)] = 36537,
  [SMALL_STATE(833)] = 36556,
  [SMALL_STATE(834)] = 36579,
  [SMALL_STATE(835)] = 36596,
  [SMALL_STATE(836)] = 36614,
  [SMALL_STATE(837)] = 36632,
  [SMALL_STATE(838)] = 36650,
  [SMALL_STATE(839)] = 36670,
  [SMALL_STATE(840)] = 36694,
  [SMALL_STATE(841)] = 36712,
  [SMALL_STATE(842)] = 36730,
  [SMALL_STATE(843)] = 36748,
  [SMALL_STATE(844)] = 36766,
  [SMALL_STATE(845)] = 36784,
  [SMALL_STATE(846)] = 36802,
  [SMALL_STATE(847)] = 36820,
  [SMALL_STATE(848)] = 36844,
  [SMALL_STATE(849)] = 36868,
  [SMALL_STATE(850)] = 36886,
  [SMALL_STATE(851)] = 36904,
  [SMALL_STATE(852)] = 36922,
  [SMALL_STATE(853)] = 36946,
  [SMALL_STATE(854)] = 36970,
  [SMALL_STATE(855)] = 36988,
  [SMALL_STATE(856)] = 37006,
  [SMALL_STATE(857)] = 37030,
  [SMALL_STATE(858)] = 37054,
  [SMALL_STATE(859)] = 37072,
  [SMALL_STATE(860)] = 37090,
  [SMALL_STATE(861)] = 37108,
  [SMALL_STATE(862)] = 37132,
  [SMALL_STATE(863)] = 37150,
  [SMALL_STATE(864)] = 37174,
  [SMALL_STATE(865)] = 37198,
  [SMALL_STATE(866)] = 37222,
  [SMALL_STATE(867)] = 37246,
  [SMALL_STATE(868)] = 37264,
  [SMALL_STATE(869)] = 37288,
  [SMALL_STATE(870)] = 37312,
  [SMALL_STATE(871)] = 37336,
  [SMALL_STATE(872)] = 37356,
  [SMALL_STATE(873)] = 37380,
  [SMALL_STATE(874)] = 37404,
  [SMALL_STATE(875)] = 37428,
  [SMALL_STATE(876)] = 37452,
  [SMALL_STATE(877)] = 37470,
  [SMALL_STATE(878)] = 37489,
  [SMALL_STATE(879)] = 37510,
  [SMALL_STATE(880)] = 37531,
  [SMALL_STATE(881)] = 37554,
  [SMALL_STATE(882)] = 37575,
  [SMALL_STATE(883)] = 37596,
  [SMALL_STATE(884)] = 37617,
  [SMALL_STATE(885)] = 37638,
  [SMALL_STATE(886)] = 37659,
  [SMALL_STATE(887)] = 37680,
  [SMALL_STATE(888)] = 37703,
  [SMALL_STATE(889)] = 37724,
  [SMALL_STATE(890)] = 37747,
  [SMALL_STATE(891)] = 37766,
  [SMALL_STATE(892)] = 37787,
  [SMALL_STATE(893)] = 37810,
  [SMALL_STATE(894)] = 37833,
  [SMALL_STATE(895)] = 37852,
  [SMALL_STATE(896)] = 37872,
  [SMALL_STATE(897)] = 37892,
  [SMALL_STATE(898)] = 37912,
  [SMALL_STATE(899)] = 37932,
  [SMALL_STATE(900)] = 37952,
  [SMALL_STATE(901)] = 37972,
  [SMALL_STATE(902)] = 37992,
  [SMALL_STATE(903)] = 38012,
  [SMALL_STATE(904)] = 38032,
  [SMALL_STATE(905)] = 38052,
  [SMALL_STATE(906)] = 38072,
  [SMALL_STATE(907)] = 38092,
  [SMALL_STATE(908)] = 38112,
  [SMALL_STATE(909)] = 38132,
  [SMALL_STATE(910)] = 38152,
  [SMALL_STATE(911)] = 38166,
  [SMALL_STATE(912)] = 38186,
  [SMALL_STATE(913)] = 38206,
  [SMALL_STATE(914)] = 38224,
  [SMALL_STATE(915)] = 38244,
  [SMALL_STATE(916)] = 38264,
  [SMALL_STATE(917)] = 38282,
  [SMALL_STATE(918)] = 38296,
  [SMALL_STATE(919)] = 38316,
  [SMALL_STATE(920)] = 38330,
  [SMALL_STATE(921)] = 38350,
  [SMALL_STATE(922)] = 38370,
  [SMALL_STATE(923)] = 38387,
  [SMALL_STATE(924)] = 38404,
  [SMALL_STATE(925)] = 38421,
  [SMALL_STATE(926)] = 38438,
  [SMALL_STATE(927)] = 38459,
  [SMALL_STATE(928)] = 38474,
  [SMALL_STATE(929)] = 38489,
  [SMALL_STATE(930)] = 38506,
  [SMALL_STATE(931)] = 38525,
  [SMALL_STATE(932)] = 38538,
  [SMALL_STATE(933)] = 38551,
  [SMALL_STATE(934)] = 38566,
  [SMALL_STATE(935)] = 38583,
  [SMALL_STATE(936)] = 38600,
  [SMALL_STATE(937)] = 38613,
  [SMALL_STATE(938)] = 38626,
  [SMALL_STATE(939)] = 38643,
  [SMALL_STATE(940)] = 38660,
  [SMALL_STATE(941)] = 38675,
  [SMALL_STATE(942)] = 38692,
  [SMALL_STATE(943)] = 38711,
  [SMALL_STATE(944)] = 38728,
  [SMALL_STATE(945)] = 38747,
  [SMALL_STATE(946)] = 38764,
  [SMALL_STATE(947)] = 38779,
  [SMALL_STATE(948)] = 38796,
  [SMALL_STATE(949)] = 38813,
  [SMALL_STATE(950)] = 38830,
  [SMALL_STATE(951)] = 38851,
  [SMALL_STATE(952)] = 38868,
  [SMALL_STATE(953)] = 38887,
  [SMALL_STATE(954)] = 38904,
  [SMALL_STATE(955)] = 38923,
  [SMALL_STATE(956)] = 38940,
  [SMALL_STATE(957)] = 38957,
  [SMALL_STATE(958)] = 38972,
  [SMALL_STATE(959)] = 38985,
  [SMALL_STATE(960)] = 39002,
  [SMALL_STATE(961)] = 39019,
  [SMALL_STATE(962)] = 39034,
  [SMALL_STATE(963)] = 39051,
  [SMALL_STATE(964)] = 39064,
  [SMALL_STATE(965)] = 39083,
  [SMALL_STATE(966)] = 39100,
  [SMALL_STATE(967)] = 39119,
  [SMALL_STATE(968)] = 39136,
  [SMALL_STATE(969)] = 39155,
  [SMALL_STATE(970)] = 39172,
  [SMALL_STATE(971)] = 39191,
  [SMALL_STATE(972)] = 39208,
  [SMALL_STATE(973)] = 39229,
  [SMALL_STATE(974)] = 39246,
  [SMALL_STATE(975)] = 39263,
  [SMALL_STATE(976)] = 39280,
  [SMALL_STATE(977)] = 39293,
  [SMALL_STATE(978)] = 39312,
  [SMALL_STATE(979)] = 39333,
  [SMALL_STATE(980)] = 39348,
  [SMALL_STATE(981)] = 39365,
  [SMALL_STATE(982)] = 39378,
  [SMALL_STATE(983)] = 39397,
  [SMALL_STATE(984)] = 39416,
  [SMALL_STATE(985)] = 39433,
  [SMALL_STATE(986)] = 39450,
  [SMALL_STATE(987)] = 39467,
  [SMALL_STATE(988)] = 39484,
  [SMALL_STATE(989)] = 39503,
  [SMALL_STATE(990)] = 39520,
  [SMALL_STATE(991)] = 39539,
  [SMALL_STATE(992)] = 39558,
  [SMALL_STATE(993)] = 39575,
  [SMALL_STATE(994)] = 39592,
  [SMALL_STATE(995)] = 39611,
  [SMALL_STATE(996)] = 39624,
  [SMALL_STATE(997)] = 39641,
  [SMALL_STATE(998)] = 39658,
  [SMALL_STATE(999)] = 39675,
  [SMALL_STATE(1000)] = 39688,
  [SMALL_STATE(1001)] = 39705,
  [SMALL_STATE(1002)] = 39722,
  [SMALL_STATE(1003)] = 39739,
  [SMALL_STATE(1004)] = 39756,
  [SMALL_STATE(1005)] = 39777,
  [SMALL_STATE(1006)] = 39794,
  [SMALL_STATE(1007)] = 39813,
  [SMALL_STATE(1008)] = 39830,
  [SMALL_STATE(1009)] = 39851,
  [SMALL_STATE(1010)] = 39864,
  [SMALL_STATE(1011)] = 39885,
  [SMALL_STATE(1012)] = 39898,
  [SMALL_STATE(1013)] = 39915,
  [SMALL_STATE(1014)] = 39932,
  [SMALL_STATE(1015)] = 39949,
  [SMALL_STATE(1016)] = 39966,
  [SMALL_STATE(1017)] = 39983,
  [SMALL_STATE(1018)] = 40000,
  [SMALL_STATE(1019)] = 40017,
  [SMALL_STATE(1020)] = 40033,
  [SMALL_STATE(1021)] = 40047,
  [SMALL_STATE(1022)] = 40061,
  [SMALL_STATE(1023)] = 40075,
  [SMALL_STATE(1024)] = 40089,
  [SMALL_STATE(1025)] = 40103,
  [SMALL_STATE(1026)] = 40119,
  [SMALL_STATE(1027)] = 40133,
  [SMALL_STATE(1028)] = 40147,
  [SMALL_STATE(1029)] = 40159,
  [SMALL_STATE(1030)] = 40173,
  [SMALL_STATE(1031)] = 40187,
  [SMALL_STATE(1032)] = 40201,
  [SMALL_STATE(1033)] = 40213,
  [SMALL_STATE(1034)] = 40227,
  [SMALL_STATE(1035)] = 40241,
  [SMALL_STATE(1036)] = 40255,
  [SMALL_STATE(1037)] = 40275,
  [SMALL_STATE(1038)] = 40291,
  [SMALL_STATE(1039)] = 40305,
  [SMALL_STATE(1040)] = 40319,
  [SMALL_STATE(1041)] = 40333,
  [SMALL_STATE(1042)] = 40347,
  [SMALL_STATE(1043)] = 40363,
  [SMALL_STATE(1044)] = 40377,
  [SMALL_STATE(1045)] = 40393,
  [SMALL_STATE(1046)] = 40407,
  [SMALL_STATE(1047)] = 40421,
  [SMALL_STATE(1048)] = 40437,
  [SMALL_STATE(1049)] = 40453,
  [SMALL_STATE(1050)] = 40467,
  [SMALL_STATE(1051)] = 40481,
  [SMALL_STATE(1052)] = 40495,
  [SMALL_STATE(1053)] = 40509,
  [SMALL_STATE(1054)] = 40525,
  [SMALL_STATE(1055)] = 40541,
  [SMALL_STATE(1056)] = 40555,
  [SMALL_STATE(1057)] = 40569,
  [SMALL_STATE(1058)] = 40583,
  [SMALL_STATE(1059)] = 40599,
  [SMALL_STATE(1060)] = 40615,
  [SMALL_STATE(1061)] = 40629,
  [SMALL_STATE(1062)] = 40643,
  [SMALL_STATE(1063)] = 40657,
  [SMALL_STATE(1064)] = 40671,
  [SMALL_STATE(1065)] = 40685,
  [SMALL_STATE(1066)] = 40699,
  [SMALL_STATE(1067)] = 40713,
  [SMALL_STATE(1068)] = 40727,
  [SMALL_STATE(1069)] = 40741,
  [SMALL_STATE(1070)] = 40755,
  [SMALL_STATE(1071)] = 40771,
  [SMALL_STATE(1072)] = 40787,
  [SMALL_STATE(1073)] = 40801,
  [SMALL_STATE(1074)] = 40815,
  [SMALL_STATE(1075)] = 40829,
  [SMALL_STATE(1076)] = 40843,
  [SMALL_STATE(1077)] = 40859,
  [SMALL_STATE(1078)] = 40875,
  [SMALL_STATE(1079)] = 40889,
  [SMALL_STATE(1080)] = 40905,
  [SMALL_STATE(1081)] = 40921,
  [SMALL_STATE(1082)] = 40935,
  [SMALL_STATE(1083)] = 40949,
  [SMALL_STATE(1084)] = 40965,
  [SMALL_STATE(1085)] = 40981,
  [SMALL_STATE(1086)] = 40999,
  [SMALL_STATE(1087)] = 41011,
  [SMALL_STATE(1088)] = 41025,
  [SMALL_STATE(1089)] = 41039,
  [SMALL_STATE(1090)] = 41053,
  [SMALL_STATE(1091)] = 41067,
  [SMALL_STATE(1092)] = 41081,
  [SMALL_STATE(1093)] = 41095,
  [SMALL_STATE(1094)] = 41109,
  [SMALL_STATE(1095)] = 41123,
  [SMALL_STATE(1096)] = 41137,
  [SMALL_STATE(1097)] = 41151,
  [SMALL_STATE(1098)] = 41165,
  [SMALL_STATE(1099)] = 41179,
  [SMALL_STATE(1100)] = 41193,
  [SMALL_STATE(1101)] = 41207,
  [SMALL_STATE(1102)] = 41221,
  [SMALL_STATE(1103)] = 41239,
  [SMALL_STATE(1104)] = 41253,
  [SMALL_STATE(1105)] = 41267,
  [SMALL_STATE(1106)] = 41281,
  [SMALL_STATE(1107)] = 41295,
  [SMALL_STATE(1108)] = 41309,
  [SMALL_STATE(1109)] = 41320,
  [SMALL_STATE(1110)] = 41331,
  [SMALL_STATE(1111)] = 41342,
  [SMALL_STATE(1112)] = 41355,
  [SMALL_STATE(1113)] = 41366,
  [SMALL_STATE(1114)] = 41381,
  [SMALL_STATE(1115)] = 41392,
  [SMALL_STATE(1116)] = 41403,
  [SMALL_STATE(1117)] = 41414,
  [SMALL_STATE(1118)] = 41427,
  [SMALL_STATE(1119)] = 41438,
  [SMALL_STATE(1120)] = 41451,
  [SMALL_STATE(1121)] = 41466,
  [SMALL_STATE(1122)] = 41477,
  [SMALL_STATE(1123)] = 41494,
  [SMALL_STATE(1124)] = 41505,
  [SMALL_STATE(1125)] = 41518,
  [SMALL_STATE(1126)] = 41529,
  [SMALL_STATE(1127)] = 41540,
  [SMALL_STATE(1128)] = 41557,
  [SMALL_STATE(1129)] = 41572,
  [SMALL_STATE(1130)] = 41587,
  [SMALL_STATE(1131)] = 41598,
  [SMALL_STATE(1132)] = 41615,
  [SMALL_STATE(1133)] = 41628,
  [SMALL_STATE(1134)] = 41645,
  [SMALL_STATE(1135)] = 41656,
  [SMALL_STATE(1136)] = 41671,
  [SMALL_STATE(1137)] = 41686,
  [SMALL_STATE(1138)] = 41703,
  [SMALL_STATE(1139)] = 41720,
  [SMALL_STATE(1140)] = 41737,
  [SMALL_STATE(1141)] = 41754,
  [SMALL_STATE(1142)] = 41771,
  [SMALL_STATE(1143)] = 41788,
  [SMALL_STATE(1144)] = 41799,
  [SMALL_STATE(1145)] = 41816,
  [SMALL_STATE(1146)] = 41833,
  [SMALL_STATE(1147)] = 41850,
  [SMALL_STATE(1148)] = 41865,
  [SMALL_STATE(1149)] = 41882,
  [SMALL_STATE(1150)] = 41893,
  [SMALL_STATE(1151)] = 41910,
  [SMALL_STATE(1152)] = 41921,
  [SMALL_STATE(1153)] = 41938,
  [SMALL_STATE(1154)] = 41951,
  [SMALL_STATE(1155)] = 41962,
  [SMALL_STATE(1156)] = 41975,
  [SMALL_STATE(1157)] = 41988,
  [SMALL_STATE(1158)] = 42001,
  [SMALL_STATE(1159)] = 42012,
  [SMALL_STATE(1160)] = 42023,
  [SMALL_STATE(1161)] = 42038,
  [SMALL_STATE(1162)] = 42049,
  [SMALL_STATE(1163)] = 42060,
  [SMALL_STATE(1164)] = 42073,
  [SMALL_STATE(1165)] = 42084,
  [SMALL_STATE(1166)] = 42097,
  [SMALL_STATE(1167)] = 42112,
  [SMALL_STATE(1168)] = 42123,
  [SMALL_STATE(1169)] = 42138,
  [SMALL_STATE(1170)] = 42149,
  [SMALL_STATE(1171)] = 42166,
  [SMALL_STATE(1172)] = 42177,
  [SMALL_STATE(1173)] = 42188,
  [SMALL_STATE(1174)] = 42199,
  [SMALL_STATE(1175)] = 42216,
  [SMALL_STATE(1176)] = 42233,
  [SMALL_STATE(1177)] = 42244,
  [SMALL_STATE(1178)] = 42257,
  [SMALL_STATE(1179)] = 42274,
  [SMALL_STATE(1180)] = 42289,
  [SMALL_STATE(1181)] = 42306,
  [SMALL_STATE(1182)] = 42317,
  [SMALL_STATE(1183)] = 42332,
  [SMALL_STATE(1184)] = 42349,
  [SMALL_STATE(1185)] = 42366,
  [SMALL_STATE(1186)] = 42383,
  [SMALL_STATE(1187)] = 42400,
  [SMALL_STATE(1188)] = 42417,
  [SMALL_STATE(1189)] = 42432,
  [SMALL_STATE(1190)] = 42443,
  [SMALL_STATE(1191)] = 42458,
  [SMALL_STATE(1192)] = 42469,
  [SMALL_STATE(1193)] = 42480,
  [SMALL_STATE(1194)] = 42491,
  [SMALL_STATE(1195)] = 42506,
  [SMALL_STATE(1196)] = 42517,
  [SMALL_STATE(1197)] = 42532,
  [SMALL_STATE(1198)] = 42549,
  [SMALL_STATE(1199)] = 42560,
  [SMALL_STATE(1200)] = 42575,
  [SMALL_STATE(1201)] = 42590,
  [SMALL_STATE(1202)] = 42607,
  [SMALL_STATE(1203)] = 42620,
  [SMALL_STATE(1204)] = 42635,
  [SMALL_STATE(1205)] = 42652,
  [SMALL_STATE(1206)] = 42669,
  [SMALL_STATE(1207)] = 42684,
  [SMALL_STATE(1208)] = 42701,
  [SMALL_STATE(1209)] = 42712,
  [SMALL_STATE(1210)] = 42723,
  [SMALL_STATE(1211)] = 42740,
  [SMALL_STATE(1212)] = 42757,
  [SMALL_STATE(1213)] = 42774,
  [SMALL_STATE(1214)] = 42791,
  [SMALL_STATE(1215)] = 42808,
  [SMALL_STATE(1216)] = 42825,
  [SMALL_STATE(1217)] = 42840,
  [SMALL_STATE(1218)] = 42857,
  [SMALL_STATE(1219)] = 42874,
  [SMALL_STATE(1220)] = 42885,
  [SMALL_STATE(1221)] = 42900,
  [SMALL_STATE(1222)] = 42911,
  [SMALL_STATE(1223)] = 42928,
  [SMALL_STATE(1224)] = 42943,
  [SMALL_STATE(1225)] = 42958,
  [SMALL_STATE(1226)] = 42969,
  [SMALL_STATE(1227)] = 42984,
  [SMALL_STATE(1228)] = 42995,
  [SMALL_STATE(1229)] = 43010,
  [SMALL_STATE(1230)] = 43021,
  [SMALL_STATE(1231)] = 43034,
  [SMALL_STATE(1232)] = 43049,
  [SMALL_STATE(1233)] = 43060,
  [SMALL_STATE(1234)] = 43075,
  [SMALL_STATE(1235)] = 43086,
  [SMALL_STATE(1236)] = 43097,
  [SMALL_STATE(1237)] = 43108,
  [SMALL_STATE(1238)] = 43123,
  [SMALL_STATE(1239)] = 43134,
  [SMALL_STATE(1240)] = 43149,
  [SMALL_STATE(1241)] = 43166,
  [SMALL_STATE(1242)] = 43177,
  [SMALL_STATE(1243)] = 43188,
  [SMALL_STATE(1244)] = 43199,
  [SMALL_STATE(1245)] = 43214,
  [SMALL_STATE(1246)] = 43229,
  [SMALL_STATE(1247)] = 43240,
  [SMALL_STATE(1248)] = 43251,
  [SMALL_STATE(1249)] = 43262,
  [SMALL_STATE(1250)] = 43273,
  [SMALL_STATE(1251)] = 43284,
  [SMALL_STATE(1252)] = 43299,
  [SMALL_STATE(1253)] = 43310,
  [SMALL_STATE(1254)] = 43321,
  [SMALL_STATE(1255)] = 43338,
  [SMALL_STATE(1256)] = 43350,
  [SMALL_STATE(1257)] = 43364,
  [SMALL_STATE(1258)] = 43376,
  [SMALL_STATE(1259)] = 43386,
  [SMALL_STATE(1260)] = 43400,
  [SMALL_STATE(1261)] = 43412,
  [SMALL_STATE(1262)] = 43426,
  [SMALL_STATE(1263)] = 43440,
  [SMALL_STATE(1264)] = 43452,
  [SMALL_STATE(1265)] = 43464,
  [SMALL_STATE(1266)] = 43474,
  [SMALL_STATE(1267)] = 43486,
  [SMALL_STATE(1268)] = 43498,
  [SMALL_STATE(1269)] = 43512,
  [SMALL_STATE(1270)] = 43526,
  [SMALL_STATE(1271)] = 43538,
  [SMALL_STATE(1272)] = 43552,
  [SMALL_STATE(1273)] = 43566,
  [SMALL_STATE(1274)] = 43576,
  [SMALL_STATE(1275)] = 43590,
  [SMALL_STATE(1276)] = 43604,
  [SMALL_STATE(1277)] = 43618,
  [SMALL_STATE(1278)] = 43632,
  [SMALL_STATE(1279)] = 43646,
  [SMALL_STATE(1280)] = 43660,
  [SMALL_STATE(1281)] = 43674,
  [SMALL_STATE(1282)] = 43688,
  [SMALL_STATE(1283)] = 43698,
  [SMALL_STATE(1284)] = 43708,
  [SMALL_STATE(1285)] = 43722,
  [SMALL_STATE(1286)] = 43734,
  [SMALL_STATE(1287)] = 43748,
  [SMALL_STATE(1288)] = 43762,
  [SMALL_STATE(1289)] = 43776,
  [SMALL_STATE(1290)] = 43790,
  [SMALL_STATE(1291)] = 43804,
  [SMALL_STATE(1292)] = 43816,
  [SMALL_STATE(1293)] = 43830,
  [SMALL_STATE(1294)] = 43842,
  [SMALL_STATE(1295)] = 43854,
  [SMALL_STATE(1296)] = 43866,
  [SMALL_STATE(1297)] = 43878,
  [SMALL_STATE(1298)] = 43892,
  [SMALL_STATE(1299)] = 43906,
  [SMALL_STATE(1300)] = 43920,
  [SMALL_STATE(1301)] = 43934,
  [SMALL_STATE(1302)] = 43948,
  [SMALL_STATE(1303)] = 43962,
  [SMALL_STATE(1304)] = 43974,
  [SMALL_STATE(1305)] = 43988,
  [SMALL_STATE(1306)] = 43999,
  [SMALL_STATE(1307)] = 44010,
  [SMALL_STATE(1308)] = 44019,
  [SMALL_STATE(1309)] = 44028,
  [SMALL_STATE(1310)] = 44039,
  [SMALL_STATE(1311)] = 44050,
  [SMALL_STATE(1312)] = 44061,
  [SMALL_STATE(1313)] = 44070,
  [SMALL_STATE(1314)] = 44081,
  [SMALL_STATE(1315)] = 44090,
  [SMALL_STATE(1316)] = 44099,
  [SMALL_STATE(1317)] = 44108,
  [SMALL_STATE(1318)] = 44119,
  [SMALL_STATE(1319)] = 44130,
  [SMALL_STATE(1320)] = 44139,
  [SMALL_STATE(1321)] = 44150,
  [SMALL_STATE(1322)] = 44159,
  [SMALL_STATE(1323)] = 44168,
  [SMALL_STATE(1324)] = 44177,
  [SMALL_STATE(1325)] = 44186,
  [SMALL_STATE(1326)] = 44195,
  [SMALL_STATE(1327)] = 44204,
  [SMALL_STATE(1328)] = 44215,
  [SMALL_STATE(1329)] = 44224,
  [SMALL_STATE(1330)] = 44235,
  [SMALL_STATE(1331)] = 44244,
  [SMALL_STATE(1332)] = 44253,
  [SMALL_STATE(1333)] = 44264,
  [SMALL_STATE(1334)] = 44273,
  [SMALL_STATE(1335)] = 44284,
  [SMALL_STATE(1336)] = 44293,
  [SMALL_STATE(1337)] = 44302,
  [SMALL_STATE(1338)] = 44313,
  [SMALL_STATE(1339)] = 44324,
  [SMALL_STATE(1340)] = 44335,
  [SMALL_STATE(1341)] = 44346,
  [SMALL_STATE(1342)] = 44357,
  [SMALL_STATE(1343)] = 44365,
  [SMALL_STATE(1344)] = 44373,
  [SMALL_STATE(1345)] = 44381,
  [SMALL_STATE(1346)] = 44389,
  [SMALL_STATE(1347)] = 44397,
  [SMALL_STATE(1348)] = 44405,
  [SMALL_STATE(1349)] = 44413,
  [SMALL_STATE(1350)] = 44421,
  [SMALL_STATE(1351)] = 44429,
  [SMALL_STATE(1352)] = 44437,
  [SMALL_STATE(1353)] = 44445,
  [SMALL_STATE(1354)] = 44453,
  [SMALL_STATE(1355)] = 44461,
  [SMALL_STATE(1356)] = 44469,
  [SMALL_STATE(1357)] = 44477,
  [SMALL_STATE(1358)] = 44485,
  [SMALL_STATE(1359)] = 44493,
  [SMALL_STATE(1360)] = 44501,
  [SMALL_STATE(1361)] = 44509,
  [SMALL_STATE(1362)] = 44517,
  [SMALL_STATE(1363)] = 44525,
  [SMALL_STATE(1364)] = 44533,
  [SMALL_STATE(1365)] = 44541,
  [SMALL_STATE(1366)] = 44549,
  [SMALL_STATE(1367)] = 44557,
  [SMALL_STATE(1368)] = 44565,
  [SMALL_STATE(1369)] = 44573,
  [SMALL_STATE(1370)] = 44581,
  [SMALL_STATE(1371)] = 44589,
  [SMALL_STATE(1372)] = 44597,
  [SMALL_STATE(1373)] = 44605,
  [SMALL_STATE(1374)] = 44613,
  [SMALL_STATE(1375)] = 44621,
  [SMALL_STATE(1376)] = 44629,
  [SMALL_STATE(1377)] = 44637,
  [SMALL_STATE(1378)] = 44645,
  [SMALL_STATE(1379)] = 44653,
  [SMALL_STATE(1380)] = 44661,
  [SMALL_STATE(1381)] = 44669,
  [SMALL_STATE(1382)] = 44677,
  [SMALL_STATE(1383)] = 44685,
  [SMALL_STATE(1384)] = 44693,
  [SMALL_STATE(1385)] = 44701,
  [SMALL_STATE(1386)] = 44709,
  [SMALL_STATE(1387)] = 44717,
  [SMALL_STATE(1388)] = 44725,
  [SMALL_STATE(1389)] = 44733,
  [SMALL_STATE(1390)] = 44741,
  [SMALL_STATE(1391)] = 44749,
  [SMALL_STATE(1392)] = 44757,
  [SMALL_STATE(1393)] = 44765,
  [SMALL_STATE(1394)] = 44773,
  [SMALL_STATE(1395)] = 44781,
  [SMALL_STATE(1396)] = 44789,
  [SMALL_STATE(1397)] = 44797,
  [SMALL_STATE(1398)] = 44805,
  [SMALL_STATE(1399)] = 44813,
  [SMALL_STATE(1400)] = 44821,
  [SMALL_STATE(1401)] = 44829,
  [SMALL_STATE(1402)] = 44837,
  [SMALL_STATE(1403)] = 44845,
  [SMALL_STATE(1404)] = 44853,
  [SMALL_STATE(1405)] = 44861,
  [SMALL_STATE(1406)] = 44869,
  [SMALL_STATE(1407)] = 44877,
  [SMALL_STATE(1408)] = 44885,
  [SMALL_STATE(1409)] = 44893,
  [SMALL_STATE(1410)] = 44901,
  [SMALL_STATE(1411)] = 44909,
  [SMALL_STATE(1412)] = 44917,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(676),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(232),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(313),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(306),
  [67] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesis, 3, 0, 0),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1116),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(231),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1066),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(974),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(206),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1056),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(247),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(967),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(914),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(833),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(815),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(830),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(911),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(448),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(378),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1151),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(277),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(279),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(281),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [125] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 2, 0, 7),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1232),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(196),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1235),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1109),
  [137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(784),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1227),
  [143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 3, 0, 7),
  [145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_clause, 3, 0, 7),
  [147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1195),
  [151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1110),
  [153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20),
  [155] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 1, 0, 0),
  [157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(230),
  [161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1126),
  [163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1248),
  [165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1242),
  [167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(26),
  [169] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_otherwise_clause, 1, 0, 0),
  [171] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 2, 0, 0),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(22),
  [175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1221),
  [177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 0),
  [179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 3, 0, 0),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1112),
  [183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(27),
  [185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1249),
  [187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1181),
  [191] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_otherwise_clause, 2, 0, 0),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1234),
  [195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1192),
  [197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 8),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1293),
  [201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 22),
  [211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(991),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 16),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(952),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1303),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 8),
  [227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1270),
  [229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(954),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 16),
  [237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(964),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [241] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 22),
  [243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(942),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 8),
  [249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1255),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1255),
  [253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 16),
  [255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1285),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1285),
  [259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1294),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(977),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 22),
  [269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(930),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(982),
  [275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1257),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1257),
  [281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1264),
  [283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1295),
  [287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1295),
  [289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(988),
  [291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(813),
  [295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1163),
  [301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1177),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1111),
  [307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1117),
  [311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1230),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1230),
  [317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 1, 0, 0),
  [319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [321] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 1, 0, 0),
  [323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1119),
  [325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1156),
  [329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1156),
  [331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1132),
  [333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1157),
  [337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1157),
  [339] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(232),
  [342] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(313),
  [345] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(306),
  [348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0),
  [350] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(231),
  [353] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1066),
  [356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(974),
  [359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(193),
  [362] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(206),
  [365] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1056),
  [368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0),
  [370] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(247),
  [373] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(967),
  [376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(914),
  [379] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(294),
  [382] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(299),
  [385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(833),
  [388] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(815),
  [391] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(830),
  [394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(911),
  [397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(8),
  [400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(14),
  [403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(448),
  [406] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(378),
  [409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(934),
  [412] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1048),
  [415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1025),
  [418] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(676),
  [421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(828),
  [423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(814),
  [427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(817),
  [431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(818),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(819),
  [439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(820),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(822),
  [447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(825),
  [451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [453] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1073),
  [456] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_block, 1, 0, 0), SHIFT(830),
  [459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [461] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1033),
  [464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binary_expression, 1, 0, 0),
  [466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(179),
  [468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(800),
  [470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1016),
  [472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(152),
  [474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_expression, 1, 0, 0),
  [478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, 0, 0),
  [480] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 0, 0),
  [483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, 0, 0),
  [485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_operator, 2, 0, 1),
  [491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_operator, 2, 0, 1),
  [493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_handle_operator, 2, 0, 0),
  [495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1093),
  [497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handle_operator, 2, 0, 0),
  [499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_handle_operator, 3, 0, 0),
  [501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handle_operator, 3, 0, 0),
  [503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaclass_operator, 3, 0, 0),
  [505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaclass_operator, 3, 0, 0),
  [507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0),
  [509] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1093),
  [512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0),
  [514] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 2, 0, 4),
  [516] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 2, 0, 4),
  [518] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14),
  [520] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14), SHIFT_REPEAT(800),
  [523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14),
  [525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12),
  [527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12),
  [529] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaclass_operator, 2, 0, 0),
  [531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaclass_operator, 2, 0, 0),
  [533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 6),
  [535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 6),
  [537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1017),
  [539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 3),
  [541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 3),
  [543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indirect_access, 3, 0, 0),
  [545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indirect_access, 3, 0, 0),
  [547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__args, 2, 0, 0),
  [549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__args, 2, 0, 0),
  [551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__args, 3, 0, 0),
  [553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__args, 3, 0, 0),
  [555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 18),
  [557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 18),
  [559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 19),
  [561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 19),
  [563] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_identifier, 1, 0, 0),
  [565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifier, 1, 0, 0),
  [567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 5, 0, 20),
  [569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(295),
  [571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(296),
  [573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(297),
  [575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 5, 0, 20),
  [577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operator, 3, 0, 13),
  [579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(257),
  [581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operator, 3, 0, 13),
  [583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(255),
  [585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(233),
  [587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(259),
  [589] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 3, 0, 0),
  [591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(271),
  [593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 3, 0, 0),
  [595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 4, 0, 0),
  [597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 4, 0, 0),
  [599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 4, 0, 0),
  [601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 4, 0, 0),
  [603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 5, 0, 0),
  [605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 5, 0, 0),
  [607] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, -1, 0),
  [610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 5, 0, 0),
  [612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 5, 0, 0),
  [614] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean, 1, 0, 0),
  [616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1, 0, 0),
  [618] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, -1, 0),
  [620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_operator, 3, 0, 13),
  [622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_operator, 3, 0, 13),
  [624] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 5, 0, 0),
  [626] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_range, 3, 0, 0), REDUCE(sym_range, 5, 0, 0),
  [629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(333),
  [631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 5, 0, 0),
  [633] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [637] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 4, 0, 15),
  [639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 4, 0, 15),
  [641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comparison_operator, 3, 0, 0),
  [643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comparison_operator, 3, 0, 0),
  [645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, -1, 0),
  [647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, 1, 0),
  [649] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 1, 0),
  [652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, 1, 0),
  [654] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_not_operator, 2, 0, 0),
  [656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_not_operator, 2, 0, 0),
  [658] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 2, 0, 0),
  [660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 2, 0, 0),
  [662] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 2, 0, 0),
  [664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 2, 0, 0),
  [666] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_postfix_operator, 2, 0, 2),
  [668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postfix_operator, 2, 0, 2),
  [670] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesis, 3, 0, 0),
  [676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 3, 0, 0),
  [678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 3, 0, 0),
  [680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 3, 0, 0),
  [682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 3, 0, 0),
  [684] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1087),
  [687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1087),
  [689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(670),
  [697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat2, 1, 0, 0),
  [729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(228),
  [731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(398),
  [733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(234),
  [735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(325),
  [737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(210),
  [739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1072),
  [741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(980),
  [743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(198),
  [745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat2, 1, 0, 0),
  [747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(199),
  [749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(547),
  [751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [759] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_iterator, 3, 0, 0),
  [761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_iterator, 3, 0, 0),
  [763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(150),
  [767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(577),
  [771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(578),
  [775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(588),
  [779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(591),
  [781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(419),
  [785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(484),
  [787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(420),
  [789] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(196),
  [792] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0),
  [794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0),
  [796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(498),
  [800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(499),
  [804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(504),
  [806] = {.entry = {.count = 1, .reusable = false}}, SHIFT(505),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(151),
  [812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(155),
  [814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(156),
  [816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(428),
  [820] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 4, 0, 0),
  [822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 4, 0, 0),
  [824] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 2, 0, 0),
  [826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 2, 0, 0),
  [828] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 3, 0, 0),
  [830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 3, 0, 0),
  [832] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ignored_argument, 1, 0, 0),
  [834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(329),
  [836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1090),
  [838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(996),
  [840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ignored_argument, 1, 0, 0),
  [842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(527),
  [844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 3, 0, 0),
  [846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [848] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 3, 0, 0),
  [850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [854] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 5),
  [856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [858] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 5),
  [860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0),
  [862] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(215),
  [865] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0),
  [867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 3, 0, 5),
  [869] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 3, 0, 5),
  [871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [961] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [963] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(883),
  [966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [996] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(332),
  [999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [1001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [1003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(790),
  [1005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(975),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(463),
  [1009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [1011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 4, 0, 0),
  [1013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 4, 0, 0),
  [1015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 3, 0, 0),
  [1017] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 3, 0, 0),
  [1019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 4, 0, 25),
  [1021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 4, 0, 25),
  [1023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 5, 0, 25),
  [1025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 5, 0, 25),
  [1027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(945),
  [1029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(177),
  [1031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(786),
  [1033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1014),
  [1035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(500),
  [1037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(174),
  [1039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(250),
  [1041] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression_with_end, 1, 0, 0),
  [1043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [1045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_expression_with_end, 1, 0, 0),
  [1047] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binary_expression_with_end, 1, 0, 0),
  [1049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(785),
  [1051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [1053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [1055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [1057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(197),
  [1059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element_with_end, 1, 0, 0),
  [1061] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14), SHIFT_REPEAT(790),
  [1064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(202),
  [1066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [1068] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 0, 0),
  [1071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1015),
  [1073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1049),
  [1075] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1049),
  [1078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(267),
  [1080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [1084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(264),
  [1086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(265),
  [1088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(269),
  [1090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(266),
  [1092] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14), SHIFT_REPEAT(786),
  [1095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(235),
  [1097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(236),
  [1099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(237),
  [1101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [1103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1091),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [1107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [1109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [1111] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1091),
  [1114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(289),
  [1116] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14), SHIFT_REPEAT(785),
  [1119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(239),
  [1121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [1123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(238),
  [1125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(242),
  [1127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(246),
  [1129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1089),
  [1131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1089),
  [1134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(290),
  [1136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(291),
  [1138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(251),
  [1140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [1142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(262),
  [1144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [1146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, -1, 0),
  [1149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element_with_end, 1, -1, 0),
  [1151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(344),
  [1153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [1155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [1157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1159] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 1, 0),
  [1162] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_range, 3, 0, 0), REDUCE(sym_range, 5, 0, 0),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [1169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [1171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(322),
  [1173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(252),
  [1175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(253),
  [1177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(254),
  [1179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [1181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(315),
  [1183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [1185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [1187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [1191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [1193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [1195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [1197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [1199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [1201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [1203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1372),
  [1207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [1209] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0),
  [1211] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(655),
  [1214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0),
  [1216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(767),
  [1218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(661),
  [1220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1284),
  [1222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(986),
  [1224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1024),
  [1226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [1228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [1230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1026),
  [1232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [1234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [1236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [1238] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1051),
  [1241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(773),
  [1243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1114),
  [1245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(284),
  [1247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(763),
  [1251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(724),
  [1253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [1255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(771),
  [1257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [1259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_expression_with_end, 1, 0, 9),
  [1261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_operator_with_end, 3, 0, 13),
  [1263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [1265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element_with_end, 1, 1, 11),
  [1267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_expression_with_end, 1, 0, 11),
  [1269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [1273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element_with_end, 1, 0, 9),
  [1275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression_with_end, 1, 0, 11),
  [1277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(356),
  [1279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(700),
  [1283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(273),
  [1285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(812),
  [1287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [1289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1374),
  [1291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(491),
  [1293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(958),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [1297] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(732),
  [1300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(700),
  [1303] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(273),
  [1306] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(812),
  [1309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0),
  [1311] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(491),
  [1314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [1316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [1318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1051),
  [1320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [1322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1372),
  [1324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [1326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [1328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(995),
  [1330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [1332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [1334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [1336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [1338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [1340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(766),
  [1342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1078),
  [1344] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(232),
  [1347] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(232),
  [1350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0),
  [1352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(824),
  [1355] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(1095),
  [1358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(676),
  [1361] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1078),
  [1364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [1366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [1368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [1370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [1372] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1064),
  [1375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [1377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 1, 0, 0),
  [1379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1379),
  [1381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [1383] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1096),
  [1386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [1388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [1390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [1392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [1394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [1396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10),
  [1400] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 2, -1, 0),
  [1402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(987),
  [1404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 2, -1, 0),
  [1406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [1408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [1410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [1412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [1414] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 1, 0, 0),
  [1416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 1, 0, 0),
  [1418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [1420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [1422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [1424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [1426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [1428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [1432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [1434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [1440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [1442] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(793),
  [1445] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(700),
  [1448] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(273),
  [1451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0),
  [1453] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(491),
  [1456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(314),
  [1458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [1460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(744),
  [1462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(981),
  [1464] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0), SHIFT_REPEAT(744),
  [1467] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0), SHIFT_REPEAT(232),
  [1470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0),
  [1472] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0), SHIFT_REPEAT(232),
  [1475] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0),
  [1477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0),
  [1479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(753),
  [1481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(743),
  [1483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1011),
  [1485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(213),
  [1487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(937),
  [1489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(774),
  [1491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(971),
  [1493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(758),
  [1495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(936),
  [1497] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0), SHIFT_REPEAT(758),
  [1500] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0), SHIFT_REPEAT(232),
  [1503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0),
  [1505] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0), SHIFT_REPEAT(232),
  [1508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [1510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [1512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 3, -1, 0),
  [1514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 3, -1, 0),
  [1516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 14), SHIFT_REPEAT(791),
  [1519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(763),
  [1522] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 4, -1, 0),
  [1524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 4, -1, 0),
  [1526] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_value, 2, 0, 0),
  [1528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 3, 0, 3),
  [1530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 3, 0, 3),
  [1532] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 2, 0, 3),
  [1534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 2, 0, 3),
  [1536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment, 3, 0, 13),
  [1538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(724),
  [1541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0),
  [1543] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(771),
  [1546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [1548] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 6, 0, 3),
  [1550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 6, 0, 3),
  [1552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(871),
  [1554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1209),
  [1556] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 4, 0, 3),
  [1558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 4, 0, 3),
  [1560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(757),
  [1562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(976),
  [1564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 1, 0, 0),
  [1566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(779),
  [1568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [1570] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 5, 0, 3),
  [1572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 5, 0, 3),
  [1574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [1576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [1578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1252),
  [1580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [1582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [1584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [1586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(878),
  [1588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [1590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [1592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [1596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [1598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [1600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [1602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [1604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [1606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [1608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [1610] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(794),
  [1613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [1615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [1617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [1619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
  [1621] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_properties_repeat1, 2, 0, 0), SHIFT_REPEAT(724),
  [1624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_properties_repeat1, 2, 0, 0),
  [1626] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_properties_repeat1, 2, 0, 0), SHIFT_REPEAT(771),
  [1629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [1631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(802),
  [1634] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(882),
  [1637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0),
  [1639] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(900),
  [1642] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(901),
  [1645] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(902),
  [1648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [1650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [1652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [1654] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 16),
  [1656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 8, 0, 16),
  [1658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [1660] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_operator, 2, 0, 0),
  [1662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [1666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, 0, 0),
  [1668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_persistent_operator, 2, 0, 0),
  [1670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [1672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 16),
  [1674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 5, 0, 16),
  [1676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [1678] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 8),
  [1680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 5, 0, 8),
  [1682] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_persistent_operator, 1, 0, 0),
  [1684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0),
  [1686] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(724),
  [1689] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(724),
  [1692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [1694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 16),
  [1696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 6, 0, 16),
  [1698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [1700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 8),
  [1702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 6, 0, 8),
  [1704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [1706] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 22),
  [1708] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 6, 0, 22),
  [1710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [1712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 16),
  [1714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 7, 0, 16),
  [1716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [1718] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 8),
  [1720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 7, 0, 8),
  [1722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [1724] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 22),
  [1726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 7, 0, 22),
  [1728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2, 0, 0),
  [1730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [1732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [1734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 22),
  [1736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 8, 0, 22),
  [1738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [1740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 9, 0, 22),
  [1742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 9, 0, 22),
  [1744] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions, 3, 0, 0),
  [1746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimensions, 3, 0, 0),
  [1748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [1750] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 4, 0, 8),
  [1752] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 4, 0, 8),
  [1754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [1756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [1758] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions, 4, 0, 0),
  [1760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimensions, 4, 0, 0),
  [1762] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_operator, 1, 0, 0),
  [1764] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 4, 0, 16),
  [1766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 4, 0, 16),
  [1768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0),
  [1770] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 4, 0, 8),
  [1772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 4, 0, 8),
  [1774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(973),
  [1776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [1778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 1, 0, 5),
  [1780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 1, 0, 5),
  [1782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 5, 0, 16),
  [1784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 5, 0, 16),
  [1786] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 2, 0, 3),
  [1788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 2, 0, 3),
  [1790] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 3, 0, 8),
  [1792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 3, 0, 8),
  [1794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [1796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [1798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1312),
  [1800] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 3, 0, 3),
  [1802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 3, 0, 3),
  [1804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [1806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1253),
  [1808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [1810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [1812] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 8),
  [1814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 8, 0, 8),
  [1816] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 9, 0, 16),
  [1818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 9, 0, 16),
  [1820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [1824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [1828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [1830] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 10, 0, 22),
  [1832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 10, 0, 22),
  [1834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [1836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [1838] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(871),
  [1841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [1843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [1845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [1847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [1849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0),
  [1851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_property, 3, 0, 0),
  [1853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [1855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(780),
  [1857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(67),
  [1859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(853),
  [1861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(979),
  [1863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(689),
  [1865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1002),
  [1867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(664),
  [1869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1038),
  [1871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [1873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [1875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [1877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(44),
  [1879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [1881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [1885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(39),
  [1887] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1094),
  [1890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [1892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [1896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(844),
  [1898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(56),
  [1900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_property, 4, 0, 0),
  [1902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(73),
  [1904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(53),
  [1906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(30),
  [1908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(31),
  [1910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(846),
  [1912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [1914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [1916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(749),
  [1918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(57),
  [1920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(782),
  [1922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(924),
  [1924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [1926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(835),
  [1928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(32),
  [1930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [1932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [1934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [1936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(55),
  [1938] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 1, -1, 0),
  [1940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [1942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [1944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(43),
  [1946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1107),
  [1948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [1950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [1952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 8),
  [1954] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 8),
  [1956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [1958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [1962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 22),
  [1964] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 22),
  [1966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(943),
  [1968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 5, 0, 0),
  [1970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 5, 0, 0),
  [1972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [1974] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 1, 0, 0),
  [1976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [1978] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 5, 0, 0),
  [1980] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 5, 0, 0),
  [1982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1333),
  [1984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, 0, 16),
  [1986] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, 0, 16),
  [1988] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 2, 0, 0),
  [1990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [1992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(929),
  [1994] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 22),
  [1996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, 0, 22),
  [1998] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, 0, 22),
  [2000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(947),
  [2002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [2004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 10, 0, 22),
  [2006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 10, 0, 22),
  [2008] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat1, 2, 0, 0),
  [2010] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 2, 0, 0), SHIFT_REPEAT(948),
  [2013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [2017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [2019] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_superclasses, 2, 0, 0),
  [2021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(959),
  [2023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(984),
  [2025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 16),
  [2027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(985),
  [2029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 8),
  [2031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(673),
  [2033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 4, 0, 0),
  [2035] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_superclasses, 3, 0, 0),
  [2037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(677),
  [2039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 16),
  [2041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 16),
  [2043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 4, 0, 0),
  [2045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1005),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [2049] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 8),
  [2051] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 8),
  [2053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(923),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [2057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [2059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [2061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [2063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 4, 0, 0),
  [2065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(956),
  [2067] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 8),
  [2069] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_output, 2, 0, 0),
  [2071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_output, 2, 0, 0),
  [2073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [2077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 4, 0, 0),
  [2079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(962),
  [2081] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 16),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [2085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 8),
  [2087] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 8),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [2093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(969),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [2097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [2099] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0), SHIFT_REPEAT(229),
  [2102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(955),
  [2104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 22),
  [2106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [2108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_superclasses_repeat1, 2, 0, 0),
  [2110] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_superclasses_repeat1, 2, 0, 0), SHIFT_REPEAT(959),
  [2113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 3, 0, 0),
  [2115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [2117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [2119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [2121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 3, 0, 0),
  [2123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [2125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [2127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [2129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 16),
  [2131] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 16),
  [2133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(939),
  [2135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [2137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [2139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 3, 0, 0),
  [2141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 3, 0, 0),
  [2143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1325),
  [2145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [2149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(214),
  [2151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [2153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(837),
  [2155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [2157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [2159] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_validation_functions, 3, 0, 0),
  [2161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(33),
  [2163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(843),
  [2165] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_validation_functions, 4, 0, 0),
  [2167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parfor_options, 1, 0, 0),
  [2169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0),
  [2171] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(1037),
  [2174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(37),
  [2176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [2178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [2180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [2182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(701),
  [2184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [2186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(776),
  [2188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(747),
  [2190] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(1047),
  [2193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [2195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(78),
  [2197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0),
  [2199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(284),
  [2202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [2204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [2206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(803),
  [2208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(46),
  [2210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [2212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(58),
  [2214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(40),
  [2216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [2218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [2220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [2222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(324),
  [2224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [2226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [2228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [2232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [2234] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_matrix_repeat2, 2, 0, 0), SHIFT_REPEAT(184),
  [2237] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_matrix_repeat2, 2, 0, 0), SHIFT_REPEAT(184),
  [2240] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat2, 2, 0, 0),
  [2242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(48),
  [2244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(68),
  [2246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(70),
  [2248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(75),
  [2250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(876),
  [2252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [2254] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(281),
  [2257] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [2259] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 1, 0, 0),
  [2261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(304),
  [2263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(836),
  [2265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(795),
  [2267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 7, 0, 16),
  [2269] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, 0, 0),
  [2271] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 3, 0, 0),
  [2273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1246),
  [2275] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 6, 0, 0),
  [2277] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 3, 0, 7),
  [2279] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 5, 0, 0),
  [2281] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 5, 0, 0),
  [2283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1161),
  [2285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1123),
  [2287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [2289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [2291] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 4, 0, 0),
  [2293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1159),
  [2295] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 2, 0, 0),
  [2297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [2299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [2301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [2303] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 24), SHIFT_REPEAT(182),
  [2306] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 24),
  [2308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(184),
  [2310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [2312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1164),
  [2314] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 9, 0, 0),
  [2316] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 7, 0, 17),
  [2318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1266),
  [2320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [2322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(602),
  [2324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(603),
  [2326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(604),
  [2328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(605),
  [2330] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributes, 3, 0, 0),
  [2332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [2334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(436),
  [2336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 0),
  [2338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [2340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(447),
  [2342] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 3, 0, 7),
  [2344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [2346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1125),
  [2348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributes, 4, 0, 0),
  [2350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_with_end, 3, 0, 0),
  [2352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [2354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1130),
  [2356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1118),
  [2358] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 5, 0, 0),
  [2360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1149),
  [2362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1167),
  [2364] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [2366] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(831),
  [2369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [2371] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 1, 0, 10),
  [2373] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 7),
  [2375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributes, 3, 0, 0),
  [2377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 7),
  [2379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 6, 0, 7),
  [2381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [2383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 7, 0, 0),
  [2385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0),
  [2387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(514),
  [2389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(515),
  [2391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(516),
  [2393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, 0, 0),
  [2395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(970),
  [2397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [2399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 5, 0, 0),
  [2401] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 8, 0, 0),
  [2403] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, 0, 7),
  [2405] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat2, 2, 0, 0), SHIFT_REPEAT(1034),
  [2408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat2, 2, 0, 0),
  [2410] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 3, 0, 0),
  [2412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [2414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [2416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [2418] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 5, 0, 7),
  [2420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(944),
  [2422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [2424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 5, 0, 10),
  [2426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [2428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat2, 2, 0, 0),
  [2430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(450),
  [2432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_arguments, 3, 0, 21),
  [2434] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 4, 0, 7),
  [2436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(117),
  [2438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [2440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(119),
  [2442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(123),
  [2444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [2446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [2448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [2450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [2452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, 0, 8),
  [2454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_spmd_statement, 4, 0, 0),
  [2456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(451),
  [2458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 6, 0, 10),
  [2460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 6, 0, 17),
  [2462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 4, 0, 8),
  [2464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1291),
  [2466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [2468] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 2, 0, 0),
  [2470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1263),
  [2472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [2474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributes, 4, 0, 0),
  [2476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1162),
  [2478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 3, 0, 7),
  [2480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 0),
  [2482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 7),
  [2484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, 0, 8),
  [2486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [2488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 0),
  [2490] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 7),
  [2492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 4, 0, 7),
  [2494] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__argument_attributes, 4, 0, 26),
  [2496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 1, -1, 0),
  [2498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [2500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1006),
  [2502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [2504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, 0, 16),
  [2506] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 4, 0, 0),
  [2508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 0),
  [2510] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__argument_attributes, 3, 0, 23),
  [2512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [2514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 2, 0, 17),
  [2516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, 0, 16),
  [2518] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_arguments, 2, 0, 0),
  [2520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(517),
  [2522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1314),
  [2524] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__lambda_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(916),
  [2527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__lambda_arguments_repeat1, 2, 0, 0),
  [2529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1319),
  [2531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_spread_operator, 1, 0, 0),
  [2533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_clause, 4, 0, 7),
  [2535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 4, 0, 7),
  [2537] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2, 0, 0), SHIFT_REPEAT(307),
  [2540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [2542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [2544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [2546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [2548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 4, 0, 7),
  [2550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [2552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_clause, 3, 0, 7),
  [2554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [2556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [2558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_arguments, 1, 0, 0),
  [2560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [2562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1229),
  [2564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 23),
  [2566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [2568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1250),
  [2570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [2572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [2574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [2576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [2578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [2580] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_arguments, 2, 0, 0),
  [2582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat2, 4, 0, 0),
  [2584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_with_end, 5, 0, 0),
  [2586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [2588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [2590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1143),
  [2592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [2594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1154),
  [2596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [2598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1336),
  [2600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1316),
  [2602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 1, 0, 0),
  [2604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [2606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [2608] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0), SHIFT_REPEAT(935),
  [2611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0),
  [2613] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2, 0, 0), SHIFT_REPEAT(1276),
  [2616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2, 0, 0),
  [2618] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 24), SHIFT_REPEAT(1022),
  [2621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 24),
  [2623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [2625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [2627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [2629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1124),
  [2631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [2633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(805),
  [2635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [2637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1165),
  [2639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [2641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1153),
  [2643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1153),
  [2645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 23),
  [2647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(826),
  [2649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [2651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(821),
  [2653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [2655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_otherwise_clause, 3, 0, 0),
  [2657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [2659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 4, 0, 0),
  [2661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 4, 0, 0),
  [2663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [2665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [2667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [2669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [2671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 3, 0, 0),
  [2673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [2675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [2679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [2681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [2683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [2685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 0),
  [2687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 5, 0, 0),
  [2689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [2691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [2693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1115),
  [2697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [2699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [2701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 3, 0, 0),
  [2703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 3, 0, 0),
  [2705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [2707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 2, 0, 0),
  [2709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [2711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [2713] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [2717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 6, 0, 0),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [2721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [2723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [2725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [2727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1181),
  [2729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [2731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [2733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [2735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1134),
  [2737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [2739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [2741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [2743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_otherwise_clause, 2, 0, 0),
  [2745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [2747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [2749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [2751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [2753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [2755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [2757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [2759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [2761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [2763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [2765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1191),
  [2767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [2769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_comment = 0,
  ts_external_token_line_continuation = 1,
  ts_external_token_command_name = 2,
  ts_external_token_command_argument = 3,
  ts_external_token__single_quote_string_start = 4,
  ts_external_token__single_quote_string_end = 5,
  ts_external_token__double_quote_string_start = 6,
  ts_external_token__double_quote_string_end = 7,
  ts_external_token_formatting_sequence = 8,
  ts_external_token_escape_sequence = 9,
  ts_external_token_string_content = 10,
  ts_external_token__entry_delimiter = 11,
  ts_external_token__multioutput_variable_start = 12,
  ts_external_token__external_identifier = 13,
  ts_external_token_error_sentinel = 14,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_comment] = sym_comment,
  [ts_external_token_line_continuation] = sym_line_continuation,
  [ts_external_token_command_name] = sym_command_name,
  [ts_external_token_command_argument] = sym_command_argument,
  [ts_external_token__single_quote_string_start] = sym__single_quote_string_start,
  [ts_external_token__single_quote_string_end] = sym__single_quote_string_end,
  [ts_external_token__double_quote_string_start] = sym__double_quote_string_start,
  [ts_external_token__double_quote_string_end] = sym__double_quote_string_end,
  [ts_external_token_formatting_sequence] = sym_formatting_sequence,
  [ts_external_token_escape_sequence] = sym_escape_sequence,
  [ts_external_token_string_content] = sym_string_content,
  [ts_external_token__entry_delimiter] = sym__entry_delimiter,
  [ts_external_token__multioutput_variable_start] = sym__multioutput_variable_start,
  [ts_external_token__external_identifier] = sym__external_identifier,
  [ts_external_token_error_sentinel] = sym_error_sentinel,
};

static const bool ts_external_scanner_states[12][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_name] = true,
    [ts_external_token_command_argument] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__single_quote_string_end] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__double_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
    [ts_external_token__entry_delimiter] = true,
    [ts_external_token__multioutput_variable_start] = true,
    [ts_external_token__external_identifier] = true,
    [ts_external_token_error_sentinel] = true,
  },
  [2] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_name] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__multioutput_variable_start] = true,
    [ts_external_token__external_identifier] = true,
  },
  [3] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__external_identifier] = true,
  },
  [4] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__entry_delimiter] = true,
    [ts_external_token__external_identifier] = true,
  },
  [5] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
  },
  [6] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__entry_delimiter] = true,
  },
  [7] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__external_identifier] = true,
  },
  [8] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__multioutput_variable_start] = true,
    [ts_external_token__external_identifier] = true,
  },
  [9] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_argument] = true,
  },
  [10] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
  },
  [11] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__double_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_matlab_external_scanner_create(void);
void tree_sitter_matlab_external_scanner_destroy(void *);
bool tree_sitter_matlab_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_matlab_external_scanner_serialize(void *, char *);
void tree_sitter_matlab_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_matlab(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_matlab_external_scanner_create,
      tree_sitter_matlab_external_scanner_destroy,
      tree_sitter_matlab_external_scanner_scan,
      tree_sitter_matlab_external_scanner_serialize,
      tree_sitter_matlab_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "matlab",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 1,
      .minor_version = 0,
      .patch_version = 10,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
